#ifndef APPKIT_NSACCESSIBILITY_H
#define APPKIT_NSACCESSIBILITY_H

#import <AppKit/AppKitDefines.h>
#import <AppKit/NSErrors.h>
#import <Foundation/NSGeometry.h>
#import <Foundation/NSObject.h>

@class NSString, NSArray;

@interface NSObject (NSAccessibility)

/*accessibilityHitTest:

Returns the deepest descendant of the accessibility hierarchy that contains the point point, which is in lower-left relative screen coordinates.

- (id)accessibilityHitTest:(NSPoint)point
Discussion

You can assume the point has already been determined to lie within the receiver. Override this method to do deeper hit-testing by identifying which child element, if any, contains the point. NSMatrix, for example, identifies which of its cells contains point and propagates the hit-test to it. If point is not contained within one of the receivers children, either return self or, if available, invoke the superclasss implementation. The default NSView and NSCell implementations test whether the receiver is an ignored element and, if so, return the receivers first unignored parent; otherwise they return self.
Availability

    * Available in Mac OS X v10.2 and later.

Declared In
NSAccessibility.h*/
- (id)accessibilityHitTest:(NSPoint)point;

/*accessibilityAttributeValue:

Returns the value of the receivers attribute attribute.

- (id)accessibilityAttributeValue:(NSString *)attribute
Discussion

User interface classes must implement this method. Subclasses should invoke the superclasss implementation, if it exists, if attribute is not implemented in the subclass.
Availability

    * Available in Mac OS X v10.2 and later.

Declared In
NSAccessibility.h
accessibilityAttribute*/
- (id)accessibilityAttributeValue:(NSString *)attribute;

/* accessibilityAttributeNames

Returns an array of attribute names supported by the receiver.

- (NSArray *)accessibilityAttributeNames
Discussion

User interface classes must implement this method. Subclasses should invoke the superclasss implementation, if it exists, and append additional attributes or remove unsupported attributes. Some attribute names are defined by Cocoa and are described in the Constants section.
Availability

    * Available in Mac OS X v10.2 and later.

Declared In
NSAccessibility.h */
- (NSArray *)accessibilityAttributeNames;

@end


@interface NSObject (NSAccessibilityAdditions)

@end

/*Standard attributes for any object

The following are the standard attributes that can be adopted by any object.

NSString *const NSAccessibilityChildrenAttribute;
NSString *const NSAccessibilityContentsAttribute;
NSString *const NSAccessibilityDescriptionAttribute;
NSString *const NSAccessibilityEnabledAttribute;
NSString *const NSAccessibilityFocusedAttribute;
NSString *const NSAccessibilityHelpAttribute;
NSString *const NSAccessibilityMaxValueAttribute;
NSString *const NSAccessibilityMinValueAttribute;
NSString *const NSAccessibilityParentAttribute;
NSString *const NSAccessibilityPositionAttribute;
NSString *const NSAccessibilityRoleAttribute;
NSString *const NSAccessibilityRoleDescriptionAttribute;
NSString *const NSAccessibilitySelectedChildrenAttribute;
NSString *const NSAccessibilityShownMenuAttribute;
NSString *const NSAccessibilitySizeAttribute;
NSString *const NSAccessibilitySubroleAttribute;
NSString *const NSAccessibilityTitleAttribute;
NSString *const NSAccessibilityTopLevelUIElementAttribute;
NSString *const NSAccessibilityValueAttribute;
NSString *const NSAccessibilityValueDescriptionAttribute;
NSString *const NSAccessibilityVisibleChildrenAttribute;
NSString *const NSAccessibilityWindowAttribute;

Constants

NSAccessibilityChildrenAttribute

    Elements that current element contains (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityContentsAttribute

    Elements that represent the contents in the current element, such as the document view of a scroll view (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityDescriptionAttribute

    Instance description (NSString)

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityEnabledAttribute

    Flag indicating enabled state of element (NSNumber)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityFocusedAttribute

    Flag indicating presence of keyboard focus (NSNumber)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityHelpAttribute

    Instance description, such as a help tag string (NSString)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMaxValueAttribute

    Elements maximum value (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMinValueAttribute

    Elements minimum value (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityParentAttribute

    Element containing current element (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityPositionAttribute

    Screen position of elements lower-left corner in lower-left relative screen coordinates (NSValue)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityRoleAttribute

    Element type, such as NSAccessibilityRadioButtonRole (NSString). See the role attribute table below

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityRoleDescriptionAttribute

    Localized, user-readable description of role, such as radio button (NSString)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySelectedChildrenAttribute

    Currently selected children (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityShownMenuAttribute

    Menu currently being displayed (id)

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilitySizeAttribute

    Element size (NSValue)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySubroleAttribute

    Element subrole type, such as NSAccessibilityTableRowSubrole (NSString). See the subrole attribute table below.

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityTitleAttribute

    Title of element, such as button text (NSString)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityTopLevelUIElementAttribute

    User interface element for the top-level element (id)

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityValueAttribute

    Elements value (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityValueDescriptionAttribute

    Text description of value (NSString)

    Available in Mac OS X v10.5 and later.

    Declared in NSAccessibility.h
NSAccessibilityVisibleChildrenAttribute

    Child elements that are visible (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityWindowAttribute

    Window containing current element (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h

Declared In
NSAccessibility.h*/
extern  NSString *const NSAccessibilityChildrenAttribute;
extern  NSString *const NSAccessibilityContentsAttribute;
extern  NSString *const NSAccessibilityDescriptionAttribute;
extern  NSString *const NSAccessibilityEnabledAttribute;
extern  NSString *const NSAccessibilityFocusedAttribute;
extern  NSString *const NSAccessibilityHelpAttribute;
extern  NSString *const NSAccessibilityMaxValueAttribute;
extern  NSString *const NSAccessibilityMinValueAttribute;
extern  NSString *const NSAccessibilityParentAttribute;
extern  NSString *const NSAccessibilityPositionAttribute;
extern  NSString *const NSAccessibilityRoleAttribute;
extern  NSString *const NSAccessibilityRoleDescriptionAttribute;
extern  NSString *const NSAccessibilitySelectedChildrenAttribute;
extern  NSString *const NSAccessibilityShownMenuAttribute;
extern  NSString *const NSAccessibilitySizeAttribute;
extern  NSString *const NSAccessibilitySubroleAttribute;
extern  NSString *const NSAccessibilityTitleAttribute;
extern  NSString *const NSAccessibilityTopLevelUIElementAttribute;
extern  NSString *const NSAccessibilityValueAttribute;
extern  NSString *const NSAccessibilityValueDescriptionAttribute;
extern  NSString *const NSAccessibilityVisibleChildrenAttribute;
extern  NSString *const NSAccessibilityWindowAttribute;

/* Table view and outline view attributes

The following are attributes specific to tables and outlines.

NSString *const NSAccessibilityColumnsAttribute;
NSString *const NSAccessibilityRowsAttribute;
NSString *const NSAccessibilitySelectedColumnsAttribute;
NSString *const NSAccessibilitySelectedRowsAttribute;
NSString *const NSAccessibilitySortDirectionAttribute;
NSString *const NSAccessibilityVisibleColumnsAttribute;
NSString *const NSAccessibilityVisibleRowsAttribute;

Constants

NSAccessibilityColumnsAttribute

    Tables columns (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityRowsAttribute

    Tables rows (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySelectedColumnsAttribute

    Tables selected columns (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySelectedRowsAttribute

    Tables selected rows (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySortDirectionAttribute

    Columns sort direction (NSString). See Column sort direction.

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityVisibleColumnsAttribute

    Tables visible columns (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityVisibleRowsAttribute

    Tables visible rows (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h

Declared In
NSAccessibility.h */
extern NSString *const NSAccessibilityColumnsAttribute;
extern NSString *const NSAccessibilityRowsAttribute;
extern NSString *const NSAccessibilitySelectedColumnsAttribute;
extern NSString *const NSAccessibilitySelectedRowsAttribute;
extern NSString *const NSAccessibilitySortDirectionAttribute;
extern NSString *const NSAccessibilityVisibleColumnsAttribute;
extern NSString *const NSAccessibilityVisibleRowsAttribute;

/*NSAccessibilityRoleDescription

Returns a standard description for a role and subrole.

NSString * NSAccessibilityRoleDescription (
   NSString *role,
   NSString *subrole
);

Discussion

You should pass nil to this function if there is no subrole. This function returns a description of a standard role. For example, if you implement a button widget that does not inherit from NSButton, you should use NSAccessibilityRoleDescription to return a localized role description matching that returned by a standard button.
Availability

    * Available in Mac OS X v10.4 and later.

Declared In
NSAccessibility.h*/
NSString * NSAccessibilityRoleDescription (
   NSString *role,
   NSString *subrole
);

/*NSAccessibilityUnignoredAncestor

Returns an unignored accessibility object, ascending the hierarchy if necessary.

id NSAccessibilityUnignoredAncestor (
   id element
);

Discussion

Tests whether element is an ignored object, returning either element, if it is not ignored, or the first unignored ancestor of element.
Availability

    * Available in Mac OS X v10.2 and later.

Declared In
NSAccessibility.h*/
id NSAccessibilityUnignoredAncestor (
   id element
);

/*Application-specific attributes

The following are attributes specific to the application object.

NSString *const NSAccessibilityClearButtonAttribute;
NSString *const NSAccessibilityColumnTitlesAttribute;
NSString *const NSAccessibilityFocusedUIElementAttribute;
NSString *const NSAccessibilityFocusedWindowAttribute;
NSString *const NSAccessibilityFrontmostAttribute;
NSString *const NSAccessibilityHiddenAttribute;
NSString *const NSAccessibilityMainWindowAttribute;
NSString *const NSAccessibilityMenuBarAttribute;
NSString *const NSAccessibilityOrientationAttribute;
NSString *const NSAccessibilitySearchButtonAttribute;
NSString *const NSAccessibilitySearchMenuAttribute;
NSString *const NSAccessibilityWindowsAttribute;

Constants

NSAccessibilityFocusedUIElementAttribute

    Element with the current focus (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityFocusedWindowAttribute

    Applications window with current focus (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityFrontmostAttribute

    Flag indicating whether application is in front (NSNumber)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityHiddenAttribute

    Flag indicating whether application is hidden (NSNumber)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMainWindowAttribute

    Applications main window (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMenuBarAttribute

    Applications menu bar (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityWindowsAttribute

    Applications windows (NSArray)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h

Declared In
NSAccessibility.h*/
extern NSString *const NSAccessibilityClearButtonAttribute;
extern NSString *const NSAccessibilityColumnTitlesAttribute;
extern NSString *const NSAccessibilityFocusedUIElementAttribute;
extern NSString *const NSAccessibilityFocusedWindowAttribute;
extern NSString *const NSAccessibilityFrontmostAttribute;
extern NSString *const NSAccessibilityHiddenAttribute;
extern NSString *const NSAccessibilityMainWindowAttribute;
extern NSString *const NSAccessibilityMenuBarAttribute;
extern NSString *const NSAccessibilityOrientationAttribute;
extern NSString *const NSAccessibilitySearchButtonAttribute;
extern NSString *const NSAccessibilitySearchMenuAttribute;
extern NSString *const NSAccessibilityWindowsAttribute;

/*NSAccessibilityActionDescription

Returns a standard description for an action.

NSString * NSAccessibilityActionDescription (
   NSString *action
);

Discussion

This function returns a standard description for action.
Availability

    * Available in Mac OS X v10.4 and later.

Declared In
NSAccessibility.h*/
NSString * NSAccessibilityActionDescription (
   NSString *action
);

/*NSAccessibilityRoleDescriptionForUIElement

Returns a standard role description for a user interface element.

NSString * NSAccessibilityRoleDescriptionForUIElement (
   id element
);

Discussion

This function is like NSAccessibilityRoleDescription, but it queries element to get the role and subrole. NSAccessibilityRoleDescription is more efficient, but this function is useful for accessorizing base classes so that they properly handle derived classes, which may override the subrole or even the role.
Availability

    * Available in Mac OS X v10.4 and later.

Declared In
NSAccessibility.h*/
NSString * NSAccessibilityRoleDescriptionForUIElement (
   id element
);

/*NSAccessibilityUnignoredChildren

Returns a list of unignored accessibility objects, descending the hierarchy if necessary.

NSArray * NSAccessibilityUnignoredChildren (
   NSArray *originalChildren
);

Discussion

Returns a copy of originalChildren with any ignored objects in the array replaced by their unignored descendants.
Availability

    * Available in Mac OS X v10.2 and later.

Declared In
NSAccessibility.h*/
NSArray * NSAccessibilityUnignoredChildren (
   NSArray *originalChildren
);

/* Roles

These constants define standard roles that identify the type of object an accessibility object represents. One of these values is returned as the value for an objects NSAccessibilityRoleAttribute.

NSString *const NSAccessibilityApplicationRole;
NSString *const NSAccessibilityBrowserRole;
NSString *const NSAccessibilityBusyIndicatorRole;
NSString *const NSAccessibilityButtonRole;
NSString *const NSAccessibilityCheckBoxRole;
NSString *const NSAccessibilityColorWellRole;
NSString *const NSAccessibilityColumnRole;
NSString *const NSAccessibilityComboBoxRole;
NSString *const NSAccessibilityDisclosureTriangleRole;
NSString *const NSAccessibilityDrawerRole;
NSString *const NSAccessibilityGridRole;
NSString *const NSAccessibilityGroupRole;
NSString *const NSAccessibilityGrowAreaRole;
NSString *const NSAccessibilityHelpTagRole;
NSString *const NSAccessibilityImageRole;
NSString *const NSAccessibilityIncrementorRole;
NSString *const NSAccessibilityLinkRole;
NSString *const NSAccessibilityListRole;
NSString *const NSAccessibilityMatteRole;
NSString *const NSAccessibilityMenuBarRole;
NSString *const NSAccessibilityMenuButtonRole;
NSString *const NSAccessibilityMenuItemRole;
NSString *const NSAccessibilityMenuRole;
NSString *const NSAccessibilityOutlineRole;
NSString *const NSAccessibilityPopUpButtonRole;
NSString *const NSAccessibilityProgressIndicatorRole;
NSString *const NSAccessibilityRadioButtonRole;
NSString *const NSAccessibilityRadioGroupRole;
NSString *const NSAccessibilityRowRole;
NSString *const NSAccessibilityRulerMarkerRole;
NSString *const NSAccessibilityRulerRole;
NSString *const NSAccessibilityScrollAreaRole;
NSString *const NSAccessibilityScrollBarRole;
NSString *const NSAccessibilitySheetRole;
NSString *const NSAccessibilitySliderRole;
NSString *const NSAccessibilitySortButtonRole;
NSString *const NSAccessibilitySplitGroupRole;
NSString *const NSAccessibilitySplitterRole;
NSString *const NSAccessibilityStaticTextRole;
NSString *const NSAccessibilitySystemWideRole;
NSString *const NSAccessibilityTabGroupRole;
NSString *const NSAccessibilityTableRole;
NSString *const NSAccessibilityTextAreaRole;
NSString *const NSAccessibilityTextFieldRole;
NSString *const NSAccessibilityToolbarRole;
NSString *const NSAccessibilityUnknownRole;
NSString *const NSAccessibilityValueIndicatorRole;
NSString *const NSAccessibilityWindowRole;

Constants

NSAccessibilityApplicationRole

    Application

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityBrowserRole

    Browser

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityBusyIndicatorRole

    Busy indicator

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityCheckBoxRole

    Checkbox

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityColorWellRole

    Color well

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityColumnRole

    Column

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityComboBoxRole

    Combo box

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityDisclosureTriangleRole

    Disclosure triangle

    Available in Mac OS X v10.5 and later.

    Declared in NSAccessibility.h
NSAccessibilityDrawerRole

    Drawer

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityGridRole

    Grid

    Available in Mac OS X v10.5 and later.

    Declared in NSAccessibility.h
NSAccessibilityGroupRole

    Group

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityGrowAreaRole

    Windows grow (resize) area

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityHelpTagRole

    Help tag

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityImageRole

    Image

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityIncrementorRole

    Stepper

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityLinkRole

    Link

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityListRole

    List

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMatteRole

    Matte

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityMenuBarRole

    Menu bar

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMenuButtonRole

    Menu button

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMenuItemRole

    Menu item

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityMenuRole

    Menu

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityOutlineRole

    Outline

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityPopUpButtonRole

    Pop-up button

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityProgressIndicatorRole

    Progress indicator

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityButtonRole

    Button

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityRadioButtonRole

    Radio button

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityRadioGroupRole

    Radio group

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityRowRole

    Row

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityRulerRole

    Ruler

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityRulerMarkerRole

    Ruler marker

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityScrollAreaRole

    Scroll view

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityScrollBarRole

    Scroll bar

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySheetRole

    Sheet

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySliderRole

    Slider

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySortButtonRole

    Sort button

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilitySplitGroupRole

    Split view

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySplitterRole

    Splitter bar of a split view

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityStaticTextRole

    Uneditable text

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilitySystemWideRole

    Special system-wide element

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityTabGroupRole

    Tab group

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityTableRole

    Table

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityTextAreaRole

    Text view

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityTextFieldRole

    Text field

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityToolbarRole

    Toolbar

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityUnknownRole

    Unknown object type

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityValueIndicatorRole

    Value indicator

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityWindowRole

    Window

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h

Declared In
NSAccessibility.h */
extern NSString *const NSAccessibilityApplicationRole;
extern NSString *const NSAccessibilityBrowserRole;
extern NSString *const NSAccessibilityBusyIndicatorRole;
extern NSString *const NSAccessibilityButtonRole;
extern NSString *const NSAccessibilityCheckBoxRole;
extern NSString *const NSAccessibilityColorWellRole;
extern NSString *const NSAccessibilityColumnRole;
extern NSString *const NSAccessibilityComboBoxRole;
extern NSString *const NSAccessibilityDisclosureTriangleRole;
extern NSString *const NSAccessibilityDrawerRole;
extern NSString *const NSAccessibilityGridRole;
extern NSString *const NSAccessibilityGroupRole;
extern NSString *const NSAccessibilityGrowAreaRole;
extern NSString *const NSAccessibilityHelpTagRole;
extern NSString *const NSAccessibilityImageRole;
extern NSString *const NSAccessibilityIncrementorRole;
extern NSString *const NSAccessibilityLinkRole;
extern NSString *const NSAccessibilityListRole;
extern NSString *const NSAccessibilityMatteRole;
extern NSString *const NSAccessibilityMenuBarRole;
extern NSString *const NSAccessibilityMenuButtonRole;
extern NSString *const NSAccessibilityMenuItemRole;
extern NSString *const NSAccessibilityMenuRole;
extern NSString *const NSAccessibilityOutlineRole;
extern NSString *const NSAccessibilityPopUpButtonRole;
extern NSString *const NSAccessibilityProgressIndicatorRole;
extern NSString *const NSAccessibilityRadioButtonRole;
extern NSString *const NSAccessibilityRadioGroupRole;
extern NSString *const NSAccessibilityRowRole;
extern NSString *const NSAccessibilityRulerMarkerRole;
extern NSString *const NSAccessibilityRulerRole;
extern NSString *const NSAccessibilityScrollAreaRole;
extern NSString *const NSAccessibilityScrollBarRole;
extern NSString *const NSAccessibilitySheetRole;
extern NSString *const NSAccessibilitySliderRole;
extern NSString *const NSAccessibilitySortButtonRole;
extern NSString *const NSAccessibilitySplitGroupRole;
extern NSString *const NSAccessibilitySplitterRole;
extern NSString *const NSAccessibilityStaticTextRole;
extern NSString *const NSAccessibilitySystemWideRole;
extern NSString *const NSAccessibilityTabGroupRole;
extern NSString *const NSAccessibilityTableRole;
extern NSString *const NSAccessibilityTextAreaRole;
extern NSString *const NSAccessibilityTextFieldRole;
extern NSString *const NSAccessibilityToolbarRole;
extern NSString *const NSAccessibilityUnknownRole;
extern NSString *const NSAccessibilityValueIndicatorRole;
extern NSString *const NSAccessibilityWindowRole;

/* Action values

These constants define standard actions that accessibility objects can perform.

NSString *const NSAccessibilityCancelAction;
NSString *const NSAccessibilityConfirmAction;
NSString *const NSAccessibilityDecrementAction;
NSString *const NSAccessibilityDeleteAction;
NSString *const NSAccessibilityIncrementAction;
NSString *const NSAccessibilityPickAction;
NSString *const NSAccessibilityPressAction;
NSString *const NSAccessibilityRaiseAction;
NSString *const NSAccessibilityShowMenuAction;

Constants

NSAccessibilityConfirmAction

    Simulates pressing Return in object, such as a text field.

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityDecrementAction

    Decrements the value of object.

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityDeleteAction

    Deletes the value of object.

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityIncrementAction

    Increments the value of object.

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityPickAction

    Selects the object, such as a menu item.

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityPressAction

    Simulates clicking an object, such as a button.

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityCancelAction

    Cancels the operation.

    Available in Mac OS X v10.3 and later.

    Declared in NSAccessibility.h
NSAccessibilityRaiseAction

    Simulates bringing a window forward by clicking on its title bar.

    Available in Mac OS X v10.3 and later.

    Declared in NSAccessibility.h
NSAccessibilityShowMenuAction

    Simulates showing a menu by clicking on it.

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h

Declared In
NSAccessibility.h */
extern NSString *const NSAccessibilityCancelAction;
extern NSString *const NSAccessibilityConfirmAction;
extern NSString *const NSAccessibilityDecrementAction;
extern NSString *const NSAccessibilityDeleteAction;
extern NSString *const NSAccessibilityIncrementAction;
extern NSString *const NSAccessibilityPickAction;
extern NSString *const NSAccessibilityPressAction;
extern NSString *const NSAccessibilityRaiseAction;
extern NSString *const NSAccessibilityShowMenuAction;

/*NSAccessibilityUnignoredDescendant

Returns an unignored accessibility object, descending the hierarchy if necessary.

id NSAccessibilityUnignoredDescendant (
   id element
);

Discussion

Tests whether element is an ignored object, returning either element, if it is not ignored, or the first unignored descendant of element. Use this function only if you know there is a linear, one-to-one, hierarchy below element. Otherwise, if element has either no unignored children or multiple unignored children, this function fails and returns nil.
Availability

    * Available in Mac OS X v10.2 and later.

Declared In
NSAccessibility.h*/
id NSAccessibilityUnignoredDescendant (
   id element
);

/* Linkage elements

These constants define link attributes.

NSString *const NSAccessibilityLinkedUIElementsAttribute;
NSString *const NSAccessibilityServesAsTitleForUIElementsAttribute;
NSString *const NSAccessibilityTitleUIElementAttribute;

Constants

NSAccessibilityLinkedUIElementsAttribute

    Elements corresponding to each other (NSArray)

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h
NSAccessibilityTitleUIElementAttribute

    Elements title element (id)

    Available in Mac OS X v10.2 and later.

    Declared in NSAccessibility.h
NSAccessibilityServesAsTitleForUIElementsAttribute

    Elements to which title applies (NSArray)

    Available in Mac OS X v10.4 and later.

    Declared in NSAccessibility.h

Declared In
NSAccessibility.h */

extern NSString *const NSAccessibilityLinkedUIElementsAttribute;
extern NSString *const NSAccessibilityServesAsTitleForUIElementsAttribute;
extern NSString *const NSAccessibilityTitleUIElementAttribute;

#endif //APPKIT_NSACCESSIBILITY_H
