#ifndef OC_APPKIT_NSLAYOUTMANAGER_H
#define OC_APPKIT_NSLAYOUTMANAGER_H

#import "/usr/GNUstep/System/Library/Headers/AppKit/NSLayoutManager.h"

@interface NSLayoutManager (OC)

/*removeTemporaryAttribute:forCharacterRange:

Removes a temporary attribute from the list of attributes for the specified character range.

- (void)removeTemporaryAttribute:(NSString *)attrName forCharacterRange:(NSRange)charRange
Parameters

attrName

    The name of a temporary attribute.
charRange

    The range of characters from which to remove the specified temporary attribute.

Discussion

Temporary attributes are used only for onscreen drawing and are not persistent in any way. NSTextView uses them to color misspelled words when continuous spell checking is enabled. Currently the only temporary attributes recognized are those that do not affect layout (colors, underlines, and so on).
Availability

    * Available in Mac OS X v10.0 and later.

See Also

    * ? setTemporaryAttributes:forCharacterRange:
    * ? addTemporaryAttributes:forCharacterRange:
    * ? temporaryAttributesAtCharacterIndex:effectiveRange:

Declared In
NSLayoutManager.h*/
- (void)removeTemporaryAttribute:(NSString *)attrName forCharacterRange:(NSRange)charRange;

/*addTemporaryAttributes:forCharacterRange:

Appends one or more temporary attributes to the attributes dictionary of the specified character range.

- (void)addTemporaryAttributes:(NSDictionary *)attrs forCharacterRange:(NSRange)charRange
Parameters

attrs

    Attributes dictionary containing the temporary attributes to add.
charRange

    The range of characters to which the specified attributes apply.

Discussion

Temporary attributes are used only for onscreen drawing and are not persistent in any way. NSTextView uses them to color misspelled words when continuous spell checking is enabled. Currently the only temporary attributes recognized are those that do not affect layout (colors, underlines, and so on).
Availability

    * Available in Mac OS X v10.0 and later.

See Also

    * ? setTemporaryAttributes:forCharacterRange:
    * ? removeTemporaryAttribute:forCharacterRange:
    * ? temporaryAttributesAtCharacterIndex:effectiveRange:

Declared In
NSLayoutManager.h*/
- (void)addTemporaryAttributes:(NSDictionary *)attrs forCharacterRange:(NSRange)charRange;

@end//NSLayoutManager (OC)

#endif//OC_APPKIT_NSLAYOUTMANAGER_H
