#ifndef APPKIT_NSSHADOW_H
#define APPKIT_NSSHADOW_H

#import <Foundation/NSObject.h>
#import <Foundation/NSGeometry.h>


@class NSColor;

@interface NSShadow : NSObject <NSCopying, NSCoding>

/*SetShadowOffset:

Sets the offset values for the receiver.

- (void)setShadowOffset:(NSSize)offset
Parameters
offset

The horizontal and vertical offset values, specified using the width and height fields of the NSSize data type. These offsets are measured using the default user coordinate space and are not affected by custom transformations. This means that positive values always extend up and to the right from the user's perspective. 
Availability
Available in Mac OS X v10.3 and later.
See Also
– shadowOffset
Declared In
NSShadow.h*/
- (void)setShadowOffset:(NSSize)offset;

/*setShadowBlurRadius:

Sets the blur radius of the receiver. 

- (void)setShadowBlurRadius:(CGFloat)val
Parameters
val

The blur radius, as measured in the default user coordinate space. A value of 0 indicates no blur, while larger values produce correspondingly larger blurring. This value must not be negative.
Availability
Available in Mac OS X v10.3 and later.
See Also
– shadowBlurRadius
Declared In
NSShadow.h*/
- (void)setShadowBlurRadius:(CGFloat)val;

/*setShadowColor:

Sets the shadow color for the receiver. 

- (void)setShadowColor:(NSColor *)color
Parameters
color

The shadow color, which must be convertible to an RGBA color. Specify nil if you do not want the shadow to be drawn. Your color may contain alpha information. 
Availability
Available in Mac OS X v10.3 and later.
See Also
– shadowColor
Declared In
NSShadow.h*/
- (void)setShadowColor:(NSColor *)color;

@end

#endif
