#ifndef APPKIT_NSWINDOW_H
#define APPKIT_NSWINDOW_H

#import "/usr/GNUstep/System/Library/Headers/AppKit/NSWindow.h"

@interface NSWindow (OC)

/*isZoomed

Returns a Boolean value that indicates whether the receiver is in a zoomed state.

- (BOOL)isZoomed
Return Value

YES if the window is in a zoomed state, otherwise NO.
Discussion

The zoomed state of the window is determined using the following steps:
If the delegate or the window class implements windowWillUseStandardFrame:defaultFrame:, it is invoked to obtain the zoomed frame of the window. The result of isZoomed is then determined by whether or not the current window frame is equal to the zoomed frame.
If the neither the delegate nor the window class implements windowWillUseStandardFrame:defaultFrame:, a default frame that nearly fits the screen is chosen. If the delegate or window class implements windowWillResize:toSize:, it is invoked to validate the proposed zoomed frame. Once the zoomed frame is validated, the result of isZoomed is determined by whether or not the current window frame is equal to the zoomed frame.
Availability
Available in Mac OS X v10.0 and later.
See Also
– zoom:
Declared In
NSWindow.h*/
- (BOOL)isZoomed;

/*disableScreenUpdatesUntilFlush
Disables the receiver’s screen updates until the window is flushed.

- (void)disableScreenUpdatesUntilFlush

Discussion
This method can be invoked to synchronize hardware surface flushes with the window’s flushes. The receiver immediately disables screen updates using the NSDisableScreenUpdates function and reenables screen updates when the window flushes. Sending this message multiple times during a window update cycle has no effect.

Availability
Available in Mac OS X v10.4 and later.
Declared In
NSWindow.h
discardCachedImagedisableScreenUpdatesUntilFlush
Disables the receiver’s screen updates until the window is flushed.

- (void)disableScreenUpdatesUntilFlush

Discussion
This method can be invoked to synchronize hardware surface flushes with the window’s flushes. The receiver immediately disables screen updates using the NSDisableScreenUpdates function and reenables screen updates when the window flushes. Sending this message multiple times during a window update cycle has no effect.

Availability
Available in Mac OS X v10.4 and later.
Declared In
NSWindow.h*/
- (void)disableScreenUpdatesUntilFlush;

/*isSheet

Indicates whether the receiver has ever run as a modal sheet.

- (BOOL)isSheet
Return Value

YES if the receiver has ever run as a modal sheet, otherwise NO.
Discussion

Sheets are created using the NSPanel subclass.
Availability
Available in Mac OS X v10.1 and later.
Declared In
NSWindow.h*/
- (BOOL)isSheet;

@end


#endif
