
#if !defined(__AudioDriverPlugIn_h__)
#define __AudioDriverPlugIn_h__

#include <CoreAudio/AudioHardware.h>
#include <IOKit/IOKitLib.h>

#if defined(__cplusplus)
extern "C"
{
#endif

/*AudioDriverPlugInDevicePropertyChangedProc


A plug-in calls this routine to notify the HAL that one of it's device's properties has changed. 
typedef OSStatus (*AudioDriverPlugInDevicePropertyChangedProc)(
    AudioDeviceID inDevice, 
    UInt32 inChannel, 
    Boolean isInput, 
    AudioDevicePropertyID inPropertyID);  
Parameters
inDevice
The device whose property has changed.
inChannel
The channel of the device the property that has changed belongs to.
isInput
The section of the device the property that has changed belongs to.
inPropertyID
The selector of the property that has changed.
Return Value

The return value is currently unused and should always be 0. 
Discussion 

The HAL will notify any listeners on behalf of the plug-in. The pointer to this routine is supplied to the plug-in when it is opened.*/
typedef OSStatus (*AudioDriverPlugInDevicePropertyChangedProc)(
    AudioDeviceID inDevice, 
    UInt32 inChannel, 
    Boolean isInput, 
    AudioDevicePropertyID inPropertyID);  

/*AudioDriverPlugInStreamPropertyChangedProc


A plug-in calls this routine to notify the HAL that a property of one of the streams of one of it's devices has changed. 
typedef OSStatus (*AudioDriverPlugInStreamPropertyChangedProc)(
    AudioDeviceID inDevice, 
    io_object_t inIOAudioStream, 
    UInt32 inChannel, 
    AudioDevicePropertyID inPropertyID);  
Parameters
inDevice
The device whose property has changed.
inIOAudioStream
The stream whose property has changed.
inChannel
The channel of the stream the property that has changed belongs to.
inPropertyID
The selector of the property that has changed.
Return Value

The return value is currently unused and should always be 0. 
Discussion 

The HAL will notify any listeners on behalf of the plug-in. The pointer to this routine is supplied to the plug-in when it is opened*/
typedef OSStatus (*AudioDriverPlugInStreamPropertyChangedProc)(
    AudioDeviceID inDevice, 
    io_object_t inIOAudioStream, 
    UInt32 inChannel, 
    AudioDevicePropertyID inPropertyID);

/*AudioDriverPlugInHostInfo


This structure provides the plug-in with all the info it needs with respect to communicating with the HAL. 
struct AudioDriverPlugInHostInfo { 
    AudioDeviceID mDeviceID; 
    io_object_t mIOAudioDevice; 
    io_object_t mIOAudioEngine; 
    AudioDriverPlugInDevicePropertyChangedProc mDevicePropertyChangedProc; 
    AudioDriverPlugInStreamPropertyChangedProc mStreamPropertyChangedProc; 
};  
Fields
mDeviceID
The AudioDeviceID of the audio device.
mIOAudioDevice
The io_object_t that points to the IOAudioDevice object for the device in the driver.
mIOAudioEngine
The io_object_t that points to the IOAudioEngine object for the device in the driver.
mDevicePropertyChangedProc
The AudioDriverPlugInDevicePropertyChangedProc the plug-in should call when a device property changes.
mStreamPropertyChangedProc
The AudioDriverPlugInStreamPropertyChangedProc the plug-in should call when a stream property changes.*/
struct AudioDriverPlugInHostInfo { 
    AudioDeviceID mDeviceID; 
    io_object_t mIOAudioDevice; 
    io_object_t mIOAudioEngine; 
    AudioDriverPlugInDevicePropertyChangedProc mDevicePropertyChangedProc; 
    AudioDriverPlugInStreamPropertyChangedProc mStreamPropertyChangedProc; 
};  
typedef struct AudioDriverPlugInHostInfo AudioDriverPlugInHostInfo;

#if defined(__cplusplus)
}
#endif


#endif  //  __AudioDriverPlugIn_h__
