#ifndef OC_CFBAG_H
#define OC_CFBAG_H

#include <CoreFoundation/CFBase.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFBag.h"
#endif //OC_CF

#if defined(__cplusplus)
extern "C" {
#endif

/*CFMutableBagRef

A reference to a mutable bag object.

typedef struct __CFBag *CFMutableBagRef;
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef struct __CFBag *CFMutableBagRef;
#endif

/*CFBagRef

A reference to an immutable bag object.

typedef const struct __CFBag *CFBagRef;

Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef const struct __CFBag *CFBagRef;
#endif

/*CFBagRetainCallBack

Prototype of a callback function used to retain a value being added to a bag.

typedef const void *(*CFBagRetainCallBack) (
   CFAllocatorRef allocator,
   const void *value
);


If you name your function MyCallBack, you would declare it like this:

const void *MyCallBack (
   CFAllocatorRef allocator,
   const void *value
);
Parameters
allocator

The bag’s allocator.
value

The value being added to the bag.
Return Value

The value to store in the bag, which is usually the value parameter passed to this callback, but may be a different value if a different value should be stored in the collection.
Discussion

This callback is passed to CFBagCreate in a CFBagCallBacks structure.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef const void *(*CFBagRetainCallBack) (
   CFAllocatorRef allocator,
   const void *value
);
#endif

/*CFBagReleaseCallBack

Prototype of a callback function used to release a value before it’s removed from a bag.

typedef void (*CFBagReleaseCallBack) (
   CFAllocatorRef allocator,
   const void *value
);


If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   CFAllocatorRef allocator,
   const void *value
);
Parameters
allocator

The bag’s allocator.
value

The value being removed from the bag.
Discussion

This callback is passed to CFBagCreate in a CFBagCallBacks structure.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef void (*CFBagReleaseCallBack) (
   CFAllocatorRef allocator,
   const void *value
);
#endif

/*CFBagCopyDescriptionCallBack

Prototype of a callback function used to get a description of a value in a bag.

typedef CFStringRef (*CFBagCopyDescriptionCallBack) (
   const void *value
);


If you name your function MyCallBack, you would declare it like this:

CFStringRef MyCallBack (
   const void *value
);
Parameters
value

The value to be described.
Return Value

A textual description of value. mmancreate
Discussion

This callback is passed to CFBagCreate in a CFBagCallBacks structure. This callback is used by the CFCopyDescription function.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef CFStringRef (*CFBagCopyDescriptionCallBack) (
   const void *value
);
#endif

/*CFBagEqualCallBack

Prototype of a callback function used to determine if two values in a bag are equal.

typedef Boolean (*CFBagEqualCallBack) (
   const void *value1,
   const void *value2
);


If you name your function MyCallBack, you would declare it like this:

Boolean MyCallBack (
   const void *value1,
   const void *value2
);
Parameters
value1

A value in the bag.
value2

Another value in the bag.
Return Value

true if value1 and value2 are equal, false otherwise.
Discussion

This callback is passed to CFBagCreate in a CFBagCallBacks structure.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef Boolean (*CFBagEqualCallBack) (
   const void *value1,
   const void *value2
);
#endif

/*CFBagHashCallBack

Prototype of a callback function invoked to compute a hash code for a value. Hash codes are used when values are accessed, added, or removed from a collection.

typedef CFHashCode      (*CFBagHashCallBack) (
   const void *value
);


If you name your function MyCallBack, you would declare it like this:

CFHashCode CFBagHashCallBack (
   const void *value
);
Parameters
value

The value used to compute the hash code.
Return Value

An integer that can be used as a table address in a hash table structure.
Discussion

This callback is passed to CFBagCreate in a CFBagCallBacks structure.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef CFHashCode      (*CFBagHashCallBack) (
   const void *value
);
#endif

/*CFBagCallBacks

This structure contains the callbacks used to retain, release, describe, and compare the values of a CFBag object.

struct CFBagCallBacks {
   CFIndex version;
   CFBagRetainCallBack retain;
   CFBagReleaseCallBack release;
   CFBagCopyDescriptionCallBack copyDescription;
   CFBagEqualCallBack equal;
   CFBagHashCallBack hash;
};
typedef struct CFBagCallBacks CFBagCallBacks;

Fields
version

The version number of this structure. If not one of the defined version numbers for this opaque type, the behavior is undefined. The current version of this structure is 0. 
retain

The callback used to retain each value as they are added to the collection. If NULL, values are not retained. See CFBagRetainCallBack for a descriptions of this function’s parameters. 
release

The callback used to release values as they are removed from the collection. If NULL, values are not released. See CFBagReleaseCallBack for a description of this callback. 
copyDescription

The callback used to create a descriptive string representation of each value in the collection. If NULL, the collection will create a simple description of each value. See CFBagCopyDescriptionCallBack for a description of this callback. 
equal

The callback used to compare values in the collection for equality for some operations. If NULL, the collection will use pointer equality to compare values in the collection. See CFBagEqualCallBack for a description of this callback. 
hash

The callback used to compute a hash code for values in a collection. If NULL, the collection computes a hash code by converting the pointer value to an integer. See CFBagHashCallBack for a description of this callback. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
struct CFBagCallBacks {
   CFIndex version;
   CFBagRetainCallBack retain;
   CFBagReleaseCallBack release;
   CFBagCopyDescriptionCallBack copyDescription;
   CFBagEqualCallBack equal;
   CFBagHashCallBack hash;
};
typedef struct CFBagCallBacks CFBagCallBacks;
#endif

/*CFBagApplierFunction

Prototype of a callback function that may be applied to every value in a bag.

typedef void (*CFBagApplierFunction) (
   const void *value,
   void *context
);

If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   const void *value,
   void *context
);

Parameters
value

The current value in a bag.
context

The program-defined context parameter given to the apply function.
Discussion

This callback is passed to the CFBagApplyFunction function which iterates over the values in a bag and applies the behavior defined in the applier function to each value in a bag. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
typedef void (*CFBagApplierFunction) (
   const void *value,
   void *context
);
#endif

//func

/*CFBagGetCountOfValue

Returns the number of times a value occurs in a bag.

CFIndex CFBagGetCountOfValue (
   CFBagRef theBag,
   const void *value
);
Parameters
theBag

The bag to examine. 
value

The value for which to find matches in theBag. The equal callback provided when theBag was created is used to compare. If the equal callback was NULL, pointer equality (in C, ==) is used. If value, or any other value in theBag, is not understood by the equal callback, the behavior is undefined.
Return Value

The number of times value occurs in theBag. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFIndex CFBagGetCountOfValue (
   CFBagRef theBag,
   const void *value
);
#endif

/*CFBagRemoveValue

Removes a value from a mutable bag.

void CFBagRemoveValue (
   CFMutableBagRef theBag,
   const void *value
);

Parameters
theBag

The bag from which value is to be removed. 
value

The value to be removed from the collection. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
void CFBagRemoveValue (
   CFMutableBagRef theBag,
   const void *value
);
#endif

/*CFBagAddValue

Adds a value to a mutable bag.

void CFBagAddValue (
   CFMutableBagRef theBag,
   const void *value
);

Parameters
theBag

The bag to which value is added.
value

A CFType object or a pointer value to add to theBag (or the value itself, if it fits into the size of a pointer). 
Discussion

The value parameter is retained by theBag using the retain callback provided when theBag was created. If value is not of the type expected by the retain callback, the behavior is undefined. If value already exists in the collection, it is simply retained again—no memory is allocated for the added value. Use a CFSet object if you don’t want duplicate values in your collection. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
void CFBagAddValue (
   CFMutableBagRef theBag,
   const void *value
);
#endif

/*CFBagCreateMutable

Creates a new empty mutable bag.

CFMutableBagRef CFBagCreateMutable (
   CFAllocatorRef allocator,
   CFIndex capacity,
   const CFBagCallBacks *callBacks
);
Parameters
allocator

The allocator object to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator.
capacity

The maximum number of values that can be contained by the new bag. The bag starts empty and can grow to this number of values (and it can have less). If this parameter is 0, the bag’s maximum capacity is not limited. This value must not be negative. 
callBacks

A pointer to a CFBagCallBacks structure initialized with the callbacks to use to retain, release, describe, and compare values in the bag. A copy of the contents of the callbacks structure is made, so that a pointer to a structure on the stack can be passed in or can be reused for multiple collection creations. This parameter may be NULL, which is treated as if a valid structure of version 0 with all fields NULL had been passed in.

If any of the fields are not valid pointers to functions of the correct type, or this parameter is not a valid pointer to a CFBagCallBacks structure, the behavior is undefined. If any value put into the collection is not one understood by one of the callback functions, the behavior when that callback function is used is undefined.

If the collection contains only CFType objects, then pass kCFTypeBagCallBacks as this parameter to use the default callback functions. 
Return Value

A new mutable bag, or NULL if there was a problem creating the object. Ownership follows the Create Rule.
Discussion

This function creates an new empty mutable bag to which you can add values using the CFBagAddValue function. The capacity parameter specifies the maximum number of values that the CFBag object can contain. If it is 0, then there is no limit to the number of values that can be added (aside from constraints such as available memory). 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFMutableBagRef CFBagCreateMutable (
   CFAllocatorRef allocator,
   CFIndex capacity,
   const CFBagCallBacks *callBacks
);
#endif

/*CFBagCreateMutableCopy

Creates a new mutable bag with the values from another bag.

CFMutableBagRef CFBagCreateMutableCopy (
   CFAllocatorRef allocator,
   CFIndex capacity,
   CFBagRef theBag
);

Parameters
allocator

The allocator to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
capacity

The maximum number of values that can be contained by the new bag. The bag starts with the same count as theBag, and can grow to this number of values (and it can have less). If this value is 0, the bag’s maximum capacity is not limited. This value must be greater than or equal to the count of theBag, and must not be negative. 
theBag

The bag to copy. The pointer values from theBag are copied into the new bag. However, the values are also retained by the new bag. The count of the new bag is the same as the count of theBag. The new bag uses the same callbacks as theBag. 
Return Value

A new mutable bag that contains the same values as theBag. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFMutableBagRef CFBagCreateMutableCopy (
   CFAllocatorRef allocator,
   CFIndex capacity,
   CFBagRef theBag
);
#endif
// 
/*CFBagGetCount

Returns the number of values currently in a bag.

CFIndex CFBagGetCount (
   CFBagRef theBag
);
Parameters
theBag

The bag to examine. 
Return Value

The number of values in theBag. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFIndex CFBagGetCount (
   CFBagRef theBag
);
#endif

/*CFBagGetValues

Fills a buffer with values from a bag.

void CFBagGetValues (
   CFBagRef theBag,
   const void **values
);

Parameters
theBag

The bag to examine. 
values

A C array of pointer-sized values to be filled with values from theBag. The value must be a valid C array of the appropriate type and size (that is, a size equal to the count of theBag). 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
void CFBagGetValues (
   CFBagRef theBag,
   const void **values
);
#endif

/*CFBagCreateCopy

Creates an immutable bag with the values of another bag.

CFBagRef CFBagCreateCopy (
   CFAllocatorRef allocator,
   CFBagRef theBag
);
Parameters
allocator

The allocator to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
theBag

The bag to copy. The pointer values from theBag are copied into the new bag. However, the values are also retained by the new bag. The count of the new bag is the same as the count of theBag. The new bag uses the same callbacks as theBag. 
Return Value

A new bag that contains the same values as theBag, or NULL if there was a problem creating the object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
CFBagRef CFBagCreateCopy (
   CFAllocatorRef allocator,
   CFBagRef theBag
);

/*CFBagApplyFunction

Calls a function once for each value in a bag.

void CFBagApplyFunction (
   CFBagRef theBag,
   CFBagApplierFunction applier,
   void *context
);

Parameters
theBag

The bag to operate upon. 
applier

The callback function to call once for each value in the theBag. If this parameter is not a pointer to a function of the correct prototype, the behavior is undefined. If there are values in the range that the applier function does not expect or cannot properly apply to, the behavior is undefined.
context

A pointer-sized program-defined value, which is passed as the second parameter to the applier function, but is otherwise unused by this function. If the context is not what is expected by the applier function, the behavior is undefined.
Discussion

While this function iterates over a mutable collection, it is unsafe for the applier function to change the contents of the collection. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
void CFBagApplyFunction (
   CFBagRef theBag,
   CFBagApplierFunction applier,
   void *context
);

#ifdef __cplusplus
}
#endif

#endif//OC_CFBAG_H
