#ifndef OC_CFBINARYHEAP_H
#define OC_CFBINARYHEAP_H

#include <CoreFoundation/CFBase.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFBinaryHeap.h"
#endif //OC_CF

#if defined(__cplusplus)
extern "C" {
#endif

/*CFBinaryHeapRetainCallBack

Callback function used to retain a value being added to a binary heap.

typedef const void *(*CFBinaryHeapRetainCallBack) (
   CFAllocatorRef allocator,
   const void *ptr
);


If you name your function MyCallBack, you would declare it like this:

const void *MyCallBack (
   CFAllocatorRef allocator,
   const void *ptr
);
Parameters
allocator

The binary heap’s allocator.
ptr

The value to retain.
Return Value

The value to store in the binary heap, which is usually the ptr parameter passed to this callback, but may be a different value if a different value should be stored in the binary heap.*/
typedef const void *(*CFBinaryHeapRetainCallBack) (
   CFAllocatorRef allocator,
   const void *ptr
);

/*CFBinaryHeapReleaseCallBack

Callback function used to release a value before it is removed from a binary heap.

typedef void (*CFBinaryHeapReleaseCallBack) (
   CFAllocatorRef allocator,
   const void *ptr
);


If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   CFAllocatorRef allocator,
   const void *ptr
);
Parameters
allocator

The binary heap’s allocator.
ptr

The value to release.*/
typedef void (*CFBinaryHeapReleaseCallBack) (
   CFAllocatorRef allocator,
   const void *ptr
);

/*CFBinaryHeapCompareCallBack

Callback function used to compare two members of a binary heap.

typedef CFComparisonResult (*CFBinaryHeapCompareCallBack) (
   const void *ptr1,
   const void *ptr2,
   void *info
);


If you name your function MyCallBack, you would declare it like this:

CFComparisonResult MyCallBack (
   const void *ptr1,
   const void *ptr2,
   void *info
);
Parameters
ptr1

First value to compare.
ptr2

Second value to compare.
info

Not used. Should always be NULL.
Return Value

kCFCompareLessThan if ptr1 is less than ptr2, kCFCompareEqualTo if ptr1 and ptr2 are equal, or kCFCompareGreaterThan if ptr1 is greater than ptr2.*/
typedef CFComparisonResult (*CFBinaryHeapCompareCallBack) (
   const void *ptr1,
   const void *ptr2,
   void *info
);


/*CFBinaryHeapCallBacks

Structure containing the callbacks for values for a CFBinaryHeap object.

struct CFBinaryHeapCallBacks {
   CFIndex version;
   CFBinaryHeapRetainCallBack retain;
   CFBinaryHeapReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
   CFBinaryHeapCompareCallBack compare;
};
typedef struct CFBinaryHeapCallBacks CFBinaryHeapCallBacks;

Fields
version

The version number of the structure type being passed in as a parameter to the CFBinaryHeap creation functions. This structure is version 0.
retain

The callback used to add a retain for the binary heap on values as they are put into the binary heap. This callback returns the value to use as the value in the binary heap, which is usually the value parameter passed to this callback, but may be a different value if a different value should be added to the binary heap. If this field is NULL, the binary heap does nothing to retain a value being added.
release

The callback used to remove a retain previously added for the binary heap from values as they are removed from the binary heap. If this field is NULL, the binary heap does nothing to release a value being removed.
copyDescription

The callback used to create a descriptive string representation of each value in the binary heap. This is used by the CFCopyDescription function. If this field is NULL, the binary heap constructs a CFString object describing the value based on its pointer value.
compare

The callback used to compare values in the binary heap in some operations. This field cannot be NULL.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
struct CFBinaryHeapCallBacks {
   CFIndex version;
   CFBinaryHeapRetainCallBack retain;
   CFBinaryHeapReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
   CFBinaryHeapCompareCallBack compare;
};
typedef struct CFBinaryHeapCallBacks CFBinaryHeapCallBacks;
#endif

/*CFBinaryHeapCompareContext

Not used.

struct CFBinaryHeapCompareContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
};
typedef struct CFBinaryHeapCompareContext CFBinaryHeapCompareContext;
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
struct CFBinaryHeapCompareContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
};
typedef struct CFBinaryHeapCompareContext CFBinaryHeapCompareContext;
#endif

/*CFBinaryHeapRef

A reference to a binary heap object.

typedef struct __CFBinaryHeap *CFBinaryHeapRef;

Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
typedef struct __CFBinaryHeap *CFBinaryHeapRef;
#endif

/*CFBinaryHeapApplierFunction

Callback function used to apply a function to all members of a binary heap.

typedef void (*CFBinaryHeapApplierFunction) (
   const void *val,
   void *context
);


If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   const void *val,
   void *context
);
Parameters
val

The current value from the binary heap.
context

The program-defined context parameter given to the CFBinaryHeapApplyFunction function.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
typedef void (*CFBinaryHeapApplierFunction) (
   const void *val,
   void *context
);
#endif

//function

/*CFBinaryHeapGetValues

Copies all the values from a binary heap into a sorted C array.

void CFBinaryHeapGetValues (
   CFBinaryHeapRef heap,
   const void **values
);
Parameters
heap

The binary heap to use.
values

On return, the memory pointed to by this argument holds a C array of all the values in heap, sorted from minimum to maximum values. You must allocate sufficient memory to hold all the values in heap before calling this function. If the values are Core Foundation objects, ownership follows the Get Rule.
Availability
Available in Mac OS X v10.0 and later. 
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
void CFBinaryHeapGetValues (
   CFBinaryHeapRef heap,
   const void **values
);
#endif

/*CFBinaryHeapRemoveAllValues

Removes all values from a binary heap, making it empty.

void CFBinaryHeapRemoveAllValues (
   CFBinaryHeapRef heap
);

Parameters
heap

The binary heap to use.
Availability
Available in Mac OS X v10.0 and later. 
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
void CFBinaryHeapRemoveAllValues (
   CFBinaryHeapRef heap
);
#endif

/*CFBinaryHeapAddValue

Adds a value to a binary heap.

void CFBinaryHeapAddValue (
   CFBinaryHeapRef heap,
   const void *value
);

Parameters
heap

The binary heap to use.
value

The value to add to the binary heap. The value is retained by the binary heap using the retain callback provided in the CFBinaryHeapCallBacks structure when the binary heap was created.
Availability
Available in Mac OS X v10.0 and later. 
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
void CFBinaryHeapAddValue (
   CFBinaryHeapRef heap,
   const void *value
);
#endif

/*CFBinaryHeapRemoveMinimumValue

Removes the minimum value from a binary heap.

void CFBinaryHeapRemoveMinimumValue (
   CFBinaryHeapRef heap
);
Parameters
heap

The binary heap to use.
Discussion

If heap contains several equal minimum values, only one of them is removed. If heap is empty, this function does nothing.
Availability
Available in Mac OS X v10.0 and later. 
Declared In
CFBinaryHeap.h*/
#ifdef OC_CF
void CFBinaryHeapRemoveMinimumValue (
   CFBinaryHeapRef heap
);
#endif

#ifdef __cplusplus
}
#endif

#endif//CFBINARYHEAP_H
