#ifndef OC_CFBYTEORDER_H
#define OC_CFBYTEORDER_H

#define OC_CF

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFByteOrder.h"
#endif //OC_CF

#if defined(__i386) && !defined(__LITTLE_ENDIAN__)
    #define __LITTLE_ENDIAN__ 1
#endif

#if !defined(__BIG_ENDIAN__) && !defined(__LITTLE_ENDIAN__)
#error Do not know the endianess of this architecture
#endif

#include <CoreFoundation/CFBase.h>


#if defined(__cplusplus)
extern "C" {
#endif

/*CFSwappedFloat64

Structure holding a 64-bit float value in a platform-independent byte order.

struct CFSwappedFloat64 {
   uint64_t v;
};
typedef struct CFSwappedFloat64 CFSwappedFloat64;
Fields
v

A 64-bit float value stored with a platform-independent byte order.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
struct CFSwappedFloat64 {
   uint64_t v;
};
typedef struct CFSwappedFloat64 CFSwappedFloat64;
#endif

/*CFSwappedFloat32

Structure holding a 32-bit float value in a platform-independent byte order.

struct CFSwappedFloat32 {
   uint32_t v;
};
typedef struct CFSwappedFloat32 CFSwappedFloat32;

Fields
v

A 32-bit float value stored with a platform-independent byte order.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
struct CFSwappedFloat32 {
   uint32_t v;
};
typedef struct CFSwappedFloat32 CFSwappedFloat32;
#endif

//function

/*CFSwapInt32BigToHost

Converts a 32-bit integer from big-endian format to the host’s native byte order.

uint32_t CFSwapInt32BigToHost (
   uint32_t arg
);
Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is big-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
uint32_t CFSwapInt32BigToHost (
   uint32_t arg
);
#endif

/*CFSwapInt32HostToBig

Converts a 32-bit integer from the host’s native byte order to big-endian format.

uint32_t CFSwapInt32HostToBig (
   uint32_t arg
);
Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is big-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
uint32_t CFSwapInt32HostToBig (
   uint32_t arg
);
#endif

/*CFSwapInt32HostToLittle

Converts a 32-bit integer from the host’s native byte order to little-endian format.

uint32_t CFSwapInt32HostToLittle (
   uint32_t arg
);
Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is little-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint32_t CFSwapInt32HostToLittle (
   uint32_t arg
);
#endif

/*CFSwapInt32LittleToHost

Converts a 32-bit integer from little-endian format to the host’s native byte order.

uint32_t CFSwapInt32LittleToHost (
   uint32_t arg
);

Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is little-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint32_t CFSwapInt32LittleToHost (
   uint32_t arg
);
#endif

/*CFSwapInt16BigToHost

Converts a 16-bit integer from big-endian format to the host’s native byte order.

uint16_t CFSwapInt16BigToHost (
   uint16_t arg
);

Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is big-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint16_t CFSwapInt16BigToHost (
   uint16_t arg
);
#endif

/*CFConvertFloat64SwappedToHost

Converts a 64-bit float from a platform-independent format to the host’s native byte order.

Float64 CFConvertFloat64SwappedToHost (
   CFSwappedFloat64 arg
);

Parameters
arg

A structure holding the real value to convert.
Return Value

The real value in the host’s native format.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
Float64 CFConvertFloat64SwappedToHost (
   CFSwappedFloat64 arg
);
#endif

/*CFConvertFloat32SwappedToHost

Converts a 32-bit float from a platform-independent format to the host’s native byte order.

Float32 CFConvertFloat32SwappedToHost (
   CFSwappedFloat32 arg
);

Parameters
arg

A structure holding the real value to convert.
Return Value

The real value in the host’s native format.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
Float32 CFConvertFloat32SwappedToHost (
   CFSwappedFloat32 arg
);
#endif

/*CFSwapInt64HostToBig

Converts a 64-bit integer from the host’s native byte order to big-endian format.

uint64_t CFSwapInt64HostToBig (
   uint64_t arg
);
Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is big-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint64_t CFSwapInt64HostToBig (
   uint64_t arg
);
#endif

/*CFSwapInt64BigToHost

Converts a 64-bit integer from big-endian format to the host’s native byte order.

uint64_t CFSwapInt64BigToHost (
   uint64_t arg
);

Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is big-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint64_t CFSwapInt64BigToHost (
   uint64_t arg
);
#endif

/*CFConvertFloat64HostToSwapped

Converts a 64-bit float from the host’s native byte order to a platform-independent format.

CFSwappedFloat64 CFConvertFloat64HostToSwapped (
   Float64 arg
);
Parameters
arg

The real value to convert.
Return Value

A structure holding the real value in a canonical byte order.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
CFSwappedFloat64 CFConvertFloat64HostToSwapped (
   Float64 arg
);
#endif

/*CFConvertFloat32HostToSwapped

Converts a 32-bit float from the host’s native byte order to a platform-independent format.

CFSwappedFloat32 CFConvertFloat32HostToSwapped (
   Float32 arg
);
Parameters
arg

The real value to convert.
Return Value

A structure holding the real value in a canonical byte order.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
CFSwappedFloat32 CFConvertFloat32HostToSwapped (
   Float32 arg
);
#endif

/*CFSwapInt16HostToBig

Converts a 16-bit integer from the host’s native byte order to big-endian format.

uint16_t CFSwapInt16HostToBig (
   uint16_t arg
);
Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is big-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint16_t CFSwapInt16HostToBig (
   uint16_t arg
);
#endif

/*CFSwapInt32

Swaps the bytes of a 32-bit integer.

uint32_t CFSwapInt32 (
   uint32_t arg
);

Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint32_t CFSwapInt32 (
   uint32_t arg
);
#endif

/*CFSwapInt64

Swaps the bytes of a 64-bit integer.

uint64_t CFSwapInt64 (
   uint64_t arg
);

Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint64_t CFSwapInt64 (
   uint64_t arg
);
#endif

/*CFSwapInt16HostToLittle

Converts a 16-bit integer from the host’s native byte order to little-endian format.

uint16_t CFSwapInt16HostToLittle (
   uint16_t arg
);
Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped. If the host is little-endian, this function returns arg unchanged.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint16_t CFSwapInt16HostToLittle (
   uint16_t arg
);
#endif

/*CFSwapInt16

Swaps the bytes of a 16-bit integer.

uint16_t CFSwapInt16 (
   uint16_t arg
);
Parameters
arg

The integer whose bytes should be swapped.
Return Value

The integer with its bytes swapped.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFByteOrder.h*/
#ifdef OC_CF
uint16_t CFSwapInt16 (
   uint16_t arg
);
#endif

#ifdef __cplusplus
}
#endif

#endif//OC_CFBYTEORDER_H
