

#if !defined(OC__COREFOUNDATION_CFCALENDAR__)
#define OC__COREFOUNDATION_CFCALENDAR__ 1

#include <CoreFoundation/CFBase.h>
#include <CoreFoundation/CFLocale.h>
#include <CoreFoundation/CFDate.h>
#include <CoreFoundation/CFTimeZone.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFCalendar.h"
#endif //OC_CF

#if defined(__cplusplus)
extern "C" {
#endif

/*CFCalendarRef

A reference to a CFCalendar object.

typedef const struct __CFCalendar *CFCalendarRef;

Availability
Available in Mac OS X v10.4 and later.
Declared In
CFCalendar.h*/
//typedef const struct __CFCalendar *CFCalendarRef;
#ifdef OC_CF
typedef struct __CFCalendar * CFCalendarRef;
#endif

/*CFCalendarUnit

CFCalendarUnit constants are used to specify calendrical units, such as day or month, in various calendar calculations.

typedef enum {
   kCFCalendarUnitEra = (1 << 1),
   kCFCalendarUnitYear = (1 << 2),
   kCFCalendarUnitMonth = (1 << 3),
   kCFCalendarUnitDay = (1 << 4),
   kCFCalendarUnitHour = (1 << 5),
   kCFCalendarUnitMinute = (1 << 6),
   kCFCalendarUnitSecond = (1 << 7),
   kCFCalendarUnitWeek = (1 << 8),
   kCFCalendarUnitWeekday = (1 << 9),
   kCFCalendarUnitWeekdayOrdinal = (1 << 10),
} CFCalendarUnit;
Constants
kCFCalendarUnitEra

Specifies the era unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitYear

Specifies the year unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitMonth

Specifies the month unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitDay

Specifies the day unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitHour

Specifies the hour unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitMinute

Specifies the minute unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitSecond

Specifies the second unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitWeek

Specifies the week unit.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitWeekday

Specifies the weekday unit.

The weekday units are the numbers 1-N (where for the Gregorian calendar N=7 and 1 is Sunday).

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h
kCFCalendarUnitWeekdayOrdinal

Specifies the ordinal weekday unit.

The weekday ordinal unit describes ordinal position within the month unit of the corresponding weekday unit. For example, in the Gregorian calendar a weekday ordinal unit of 2 for a weekday unit 3 indicates "the second Tuesday in the month".

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h*/
#ifdef OC_CF
typedef enum {
   kCFCalendarUnitEra = (1 << 1),
   kCFCalendarUnitYear = (1 << 2),
   kCFCalendarUnitMonth = (1 << 3),
   kCFCalendarUnitDay = (1 << 4),
   kCFCalendarUnitHour = (1 << 5),
   kCFCalendarUnitMinute = (1 << 6),
   kCFCalendarUnitSecond = (1 << 7),
   kCFCalendarUnitWeek = (1 << 8),
   kCFCalendarUnitWeekday = (1 << 9),
   kCFCalendarUnitWeekdayOrdinal = (1 << 10),
} CFCalendarUnit;
#endif

/*Component Wrapping Options

The wrapping option specifies overflow behavior for calendar components in calendrical calculations—see CFCalendarAddComponents and CFCalendarGetComponentDifference.

enum {
   kCFCalendarComponentsWrap = (1 << 0)
}

Constants
kCFCalendarComponentsWrap

Specifies that the components specified for calendar components should be incremented and wrap around to zero/one on overflow, but should not cause higher units to be incremented.

Available in Mac OS X v10.4 and later.

Declared in CFCalendar.h*/
#ifdef OC_CF
enum {
   kCFCalendarComponentsWrap = (1 << 0)
};
#endif

//func

/*CFCalendarSetLocale

Sets the locale for a calendar.

void CFCalendarSetLocale (
   CFCalendarRef calendar,
   CFLocaleRef locale
);
Parameters
calendar

The calendar to modify. 
locale

The locale to set for calendar.
Availability
Available in Mac OS X v10.4 and later.
Declared In
CFCalendar.h*/
#ifdef OC_CF
void CFCalendarSetLocale (
   CFCalendarRef calendar,
   CFLocaleRef locale
);
#endif

/*CFCalendarCreateWithIdentifier

Returns a calendar object for the calendar identified by a calendar identifier.

CFCalendarRef CFCalendarCreateWithIdentifier (
   CFAllocatorRef allocator,
   CFStringRef identifier
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
ident

A calendar identifier. Calendar identifier constants are given in CFLocaleRef.
Return Value

A calendar object for the calendar identified by ident. If the identifier is unknown (if, for example, it is either an unrecognized string, or the calendar is not supported by the current version of the operating system), returns NULL. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.4 and later.
Declared In
CFCalendar.h*/
#ifdef OC_CF
CFCalendarRef CFCalendarCreateWithIdentifier (
   CFAllocatorRef allocator,
   CFStringRef identifier
);
#endif

/*CFCalendarGetIdentifier

Returns the given calendar’s identifier.

CFStringRef CFCalendarGetIdentifier (
   CFCalendarRef calendar
);
Parameters
calendar

The calendar to examine.
Return Value

A string representation of calendar’s identifier. Calendar identifier constants can be found in CFLocaleRef. Ownership follows the Get Rule.
Availability
Available in Mac OS X v10.4 and later.
Declared In
CFCalendar.h*/
#ifdef OC_CF
CFStringRef CFCalendarGetIdentifier (
   CFCalendarRef calendar
);
#endif

#if defined(__cplusplus)
}
#endif


#endif 


