#ifndef OC_CFCHARACTERSET_H
#define OC_CFCHARACTERSET_H

#include <CoreFoundation/CFBase.h>
#include <CoreFoundation/CFDate.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFCharacterSet.h"
#endif //OC_CF

/*CFMutableCharacterSetRef

A reference to a mutable character set object.

typedef struct __CFCharacterSet *CFMutableCharacterSetRef;
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
typedef struct __CFCharacterSet *CFMutableCharacterSetRef;
#endif

/*CFCharacterSetRef

A reference to an immutable character set object.

typedef const struct __CFCharacterSet *CFCharacterSetRef;
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
typedef const struct __CFCharacterSet *CFCharacterSetRef;
#endif

/*Predefined CFCharacterSet Selector Values

Identifiers for the available predefined CFCharacterSet objects.


enum {
   kCFCharacterSetControl = 1,
   kCFCharacterSetWhitespace,
   kCFCharacterSetWhitespaceAndNewline,
   kCFCharacterSetDecimalDigit,
   kCFCharacterSetLetter,
   kCFCharacterSetLowercaseLetter,
   kCFCharacterSetUppercaseLetter,
   kCFCharacterSetNonBase,
   kCFCharacterSetDecomposable,
   kCFCharacterSetAlphaNumeric,
   kCFCharacterSetPunctuation,
   kCFCharacterSetCapitalizedLetter = 13,
   kCFCharacterSetSymbol = 14,
   kCFCharacterSetNewline = 15,
   kCFCharacterSetIllegal = 12
};

Constants
kCFCharacterSetControl

Control character set (Unicode General Category Cc and Cf).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetWhitespace

Whitespace character set (Unicode General Category Zs and U0009 CHARACTER TABULATION).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetWhitespaceAndNewline

Whitespace and Newline character set (Unicode General Category Z*, U000A ~ U000D, and U0085).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetDecimalDigit

Decimal digit character set.

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetLetter

Letter character set (Unicode General Category L* & M*).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetLowercaseLetter

Lowercase character set (Unicode General Category Ll).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetUppercaseLetter

Uppercase character set (Unicode General Category Lu and Lt).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetNonBase

Non-base character set (Unicode General Category M*).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetDecomposable

Canonically decomposable character set.

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetAlphaNumeric

Alpha Numeric character set (Unicode General Category L*, M*, & N*).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetPunctuation

Punctuation character set (Unicode General Category P*).

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
kCFCharacterSetCapitalizedLetter

Titlecase character set (Unicode General Category Lt).

Available in Mac OS X v10.2 and later.

Declared in CFCharacterSet.h
kCFCharacterSetSymbol

Symbol character set (Unicode General Category S*).

Available in Mac OS X v10.3 and later.

Declared in CFCharacterSet.h
kCFCharacterSetNewline

Newline character set (U000A ~ U000D, U0085, U2028, and U2029).

Available in Mac OS X v10.5 and later.

Declared in CFCharacterSet.h
kCFCharacterSetIllegal

Illegal character set.

Available in Mac OS X v10.0 and later.

Declared in CFCharacterSet.h
Discussion

Use these constants with the CFCharacterSetGetPredefined function to get one of the predefined character sets.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
enum {
   kCFCharacterSetControl = 1,
   kCFCharacterSetWhitespace,
   kCFCharacterSetWhitespaceAndNewline,
   kCFCharacterSetDecimalDigit,
   kCFCharacterSetLetter,
   kCFCharacterSetLowercaseLetter,
   kCFCharacterSetUppercaseLetter,
   kCFCharacterSetNonBase,
   kCFCharacterSetDecomposable,
   kCFCharacterSetAlphaNumeric,
   kCFCharacterSetPunctuation,
   kCFCharacterSetCapitalizedLetter = 13,
   kCFCharacterSetSymbol = 14,
   kCFCharacterSetNewline = 15,
   kCFCharacterSetIllegal = 12
};
#endif

/*CFCharacterSetPredefinedSet

Defines a predefined character set.

typedef CFIndex CFCharacterSetPredefinedSet;

Discussion

See “Predefined CFCharacterSet Selector Values” for values.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
typedef CFIndex CFCharacterSetPredefinedSet;
#endif

//function

/*CFCharacterSetGetPredefined

Returns a predefined character set.

CFCharacterSetRef CFCharacterSetGetPredefined (
   CFCharacterSetPredefinedSet theSetIdentifier
);

Parameters
theSetIdentifier

A predefined character set. See “Predefined CFCharacterSet Selector Values” for the list of available character sets.
Return Value

A predefined character set. This instance is owned by Core Foundation.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFCharacterSetRef CFCharacterSetGetPredefined (
   CFCharacterSetPredefinedSet theSetIdentifier
);
#endif

/*CFCharacterSetIsCharacterMember

Reports whether or not a given Unicode character is in a character set.

Boolean CFCharacterSetIsCharacterMember (
   CFCharacterSetRef theSet,
   UniChar theChar
);
Parameters
theSet

The character set to examine. 
theChar

The Unicode character for which to test against the character set. Note that this function takes 16-bit Unicode character value; hence, it does not support access to the non-BMP planes.
Return Value

true if theSet contains theChar, otherwise false.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
Boolean CFCharacterSetIsCharacterMember (
   CFCharacterSetRef theSet,
   UniChar theChar
);
#endif

/*CFCharacterSetIsLongCharacterMember

Reports whether or not a given UTF-32 character is in a character set.

Boolean CFCharacterSetIsLongCharacterMember (
   CFCharacterSetRef theSet,
   UTF32Char theChar
);

Parameters
theSet

The character set to examine. 
theChar

The UTF-32 character for which to test against the character set.
Return Value

true if theSet contains theChar, otherwise false.
Availability
Available in Mac OS X v10.2 and later. 
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
Boolean CFCharacterSetIsLongCharacterMember (
   CFCharacterSetRef theSet,
   UTF32Char theChar
);
#endif

/*CFCharacterSetCreateMutable

Creates a new empty mutable character set.

CFMutableCharacterSetRef CFCharacterSetCreateMutable (
   CFAllocatorRef alloc
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator.
Return Value

A new empty mutable character set. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFMutableCharacterSetRef CFCharacterSetCreateMutable (
   CFAllocatorRef alloc
);
#endif

/*CFCharacterSetAddCharactersInRange

Adds a given range to a character set.

void CFCharacterSetAddCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
);

Parameters
theSet

The character set to modify.
theRange

The range to add to the character set. The range is specified in 32-bits in UTF-32 format, and must lie within the valid Unicode character range (from 0x00000 to 0x10FFFF).
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetAddCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
);
#endif

/*CFCharacterSetAddCharactersInString

Adds the characters in a given string to a character set.

void CFCharacterSetAddCharactersInString (
   CFMutableCharacterSetRef theSet,
   CFStringRef theString
);

Parameters
theSet

The character set to modify.
theString

A string containing the characters to add to theSet.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetAddCharactersInString (
   CFMutableCharacterSetRef theSet,
   CFStringRef theString
);
#endif

/*CFCharacterSetCreateCopy

Creates a new character set with the values from a given character set.

CFCharacterSetRef CFCharacterSetCreateCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
theSet

The character set to copy.
Return Value

A new character set that is a copy of theSet. Ownership follows the Create Rule.
Discussion

This function tries to compact the backing store where applicable.
Availability
Available in Mac OS X v10.3 and later. 
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFCharacterSetRef CFCharacterSetCreateCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
);
#endif

/*CFCharacterSetRemoveCharactersInRange

Removes a given range of Unicode characters from a character set.

void CFCharacterSetRemoveCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
);
Parameters
theSet

The character set to modify.
theRange

The range to remove from the character set. The range is specified in 32-bits in UTF-32 format, and must lie within the valid Unicode character range (from 0x00000 to 0x10FFFF).
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetRemoveCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
);
#endif

/*CFCharacterSetGetTypeID

Returns the type identifier of the CFCharacterSet opaque type.

CFTypeID CFCharacterSetGetTypeID (
   void
);

Return Value

The type identifier of the CFCharacterSet opaque type.
Discussion

CFMutableCharacterSet objects have the same type identifier as CFCharacterSet objects.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFTypeID CFCharacterSetGetTypeID (
   void
);
#endif

/*CFCharacterSetCreateMutableCopy

Creates a new mutable character set with the values from another character set.

CFMutableCharacterSetRef CFCharacterSetCreateMutableCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator.
theSet

The character set to copy.
Return Value

A new mutable character set containing the same characters as theSet. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFMutableCharacterSetRef CFCharacterSetCreateMutableCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
);
#endif

/*CFCharacterSetInvert

Inverts the content of a given character set.

void CFCharacterSetInvert (
   CFMutableCharacterSetRef theSet
);

Parameters
theSet

The character set to invert.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetInvert (
   CFMutableCharacterSetRef theSet
);
#endif

/*CFCharacterSetIntersect

Forms an intersection of two character sets.

void CFCharacterSetIntersect (
   CFMutableCharacterSetRef theSet,
   CFCharacterSetRef theOtherSet
);

Parameters
theSet

The source character set, modified by intersection with theOtherSet.
theOtherSet

The character set with which the intersection is formed.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetIntersect (
   CFMutableCharacterSetRef theSet,
   CFCharacterSetRef theOtherSet
);
#endif

#endif//OC_CFCHARACTERSET_H
