
#if !defined(OC__COREFOUNDATION_CFERROR__)
#define OC__COREFOUNDATION_CFERROR__ 1

#include <CoreFoundation/CFBase.h>
#include <CoreFoundation/CFString.h>
#include <CoreFoundation/CFDictionary.h>


//#ifndef OC_CF
//#include "/usr/include/CoreFoundation/CFError.h"
//#endif //OC_CF

/*CFErrorRef

A reference to a CFError object.

typedef struct __CFError * CFErrorRef;
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
typedef struct __CFError * CFErrorRef;
#endif

/*Error domains

These constants define domains for CFError objects.

const CFStringRef kCFErrorDomainPOSIX;
const CFStringRef kCFErrorDomainOSStatus;
const CFStringRef kCFErrorDomainMach;
const CFStringRef kCFErrorDomainCocoa;

Constants
kCFErrorDomainPOSIX

A constant that specified the POSIX domain.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
kCFErrorDomainOSStatus

A constant that specified the OS domain.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
kCFErrorDomainMach

A constant that specified the Mach domain.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
kCFErrorDomainCocoa

A constant that specified the Cocoa domain.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
Discussion

The value of "code" will correspond to preexisting values in these domains.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
extern const CFStringRef kCFErrorDomainPOSIX;
extern const CFStringRef kCFErrorDomainOSStatus;
extern const CFStringRef kCFErrorDomainMach;
extern const CFStringRef kCFErrorDomainCocoa;
#endif

/*Keys for the user info dictionary

Keys in the userInfo dictionary.

const CFStringRef kCFErrorLocalizedDescriptionKey;
const CFStringRef kCFErrorLocalizedFailureReasonKey;
const CFStringRef kCFErrorLocalizedRecoverySuggestionKey;
const CFStringRef kCFErrorDescriptionKey;
const CFStringRef kCFErrorUnderlyingErrorKey;

Constants
kCFErrorLocalizedDescriptionKey

Key to identify the end user-presentable description in the userInfo dictionary.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
kCFErrorLocalizedFailureReasonKey

Key to identify the end user-presentable failure reason in the userInfo dictionary.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
kCFErrorLocalizedRecoverySuggestionKey

Key to identify the end user-presentable recovery suggestion in the userInfo dictionary.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
kCFErrorDescriptionKey

Key to identify the description in the userInfo dictionary.

When you create a CFError, you can provide a value for this key if you do not have localizable error strings. The description should be a complete sentence if possible, and should not contain the domain name or error code.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
kCFErrorUnderlyingErrorKey

Key to identify the underlying error in the userInfo dictionary.

Available in Mac OS X v10.5 and later.

Declared in CFError.h
Discussion

When you create a user info dictionary, at a minimum you should provide values for one of kCFErrorLocalizedDescriptionKey and kCFErrorLocalizedFailureReasonKey; ideally you should provide values for kCFErrorLocalizedDescriptionKey, kCFErrorLocalizedFailureReasonKey, and kCFErrorLocalizedRecoverySuggestionKey.
Availability
Available in Mac OS X v10.5 and later.
Declared In
NSError.h*/
#ifdef OC_CF
extern const CFStringRef kCFErrorLocalizedDescriptionKey;
extern const CFStringRef kCFErrorLocalizedFailureReasonKey;
extern const CFStringRef kCFErrorLocalizedRecoverySuggestionKey;
extern const CFStringRef kCFErrorDescriptionKey;
extern const CFStringRef kCFErrorUnderlyingErrorKey;
#endif

//function

/*CFErrorGetCode

Returns the error code for a given CFError.

CFIndex CFErrorGetCode (
   CFErrorRef err
);

Parameters
err

The error to examine. If this is not a valid CFError, the behavior is undefined.
Return Value

The error code of err.
Discussion

Note that this function returns the error code for the specified CFError, not an error return for the current call.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
CFIndex CFErrorGetCode (
   CFErrorRef err
);
#endif

/*CFErrorGetDomain

Returns the error domain for a given CFError.

CFStringRef CFErrorGetDomain (
   CFErrorRef err
);
Parameters
err

The error to examine. If this is not a valid CFError, the behavior is undefined.
Return Value

The error domain for err. Ownership follows the Get Rule.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
CFStringRef CFErrorGetDomain (
   CFErrorRef err
);
#endif

/*CFErrorCopyUserInfo

Returns the user info dictionary for a given CFError.

CFDictionaryRef CFErrorCopyUserInfo (
   CFErrorRef err
);
Parameters
err

The error to examine. If this is not a valid CFError, the behavior is undefined.
Return Value

A dictionary containing the same keys and values as in the userInfo dictionary err was created with. Returns an empty dictionary if NULL was supplied to the create function. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
CFDictionaryRef CFErrorCopyUserInfo (
   CFErrorRef err
);
#endif

/*CFErrorCopyDescription

Returns a human-presentable description for a given error.

CFStringRef CFErrorCopyDescription (
   CFErrorRef err
);

Parameters
err

The CFError to examine. If this is not a valid CFError, the behavior is undefined.
Return Value

A localized, human-presentable description of err. This function never returns NULL. Ownership follows the Create Rule.
Discussion

This is a complete sentence or two which says what failed and why it failed. The structure of the description depends on the details provided in the user info dictionay. The rules for computing the return value are as follows:
If the value in the user info dictionary for kCFErrorLocalizedDescriptionKey is not NULL, returns that value as-is.
If the value in the user info dictionary for kCFErrorLocalizedFailureReasonKey is not NULL, generate an error from that.

The description is something like: "Operation could not be completed. " + kCFErrorLocalizedFailureReasonKey
Generate as good a user-presentable string as possible from kCFErrorDescriptionKey, the domain, and code.

The description is something like like: "Operation could not be completed. Error domain/code occurred. " or "Operation could not be completed. " + kCFErrorDescriptionKey + " (Error domain/code)"

Toll-free bridged instances of NSError might provide additional behaviors for manufacturing a description string. 

You should not depend on the exact contents or format of the returned string, as it might change in different releases of the operating system.

When you create a CFError, you should try to make sure the return value is human-presentable and localized by providing a value for kCFErrorLocalizedDescriptionKey in the user info dictionary.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
CFStringRef CFErrorCopyDescription (
   CFErrorRef err
);
#endif

/*CFErrorCreate

Creates a new CFError object.

CFErrorRef CFErrorCreate (
   CFAllocatorRef allocator,
   CFStringRef domain,
   CFIndex code,
   CFDictionaryRef userInfo
);

Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
domain

A CFString that identifies the error domain. If this reference is NULL or is otherwise not a valid CFString, the behavior is undefined. 
code

A CFIndex that identifies the error code. The code is interpreted within the context of the error domain.
userInfo

A CFDictionary created with kCFCopyStringDictionaryKeyCallBacks and kCFTypeDictionaryValueCallBacks. The dictionary is copied with CFDictionaryCreateCopy. If you do not want the userInfo dictionary, you can pass NULL, in which case an empty dictionary will be assigned.
Return Value

A new CFError object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
CFErrorRef CFErrorCreate (
   CFAllocatorRef allocator,
   CFStringRef domain,
   CFIndex code,
   CFDictionaryRef userInfo
);
#endif

/*CFErrorCreateWithUserInfoKeysAndValues

Creates a new CFError object using given keys and values to create the user info dictionary.

CFErrorRef CFErrorCreateWithUserInfoKeysAndValues (
   CFAllocatorRef allocator,
   CFStringRef domain,
   CFIndex code,
   const void *const *userInfoKeys,
   const void *const *userInfoValues,
   CFIndex numUserInfoValues
);

Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
domain

A CFString that identifies the error domain. If this reference is NULL or is otherwise not a valid CFString, the behavior is undefined. 
code

A CFIndex that identifies the error code. The code is interpreted within the context of the error domain.
userInfoKeys

An array of numUserInfoValues CFStrings used as keys in creating the userInfo dictionary. The value of this parameter can be NULL if numUserInfoValues is 0.
userInfoValues

An array of numUserInfoValues CF types used as values in creating the userInfo dictionary. The value of this parameter can be NULL if numUserInfoValues is 0.
numUserInfoValues

The number of keys and values in the userInfoKeys and userInfoValues arrays.
Return Value

A new CFError object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFError.h*/
#ifdef OC_CF
CFErrorRef CFErrorCreateWithUserInfoKeysAndValues (
   CFAllocatorRef allocator,
   CFStringRef domain,
   CFIndex code,
   const void *const *userInfoKeys,
   const void *const *userInfoValues,
   CFIndex numUserInfoValues
);
#endif 

#endif//OC__COREFOUNDATION_CFERROR__


