#ifndef OC_CFPLUGIN_H
#define OC_CFPLUGIN_H


#include <CoreFoundation/CFBase.h>
#include <CoreFoundation/CFArray.h>
#include <CoreFoundation/CFBundle.h>
#include <CoreFoundation/CFString.h>

#ifndef CFURL_H
#include <CoreFoundation/CFURL.h>
#endif

#include <CoreFoundation/CFUUID.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFPlugIn.h"
#endif //OC_CF


#if defined(__cplusplus)
extern "C" {
#endif

/*CFPlugInRef

A reference to a CFPlugin object.

typedef struct __CFBundle *CFPlugInRef;
Availability
Available in Mac OS X version 10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
typedef struct __CFBundle *CFPlugInRef;
#endif

/*CFPlugInFactoryFunction

Callback function that a plug-in author must implement to create a plug-in instance.

typedef void *(*CFPlugInFactoryFunction) (
   CFAllocatorRef allocator,
   CFUUIDRef typeUUID
);


If you name your function MyCallBack, you would declare it like this:

void *MyCallBack (
   CFAllocatorRef allocator,
   CFUUIDRef typeUUID
);
Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the default allocator.
typeUUID

The UUID type to instantiate. 
Discussion

The plug-in author's implementation of this function is registered with CFPlugIn either statically in the plug-in's information property list, or dynamically. This function is executed as a result of a call to CFPlugInInstanceCreate by the plug-in host. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
typedef void *(*CFPlugInFactoryFunction) (
   CFAllocatorRef allocator,
   CFUUIDRef typeUUID
);
#endif

/*CFPlugInInstanceRef

Not recommended.

typedef struct __CFPlugInInstance *CFPlugInInstanceRef;

Availability
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
typedef struct __CFPlugInInstance *CFPlugInInstanceRef;
#endif

/*CFPlugInInstanceGetInterfaceFunction

Not recommended.

Not recommended

typedef Boolean (*CFPlugInInstanceGetInterfaceFunction) (
   CFPlugInInstanceRef instance,
   CFStringRef interfaceName,
   void **ftbl
);


If you name your function MyCallBack, you would declare it like this:

Boolean MyCallBack (
   CFPlugInInstanceRef instance,
   CFStringRef interfaceName,
   void **ftbl
);
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
typedef Boolean (*CFPlugInInstanceGetInterfaceFunction) (
   CFPlugInInstanceRef instance,
   CFStringRef interfaceName,
   void **ftbl
);
#endif

/*CFPlugInInstanceDeallocateInstanceDataFunction

Not recommended.

Not recommended

typedef void (*CFPlugInInstanceDeallocateInstanceDataFunction) (
   void *instanceData
);


If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   void *instanceData
);
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
typedef void (*CFPlugInInstanceDeallocateInstanceDataFunction) (
   void *instanceData
);
#endif

/*Information Property List Keys

A plug-in’s information property list can contain these keys used for registering types, factories, and interfaces. 

const CFStringRef kCFPlugInDynamicRegistrationKey;
const CFStringRef kCFPlugInDynamicRegisterFunctionKey;
const CFStringRef kCFPlugInUnloadFunctionKey;
const CFStringRef kCFPlugInFactoriesKey;
const CFStringRef kCFPlugInTypesKey;
Constants
kCFPlugInDynamicRegistrationKey

Indicates whether a plug-in requires dynamic registration.

Available in Mac OS X v10.0 and later.

Declared in CFPlugIn.h
kCFPlugInDynamicRegisterFunctionKey

Used to specify a plug-in’s registration function.

Available in Mac OS X v10.0 and later.

Declared in CFPlugIn.h
kCFPlugInUnloadFunctionKey

Used to specify a plug-in’s unload function.

Available in Mac OS X v10.0 and later.

Declared in CFPlugIn.h
kCFPlugInFactoriesKey

Used to statically register factory functions.

Available in Mac OS X v10.0 and later.

Declared in CFPlugIn.h
kCFPlugInTypesKey

Used to statically register the factories that can create each supported type.

Available in Mac OS X v10.0 and later.

Declared in CFPlugIn.h
Availability
Mac OS X version 10.0 and later
Declared In
CFPlugIn.h*/
#ifdef OC_CF
extern const CFStringRef kCFPlugInDynamicRegistrationKey;
extern const CFStringRef kCFPlugInDynamicRegisterFunctionKey;
extern const CFStringRef kCFPlugInUnloadFunctionKey;
extern const CFStringRef kCFPlugInFactoriesKey;
extern const CFStringRef kCFPlugInTypesKey;
#endif

/*CFPlugInDynamicRegisterFunction

A callback which provides a plug-in the opportunity to dynamically register its types with a host.

typedef void (*CFPlugInDynamicRegisterFunction) (
   CFPlugInRef plugIn
);

If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   CFPlugInRef plugIn
);

Parameters
plugIn

The CFPlugIn object that is engaged in dynamic registration. When using in C++, this parameter functions as a this pointer for the plug-in. 
Discussion

This callback is called as a plug-in is being loaded. This provides the plugin the means to dynamically register its types and factories with a plug-in’s host. The call is triggered by the presence of kCFPlugInDynamicRegistrationKey in the plug-in's information property list. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
typedef void (*CFPlugInDynamicRegisterFunction) (
   CFPlugInRef plugIn
);
#endif

//func

/*CFPlugInAddInstanceForFactory

Registers a new instance of a type with CFPlugIn. .

void CFPlugInAddInstanceForFactory (
   CFUUIDRef factoryID
);
Parameters
factoryID

The CFUUID object representing the plug-in factory.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
void CFPlugInAddInstanceForFactory (
   CFUUIDRef factoryID
);
#endif

/*CFPlugInRemoveInstanceForFactory

Unregisters an instance of a type with CFPlugIn.

void CFPlugInRemoveInstanceForFactory (
   CFUUIDRef factoryID
);
Parameters
factoryID

The CFUUID object representing the plug-in factory.
Discussion

If the instance counts of every factory in a plug-in are zero, the plug-in can be unloaded.]
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
void CFPlugInRemoveInstanceForFactory (
   CFUUIDRef factoryID
);
#endif

/*CFPlugInCreate

Creates a CFPlugIn given its URL.

CFPlugInRef CFPlugInCreate (
   CFAllocatorRef allocator,
   CFURLRef plugInURL
);
Parameters
allocator

The allocator to use to allocate memory for the new plug-in. Pass NULL or kCFAllocatorDefault to use the default allocator. 
plugInURL

The location of the plug-in.
Return Value

A new plug-in. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
CFPlugInRef CFPlugInCreate (
   CFAllocatorRef allocator,
   CFURLRef plugInURL
);
#endif

/*CFPlugInFindFactoriesForPlugInTypeInPlugIn

Searches the given plug-in for factory functions capable of creating an instance of the given type.

CFArrayRef CFPlugInFindFactoriesForPlugInTypeInPlugIn (
   CFUUIDRef typeUUID,
   CFPlugInRef plugIn
);
Parameters
typeUUID

A UUID type.
plugIn

The plug-in to search.
Return Value

An array of UUIDs for factory functions capable of creating an instance of the given type. 
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
CFArrayRef CFPlugInFindFactoriesForPlugInTypeInPlugIn (
   CFUUIDRef typeUUID,
   CFPlugInRef plugIn
);
#endif

/*CFPlugInInstanceCreate

Creates a CFPlugIn instance of a given type using a given factory.

void *CFPlugInInstanceCreate (
   CFAllocatorRef allocator,
   CFUUIDRef factoryUUID,
   CFUUIDRef typeUUID
);
Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the default allocator. 
factoryUUID

The UUID representing the factory function to use to create a plug-in of the given type. 
typeUUID

The UUID type.
Return Value

Returns the IUnknown interface for the new plug-in.
Discussion

The plug-in host uses this function to create an instance of the given type. Unless the plug-in is using dynamic registration, this function causes the plug-in's code to be loaded into memory. 
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
void *CFPlugInInstanceCreate (
   CFAllocatorRef allocator,
   CFUUIDRef factoryUUID,
   CFUUIDRef typeUUID
);
#endif

/*CFPlugInRegisterFactoryFunctionByName

Registers a factory function with a CFPlugIn object using the function's name instead of its UUID.

Boolean CFPlugInRegisterFactoryFunctionByName (
   CFUUIDRef factoryUUID,
   CFPlugInRef plugIn,
   CFStringRef functionName
);
Parameters
factoryUUID

The CFUUID object representing the factory function to register. 
plugIn

The plug-in containing functionName. 
functionName

The name of the factory function to register.
Return Value

true if the factory function was successfully registered, otherwise false. 
Discussion

This function is used by a plug-in or host when performing dynamic registration.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
Boolean CFPlugInRegisterFactoryFunctionByName (
   CFUUIDRef factoryUUID,
   CFPlugInRef plugIn,
   CFStringRef functionName
);
#endif

/*CFPlugInRegisterPlugInType

Registers a type and its corresponding factory function with a CFPlugIn object.

Boolean CFPlugInRegisterPlugInType (
   CFUUIDRef factoryUUID,
   CFUUIDRef typeUUID
);

Parameters
factoryUUID

The CFUUID object representing the factory function that can create the type being registered. 
typeUUID

The UUID type to register.
Return Value

true if the factory function was successfully registered, otherwise false. 
Discussion

This function is used by a plug-in or host when performing dynamic registration.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
Boolean CFPlugInRegisterPlugInType (
   CFUUIDRef factoryUUID,
   CFUUIDRef typeUUID
);
#endif

/*CFPlugInGetBundle

Returns a plug-in's bundle.

CFBundleRef CFPlugInGetBundle (
   CFPlugInRef plugIn
);

Parameters
plugIn

The plug-in whose bundle to obtain. 
Return Value

The bundle for plugIn. Ownership follows the Get Rule.
Discussion

You should always use this function to get a plug-in's bundle. Never attempt to access the plug-in directly as a bundle. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFPlugIn.h*/
#ifdef OC_CF
CFBundleRef CFPlugInGetBundle (
   CFPlugInRef plugIn
);
#endif

#ifdef __cplusplus
}
#endif


#if !COREFOUNDATION_CFPLUGINCOM_SEPARATE
#include <CoreFoundation/CFPlugInCOM.h>
#endif

#endif//CFPLUGIN_H
