#ifndef OC_CFRUNLOOP_H
#define OC_CFRUNLOOP_H


#include <CoreFoundation/CFBase.h>
#include <CoreFoundation/CFArray.h>
#include <CoreFoundation/CFDate.h>
#include <CoreFoundation/CFString.h>

#include <mach/port.h>

#ifndef OC_CF

#ifdef __linux__
	#define DEPLOYMENT_TARGET_LINUX 1
	#define DEPLOYMENT_TARGET_LINUX_DEF 1
#endif

#include "/usr/include/CoreFoundation/CFRunLoop.h"

#ifdef DEPLOYMENT_TARGET_LINUX_DEF
	#undef DEPLOYMENT_TARGET_LINUX
	#undef DEPLOYMENT_TARGET_LINUX_DEF
#endif

#endif //OC_CF

#include <HYS/CoreFoundation/CFRunLoop.h>

#if defined(__cplusplus)
extern "C" {
#endif

/*CFRunLoopTimerRef

A reference to a run loop timer object.

typedef struct __CFRunLoopTimer *CFRunLoopTimerRef;
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
typedef struct __CFRunLoopTimer *CFRunLoopTimerRef;
#endif

/*Default Run Loop Mode

Default run loop mode.

const CFStringRef kCFRunLoopDefaultMode;
Constants
kCFRunLoopDefaultMode

Run loop mode that should be used when a thread is in its default, or idle, state, waiting for an event. This mode is used when the run loop is started with CFRunLoopRun.

Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
extern const CFStringRef kCFRunLoopDefaultMode;
#endif

/*Common Mode Flag

A run loop pseudo-mode that manages objects monitored in the “common” modes.

const CFStringRef kCFRunLoopCommonModes;
Constants
kCFRunLoopCommonModes

Objects added to a run loop using this value as the mode are monitored by all run loop modes that have been declared as a member of the set of “common” modes with CFRunLoopAddCommonMode.

Available in Mac OS X v10.0 and later.
Discussion

Run loops never run in this mode. This pseudo-mode is used only as a special set of sources, timers, and observers that is shared by other modes. See “Managing Objects in a Run Loop” for more details.*/
#ifdef OC_CF
extern const CFStringRef kCFRunLoopCommonModes;
#endif

/*CFRunLoopRef

A reference to a run loop object.

typedef struct __CFRunLoop *CFRunLoopRef;
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
typedef struct __CFRunLoop *CFRunLoopRef;
#endif

/*CFRunLoopSourceRef

A reference to a run loop source object.

typedef struct __CFRunLoopSource *CFRunLoopSourceRef;
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
typedef struct __CFRunLoopSource *CFRunLoopSourceRef;
#endif

/*CFRunLoopEqualCallBack

Callback invoked to test two CFRunLoopSource objects for equality.

typedef Boolean (*CFRunLoopEqualCallBack) (
   const void *info1,
   const void *info2
);

If you name your function MyCallBack, you would declare it like this:

Boolean MyCallBack (
   const void *info1,
   const void *info2
);
Parameters
info1

The info member of the CFRunLoopSourceContext or CFRunLoopSourceContext1 structure that was used when creating the first run loop source to test.
info2

The info member of the CFRunLoopSourceContext or CFRunLoopSourceContext1 structure that was used when creating the second run loop source to test.
Return Value

true if info1 and info2 should be considered equal; otherwise false. 
Discussion

You specify this callback in the CFRunLoopSourceContext or CFRunLoopSourceContext1 structure when creating the run loop source.*/
typedef Boolean (*CFRunLoopEqualCallBack) (
   const void *info1,
   const void *info2
);

/*CFRunLoopHashCallBack

Callback invoked to compute a hash code for the info pointer of a CFRunLoopSource object.

typedef CFHashCode (*CFRunLoopHashCallBack) (
   const void *info
);

If you name your function MyCallBack, you would declare it like this:

CFHashCode MyCallBack (
   const void *info
);
Parameters
info

The info member of the CFRunLoopSourceContext or CFRunLoopSourceContext1 structure that was used when creating the run loop source.
Return Value

A hash code value for info. 
Discussion

If a hash callback is not provided for a source, the info pointer is used.

You specify this callback in the CFRunLoopSourceContext or CFRunLoopSourceContext1 structure when creating the run loop source.*/

typedef CFHashCode (*CFRunLoopHashCallBack) (
   const void *info
);

/*CFRunLoopScheduleCallBack

Callback invoked when a version 0 CFRunLoopSource object is added to a run loop mode.

typedef void (*CFRunLoopScheduleCallBack) (
   void *info,
   CFRunLoopRef rl,
   CFStringRef mode
);

If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   void *info,
   CFRunLoopRef rl,
   CFStringRef mode
);
Parameters
info

The info member of the CFRunLoopSourceContext structure that was used when creating the run loop source.
rl

The run loop in which the source is being scheduled. 
mode

The run loop mode in which the source is being scheduled. 
Discussion

You specify this callback in the CFRunLoopSourceContext structure when creating the run loop source.*/
typedef void (*CFRunLoopScheduleCallBack) (
   void *info,
   CFRunLoopRef rl,
   CFStringRef mode
);

/*CFRunLoopCancelCallBack

Callback invoked when a version 0 CFRunLoopSource object is removed from a run loop mode.

typedef void (*CFRunLoopCancelCallBack) (
   void *info,
   CFRunLoopRef rl,
   CFStringRef mode
);

If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   void *info,
   CFRunLoopRef rl,
   CFStringRef mode
);
Parameters
info

The info member of the CFRunLoopSourceContext structure that was used when creating the run loop source.
rl

The run loop from which the run loop source is being removed. 
mode

The run loop mode from which the run loop source is being removed. 
Discussion

You specify this callback in the CFRunLoopSourceContext structure when creating the run loop source.*/
typedef void (*CFRunLoopCancelCallBack) (
   void *info,
   CFRunLoopRef rl,
   CFStringRef mode
);

/*CFRunLoopPerformCallBack

Callback invoked when a message is received on a version 0 CFRunLoopSource object.

typedef void (*CFRunLoopPerformCallBack) (
   void *info
);

If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   void *info
);
Parameters
info

The info member of the CFRunLoopSourceContext structure that was used when creating the run loop source.
Discussion

You only need to provide this callback if you create your own version 0 run loop source. CFSocket run loop sources already implement this callback to forward the received message to the CFSocket’s own callback function, which you do need to implement.

You specify this callback in the CFRunLoopSourceContext structure when creating the run loop source.*/
typedef void (*CFRunLoopPerformCallBack) (
   void *info
);


/*CFRunLoopSourceContext

A structure that contains program-defined data and callbacks with which you can configure a version 0 CFRunLoopSource’s behavior.

struct CFRunLoopSourceContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
   CFRunLoopEqualCallBack equal;
   CFRunLoopHashCallBack hash;
   CFRunLoopScheduleCallBack schedule;
   CFRunLoopCancelCallBack cancel;
   CFRunLoopPerformCallBack perform;
};
typedef struct CFRunLoopSourceContext CFRunLoopSourceContext;
Fields
version

Version number of the structure. Must be 0. 
info

An arbitrary pointer to program-defined data, which can be associated with the CFRunLoopSource at creation time. This pointer is passed to all the callbacks defined in the context.
retain

A retain callback for your program-defined info pointer. Can be NULL.
release

A release callback for your program-defined info pointer. Can be NULL. 
copyDescription

A copy description callback for your program-defined info pointer. Can be NULL. 
equal

An equality test callback for your program-defined info pointer. Can be NULL.
hash

A hash calculation callback for your program-defined info pointer. Can be NULL.
schedule

A scheduling callback for the run loop source. This callback is called when the source is added to a run loop mode. Can be NULL. 
cancel

A cancel callback for the run loop source. This callback is called when the source is removed from a run loop mode. Can be NULL. 
perform

A perform callback for the run loop source. This callback is called when the source has fired.*/
#ifdef OC_CF
struct CFRunLoopSourceContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
   CFRunLoopEqualCallBack equal;
   CFRunLoopHashCallBack hash;
   CFRunLoopScheduleCallBack schedule;
   CFRunLoopCancelCallBack cancel;
   CFRunLoopPerformCallBack perform;
};
typedef struct CFRunLoopSourceContext CFRunLoopSourceContext;
#endif

/*CFRunLoopTimerContext

A structure that contains program-defined data and callbacks with which you can configure a CFRunLoopTimer’s behavior.

struct CFRunLoopTimerContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
};
typedef struct CFRunLoopTimerContext CFRunLoopTimerContext;
Fields
version

Version number of the structure. Must be 0.
info

An arbitrary pointer to program-defined data, which can be associated with the run loop timer at creation time. This pointer is passed to all the callbacks defined in the context.
retain

A retain callback for your program-defined info pointer. Can be NULL. 
release

A release callback for your program-defined info pointer. Can be NULL. 
copyDescription

A copy description callback for your program-defined info pointer. Can be NULL.*/
#ifdef OC_CF
struct CFRunLoopTimerContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
};
typedef struct CFRunLoopTimerContext CFRunLoopTimerContext;
#endif

/*CFRunLoopTimerCallBack

Callback invoked when a CFRunLoopTimer object fires.

typedef void (*CFRunLoopTimerCallBack) (
   CFRunLoopTimerRef timer,
   void *info
);

If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   CFRunLoopTimerRef timer,
   void *info
);
Parameters
timer

The run loop timer that is firing. 
info

The info member of the CFRunLoopTimerContext structure that was used when creating the run loop timer.
Discussion

If timer repeats, the run loop automatically schedules the next firing time after calling this function, unless you manually update the firing time within this callback by calling CFRunLoopTimerSetNextFireDate. If timer does not repeat, the run loop invalidates timer.

You specify this callback when you create the timer with CFRunLoopTimerCreate.*/
#ifdef OC_CF
typedef void (*CFRunLoopTimerCallBack) (
   CFRunLoopTimerRef timer,
   void *info
);
#endif

/*CFRunLoopGetPortCallBack

Callback invoked to obtain the native Mach port represented by a version 1 CFRunLoopSource object.

typedef mach_port_t (*CFRunLoopGetPortCallBack) (
   void *info
);

If you name your function MyCallBack, you would declare it like this:

mach_port_t MyCallBack (
   void *info
);

Parameters
info

The info member of the CFRunLoopSourceContext1 structure that was used when creating the run loop source.
Return Value

The native Mach port for the run loop source.
Discussion

This callback is called whenever the run loop needs a source’s Mach port, which can happen in each iteration of the run loop’s loop. Because of the frequency with which the run loop may call this callback, make the function as efficient as possible.

A version 1 run loop source must have a one-to-one relationship between itself and its Mach port. Each source must have only one Mach port associated with it and each Mach port must represent only one source.

You specify this callback in the CFRunLoopSourceContext1 structure when creating the run loop source.*/
typedef mach_port_t (*CFRunLoopGetPortCallBack) (
   void *info
);

/*CFRunLoopMachPerformCallBack

Callback invoked to process and optionally reply to a message received on a version 1 CFRunLoopSource object (Mach port-based sources).

typedef void *(*CFRunLoopMachPerformCallBack) (
   void *msg,
   CFIndex size,
   CFAllocatorRef allocator,
   void *info
);

If you name your function MyCallBack, you would declare it like this:

void *MyCallBack (
   void *msg,
   CFIndex size,
   CFAllocatorRef allocator,
   void *info
);

Parameters
msg

The Mach message received on the Mach port. The pointer is to a mach_msg_header_t structure. A version 0 format trailer (mach_msg_format_0_trailer_t) is at the end of the Mach message.
size

Size of the Mach message in msg, excluding the message trailer.
allocator

The allocator object that should be used to allocate a reply message. 
info

The info member of the CFRunLoopSourceContext1 structure that was used when creating the run loop source.
Return Value

An optional Mach message to be sent in response to the received message. The message must be allocated using allocator. Return NULL if you want an empty reply returned to the sender.
Discussion

You only need to provide this callback if you create your own version 1 run loop source. CFMachPort and CFMessagePort run loop sources already implement this callback to forward the received message to the CFMachPort’s or CFMessagePort’s own callback function, which you do need to implement.

You specify this callback in the CFRunLoopSourceContext1 structure when creating the run loop source*/
typedef void *(*CFRunLoopMachPerformCallBack) (
   void *msg,
   CFIndex size,
   CFAllocatorRef allocator,
   void *info
);

/*CFRunLoopSourceContext1

A structure that contains program-defined data and callbacks with which you can configure a version 1 CFRunLoopSource’s behavior.

struct CFRunLoopSourceContext1 {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
   CFRunLoopEqualCallBack equal;
   CFRunLoopHashCallBack hash;
   CFRunLoopGetPortCallBack getPort;
   CFRunLoopMachPerformCallBack perform;
};
typedef struct CFRunLoopSourceContext1 CFRunLoopSourceContext1;
Fields
version

Version number of the structure. Must be 1. 
info

An arbitrary pointer to program-defined data, which can be associated with the run loop source at creation time. This pointer is passed to all the callbacks defined in the context.
retain

A retain callback for your program-defined info pointer. Can be NULL. 
release

A release callback for your program-defined info pointer. Can be NULL. 
copyDescription

A copy description callback for your program-defined info pointer. Can be NULL. 
equal

An equality test callback for your program-defined info pointer. Can be NULL. 
hash

A hash calculation callback for your program-defined info pointer. Can be NULL. 
getPort

A callback to retrieve the native Mach port represented by the source. This callback is called when the source is either added to or removed from a run loop mode. 
perform

A perform callback for the run loop source. This callback is called when the source has fired. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
#ifdef OC_CF
struct CFRunLoopSourceContext1 {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
   CFRunLoopEqualCallBack equal;
   CFRunLoopHashCallBack hash;
   CFRunLoopGetPortCallBack getPort;
   CFRunLoopMachPerformCallBack perform;
};
typedef struct CFRunLoopSourceContext1 CFRunLoopSourceContext1;
#endif

/*FRunLoopObserverRef

A reference to a run loop observer object.

typedef struct __CFRunLoopObserver *CFRunLoopObserverRef;
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
typedef struct __CFRunLoopObserver *CFRunLoopObserverRef;

/*Run Loop Activities

Run loop activity stages in which run loop observers can be scheduled.

enum CFRunLoopActivity {
   kCFRunLoopEntry = (1 << 0),
   kCFRunLoopBeforeTimers = (1 << 1),
   kCFRunLoopBeforeSources = (1 << 2),
   kCFRunLoopBeforeWaiting = (1 << 5),
   kCFRunLoopAfterWaiting = (1 << 6),
   kCFRunLoopExit = (1 << 7),
   kCFRunLoopAllActivities = 0x0FFFFFFFU
};
typedef enum CFRunLoopActivity CFRunLoopActivity;

Constants
kCFRunLoopEntry

The entrance of the run loop, before entering the event processing loop. This activity occurs once for each call to CFRunLoopRun and CFRunLoopRunInMode.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopBeforeTimers

Inside the event processing loop before any timers are processed.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopBeforeSources

Inside the event processing loop before any sources are processed.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopBeforeWaiting

Inside the event processing loop before the run loop sleeps, waiting for a source or timer to fire. This activity does not occur if CFRunLoopRunInMode is called with a timeout of 0 seconds. It also does not occur in a particular iteration of the event processing loop if a version 0 source fires.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopAfterWaiting

Inside the event processing loop after the run loop wakes up, but before processing the event that woke it up. This activity occurs only if the run loop did in fact go to sleep during the current loop.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopExit

The exit of the run loop, after exiting the event processing loop. This activity occurs once for each call to CFRunLoopRun and CFRunLoopRunInMode.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopAllActivities

A combination of all the preceding stages.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
Discussion

The run loop stages in which an observer is scheduled are selected when the observer is created with CFRunLoopObserverCreate.*/
enum CFRunLoopActivity {
   kCFRunLoopEntry = (1 << 0),
   kCFRunLoopBeforeTimers = (1 << 1),
   kCFRunLoopBeforeSources = (1 << 2),
   kCFRunLoopBeforeWaiting = (1 << 5),
   kCFRunLoopAfterWaiting = (1 << 6),
   kCFRunLoopExit = (1 << 7),
   kCFRunLoopAllActivities = 0x0FFFFFFFU
};
typedef enum CFRunLoopActivity CFRunLoopActivity;

/*CFRunLoopObserverCallBack

Callback invoked when a CFRunLoopObserver object is fired.

typedef void (*CFRunLoopObserverCallBack) (
   CFRunLoopObserverRef observer,
   CFRunLoopActivity activity,
   void *info
);


If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   CFRunLoopObserverRef observer,
   CFRunLoopActivity activity,
   void *info
);
Parameters
observer

The run loop observer that is firing. 
activity

The current activity stage of the run loop. 
info

The info member of the CFRunLoopObserverContext structure that was used when creating the run loop observer.
Discussion

You specify this callback when you create the run loop observer with CFRunLoopObserverCreate.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
typedef void (*CFRunLoopObserverCallBack) (
   CFRunLoopObserverRef observer,
   CFRunLoopActivity activity,
   void *info
);

/*CFRunLoopObserverContext

A structure that contains program-defined data and callbacks with which you can configure a CFRunLoopObserver object’s behavior.

struct CFRunLoopObserverContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
};
typedef struct CFRunLoopObserverContext CFRunLoopObserverContext;

Fields
version

Version number of the structure. Must be 0.
info

An arbitrary pointer to program-defined data, which can be associated with the run loop observer at creation time. This pointer is passed to all the callbacks defined in the context.
retain

A retain callback for your program-defined info pointer. Can be NULL. 
release

A release callback for your program-defined info pointer. Can be NULL. 
copyDescription

A copy description callback for your program-defined info pointer. Can be NULL. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
struct CFRunLoopObserverContext {
   CFIndex version;
   void *info;
   CFAllocatorRetainCallBack retain;
   CFAllocatorReleaseCallBack release;
   CFAllocatorCopyDescriptionCallBack copyDescription;
};
typedef struct CFRunLoopObserverContext CFRunLoopObserverContext;

/*CFRunLoopRunInMode Exit Codes

Return codes for CFRunLoopRunInMode, identifying the reason the run loop exited.

enum {
   kCFRunLoopRunFinished = 1,
   kCFRunLoopRunStopped = 2,
   kCFRunLoopRunTimedOut = 3,
   kCFRunLoopRunHandledSource = 4
};

Constants
kCFRunLoopRunFinished

The running run loop mode has no sources or timers to process.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopRunStopped

CFRunLoopStop was called on the run loop.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopRunTimedOut

The specified time interval for running the run loop has passed.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.
kCFRunLoopRunHandledSource

A source has been processed. This value is returned only if the run loop was told to run only until a source was processed.

Available in Mac OS X v10.0 and later.

Declared in CFRunLoop.h.*/
enum {
   kCFRunLoopRunFinished = 1,
   kCFRunLoopRunStopped = 2,
   kCFRunLoopRunTimedOut = 3,
   kCFRunLoopRunHandledSource = 4
};

//function

/*CFRunLoopSourceCreate

Creates a CFRunLoopSource object.

CFRunLoopSourceRef CFRunLoopSourceCreate (
   CFAllocatorRef allocator,
   CFIndex order,
   CFRunLoopSourceContext *context
);
Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator.
order

A priority index indicating the order in which run loop sources are processed. When multiple run loop sources are firing in a single pass through the run loop, the sources are processed in increasing order of this parameter. If the run loop is set to process only one source per loop, only the highest priority source, the one with the lowest order value, is processed. This value is ignored for version 1 sources. Pass 0 unless there is a reason to do otherwise.
context

A structure holding contextual information for the run loop source. The function copies the information out of the structure, so the memory pointed to by context does not need to persist beyond the function call.
Return Value

The new CFRunLoopSource object. You are responsible for releasing this object.
Discussion

The run loop source is not automatically added to a run loop. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFRunLoopSourceRef CFRunLoopSourceCreate (
   CFAllocatorRef allocator,
   CFIndex order,
   CFRunLoopSourceContext *context
);
#endif

/*CFRunLoopAddSource

Adds a CFRunLoopSource object to a run loop mode.

void CFRunLoopAddSource (
   CFRunLoopRef rl,
   CFRunLoopSourceRef source,
   CFStringRef mode
);
Parameters
rl

The run loop to modify. 
source

The run loop source to add. 
mode

The run loop mode to which to add source. Use the constant kCFRunLoopCommonModes to add source to the set of objects monitored by all the common modes. 
Discussion

If source is a version 0 source, this function calls the schedule callback function specified in the context structure for source. See CFRunLoopSourceContext for more details.

A run loop source can be registered in multiple run loops and run loop modes at the same time. When the source is signaled, whichever run loop that happens to detect the signal first will fire the source.

If rl already contains source in mode, this function does nothing.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopAddSource (
   CFRunLoopRef rl,
   CFRunLoopSourceRef source,
   CFStringRef mode
);
#endif


/*CFRunLoopGetCurrent

Returns the CFRunLoop object for the current thread.

CFRunLoopRef CFRunLoopGetCurrent ();
Return Value

Current thread’s run loop. Ownership follows the Get Rule.
Discussion

Each thread has exactly one run loop associated with it.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFRunLoopRef CFRunLoopGetCurrent ();
#endif

/*CFRunLoopRun

Runs the current thread’s CFRunLoop object in its default mode indefinitely.

void CFRunLoopRun ();
Discussion

The current thread’s run loop runs in the default mode (see "Default Run Loop Mode") until the run loop is stopped with CFRunLoopStop or all the sources and timers are removed from the default run loop mode.

Run loops can be run recursively. You can call CFRunLoopRun from within any run loop callout and create nested run loop activations on the current thread’s call stack.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopRun ();
#endif

/*CFRunLoopStop

Forces a CFRunLoop object to stop running.

void CFRunLoopStop (
   CFRunLoopRef rl
);
Parameters
rl

The run loop to stop.
Discussion

This function forces rl to stop running and return control to the function that called CFRunLoopRun or CFRunLoopRunInMode for the current run loop activation. If the run loop is nested with a callout from one activation starting another activation running, only the innermost activation is exited.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopStop (
   CFRunLoopRef rl
);
#endif

/*CFRunLoopSourceInvalidate

Invalidates a CFRunLoopSource object, stopping it from ever firing again.

void CFRunLoopSourceInvalidate (
   CFRunLoopSourceRef source
);
Parameters
source

The run loop source to invalidate.
Discussion

Once invalidated, source will never fire and call its perform callback function again. This function automatically removes source from all the run loop modes in which it was registered. If source is a version 0 source, this function calls its cancel callback function as it is removed from each run loop mode. The memory for source is not deallocated unless the run loop held the only reference to source.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopSourceInvalidate (
   CFRunLoopSourceRef source
);
#endif

/*CFRunLoopGetTypeID

Returns the type identifier for the CFRunLoop opaque type.

CFTypeID CFRunLoopGetTypeID ();
Return Value

The type identifier for the CFRunLoop opaque type.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTypeID CFRunLoopGetTypeID ();
#endif

/*CFRunLoopRunInMode

Runs the current thread’s CFRunLoop object in a particular mode.

SInt32 CFRunLoopRunInMode (
   CFStringRef mode,
   CFTimeInterval seconds,
   Boolean returnAfterSourceHandled
);
Parameters
mode

The run loop mode to run. mode can be any arbitrary CFString. You do not need to explicitly create a run loop mode, although a run loop mode needs to contain at least one source or timer to run.
seconds

The length of time to run the run loop. If 0, only one pass is made through the run loop before returning; if multiple sources or timers are ready to fire immediately, only one (possibly two if one is a version 0 source) will be fired, regardless of the value of returnAfterSourceHandled.
returnAfterSourceHandled

A flag indicating whether the run loop should exit after processing one source. If false, the run loop continues processing events until seconds has passed.
Return Value

A value indicating the reason the run loop exited. Possible values are described below.
Discussion

Run loops can be run recursively. You can call CFRunLoopRunInMode from within any run loop callout and create nested run loop activations on the current thread’s call stack. You are not restricted in which modes you can run from within a callout. You can create another run loop activation running in any available run loop mode, including any modes already running higher in the call stack.

The run loop exits with the following return values under the indicated conditions:
kCFRunLoopRunFinished. The run loop mode mode has no sources or timers.
kCFRunLoopRunStopped. The run loop was stopped with CFRunLoopStop.
kCFRunLoopRunTimedOut. The time interval seconds passed.
kCFRunLoopRunHandledSource. A source was processed. This exit condition only applies when returnAfterSourceHandled is true.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
SInt32 CFRunLoopRunInMode (
   CFStringRef mode,
   CFTimeInterval seconds,
   Boolean returnAfterSourceHandled
);
#endif

/*CFRunLoopRemoveSource

Removes a CFRunLoopSource object from a run loop mode.

void CFRunLoopRemoveSource (
   CFRunLoopRef rl,
   CFRunLoopSourceRef source,
   CFStringRef mode
);
Parameters
rl

The run loop to modify. 
source

The run loop source to remove. 
mode

The run loop mode of rl from which to remove source. Use the constant kCFRunLoopCommonModes to remove source from the set of objects monitored by all the common modes. 
Discussion

If source is a version 0 source, this function calls the cancel callback function specified in the context structure for source. See CFRunLoopSourceContext and CFRunLoopSourceContext1for more details.

If rl does not contain source in mode, this function does nothing.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopRemoveSource (
   CFRunLoopRef rl,
   CFRunLoopSourceRef source,
   CFStringRef mode
);
#endif

/*CFRunLoopTimerInvalidate

Invalidates a CFRunLoopTimer object, stopping it from ever firing again.

void CFRunLoopTimerInvalidate (
   CFRunLoopTimerRef timer
);
Parameters
timer

The run loop timer to invalidate. 
Discussion

Once invalidated, timer will never fire and call its callback function again. This function automatically removes timer from all run loop modes in which it had been added. The memory is not deallocated unless the run loop held the only reference to timer.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopTimerInvalidate (
   CFRunLoopTimerRef timer
);
#endif

/*CFRunLoopAddTimer

Adds a CFRunLoopTimer object to a run loop mode.

void CFRunLoopAddTimer (
   CFRunLoopRef rl,
   CFRunLoopTimerRef timer,
   CFStringRef mode
);
Parameters
rl

The run loop to modify. 
timer

The run loop timer to add. 
mode

The run loop mode of rl to which to add timer. Use the constant kCFRunLoopCommonModes to add timer to the set of objects monitored by all the common modes. 
Discussion

A run loop timer can be registered in only one run loop at a time, although it can be added to multiple run loop modes within that run loop.

If rl already contains timer in mode, this function does nothing.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopAddTimer (
   CFRunLoopRef rl,
   CFRunLoopTimerRef timer,
   CFStringRef mode
);
#endif

/*CFRunLoopTimerCreate

Creates a new CFRunLoopTimer object.

CFRunLoopTimerRef CFRunLoopTimerCreate (
   CFAllocatorRef allocator,
   CFAbsoluteTime fireDate,
   CFTimeInterval interval,
   CFOptionFlags flags,
   CFIndex order,
   CFRunLoopTimerCallBack callout,
   CFRunLoopTimerContext *context
);
Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
fireDate

The time at which the timer should first fire. The fine precision (sub-millisecond at most) of the fire date may be adjusted slightly by the timer if there are implementation reasons to do.
interval

The firing interval of the timer. If 0 or negative, the timer fires once and then is automatically invalidated. The fine precision (sub-millisecond at most) of the interval may be adjusted slightly by the timer if implementation reasons to do so exist.
flags

Currently ignored. Pass 0 for future compatibility.
order

A priority index indicating the order in which run loop timers are processed. Run loop timers currently ignore this parameter. Pass 0.
callout

The callback function that is called when the timer fires. 
context

A structure holding contextual information for the run loop timer. The function copies the information out of the structure, so the memory pointed to by context does not need to persist beyond the function call. Can be NULL if the callback function does not need the context’s info pointer to keep track of state. 
Return Value

The new CFRunLoopTimer object. Ownership follows the Create Rule.
Discussion

A timer needs to be added to a run loop mode before it will fire. To add the timer to a run loop, use CFRunLoopAddTimer. A timer can be registered to only one run loop at a time, although it can be in multiple modes within that run loop.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFRunLoopTimerRef CFRunLoopTimerCreate (
   CFAllocatorRef allocator,
   CFAbsoluteTime fireDate,
   CFTimeInterval interval,
   CFOptionFlags flags,
   CFIndex order,
   CFRunLoopTimerCallBack callout,
   CFRunLoopTimerContext *context
);
#endif

/*CFRunLoopTimerSetNextFireDate

Sets the next firing date for a CFRunLoopTimer object .

void CFRunLoopTimerSetNextFireDate (
   CFRunLoopTimerRef timer,
   CFAbsoluteTime fireDate
);
Parameters
timer

The run loop timer to modify. 
fireDate

The new firing time for timer. 
Discussion

Resetting a timer’s next firing time is a relatively expensive operation and should not be done if it can be avoided; letting timers autorepeat is more efficient. In some cases, however, manually-adjusted, repeating timers are useful. For example, if you have an action that will be performed multiple times in the future, but at irregular time intervals, it would be very expensive to create, add to run loop modes, and then destroy a timer for each firing event. Instead, you can create a repeating timer with an initial firing time in the distant future (or the initial firing time) and a very large repeat interval?on the order of decades or more?and add it to all the necessary run loop modes. Then, when you know when the timer should fire next, you reset the firing time with CFRunLoopTimerSetNextFireDate, perhaps from the timer’s own callback function. This technique effectively produces a reusable, asynchronous timer.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopTimerSetNextFireDate (
   CFRunLoopTimerRef timer,
   CFAbsoluteTime fireDate
);
#endif

/*CFRunLoopTimerGetInterval

Returns the firing interval of a repeating CFRunLoopTimer object.

CFTimeInterval CFRunLoopTimerGetInterval (
   CFRunLoopTimerRef timer
);
Parameters
timer

The run loop timer to examine. 
Return Value

The firing interval of timer. Returns 0 if timer does not repeat. 
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTimeInterval CFRunLoopTimerGetInterval (
   CFRunLoopTimerRef timer
);
#endif

/*CFRunLoopContainsSource

Returns a Boolean value that indicates whether a run loop mode contains a particular CFRunLoopSource object.

Boolean CFRunLoopContainsSource (
   CFRunLoopRef rl,
   CFRunLoopSourceRef source,
   CFStringRef mode
);
Parameters
rl

The run loop to examine. 
source

The run loop source for which to search. 
mode

The run loop mode of rl in which to search. Use the constant kCFRunLoopCommonModes to search for source in the set of objects monitored by all the common modes. 
Return Value

true if source is in mode mode of the run loop rl, otherwise false. 
Discussion

If source was added to kCFRunLoopCommonModes, this function returns true if mode is either kCFRunLoopCommonModes or any of the modes that has been added to the set of common modes.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
Boolean CFRunLoopContainsSource (
   CFRunLoopRef rl,
   CFRunLoopSourceRef source,
   CFStringRef mode
);
#endif

/*CFRunLoopRemoveTimer

Removes a CFRunLoopTimer object from a run loop mode.

void CFRunLoopRemoveTimer (
   CFRunLoopRef rl,
   CFRunLoopTimerRef timer,
   CFStringRef mode
);

Parameters
rl

The run loop to modify. 
timer

The run loop timer to remove. 
mode

The run loop mode of rl from which to remove timer. Use the constant kCFRunLoopCommonModes to remove timer from the set of objects monitored by all the common modes. 
Discussion

If rl does not contain timer in mode, this function does nothing.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRunLoopRemoveTimer (
   CFRunLoopRef rl,
   CFRunLoopTimerRef timer,
   CFStringRef mode
);
#endif

/*CFRunLoopCopyCurrentMode

Returns the name of the mode in which a given run loop is currently running.

CFStringRef CFRunLoopCopyCurrentMode (
   CFRunLoopRef rl
);
Parameters
rl

The run loop to examine.
Return Value

The mode in which rl is currently running; NULL if rl is not running. Ownership follows the Create Rule.
Discussion

When run on the current thread’s run loop, the returned value identifies the run loop mode that made the callout in which your code is currently executing.
Availability
Available in Mac OS X v10.0 and later.
See Also
CFRunLoopAddCommonMode
CFRunLoopCopyAllModes
Declared In
CFRunLoop.h*/
#ifdef OC_CF
CFStringRef CFRunLoopCopyCurrentMode (
   CFRunLoopRef rl
);
#endif

/*CFRunLoopIsWaiting

Returns a Boolean value that indicates whether the run loop is waiting for an event.

Boolean CFRunLoopIsWaiting (
   CFRunLoopRef rl
);

Parameters
rl

The run loop to examine.
Return Value

true if rl has no events to process and is blocking, waiting for a source or timer to become ready to fire; false if rl either is not running or is currently processing a source, timer, or observer.
Discussion

This function is useful only to test the state of another thread’s run loop. When called with the current thread’s run loop, this function always returns false.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
#ifdef OC_CF
Boolean CFRunLoopIsWaiting (
   CFRunLoopRef rl
);
#endif

/*CFRunLoopSourceSignal

Signals a CFRunLoopSource object, marking it as ready to fire.

void CFRunLoopSourceSignal (
   CFRunLoopSourceRef source
);

Parameters
source

The run loop source to signal.
Discussion

This function has no effect on version 1 sources, which are automatically handled when Mach messages arrive for them. After signaling a version 0 source, you need to call CFRunLoopWakeUp on one of the run loops in which the source is registered to get the source handled immediately.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
#ifdef OC_CF
void CFRunLoopSourceSignal (
   CFRunLoopSourceRef source
);
#endif

/*CFRunLoopWakeUp

Wakes a waiting CFRunLoop object.

void CFRunLoopWakeUp (
   CFRunLoopRef rl
);
Parameters
rl

The run loop to wake up.
Discussion

A run loop goes to sleep when it is waiting for a source or timer to become ready to fire. If no source or timer fires, the run loop stays there until it times out or is explicitly woken up. If a run loop is modified, such as a new source added, you need to wake up the run loop to allow it to process the change. Version 0 sources use CFRunLoopWakeUp to cause the run loop to wake up after setting a source to be signaled, if they want the source handled immediately.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
#ifdef OC_CF
void CFRunLoopWakeUp (
   CFRunLoopRef rl
);
#endif

/*CFRunLoopSourceIsValid

Returns a Boolean value that indicates whether a CFRunLoopSource object is valid and able to fire.

Boolean CFRunLoopSourceIsValid (
   CFRunLoopSourceRef source
);
Parameters
source

The run loop source to examine.
Return Value

true if source is valid, otherwise false.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
#ifdef OC_CF
Boolean CFRunLoopSourceIsValid (
   CFRunLoopSourceRef source
);
#endif

/*CFRunLoopGetMain

Returns the main CFRunLoop object.

CFRunLoopRef CFRunLoopGetMain (
   void
);

Return Value

The main run loop. Ownership follows the Get Rule.
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFRunLoop.h*/
#ifdef OC_CF
CFRunLoopRef CFRunLoopGetMain (
   void
);
#endif

/*CFRunLoopAddObserver

Adds a CFRunLoopObserver object to a run loop mode.

void CFRunLoopAddObserver (
   CFRunLoopRef rl,
   CFRunLoopObserverRef observer,
   CFStringRef mode
);
Parameters
rl

The run loop to modify. 
observer

The run loop observer to add.
mode

The run loop mode to which to add observer. Use the constant kCFRunLoopCommonModes to add observer to the set of objects monitored by all the common modes. 
Discussion

A run loop observer can be registered in only one run loop at a time, although it can be added to multiple run loop modes within that run loop.

If rl already contains observer in mode, this function does nothing.
Availability
Available in Mac OS X v10.0 and later.
See Also
CFRunLoopContainsObserver
CFRunLoopRemoveObserver
Declared In
CFRunLoop.h*/
void CFRunLoopAddObserver (
   CFRunLoopRef rl,
   CFRunLoopObserverRef observer,
   CFStringRef mode
);

/*CFRunLoopRemoveObserver

Removes a CFRunLoopObserver object from a run loop mode.

void CFRunLoopRemoveObserver (
   CFRunLoopRef rl,
   CFRunLoopObserverRef observer,
   CFStringRef mode
);

Parameters
rl

The run loop to modify. 
observer

The run loop observer to remove. 
mode

The run loop mode of rl from which to remove observer. Use the constant kCFRunLoopCommonModes to remove observer from the set of objects monitored by all the common modes. 
Discussion

If rl does not contain observer in mode, this function does nothing.
Availability
Available in Mac OS X v10.0 and later.
See Also
CFRunLoopAddObserver
CFRunLoopContainsObserver
Declared In
CFRunLoop.h*/
void CFRunLoopRemoveObserver (
   CFRunLoopRef rl,
   CFRunLoopObserverRef observer,
   CFStringRef mode
);

/*CFRunLoopObserverInvalidate

Invalidates a CFRunLoopObserver object, stopping it from ever firing again.

void CFRunLoopObserverInvalidate (
   CFRunLoopObserverRef observer
);

Parameters
observer

The run loop observer to invalidate. 
Discussion

Once invalidated, observer will never fire and call its callback function again. This function automatically removes observer from all run loop modes in which it had been added. The memory is not deallocated unless the run loop held the only reference to observer.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFRunLoop.h*/
void CFRunLoopObserverInvalidate (
   CFRunLoopObserverRef observer
);

#ifdef __cplusplus
}
#endif

#define HYS_COREFOUNDATION_CFRUNLOOP_H_END
#include <HYS/CoreFoundation/CFRunLoop.h>

#endif //CFRUNLOOP_H

