#ifndef OC_CFTIMEZONE_H
#define OC_CFTIMEZONE_H

#include <CoreFoundation/CFBase.h>
#include <CoreFoundation/CFArray.h>
#include <CoreFoundation/CFData.h>
#include <CoreFoundation/CFDate.h>
#include <CoreFoundation/CFDictionary.h>
#include <CoreFoundation/CFString.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFTimeZone.h"
#endif //OC_CF


#if defined(__cplusplus)
extern "C" {
#endif


/*CFTimeZoneNameStyle

Para

typedef CFIndex CFTimeZoneNameStyle;

Discussion

For values, see “Time Zone Name Styles.”
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
typedef CFIndex CFTimeZoneNameStyle;
#endif

//function

/*CFTimeZoneCopySystem

Returns the time zone currently used by the system.

CFTimeZoneRef CFTimeZoneCopySystem ();
Return Value

A time zone representing the time zone currently used by the system, or the GMT time zone if the current zone cannot be determined. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTimeZoneRef CFTimeZoneCopySystem ();
#endif

/*CFTimeZoneGetName

Returns the geopolitical region name that identifies a given time zone.

CFStringRef CFTimeZoneGetName (
   CFTimeZoneRef tz
);
Parameters
tz

The time zone to analyze.
Return Value

A string containing the geopolitical region name that identifies tz. Ownership follows the Get Rule.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
CFStringRef CFTimeZoneGetName (
   CFTimeZoneRef tz
);
#endif

/*CFTimeZoneCopyDefault

Returns the default time zone set for your application. 

CFTimeZoneRef CFTimeZoneCopyDefault (
   void
);

Return Value

A time zone representing the default time zone set for your application, or the system time zone if no default is set. Ownership follows the Create Rule.
Discussion

If no default time zone is set, this function simply returns the result of the CFTimeZoneCopySystem function.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
CFTimeZoneRef CFTimeZoneCopyDefault (
   void
);
#endif

/*CFTimeZoneGetSecondsFromGMT

Returns the difference in seconds between the receiver and Greenwich Mean Time (GMT) at the specified date.

CFTimeInterval CFTimeZoneGetSecondsFromGMT (
   CFTimeZoneRef tz,
   CFAbsoluteTime at
);

Parameters
tz

The time zone to analyze.
at

The date at which the interval is to be computed.
Return Value

The difference in seconds between tz and GMT at the specified date, at.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
CFTimeInterval CFTimeZoneGetSecondsFromGMT (
   CFTimeZoneRef tz,
   CFAbsoluteTime at
);
#endif

/*CFTimeZoneGetData

Returns the data that stores the information used by a time zone.

CFDataRef CFTimeZoneGetData (
   CFTimeZoneRef tz
);

Parameters
tz

The time zone to analyze.
Return Value

The data used to store tz. Ownership follows the Get Rule.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
CFDataRef CFTimeZoneGetData (
   CFTimeZoneRef tz
);
#endif

/*CFTimeZoneCopyAbbreviation

Returns the abbreviation of a time zone at a specified date. 

CFStringRef CFTimeZoneCopyAbbreviation (
   CFTimeZoneRef tz,
   CFAbsoluteTime at
);

Parameters
tz

The time zone to use.
at

The absolute time at which to obtain the abbreviation.
Return Value

A string containing the time zone abbreviation of at. Ownership follows the Create Rule.
Discussion

Note that the abbreviation may be different at different dates. For example, during daylight savings time the US/Eastern time zone has an abbreviation of "EDT." At other times, its abbreviation is "EST."
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
CFStringRef CFTimeZoneCopyAbbreviation (
   CFTimeZoneRef tz,
   CFAbsoluteTime at
);
#endif

/*CFTimeZoneIsDaylightSavingTime

Returns whether or not a time zone is in daylight savings time at a specified date.

Boolean CFTimeZoneIsDaylightSavingTime (
   CFTimeZoneRef tz,
   CFAbsoluteTime at
);

Parameters
tz

The time zone to analyze.
at

The date in tz to test for daylight savings.
Return Value

true if tz is in daylight savings time at at, otherwise false.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
Boolean CFTimeZoneIsDaylightSavingTime (
   CFTimeZoneRef tz,
   CFAbsoluteTime at
);
#endif

/*CFTimeZoneCreateWithName

Returns the time zone object identified by a given name or abbreviation. 

CFTimeZoneRef CFTimeZoneCreateWithName (
   CFAllocatorRef allocator,
   CFStringRef name,
   Boolean tryAbbrev
);
Parameters
allocator

The allocator object to use to allocate memory for the new time zone. Pass NULL or kCFAllocatorDefault to use the current default allocator.
name

The name or abbreviation of the time zone to obtain. The name may be in any of the formats understood by the system, for example "EST", "Etc/GMT-2", "America/Argentina/Buenos_Aires", "Europe/Monaco", "US/Pacific", or "posixrules". For a complete list of system names, you can see the output of CFTimeZoneCopyKnownNames.
tryAbbrev

If false, assumes name is not an abbreviation and searches the time zone information directory for a matching name. If true, tries to resolve name using the abbreviation dictionary first before searching the information dictionary.
Return Value

A time zone corresponding to name, or NULL if no match was found. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
CFTimeZoneRef CFTimeZoneCreateWithName (
   CFAllocatorRef allocator,
   CFStringRef name,
   Boolean tryAbbrev
);
#endif

/*CFTimeZoneCreateWithTimeIntervalFromGMT

Returns a time zone object for the specified time interval offset from Greenwich Mean Time (GMT). 

CFTimeZoneRef CFTimeZoneCreateWithTimeIntervalFromGMT (
   CFAllocatorRef allocator,
   CFTimeInterval ti
);

Parameters
allocator

The allocator object to use to allocate memory for the new time zone. Pass NULL or kCFAllocatorDefault to use the current default allocator.
ti

The offset, from GMT, of the new time zone.
Return Value

A new time zone whose offset from GMT is given by the interval ti. The name of the new time zone is GMT +/- the offset, in hours and minutes. Time zones created with this function never have daylight savings, and the offset is constant no matter what the date. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTimeZone.h*/
#ifdef OC_CF
CFTimeZoneRef CFTimeZoneCreateWithTimeIntervalFromGMT (
   CFAllocatorRef allocator,
   CFTimeInterval ti
);
#endif

#ifdef __cplusplus
}
#endif

#endif//OC_CFTIMEZONE_H
