#ifndef OC_CFTREE_H
#define OC_CFTREE_H

#include <CoreFoundation/CFBase.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFTree.h"
#endif //OC_CF



#if defined(__cplusplus)
extern "C" {
#endif

/*CFTreeRef

A reference to a CFTree object.

typedef struct __CFTree *CFTreeRef;
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
typedef struct __CFTree *CFTreeRef;
#endif

/*CFTreeRetainCallBack

Callback function used to retain a program-defined information pointer.

typedef const void *(*CFTreeRetainCallBack) (
const void *info
);


If you name your function MyCallBack, you would declare it like this:

const void *MyCallBack (
   const void *info
);
Parameters
info

The program-supplied information pointer provided in a CFTreeContext structure.
Return Value

The value to use whenever the information pointer is retained, which is usually the info parameter passed to this callback, but may be a different value if a different value should be used.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
typedef const void *(*CFTreeRetainCallBack) (
const void *info
);
#endif

/*CFTreeReleaseCallBack

Callback function used to release a previously retained program-defined information pointer.

typedef void (*CFTreeReleaseCallBack) (
   const void *info
);


If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   const void *info
);
Parameters
info

The program-supplied information pointer provided in a CFTreeContext structure.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
typedef void (*CFTreeReleaseCallBack) (
   const void *info
);
#endif

/*CFTreeCopyDescriptionCallBack

Callback function used to provide a description of the program-defined information pointer.

typedef CFStringRef (*CFTreeCopyDescriptionCallBack) (
   const void *info
);


If you name your function MyCallBack, you would declare it like this:

CFStringRef MyCallBack (
   const void *info
);
Parameters
info

The program-supplied information pointer provided in a CFTreeContext structure.
Return Value

A textual description of info. The caller is responsible for releasing this object.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
typedef CFStringRef (*CFTreeCopyDescriptionCallBack) (
   const void *info
);
#endif

/*CFTreeContext

Structure containing program-defined data and callbacks for a CFTree object.

struct CFTreeContext {
   CFIndex version;
   void *info;
   CFTreeRetainCallBack retain;
   CFTreeReleaseCallBack release;
   CFTreeCopyDescriptionCallBack copyDescription;
};
typedef struct CFTreeContext CFTreeContext;

Fields
version

The version number of the structure type being passed in as a parameter to a CFTree creation function. This structure is version 0.
info

A C pointer to a program-defined block of data, referred to as the information pointer.
retain

The callback used to retain the info field. If this parameter is not a pointer to a function of the correct prototype, the behavior is undefined. This value may be NULL.
release

The callback used to release a previously retained info field. If this parameter is not a pointer to a function of the correct prototype, the behavior is undefined. This value may be NULL.
copyDescription

The callback used to provide a description of the info field.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
struct CFTreeContext {
   CFIndex version;
   void *info;
   CFTreeRetainCallBack retain;
   CFTreeReleaseCallBack release;
   CFTreeCopyDescriptionCallBack copyDescription;
};
typedef struct CFTreeContext CFTreeContext;
#endif

/*CFTreeApplierFunction

Type of the callback function used by the CFTree apply function.

typedef void (*CFTreeApplierFunction) (
   const void *value,
   void *context
);


If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   const void *value,
   void *context
);
Parameters
value

The current child of a tree that is being iterated.
context

The program-defined context parameter that was passed to the applier function.
Discussion

This callback is used by the CFTreeApplyFunctionToChildren applier function.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
typedef void (*CFTreeApplierFunction) (
   const void *value,
   void *context
);
#endif

//func

/*CFTreeGetChildCount

Returns the number of children in a tree.

CFIndex CFTreeGetChildCount (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The number of children in tree.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFIndex CFTreeGetChildCount (
   CFTreeRef tree
);
#endif

/*CFTreeGetChildAtIndex

Returns the child of a tree at the specified index.

CFTreeRef CFTreeGetChildAtIndex (
   CFTreeRef tree,
   CFIndex idx
);
Parameters
tree

The tree to examine.
idx

The index of the child obtain. The value must be less than the number of children in tree.
Return Value

The child tree at idx. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTreeRef CFTreeGetChildAtIndex (
   CFTreeRef tree,
   CFIndex idx
);
#endif

/*CFTreeAppendChild

Adds a new child to a tree as the last in its list of children.

void CFTreeAppendChild (
   CFTreeRef tree,
   CFTreeRef newChild
);

Parameters
tree

The tree to which to add newChild.
newChild

The child tree to add to tree. If this parameter is a tree which is already a child of any other tree, the behavior is undefined.
Discussion

When a child tree is added to another tree, the child tree is retained by its new parent.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeAppendChild (
   CFTreeRef tree,
   CFTreeRef newChild
);
#endif


/*CFTreeGetParent

Returns the parent of a given tree.

CFTreeRef CFTreeGetParent (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The parent of tree. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeGetParent (
   CFTreeRef tree
);
#endif

/*CFTreeCreate

Creates a new CFTree object.

CFTreeRef CFTreeCreate (
   CFAllocatorRef allocator,
   const CFTreeContext *context
);

Parameters
allocator

The allocator to use to allocate memory for the new tree. Pass NULL or kCFAllocatorDefault to use the current default allocator.
context

The CFTreeContext structure to be copied and used as the context of the new tree. The information pointer will be retained by the tree if a retain function is provided. If this value is not a valid C pointer to a CFTreeContext structure-sized block of storage, the result is undefined. If the version number of the storage is not a valid CFTreeContext version number, the result is undefined.
Return Value

A new CFTree object. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeCreate (
   CFAllocatorRef allocator,
   const CFTreeContext *context
);
#endif

/*CFTreeGetContext

Returns the context of the specified tree.

void CFTreeGetContext (
   CFTreeRef tree,
   CFTreeContext *context
);
Parameters
tree

The tree to examine.
context

The CFTreeContext structure to be filled in with the context of the specified tree. This value must be a valid C pointer to a CFTreeContext structure-sized block of storage. If the version number of the storage is not a valid CFTreeContext structure version number, the result is undefined.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeGetContext (
   CFTreeRef tree,
   CFTreeContext *context
);
#endif

/*CFTreeGetFirstChild

Returns the first child of a tree.

CFTreeRef CFTreeGetFirstChild (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The first child of tree. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeGetFirstChild (
   CFTreeRef tree
);
#endif

/*CFTreeGetNextSibling

Returns the next sibling, adjacent to a given tree, in the parent's children list.

CFTreeRef CFTreeGetNextSibling (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The next sibling, adjacent to tree. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeGetNextSibling (
   CFTreeRef tree
);
#endif

/*CFTreeRemoveAllChildren

Removes all the children of a tree.

void CFTreeRemoveAllChildren (
   CFTreeRef tree
);
Parameters
tree

The tree to modify.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeRemoveAllChildren (
   CFTreeRef tree
);
#endif

/*CFTreeSetContext

Replaces the context of a tree by releasing the old information pointer and retaining the new one.

void CFTreeSetContext (
   CFTreeRef tree,
   const CFTreeContext *context
);

Parameters
tree

The tree to modify.
context

The CFTreeContext structure to be copied and used as the context of the new tree. The information pointer will be retained by the tree if a retain function is provided. If this value is not a valid C pointer to a CFTreeContext structure-sized block of storage, the result is undefined. If the version number of the storage is not a valid CFTreeContext version number, the result is undefined.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeSetContext (
   CFTreeRef tree,
   const CFTreeContext *context
);
#endif

#ifdef __cplusplus
}
#endif

#endif//CFTREE_H

