#ifndef OC_CFUSERNOTIFICATION_H
#define OC_CFUSERNOTIFICATION_H

#include <CoreFoundation/CFBase.h>
#include <CoreFoundation/CFDate.h>
#include <CoreFoundation/CFDictionary.h>
#include <CoreFoundation/CFString.h>
#include <CoreFoundation/CFURL.h>
#include <CoreFoundation/CFRunLoop.h>

#ifndef OC_CF
#include "/usr/include/CoreFoundation/CFUserNotification.h"
#endif //OC_CF


#if defined(__cplusplus)
extern "C" {
#endif

/*Response Codes

Response codes identifying the button that was pressed to dismiss a notification dialog.

enum {
   kCFUserNotificationDefaultResponse = 0,
   kCFUserNotificationAlternateResponse = 1,
   kCFUserNotificationOtherResponse = 2,
   kCFUserNotificationCancelResponse = 3
};
Constants
kCFUserNotificationDefaultResponse

The default button was pressed.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationAlternateResponse

The alternate button was pressed.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationOtherResponse

The third button was pressed.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationCancelResponse

No button was pressed and the notification timed out.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
Discussion

To extract this value from the response flags of a dismissed notification (such as returned by CFUserNotificationReceiveResponse), you must perform a bitwise-AND operation between the returned response flags and 0x3 before comparing the value to these constants.*/
#ifdef OC_CF
enum {
   kCFUserNotificationDefaultResponse = 0,
   kCFUserNotificationAlternateResponse = 1,
   kCFUserNotificationOtherResponse = 2,
   kCFUserNotificationCancelResponse = 3
};
#endif

/*Alert Levels

Flags identifying the seriousness of a user notification.

enum {
   kCFUserNotificationStopAlertLevel = 0,
   kCFUserNotificationNoteAlertLevel = 1,
   kCFUserNotificationCautionAlertLevel = 2,
   kCFUserNotificationPlainAlertLevel= 3
};
Constants
kCFUserNotificationStopAlertLevel

The notification is very serious.

A stop icon is displayed by default.

Available in Mac OS X v10.0 and later.
kCFUserNotificationNoteAlertLevel

The notification is not very serious.

A note icon is displayed by default.

Available in Mac OS X v10.0 and later.
kCFUserNotificationCautionAlertLevel

The notification is somewhat serious. 

A caution icon is displayed by default.

Available in Mac OS X v10.0 and later.
kCFUserNotificationPlainAlertLevel

The notification is not serious. 

An information icon is displayed by default.

Available in Mac OS X v10.0 and later.
Discussion

If you specify an icon to display in the dialog, this icon overrides the default icon used for each alert level.*/
#ifdef OC_CF
enum {
   kCFUserNotificationStopAlertLevel = 0,
   kCFUserNotificationNoteAlertLevel = 1,
   kCFUserNotificationCautionAlertLevel = 2,
   kCFUserNotificationPlainAlertLevel= 3
};
#endif

/*CFUserNotificationRef

A reference to a user notification object.

typedef struct __CFUserNotification *CFUserNotificationRef;
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFUserNotification.h*/
#ifdef OC_CF
typedef struct __CFUserNotification *CFUserNotificationRef;
#endif

/*CFUserNotificationCallBack

Callback invoked when an asynchronous user notification dialog is dismissed.

typedef void (*CFUserNotificationCallBack) (
   CFUserNotificationRef userNotification,
   CFOptionFlags responseFlags
);

If you name your function MyCallBack, you would declare it like this:

void MyCallBack (
   CFUserNotificationRef userNotification,
   CFOptionFlags responseFlags
);

Parameters
userNotification

The user notification that was dismissed.
responseFlags

On return, contains flags identifying how the notification was dismissed, the state of any checkboxes, and the selected item of the pop-up menu. See CFUserNotificationReceiveResponse for details.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFUserNotification.h*/
#ifdef OC_CF
typedef void (*CFUserNotificationCallBack) (
   CFUserNotificationRef userNotification,
   CFOptionFlags responseFlags
);
#endif

//function

/*CFUserNotificationDisplayNotice

Displays a user notification dialog that does not need a user response.

SInt32 CFUserNotificationDisplayNotice (
   CFTimeInterval timeout,
   CFOptionFlags flags,
   CFURLRef iconURL,
   CFURLRef soundURL,
   CFURLRef localizationURL,
   CFStringRef alertHeader,
   CFStringRef alertMessage,
   CFStringRef defaultButtonTitle
);
Parameters
timeout

The amount of time to wait for the user to dismiss the notification dialog before the dialog dismisses itself. Pass 0 to have the dialog never time out.
flags

A set of flags describing the type of notification dialog to display. The value is normally just the alert level from Alert Levels. If you don’t want a default button displayed, perform a bitwise-OR operation with the alert level and the constant kCFUserNotificationNoDefaultButtonFlag.
iconURL

A file URL pointing to the icon to display in the dialog. If NULL, a default icon is used based on the notification’s alert level specified in flags.
soundURL

Not used.
localizationURL

A file URL pointing to a bundle that contains localized versions of the strings displayed in the dialog. Can be NULL.
alertHeader

The title of the notification dialog. Cannot be NULL.
alertMessage

The message string to display in the dialog. Can be NULL.
defaultButtonTitle

The title of the default button. If NULL, the string OK is used.
Return Value

0 if the cancel was successful; a non-0 value otherwise.
Discussion

This function returns immediately. It does not wait for a user response after displaying the dialog.
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
SInt32 CFUserNotificationDisplayNotice (
   CFTimeInterval timeout,
   CFOptionFlags flags,
   CFURLRef iconURL,
   CFURLRef soundURL,
   CFURLRef localizationURL,
   CFStringRef alertHeader,
   CFStringRef alertMessage,
   CFStringRef defaultButtonTitle
);
#endif

/*Dialog Description Keys

Keys used in a user notification’s description dictionary, which describes the contents of the notification dialog to display.

const CFStringRef kCFUserNotificationIconURLKey;
const CFStringRef kCFUserNotificationSoundURLKey;
const CFStringRef kCFUserNotificationLocalizationURLKey;
const CFStringRef kCFUserNotificationAlertHeaderKey;
const CFStringRef kCFUserNotificationAlertMessageKey;
const CFStringRef kCFUserNotificationDefaultButtonTitleKey;
const CFStringRef kCFUserNotificationAlternateButtonTitleKey;
const CFStringRef kCFUserNotificationOtherButtonTitleKey;
const CFStringRef kCFUserNotificationProgressIndicatorValueKey;
const CFStringRef kCFUserNotificationPopUpTitlesKey;
const CFStringRef kCFUserNotificationTextFieldTitlesKey;
const CFStringRef kCFUserNotificationCheckBoxTitlesKey;
const CFStringRef kCFUserNotificationTextFieldValuesKey;
const CFStringRef kCFUserNotificationPopUpSelectionKey

Constants
kCFUserNotificationIconURLKey

A file URL pointing to the icon to display in the dialog. 

If absent, a default icon based on the alert level is used.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationSoundURLKey

Not used.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationLocalizationURLKey

A file URL pointing to a bundle that contains localized versions of the strings displayed in the dialog.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationAlertHeaderKey

The title of the notification dialog.

This key is required.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationAlertMessageKey

The message string to display in the dialog.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationDefaultButtonTitleKey

The title of the default button. 

If absent and the dialog is not being created with the kCFUserNotificationNoDefaultButtonFlag flag, a default button title of OK is used.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationAlternateButtonTitleKey

The title of an optional alternate button.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationOtherButtonTitleKey

The title of an optional third button.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationProgressIndicatorValueKey

Not used.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationPopUpTitlesKey

The list of strings to display in a pop-up menu. 

The array cannot have more than 256 elements.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationTextFieldTitlesKey

The list of titles for all the text fields to display. 

If only one text field is to be displayed, you can pass its title string directly without putting it into an array first.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationCheckBoxTitlesKey

The list of titles for all the checkboxes or radio buttons to display.

The array cannot have more than 8 elements. If only one checkbox is to be displayed, you can pass its title string directly without putting it into an array first.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationTextFieldValuesKey

The list of values to put into the text fields. If only one text field is to be displayed, you can pass its value string directly without putting it into an array first.

Available in Mac OS X v10.0 and later.

Declared in CFUserNotification.h
kCFUserNotificationPopUpSelectionKey

The item that was selected from a pop-up menu.

Available in Mac OS X v10.3 and later.

Declared in CFUserNotification.h
Discussion

When creating the user notification with CFUserNotificationCreate, the description dictionary must have a value for kCFUserNotificationAlertHeaderKey. All other keys are optional.

The button title keys must be given in right-to-left order—you therefore must use the kCFUserNotificationDefaultButtonTitleKey constant for the rightmost button even if it is conceptually not a "default" button (for example, if you want a single "Cancel" button that should not have color, should not pulse, and should not have return for a key equivalent). If, however, you set the kCFUserNotificationNoDefaultButtonFlag, the rightmost button does not behave as a default button (although it will still be the "default" button in the sense of using kCFUserNotificationDefaultButtonTitleKey and kCFUserNotificationDefaultResponse). The following code fragment shows how you can create a notification that contains a single "Cancel" button that does not behave as a default button.const void* keys[] = {kCFUserNotificationAlertHeaderKey,
                      kCFUserNotificationProgressIndicatorValueKey,
                      kCFUserNotificationDefaultButtonTitleKey};
const void* values[] = {CFSTR("Progress"),
                        kCFBooleanTrue,
                        CFSTR("Cancel")};
CFDictionaryRef parameters = CFDictionaryCreate(0, keys, values,
        sizeof(keys)/sizeof(*keys), &kCFTypeDictionaryKeyCallBacks,
        &kCFTypeDictionaryValueCallBacks);
SInt32 err = 0;
CFUserNotificationCreate(kCFAllocatorDefault, 0,
        kCFUserNotificationPlainAlertLevel | kCFUserNotificationNoDefaultButtonFlag,
        &err, parameters);


If you set the kCFUserNotificationNoDefaultButtonFlag flag and do not specify a value for kCFUserNotificationDefaultButtonTitleKey, the notification will have no buttons.*/
#ifdef OC_CF
extern const CFStringRef kCFUserNotificationIconURLKey;
extern const CFStringRef kCFUserNotificationSoundURLKey;
extern const CFStringRef kCFUserNotificationLocalizationURLKey;
extern const CFStringRef kCFUserNotificationAlertHeaderKey;
extern const CFStringRef kCFUserNotificationAlertMessageKey;
extern const CFStringRef kCFUserNotificationDefaultButtonTitleKey;
extern const CFStringRef kCFUserNotificationAlternateButtonTitleKey;
extern const CFStringRef kCFUserNotificationOtherButtonTitleKey;
extern const CFStringRef kCFUserNotificationProgressIndicatorValueKey;
extern const CFStringRef kCFUserNotificationPopUpTitlesKey;
extern const CFStringRef kCFUserNotificationTextFieldTitlesKey;
extern const CFStringRef kCFUserNotificationCheckBoxTitlesKey;
extern const CFStringRef kCFUserNotificationTextFieldValuesKey;
extern const CFStringRef kCFUserNotificationPopUpSelectionKey;
#endif

#ifdef __cplusplus
}
#endif

#endif//CFUSERNOTIFICATION_H
