#ifndef __PluginData_H__
#define __PluginData_H__	1


#include <DirectoryServiceCore/PrivateTypes.h>
#include <sys/types.h>

#include <HYS/DirectoryServiceCore/PluginData.h>

#define  uInt32 UInt32//add
#define  sInt32 SInt32//add

/*ePluginState Constants

Constants for setting a plug-in’s state.

typedef enum {
kUnknownState = 0x00000000,
kActive = 0x00000001,
kInactive = 0x00000002,
kInitialized = 0x00000004,
kUninitialized = 0x00000008,
kFailedToInit = 0x00000010,
} ePluginState;
Constants
kUnknownState

Plug-in has not yet been loaded.
kActive

Plug-in is loaded, initialized, and active.
kInactive

Plug-in is loaded and initialized but is not active.
kUninitialized

Plug-in is loaded but not initialized.
kFailedToInit

Plug-in is loaded but inactive because it failed to initialize.*/
typedef enum {
kUnknownState = 0x00000000,
kActive = 0x00000001,
kInactive = 0x00000002,
kInitialized = 0x00000004,
kUninitialized = 0x00000008,
kFailedToInit = 0x00000010,
} ePluginState;

/*sSetAttributeValues

Structure received when an Open Directory client calls dsSetAttributeValues.

typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInAttrType;
tDataListPtr        fInAttrValueList;
} sSetAttributeValues;
Fields
fType

Always kSetAttributeValues.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to set the specified value in the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record for which a value is to be set in an attribute. The record reference was created when the plug-in processed an sOpenRecord structure.
fInAttrType

Value of type tDataNodePtr that points to a tDataNode structure containing the type the attribute whose value is to be set.
fInAttrValueList

Value of type tAttributeValueEntryPtr that points to a tAttributeValueEntry structure containing the attribute ID of the attribute whose values are to be replaced and a list of the replacement values.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sSetAttributeValues structure when an Open Directory client calls dsSetAttributeValues to replace multiple values for the specified attribute. If the attribute does not exist, the plug-in creates the attribute and sets it to the values specified by fInAttrValueList.

The plug-in uses the fInRecRef field of the sSetAttributeValues structure to determine the record for which an attribute value is to be set and the fInAttrType field to determine the type of the attribute for which values are to be set. The fInAttrValueList field points to a tDataList structure containing a list of values that are to be set for the attribute.

If the plug-in can set the attribute values, it sets the values, sets fResult to eDSNoErr, and returns.

If the plug-in cannot set the attribute values, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInAttrType;
tDataListPtr        fInAttrValueList;
} sSetAttributeValues;

/*sGetDirNodeInfo

Structure received when an Open Directory client application calls dsGetDirNodeInfo.

typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataListPtr        fInDirNodeInfoTypeList;
tDataBufferPtr      fOutDataBuff;
bool                fInAttrInfoOnly;
unsigned long       fOutAttrInfoCount;
tAttributeListRef   fOutAttrListRef;
tContextData        fOutContinueData;
} sGetDirNodeInfo;
Fields
fType

Always kGetDirNodeInfo.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get information about the directory node identified by fInNodeRef. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node for which information is to be obtained. The directory node reference was created when the client application opened the directory node.
fInDirNodeInfoTypeList

Value of type tDataListPtr that points to a tDataList structure containing the attribute types for which information is being requested.
fOutDataBuff

Value of type tDataBufferPtr pointing to a tDataBuffer structure. If the plug-in obtains the requested information, it puts the information in the data buffer pointed to by fOutDataBuff.
fInAttrInfoOnly

Boolean value set to TRUE if the plug-in is only to provide information about attributes or set to FALSE if the plug-in is to provide the values of the attributes as well as information about the attributes.
fOutAttrInfoCount

On return, fOutAttrInfoCount contains the number of attribute types the plug-in has placed in the buffer pointed to by fOutDataBuff.
fOutAttrListRef

Value of type tAttributeListRef assigned by the DirectoryService daemon and that the plug-in associates with the internal structure the plug-in uses to maintain information about the reference.
fOutContinueData

Value of type tContextData that represents continuation data. If this is the first call in what may be a series of calls for this value of fInNodeRef, the input value of fOutContinueData is NULL. If all of the directory node information fits in the buffer pointed to by fOutDataBuff, the plug-in sets fOutContinueData to NULL. If there is more information than can fit in the buffer, set fOutContinueData to a plug-in–defined value.Your routine for processing sGetDirNodeInfo structures will be called again, and the fOutContinueData field will contain the continuation data that you previously returned to the client application. Therefore, the continuation data should be a value that you can use to determine which directory node information to place in the data buffer the next time your routine for processing sGetDirNodeInfo structures is called for this value of fInNodeRef. You may want to include a timestamp in the continuation data and return an error if you determine that fOutContinueData is out of date.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetDirNodeInfo structure when an Open Directory client calls dsGetDirNodeInfo.

The plug-in uses the fInNodeRef field of the sGetDirNodeInfo structure to determine the directory node for which information is requested, the data list pointed to by fInDirNodeInfoTypeList to determine the type of information that is requested, and fInAttrInfoOnly to determine whether to also return attribute values.

If the plug-in can get attribute information for the specified directory node, it puts the requested information in the buffer pointed to by fOutDataBuff. If fOutDataBuff is too small to hold all of the information, the plug-in sets fOutContinueData to a plug-in–defined value. If all of the information fits in the buffer, the plug-in sets fOutDataBuff to NULL. Before returning, the plug-in sets fOutAttrInfoCount to the number of attributes types that have been placed in the buffer.

If the plug-in cannot get the requested information, it sets fResult to an appropriate result code as described in “Result Codes,” sets fOutContinueData to NULL, sets fOutAttrInfoCount to zero, and returns.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataListPtr        fInDirNodeInfoTypeList;
tDataBufferPtr      fOutDataBuff;
bool                fInAttrInfoOnly;
unsigned long       fOutAttrInfoCount;
tAttributeListRef   fOutAttrListRef;
tContextData        fOutContinueData;
} sGetDirNodeInfo;

/*sCloseDirNode

Structure received when an Open Directory client calls dsCloseDirNode.

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirReference   fInNodeRef;
} sCloseDirNode;
Fields
fType

Always kCloseDirNode.
fResult

Value of type sInt32s that the plug-in sets to eDSNoErr before returning to indicate that it was able to close the directory node session specified by fInNodeRef. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirReference that identifies the directory node session that is to be closed. The directory node reference was created when the client application opened the directory node session that is to be closed.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sCloseDirNode structure when an Open Directory client calls dsCloseDirNode to close a session with a directory node.

When an Open Directory plug-in receives a request to close a directory node session, it uses the fInNodeRef field to determine whether fInNodeRef represents a valid directory node that the client application has opened.

If the directory node reference is valid, the plug-in invalidates all record references, attribute references, attribute value references, and continuation data values that are associated with the directory node reference specified by fInNodeRef. The plug-in sets fResult to eDSNoErr and returns. 

If the plug-in cannot close the node (for example, because it is invalid), it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tDirReference   fInNodeRef;
} sCloseDirNode;

/*sReleaseContinueData

Structure received when an Open Directory client calls dsReleaseContinueData.

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirReference   fInDirReference;
tContextData    fInContinueData;
} sReleaseContinueData;
Fields
fType

Always kReleaseContinueData.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to deallocate the memory associated with fInContinueData. If an error occurs, the plug-in set fResult to a value listed in “Result Codes.”
fInDirReference

Value of type tDirReference or of type tDirNodeReference, depending on the type of reference that was used in the call that created the continue data that is to be released. 
fInContinueData

Value of type tContextData that points to memory that is to be released.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sReleaseContinueData structure when an Open Directory client calls dsReleaseContinueData. 

The plug-in deallocates the memory associated with fInContinueData, sets fResult to eDSNoErr, and returns.

If the plug-in cannot deallocate the memory associated with fInContinueData, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tDirReference   fInDirReference;
tContextData    fInContinueData;
} sReleaseContinueData;

/*sGetAttributeValue

Structure received when an Open Directory client calls dsGetAttributeValue.

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tDirNodeReference       fInNodeRef;
tDataBufferPtr          fInOutDataBuff;
unsigned long           fInAttrValueIndex;
tAttributeValueListRef  fInAttrValueListRef;
tAttributeValueEntryPtr fOutAttrValue;
} sGetAttributeValue;

Fields
fType

Always kGetAttributeValue.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get the requested attribute value. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node of the record whose attribute value is to be obtained. The directory node reference was created when the client application opened the directory node session.
fInOutDataBuff

Value of type tDataBufferPtr pointing to the tDataBuffer structure containing information previously obtained when the plug-in responded to an sGetRecordList, sDoAttrValueSearch, sDoAttrValueSearchWithData, sDoMultiAttrValueSearch, or sDOMultiAttrValueSearchWithData request from the client application.
fInAttrValueIndex

Value of type unsigned long containing a one-based index that specifies which attribute value to get. A value of 1 specifies the first value, a value of 2 specifies the second value, and so on.
fInAttrValueListRef

Value of type tAttributeValueListRef created by the plug-in when its routine for processing sGetAttributeEntry structures was called. The reference contains information that the plug-in uses to locate the attribute value in the data buffer pointed to by fInOutDataBuff.
fOutAttrValue

Value of type tAttributeValueEntryPtr pointing to the tAttributeValueEntry structure in which the plug-in is to place the value of the attribute specified by the fInAttrValueIndex field.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetAttributeValue structure when an Open Directory client calls dsGetAttributeValue.

The plug-in uses the fInNodeRef field of the sGetAttributeValue structure to determine the directory node of the record for which an attribute value is being obtained.

If the plug-in can get the requested value from the data buffer pointed to by fInOutDataBuff, it puts the value in the attribute value entry structure pointed to by fOutAttrValue, sets fResult to eDSNoErr, and returns.

If the plug-in cannot get the requested value, it sets fResult to an appropriate result code as described in “Result Codes” and returns.

For information on parsing the data buffer, see the section “Client Side Buffer Parsing” in Chapter 1.*/
typedef struct {
uInt32                  fType;
sInt32                  fResult;
tDirNodeReference       fInNodeRef;
tDataBufferPtr          fInOutDataBuff;
unsigned long           fInAttrValueIndex;
tAttributeValueListRef  fInAttrValueListRef;
tAttributeValueEntryPtr fOutAttrValue;
} sGetAttributeValue;

/*sDoMultiAttrValueSearchWithData

Structure received when an Open Directory client calls dsDoMultipleAttributeValueSearch. 

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirNodeReferencefInNodeRef;
tDataBufferPtr  fOutDataBuff;
tDataListPtr    fInRecTypeList;
tDataNodePtr    fInAttrType;
tDirPatternMatchfInPattMatchType;
tDataListPtr    fInPatterns2MatchList;
unsigned long   fInOutMatchRecordCount;
tContextData    fIOContinueData;
tDataListPtr    fInAttrTypeRequestList;
bool            fInAttrInfoOnly;
} sDoMultiAttrValueSearchWithData;

Fields
fType

Always kDoMultipleAttributeValueSearchWithData.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to search for the attribute values. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.” If no matches are found, the plug-in should set fResult to eDSNoErr, fInOutMatchRecordCount to zero, and fIOContinueData to NULL.
fInNodeRef

Value of type tDirNodeReference that identifies the directory node for which the search is to be conducted. The directory node reference was created when the client application opened the directory node session.
fOutDataBuff

Value of type tDataBufferPtr that points to the tDataBuffer structure in which the plug-in is to place search results.
fInRecTypeList

Value of type tDataListPtr pointing to a tDataList structure containing the record types that are to be searched. See Standard Record Types and Meta Record Type Constants for possible values. If NULL, set fResult to eDSEmptyRecordTypeList and return.
fInAttrType

Value of type tDataNodePtr pointing to a tDataNode structure containing the attribute types that are to be searched for. See the attribute constants described in the “Constants” section for possible values. If NULL, set fResult to eDSEmptyAttributeType and return.
fInPattMatchType

Value of type tDirPatternMatch that describes the way in which the pattern specified by fInPatt2Match is to be matched. The pattern match type can be a value that the plug-in and application agree upon or a constant defined by Open Directory, as described in the section Pattern Matching Constants.
fInPatterns2MatchList

Value of type tDataListPtr pointing to a tDataList structure containing a list of patterns to be matched.
fInOutMatchRecordCount

Value of type unsigned long. The first time the client application calls dsDoAttributeValueSearch, fInOutMatchRecordCount is zero to receive all matching records or is a positive integer value that specifies the total number of records the client application wants to receive across what may be a series of dsDoAttributeValueSearch calls. If the latter, the plug-in should use the initial input value of fInOutMatchRecordCount to limit the total number of matching records it returns. Before returning, the plug-in should set fInOutMatchRecordCount to the number of records it has placed in the buffer pointed to by fOutDataBuff. The plug-in should ignore the input value of fInOutMatchRecordCount whenever it is processing a sDoMultiAttrValueSearchWithData structure that has an fIOContinueData field that is not NULL.
fIOContinueData

Value of type tContextData containing continuation data. For the first in a series of calls to dsDoAttributeValueSearch, the input value is NULL. If the plug-in can store all of the matching records in the buffer pointed to by fOutDataBuff, it sets fIOContinueData to NULL before returning. If there more records than can be stored in the buffer, the plug-in stores as much data as possible and sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoAttributeValueSearch again to get another buffer of data. You may want to include a timestamp in the continuation data and return an error if you determine that fOutContinueData is out of date.
fInAttrTypeRequestList

Value of type tDataListPtr pointing to a tDataList structure containing the types of attribute that are to be returned if matches are found. See the attribute constants described in the “Constants” section for possible values. If NULL, set fResult to eDSEmptyAttributeTypeList and return.
fInAttrInfoOnly

Boolean value set to TRUE if the plug-in is only to provide information about attributes or set to FALSE if the plug-in is to provide the values of the attributes as well as information about the attributes.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sDoMultiAttrValueSearchWithData structure when an Open Directory client calls dsDoMultipleAttributeValueSearchWithData to search for records that have attributes whose values match one of multiple specified patterns and return the values of the attributes specified by fInAttrTypeRequestList when a match occurs.

The plug-in uses the fInNodeRef field of the sDoMultiAttrValueSearch structure to determine the directory node in which the search is to be conducted, the fInRecTypeList field to determine the type of records that are to be searched, the fInAttrType field to determine the attributes that are to be searched, the fInPatterns2MatchList field to get the patterns to match, and the fInPattMatchType field to determine the way in which the patterns are to be compared. If this is the first in what may be a series of calls to get the complete search results, the fIOContinueData field is NULL. Otherwise, fIOContinueData contains a plug-in–defined value that the plug-in uses to provide the context required to resume filling the buffer pointed to by fOutDataBuff with search results.

The sDoMultiAttrValueSearchWithData structure differs from the sDoMultiAttrValueSearch structure in that the sDoMultiAttrValueSearchWithData structure has two additional fields: fInAttrTypeRequestList, which specifies the type of attributes for which information is to be returned when a match is found, and fInAttrInfoOnly, which indicates whether attribute information or attribute information and attribute values are to be returned when a match is found.

Depending on the size of the data buffer pointed to by fOutDataBuff and the length of the search results, the plug-in’s routine for processing sDoMultiAttrValueSearchWithData structures may be called multiple times in order to return all of the search results. The first time the plug-in’s routine for processing the sDoMultiAttrValueSearchWithData structure is called, the input value of fIOContinueData is NULL and input value of fInOutRecEntryCount specifies the total number of records that the plug-in should return even if the plug-in’s routine for processing sDoMultiAttrValueSearchWithData structures must be called more than once.

If there are records that match the search criteria specified by fInRecTypeList, fInAttrType, fInPattMatchType, and fInPattern2MatchList, the plug-in puts the record entries, attribute entries, and attribute values in the buffer pointed to by fOutDataBuff. It also sets fInOutMatchRecordCount to the number of records that have been placed in fOutDataBuff and sets fResult to eDSNoErr. If the buffer pointed to by fOutDataBuff is too small to hold all of the data, the plug-in sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoMultipleAttributeValueSearch again to get another buffer of data. If the buffer pointed to by fOutDataBuff contains all of the records or contains the last records in the list of records, the plug-in sets fIOContinueData to NULL.

If the plug-in returns before it gets search results to place in the buffer pointed to by fOutDataBuff, it should set fInOutMatchRecordCount to zero, set fResult to eDSNoErr, and set fIOContinueData to a plug-in–defined value that is not NULL. These settings indicate to the client that it should call dsDoMultipleAttributeValueSearch again to get the search results.

If there are no matching records, the plug-in sets fInOutMatchRecordCount to zero, fIOContinueData to NULL, sets fResult to eDSNoErr, and returns.*/
typedef struct {
	uInt32          fType;
	sInt32          fResult;
	tDirNodeReference fInNodeRef;
	tDataBufferPtr  fOutDataBuff;
	tDataListPtr    fInRecTypeList;
	tDataNodePtr    fInAttrType;
	tDirPatternMatch fInPattMatchType;
	tDataListPtr    fInPatterns2MatchList;
	unsigned long   fOutMatchRecordCount;
	tContextData    fIOContinueData;
	tDataListPtr    fInAttrTypeRequestList;
	bool            fInAttrInfoOnly;
} sDoMultiAttrValueSearchWithData;

/*sDoMultiAttrValueSearch

Structure received when an Open Directory client calls dsDoMultipleAttributeValueSearch. 

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirNodeReferencefInNodeRef;
tDataBufferPtr  fOutDataBuff;
tDataListPtr    fInRecTypeList;
tDataNodePtr    fInAttrType;
tDirPatternMatchfInPattMatchType;
tDataListPtr    fInPatterns2MatchList;
unsigned long   fInOutMatchRecordCount;
tContextData    fIOContinueData;
} sDoMultiAttrValueSearch;
Fields
fType

Always kDoMultipleAttributeValueSearch.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to search for the attribute values. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.” If no matches are found, the plug-in should set fResult to eDSNoErr, fInOutMatchRecordCount to zero, and fIOContinueData to NULL.
fInNodeRef

Value of type tDirNodeReference that identifies the directory node for which the search is to be conducted. The directory node reference was created when the client application opened the directory node session.
fOutDataBuff

Value of type tDataBufferPtr that points to the tDataBuffer structure in which the plug-in is to place search results.
fInRecTypeList

Value of type tDataListPtr pointing to a tDataList structure containing the record types that are to be searched. See Standard Record Types and Meta Record Type Constants for possible values. If NULL, set fResult to eDSEmptyRecordTypeList and return.
fInAttrType

Value of type tDataNodePtr pointing to a tDataNode structure containing the attribute types that are to be searched for. See the attribute constants described in the “Constants” section for possible values. If NULL, set fResult to eDSEmptyAttributeType and return.
fInPattMatchType

Value of type tDirPatternMatch that describes the way in which the pattern specified by fInPatt2Match is to be matched. The pattern match type can be a value that the plug-in and application agree upon or a constant defined by Open Directory, as described in the section Pattern Matching Constants.
fInPatterns2MatchList

Value of type tDataListPtr pointing to a tDataList structure containing a list of patterns to be matched.
fInOutMatchRecordCount

Value of type unsigned long. The first time the client application calls dsDoAttributeValueSearch, fInOutMatchRecordCount is zero to receive all matching records or is a positive integer value that specifies the total number of records the client application wants to receive across what may be a series of dsDoAttributeValueSearch calls. If the latter, the plug-in should use the initial input value of fInOutMatchRecordCount to limit the total number of matching records it returns. Before returning, the plug-in should set fInOutMatchRecordCount to the number of records it has placed in the buffer pointed to by fOutDataBuff. The plug-in should ignore the input value of fInOutMatchRecordCount whenever it is processing a sDoMultiAttrValueSearch structure that has anfIOContinueData field that is not NULL.
fIOContinueData

Value of type tContextData containing continuation data. For the first in a series of calls to dsDoAttributeValueSearch, the input value is NULL. If the plug-in can store all of the matching records in the buffer pointed to by fOutDataBuff, it sets fIOContinueData to NULL before returning. If there more records than can be stored in the buffer, the plug-in stores as much data as possible and sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoAttributeValueSearch again to get another buffer of data. You may want to include a timestamp in the continuation data and return an error if you determine that fOutContinueData is out of date.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sDoMultiAttrValueSearch structure when an Open Directory client calls dsDoMultipleAttributeValueSearch to search for records that have attributes whose values match one of multiple specified patterns.

The plug-in uses the fInNodeRef field of the sDoMultiAttrValueSearch structure to determine the directory node in which the search is to be conducted, the fInRecTypeList field to determine the type of records that are to be searched, the fInAttrType field to determine the attributes that are to be searched, the fInPatterns2MatchList field to get the patterns to match, and the fInPattMatchType field to determine the way in which the patterns are to be compared. If this is the first in what may be a series of calls to get the complete search results, the fIOContinueData field is NULL. Otherwise, fIOContinueData contains a plug-in–defined value that the plug-in uses to provide the context required to resume filling the buffer pointed to by fOutDataBuff with search results.

Depending on the size of the data buffer pointed to by fOutDataBuff and the length of the search results, the plug-in’s routine for processing sDoMultiAttrValueSearch structures may be called multiple times in order to return all of the search results. The first time the plug-in’s routine for processing the sDoMultiAttrValueSearch structure is called, the input value of fIOContinueData is NULL and input value of fInOutRecEntryCount specifies the total number of records that the plug-in should return even if the plug-in’s routine for processing sDoMultiAttrValueSearch structures must be called more than once.

If there are records that match the search criteria specified by fInRecTypeList, fInAttrType, fInPattMatchType, and fInPattern2MatchList, the plug-in puts the record entries, attribute entries, and attribute values in the buffer pointed to by fOutDataBuff. It also sets fInOutMatchRecordCount to the number of records that have been placed in fOutDataBuff and sets fResult to eDSNoErr. If the buffer pointed to by fOutDataBuff is too small to hold all of the data, the plug-in sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoMultipleAttributeValueSearch again to get another buffer of data. If the buffer pointed to by fOutDataBuff contains all of the records or contains the last records in the list of records, the plug-in sets fIOContinueData to NULL.

If the plug-in returns before it gets search results to place in the buffer pointed to by fOutDataBuff, it should set fInOutMatchRecordCount to zero, set fResult to eDSNoErr, and set fIOContinueData to a plug-in–defined value that is not NULL. These settings indicate to the client that it should call dsDoMultipleAttributeValueSearch again to get the search results.

If there are no matching records, the plug-in sets fInOutMatchRecordCount to zero, fIOContinueData to NULL, sets fResult to eDSNoErr, and returns.*/

typedef struct {
	UInt32					fType;
	SInt32					fResult;
	tDirNodeReference		fInNodeRef;
	tDataBufferPtr			fOutDataBuff;
	tDataListPtr			fInRecTypeList;
	tDataNodePtr			fInAttrType;
	tDirPatternMatch		fInPattMatchType;
	tDataListPtr			fInPatterns2MatchList;
	UInt32					fOutMatchRecordCount;
	tContextData			fIOContinueData;
} sDoMultiAttrValueSearch;

/*sOpenDirNode

Structure received when an Open Directory client calls dsOpenDirNode.

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirReference   fInDirRef;
tDataListPtr    fInDirNodeName;
tDirNodeReferencefOutNodeRef;
uid_t           fInUID;
uid_t           fInEffectiveUID;
} sOpenDirNode;

Fields
fType

Always kOpenDirNode.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to open the directory node specified by fInDirNodeName. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInDirRef

Value of type tDirReference that was created when the client application opened the Open Directory session for which this directory node is to be opened.
fInDirNodeName

Value of type tDataListPtr pointing to a tDataList structure containing the name of the directory node that is to be opened.
fOutNodeRef

Value of type tDirNodeReference assigned by the DirectoryService daemon and that the plug-in associates with the internal structure the plug-in uses to maintain information about the reference.
fInUID

Value of type uid_t containing the UID of the calling process. Your plug-in can use the value of fInUID and fInEffectiveUID to determine whether to allow a process to perform certain activities without requiring authentication.
fInEffectiveUID

Value of type uid_t containing the effective UID of the calling process. Your plug-in can use the value of fInEffectiveUID and fInUID to determine whether to allow a process to perform certain activities without requiring authentication.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sOpenDirNode structure when an Open Directory client calls dsOpenDirNode to open a directory node.

The plug-in uses the fInDirNodeName field to determine the name of the directory node to open.

If the plug-in can open the specified directory node, it sets fResult to eDSNoErr and returns.

If the plug-in cannot open the directory node or if the Open Directory reference is invalid, the plug-in sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tDirReference   fInDirRef;
tDataListPtr    fInDirNodeName;
tDirNodeReference fOutNodeRef;
uid_t           fInUID;
uid_t           fInEffectiveUID;
} sOpenDirNode;

/*sDoAttrValueSearchWithData

Structure received when an Open Directory client calls dsDoAttributeValueSearchWithData.

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirNodeReferencefInNodeRef;
tDataBufferPtr  fOutDataBuff;
tDataListPtr    fInRecTypeList;
tDataNodePtr    fInAttrType;
tDirPatternMatchfInPattMatchType;
tDataNodePtr    fInPatt2Match;
unsigned long   fInOutMatchRecordCount;
tContextData    fIOContinueData;
tDataListPtr    fInAttrTypeRequestList;
bool            fInAttrInfoOnly;
} sDoAttrValueSearchWithData;
Fields
fType

Always kDoAttributeValueSearchWithData.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to search for the attribute values. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.” If no matches are found, the plug-in should set fResult to eDSNoErr, fInOutMatchRecordCount to zero, and fIOContinueData to NULL.
fInNodeRef

Value of type tDirNodeReference that identifies the directory node for which the search is to be conducted. The directory node reference was created when the client application opened the directory node session.
fOutDataBuff

Value of type tDataBufferPtr that points to the tDataBuffer structure in which the plug-in is to place search results.
fInRecTypeList

Value of type tDataListPtr pointing to a tDataList structure containing the record types that are to be searched. See Standard Record Types and Meta Record Type Constants for possible values. If NULL, set fResult to eDSEmptyRecordTypeList and return.
fInAttrType

Value of type tDataNodePtr pointing to a tDataNode structure containing the attribute types that are to be searched for. See the attribute constants described in the “Constants” section for possible values. If NULL, set fResult to eDSEmptyAttributeType and return.
fInPattMatchType

Value of type tDirPatternMatch that describes the way in which the pattern specified by fInPatt2Match is to be matched. The pattern match type can be a value that the plug-in and application agree upon or a constant defined by Open Directory, as described in the section Pattern Matching Constants.
fInPatt2Match

Value of type tDataNodePtr pointing to a tDataNode structure containing the pattern that is to be matched.
fInOutMatchRecordCount

Value of type unsigned long. The first time the client application calls dsDoAttributeValueSearchWithData, fInOutMatchRecordCount is zero to receive all matching records or is a positive integer value that specifies the total number of records the client application wants to receive across what may be a series of dsDoAttributeValueSearchWithData calls. If the latter, the plug-in should use the initial input value o ffInOutMatchRecordCount to limit the total number of matching records it returns. Before returning, the plug-in should set fInOutMatchRecordCount to the number of records it has placed in the buffer pointed to by fOutDataBuff. The plug-in should ignore the input value of fInOutMatchRecordCount whenever it is processing a sDoAttributeValueSearchWithData structure that has an fIOContinueData field that is not NULL.
fIOContinueData

Value of type tContextData containing continuation data. For the first in a series of calls to dsDoAttributeValueSearchWithData, the input value is NULL. If the plug-in can store all of the matching records in the buffer pointed to by fOutDataBuff, it sets fIOContinueData to NULL before returning. If there more records than can be stored in the buffer, the plug-in stores as much data as possible and sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoAttributeValueSearchWithData again to get another buffer of data. You may want to include a timestamp in the continuation data and return an error if you determine that fOutContinueData is out of date.
fInAttrTypeRequestList

Value of type tDataListPtr pointing to a tDataList structure containing attribute types that are to be returned if matches are found. See the attribute constants described in the “Constants” section for possible values. If NULL, set fResult to eDSEmptyAttributeTypeList and return.
fInAttrInfoOnly

Boolean value set to TRUE if the plug-in is only to provide information about attributes or set to FALSE if the plug-in is to provide the values of the attributes as well as information about the attributes.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sDoAttrValueSearchWithData structure when an Open Directory client calls dsDoAttributeValueSearchWithData to search for records. Matches are based on the value of fInAttrType, fInPattMatchType, and fInPatt2Match. For records that match, the fInAttrTypeRequestList field determines which attributes to return.

The plug-in uses the fInNodeRef field of the sDoAttrValueSearchWithData structure to determine the directory node in which the search is to be conducted, the fInRecTypeList field to determine the record types that are to be searched, the fInAttrType field to determine the attribute types that are to be searched, the fInPatt2Match field to get the pattern to match, and the fInPattMatchType field to determine the way in which the pattern is to be compared. If this is the first in what may be a series of calls to get the complete search results, the fIOContinueData field is NULL. Otherwise, fIOContinueData contains a plug-in–defined value that the plug-in uses to provide the context required to resume filling the buffer pointed to by fOutDataBuff with search results.

The sDoAttrValueSearchWithData structure differs from the sDoAttrValueSearch structure in that the sDoAttrValueSearchWithData structure has two additional fields: fInAttrTypeRequestList, which specifies the type of attributes for which information is to be returned when a match is found, and fInAttrInfoOnly, which indicates whether attribute information or attribute information and attribute values are to be returned when a match is found.

Depending on the size of the data buffer pointed to by fOutDataBuff and the length of the search results, the plug-in’s routine for processing sDoAttrValueSearchWithData structures may be called multiple times in order to return all of the search results. The first time the plug-in’s routine for processing sDoAttrValueSearchWithData structures is called, the input value of fIOContinueData is NULL and input value of fInOutRecEntryCount specifies the total number of records that the plug-in should return even if the plug-in’s routine for processing sDoAttrValueSearchWithData structures must be called more than once.

If there are records that match the search criteria specified by fInRecTypeList, fInAttrType, fInPattMatchType, and fInPatt2Match, plug-in puts the record entries, attribute entries, and attribute values in the buffer pointed to by fOutDataBuff. It also sets fInOutMatchRecordCount to the number of records that have been placed in fOutDataBuff and sets fResult to eDSNoErr. If the buffer pointed to by fOutDataBuff is too small to hold all of the data, the plug-in sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoAttributeValueSearchWithData again to get another buffer of data. If the buffer pointed to by fOutDataBuff contains all of the records or contains the last records in the record list, the plug-in sets fIOContinueData to NULL.

If the plug-in returns before it gets search results to place in the buffer pointed to by fOutDataBuff, it should set fInOutMatchRecordCount to zero, set fResult to eDSNoErr, and set fIOContinueData to a plug-in–defined value that is not NULL. These settings indicate to the client application that it should call dsDoAttributeValueSearchWithData again to get the search results.

If there are no matching records, the plug-in sets fInOutMatchRecordCount to zero, fIOContinueData to NULL, sets fResult to eDSNoErr, and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tDirNodeReference fInNodeRef;
tDataBufferPtr  fOutDataBuff;
tDataListPtr    fInRecTypeList;
tDataNodePtr    fInAttrType;
tDirPatternMatch fInPattMatchType;
tDataNodePtr    fInPatt2Match;
unsigned long   fOutMatchRecordCount;
tContextData    fIOContinueData;
tDataListPtr    fInAttrTypeRequestList;
bool            fInAttrInfoOnly;
} sDoAttrValueSearchWithData;

/*sGetAttributeEntry

Structure received when an Open Directory client calls dsGetAttributeEntry.

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tDirNodeReference       fInNodeRef;
tDataBufferPtr          fInOutDataBuff;
tAttributeListRef       fInAttrListRef;
unsigned long           fInAttrInfoIndex;
tAttributeValueListRef  fOutAttrValueListRef;
tAttributeEntryPtr      fOutAttrInfoPtr;
} sGetAttributeEntry;
Fields
fType

Always kGetAttributeEntry.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get the requested attribute information. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node of the record whose attribute information is to be obtained. The directory node reference was created when the client application opened the directory node session.
fInOutDataBuff

Value of type tDataBufferPtr that points to the tDataBuffer structure from which the attribute information is to be obtained.
fInAttrListRef

Value of type tAttributeListRef that refers to an attribute list that the plug-in returned to the client application when it processed a sGetDirNodeInfo or a sGetRecordEntry structure or that the plug-in returned to the client application when it previously called dsGetAttributeEntry. The plug-in uses the attribute list reference to locate the attribute information in the buffer pointed to by fInOutDataBuff.
fInAttrInfoIndex

Value of type unsigned long that specifies the one-based index number of the attribute whose information is to be obtained from the buffer pointed to by fInOutDataBuff.
fOutAttrValueListRef

Value of type tAttributeValueListRef assigned by the DirectoryService daemon and that the plug-in associates with the internal structure the plug-in uses to maintain information about the reference.
fOutAttrInfoPtr

Pointer to a value of type tAttributeValueEntryPtr that points to a tAttributeEntry structure in which the plug-in is to place the attribute information.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetAttributeEntry structure when an Open Directory client calls dsGetAttributeEntry to get information about an attribute from the buffer pointed to by fInOutDataBuff.

The plug-in uses the fInNodeRef field to determine the directory node of the record for which attribute information is requested and the fInAttrInfoIndex field to determine the attribute for which attribute information is requested. The information includes the number of values the attribute has, the total number of bytes the values use, the maximum size of a value for the specified attribute, and the attribute’s unique signature.

If the plug-in can get the requested information from fInOutDataBuff, it puts the attribute information in the attribute entry structure pointed to by fOutAttrInfoPtr, sets fOutAttrValueListRef to a value that the plug-in can use to locate the attribute’s value if its routine for processing sGetAttributeValue structures is called, sets fResult to eDSNoErr, and returns. 

If the plug-in cannot provide the requested attribute information, it sets fOutAttrValueListRef to NULL, sets fResult to an appropriate result code as described in “Result Codes” and returns.

For information on parsing the data buffer, see the section “Client Side Buffer Parsing” in Chapter 1*/
typedef struct {
uInt32                  fType;
sInt32                  fResult;
tDirNodeReference       fInNodeRef;
tDataBufferPtr          fInOutDataBuff;
tAttributeListRef       fInAttrListRef;
unsigned long           fInAttrInfoIndex;
tAttributeValueListRef  fOutAttrValueListRef;
tAttributeEntryPtr      fOutAttrInfoPtr;
} sGetAttributeEntry;

/*sSetAttributeValue

Structure received when an Open Directory client calls dsSetAttributeValue.

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
tAttributeValueEntryPtr fInAttrValueEntry;
} sSetAttributeValue;
Fields
fType

Always kSetAttributeValue.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to set the specified value in the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record for which a value is to be set in an attribute. The record reference was created when the plug-in processed an sOpenRecord structure.
fInAttrType

Value of type tDataNodePtr that points to a tDataNode structure containing the type the attribute whose value is to be set.
fInAttrValueEntry

Value of type tAttributeValueEntryPtr that points to a tAttributeValueEntry structure containing the value that is to be set and its attribute value ID.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sSetAttributeValue structure when an Open Directory client calls dsSetAttributeValue to set an attribute’s value.

The plug-in uses the fInRecRef field of the sSetAttributeValue structure to determine the record for which an attribute value is to be set and the fInAttrType field to determine the type of the attribute whose value is to be set. The fInAttrValueEntry field contains a pointer to a tAttributeValueEntry structure whose fAttributeValueID field identifies which value is to be replaced and whose fAttributeValueData field contains the new value.

If the plug-in can set the attribute value, it sets the value, sets fResult to eDSNoErr, and returns.

If the plug-in cannot set the attribute value, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
tAttributeValueEntryPtr fInAttrValueEntry;
} sSetAttributeValue;

/*sAddAttribute

Structure received when an Open Directory client calls dsAddAttribute.

typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInNewAttr;
tAccessControlEntryPtrfInNewAttrAccess;
tDataNodePtr        fInFirstAttrValue;
} sAddAttribute;

Fields
fType

Always kAddAttribute.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to add the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record to which the attribute is to be added. The record must have been previously opened when the plug-in’s routine for processing sOpenRecord structures was called.
fInNewAttr

Value of type tDataNodePtr that points to a value of type tDataNode containing the name of the attribute that is to be added.
fInNewAttrAccess

Reserved for this release. Client applications are advised to set this value to NULL. For this release, plug-ins should ignore the value of this field.
fInFirstAttrValue

Value of type tDataListPtr that points to a value of type tDataNode containing the first value of the attribute that is being added. The tDataNode may contain an empty string or fInFirsAttrValue may be NULL to indicate that the client application does not want to set the attribute’s value.
Discussion

When an Open Directory plug-in receives an sAddAttribute structure, it uses the fInRecRef field of the sAddAttribute structure to determine the record to which an attribute is to be added, the fInNewAttr field to obtain the name of the attribute that is to be added, and the fInFirstAttrValue field as the added attribute’s first value.

If the plug-in can the add the attribute, it adds the attribute, sets its first value, sets fResult to eDSNoErr, and returns.

If the plug-in cannot add the attribute, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInNewAttr;
tAccessControlEntryPtr fInNewAttrAccess;
tDataNodePtr        fInFirstAttrValue;
} sAddAttribute;

/*sGetRecordAttributeValueByIndex

Structure received when an Open Directory client calls dsGetRecordAttributeValueByIndex.

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
unsigned long           fInAttrValueIndex;
tAttributeValueEntryPtr fOutEntryPtr;
} sGetRecordAttributeValueByIndex;

Fields
fType

Always kGetRecordAttributeValueByIndex.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get the value of the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference that represents the record whose attribute value is to be obtained. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
fInAttrType

Value of type tDataNodePtr that points to a tDataNode structure containing the type of the attribute whose value is requested.
fInAttrValueIndex

Value of type unsigned long that specifies the attribute for which information is to be obtained, using a one-based index.
fOutEntryPtr

Value of type tAttributeValueEntryPtr that points to an tAttributeValueEntry in which the plug-in is to place the attribute’s value.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetRecordAttributeValueByIndex structure when an Open Directory client calls dsGetRecordAttributeValueByIndex to get the value of an attribute by its attribute index.

The plug-in uses the fInRecRef field of the sGetRecordAttributeValueByIndex structure to determine the record for which the value of an attribute is to be obtained, the fInAttrType field to determine the type of the attribute whose value is to be obtained, and the fInAttrValueIndex field to determine which attribute value to obtain.

If the plug-in can get the specified attribute value, it places the value in the attribute value entry structure pointed to by fOutEntryPtr, sets fResult to eDSNoErr, and returns.

If the plug-in cannot get the attribute’s value, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
unsigned long           fInAttrValueIndex;
tAttributeValueEntryPtr fOutEntryPtr;
} sGetRecordAttributeValueByIndex;

/*sDoDirNodeAuth

Structure received when an Open Directory client calls dsDoDirNodeAuth.

typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataNodePtr        fInAuthMethod;
bool                fInDirNodeAuthOnlyFlag;
tDataBufferPtr      fInAuthStepData;
tDataBufferPtr      fOutAuthStepDataResponse;
tContextData        fIOContinueData;
} sDoDirNodeAuth;

Fields
fType

Always kDoDirNodeAuth.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to authenticate the session. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node session that is to be authenticated. The directory node reference was created when the client application opened the session with the directory node.
fInAuthMethod

Value of type tDataNodePtr that points to a tDataNode structure containing the authentication task that is to be performed.Examples include kDSStdAuthSetPasswd, kDSStdAuthSetPasswdAsRoot, and kDSStdAuthChangePasswd to set or change a password and kDSStdAuthClearText and kDSStdAuth2WayRandom to authenticate a user for a directory node session. See the attribute constants described in the “Constants” section for possible values.
fInDirNodeAuthOnlyFlag

Boolean value that is TRUE if the client application does not want the result of this authentication to be used to grant or deny access for subsequent operations pertaining to this node. When the value of fInDirNodeAuthOnlyFlag is FALSE, the client application wants the result of this authentication to be applied to other operations that pertain to this directory node.
fInAuthStepData

Value of type tDataBufferPtr pointing to a tDataBuffer structure that contains a value that identifies the step in the authentication process for which the plug-in ProcessRequest routine has been called.
fOutAuthStepDataResponse

Value of type tDataBufferPtr that points to the tDataBuffer structure in which the plug-in is to place its response.
fIOContinueData

Value of type tContextData. If this the first step in the authentication process, fIOContinueData is NULL. If this is any other step, fIOContinueData should contain a value that the plug-in returned to the client application when the client previously called dsDoDirNodeAuth. The plug-in can use fIOContinueData to maintain context information about the authentication process as it progresses through the various steps required by the authentication method. You may want to include a timestamp in fIOContinueData and fail the next step in the authentication process if fIOContinueData is too old.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sDoDirNoteAuth structure when an Open Directory client calls dsDoDirNodeAuth to perform an authentication task.

The plug-in uses the fInNodeRef field of the sDoDirNodeAuth structure to determine the directory node for which the authentication task is to be perform and the fInAuthMethod field to determine the authentication task. The plug-in also uses the fInDirNodeAuthOnlyFlag field to determine whether to apply the results of the authentication to other Open Directory calls the client application may make, and the fInAuthStepData field indicates the current step in the authentication process.

If this step in the authentication process is successful, the plug-in sets fResult to eDSNoErr. If there are additional steps in the authentication process, the plug-in sets fOutAuthStepDataResponse to a value that is appropriate for this authentication method and sets fIOContinueData to a plug-in–defined value before returning. If this is the last step in the authentication process, the plug-in sets fIOContinueData to NULL.

If this step in the authentication process was not successful, the plug-in sets fResult to an appropriate result code as described in “Result Codes,” sets fIOContinueData to NULL, and returns.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataNodePtr        fInAuthMethod;
bool                fInDirNodeAuthOnlyFlag;
tDataBufferPtr      fInAuthStepData;
tDataBufferPtr      fOutAuthStepDataResponse;
tContextData        fIOContinueData;
} sDoDirNodeAuth;

/*sGetRecordEntry

Structure received when an Open Directory client calls dsGetRecordEntry.

typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataBufferPtr      fInOutDataBuff;
unsigned long       fInRecEntryIndex;
tAttributeListRef   fOutAttrListRef;
tRecordEntryPtr     fOutRecEntryPtr;
} sGetRecordEntry;

Fields
fType

Always kGetRecordEntry.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get the record entries for the directory node identified by fInNodeRef. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node for which the record entry is to be obtained. The directory node reference was created when the client application opened the directory node.
fInOutDataBuff

Value of type tDataBufferPtr that points to the tDataBuffer structure from which the record entry is to be obtained. 
fInRecEntryIndex

Value of type unsigned long that specifies the record to get. The fInRecEntryIndex field contains a value that is a one-based index.
fOutAttrListRef

Value of type tAttributeListRef assigned by the DirectoryService daemon and that the plug-in associates with the internal structure the plug-in uses to maintain information about the reference.
fOutRecEntryPtr

Value of type tRecordEntryPtr that points to a tRecordEntry structure containing the requested record.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetRecordEntry structure when an Open Directory client calls dsGetRecordEntry to get information about a record.

The plug-in gets information about the record from the buffer pointed to by fInOutDataBuff. The record information consists of the record’s name, type, and number of attributes. The buffer pointed to by fInOutDataBuff was previously filled in by the plug-in when the plug-in’s ProcessRequest routine responded to the receipt of an sGetRecordList structure.

The plug-in verifies that the directory node reference provided in the fInNodeRef field is valid. If the directory node reference is valid, the plug-in uses the fInRecEntryIndex field to determine the record for which record information is to be obtained, places the information in the record entry structure pointed to by the fOutRecEntryPtr field, and places the record’s attribute information in the attribute list referred to by tOutAttrListRef. Before returning, the plug-in sets fResult to eDSNoErr.

If the plug-in cannot get the requested information, it sets fResult to an appropriate result code as described in “Result Codes” and returns.

For information on parsing the data buffer, see the section “Client Side Buffer Parsing” in Chapter 1.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataBufferPtr      fInOutDataBuff;
unsigned long       fInRecEntryIndex;
tAttributeListRef   fOutAttrListRef;
tRecordEntryPtr     fOutRecEntryPtr;
} sGetRecordEntry;

/*sHeader

Structure for passing the DirectoryService daemon’s run loop and the Kerberos mutex.

typedef struct {
uInt32              fType;
sInt32              fResult;
tContextData        fContextData;
} sHeader;
Fields
fType

kServerRunLoop or kKerberosMutex.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fContextData

Value of type tContextData containing the run loop or the Kerberos mutex.
Discussion

The DirectoryService daemon calls the plug-in’s ProcessRequest entry point once after the plug-in has been loaded and initialized to pass in the fContextData field the CFRunloop for the currently executing process. You can use the run loop to set up timers as an alternative to using the PeriodicTask entry point for setting timers.

Here is an example that gets the run loop from the fContextData field:if ( ((sHeader *)inData)->fType == kServerRunLoop)
{
    if ( (((sHeader *)inData)->fContextData) != nil )
    {
        fServerRunLoop = (CFRunLoopRef)(((sHeader *)inData)->fContextData);
    }
}


The sHeader structure is also used to pass the Kerberos mutex, a value of type DSMutexSempaphore, immediately after the run loop is passed.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tContextData        fContextData;
} sHeader;

/*sSetRecordName

Structure received when an Open Directory client calls dsSetRecordName.

typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReferencefInRecRef;
tDataNodePtr    fInNewRecName;
} sSetRecordName;
Fields
fType

Always kSetRecordName.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to set the record’s name. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record whose name is to be set. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
fInNewRecName

Value of type tDataNodePtr that points to a tDataNode structure containing the name in UTF-8 encoding that is to be set.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sSetRecordName structure when an Open Directory client calls dsSetRecordName to set the name of a record.

The plug-in uses the fInRecRef field of the sSetRecordName structure to determine the record whose name is to be set.

If the plug-in can set the new name, it sets the new name, sets fResult to eDSNoErr, and returns.

If the plug-in cannot set the new name, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/

typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReference fInRecRef;
tDataNodePtr    fInNewRecName;
} sSetRecordName;

/*sOpenRecord

Structure received when an Open Directory client calls dsOpenRecord.

typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataNodePtr        fInRecType;
tDataNodePtr        fInRecName;
tRecordReference    fOutRecRef;
} sOpenRecord;
Fields
fType

Always kOpenRecord.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to open the specified record. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node of the record that is to be opened. The directory node reference was created when the client application opened the directory node.
fInRecType

Value of type tDataNodePtr that points to a tDataNode structure containing the type of the record that is to be opened.
fInRecName

Value of type tDataNodePtr that points to a tDataNode structure containing the name of the record that is to be opened. 
fOutRecRef

Value of type tRecordReference assigned by the DirectoryService daemon and that the plug-in associates with the internal structure the plug-in uses to maintain information about the reference.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sOpenRecord structure when an Open Directory client calls dsOpenRecord.

The plug-in uses the fInNodeRef field of the sOpenRecord structure to determine the directory node of the record that is to be opened, the fInRecType field to determine the type of the record that this is to be opened, and the fInRecName field to determine the name of the record that is to be opened.

If the plug-in can open the record, it sets fResult to eDSNoErr, and returns. Later, when the client application calls Open Directory functions that operate on the opened record, the record reference will be passed to the plug-in, which should use the record reference to identify the record.

If the plug-in cannot open the record, it should set fResult to an appropriate result code as described in “Result Codes” and return.*/

typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataNodePtr        fInRecType;
tDataNodePtr        fInRecName;
tRecordReference    fOutRecRef;
} sOpenRecord;

/*sGetRecordList

Structure called when an Open Directory client calls dsGetRecordList.

typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataBufferPtr      fInDataBuff;
tDataListPtr        fInRecNameList;
tDirPatternMatch    fInPatternMatch;
tDataListPtr        fInRecTypeList;
tDataListPtr        fInAttribTypeList;
bool                fInAttribInfoOnly;
unsigned long       fOutRecEntryCount;
tContextData        fIOContinueData;
} sGetRecordList;
Fields
fType

Always kGetRecordList.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get the requested list of records for the node identified by fInNodeRef. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.” If no matches are found, the plug-in should set fResult to eDSNoErr, fOutRecEntryCount to zero, and fIOContinueData to NULL.
fInNodeRef

Value of type tDirNodeReference that identifies the directory node for which the record list is to be obtained. The directory node reference was created when the client application opened the directory node.
fInDataBuff

Value of type tDataBufferPtr pointing to the tDataBuffer structure in which the plug-in is to return the record list.
fInRecNameList

Value of type tDataListPtr that points to a tDataList structure containing patterns in UTF-8 encoding that are to be compared with record names. If fInRecNameList is kDSRecordsAll, the plug-in should ignore fInPatternMatch and include all records for the directory node identified by fInNodeRef.
fInPatternMatch

Value of type tDirPatternMatch that describes the way in which the patterns specified by fInRecNameList are to be compared. See Pattern Matching Constants for possible constants. The pattern match type may also be a type defined by the Open Directory plug-in that handles the directory system represented by inDirReference.
fInRecTypeList

Value of type tDataListPtr that points to atDataList structure containing the types of records to get. See Standard Record Types and Meta Record Type Constants for possible values.
fInAttribTypeList

Value of type tDataListPtr that points to a tDataList structure containing the attribute types of records to get. See the attribute constants described in the “Constants” section for possible values.
fInAttribInfoOnly

Value of type bool. If fInAttribInfoOnly is TRUE, the plug-in should include in the buffer pointed to by fInDataBuff attribute information for matching records. If fInAttribInfoOnly is FALSE, the plug-in should include in the buffer pointed to by fInDataBuff attribute information as well as attribute values for matching records.
fOutRecEntryCount

Value of type unsigned long. The first time the client application calls dsGetRecordList, fOutRecEntryCount is zero to receive all matching records or is a positive integer value that specifies the total number of records the client application wants to receive across what may be a series of dsGetRecordList calls. If the latter, the plug-in should use the initial input value of fOutRecEntryCount to limit the total number of matching records it returns. Before returning, the plug-in should set fOutRecEntryCount to the number of records it has placed in the buffer pointed to by fInDataBuff. The plug-in should ignore the input value of fOutRecEntryCount whenever it is processing a sGetRecordList structure that has an fIOContinueData field that is not NULL.
fIOContinueData

Value of type tContextData containing continuation data. For the first in a series of calls to dsGetRecordList, the input value is NULL. If the plug-in can store all of the matching records in the buffer pointed to by fInDataBuff, it sets fIOContinueData to NULL before returning. If there more records than can be stored in the buffer, the plug-in stores as much data as possible and sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsGetRecordList again to get another buffer of data. You may want to include a timestamp in the continuation data and return an error if you determine that fOutContinueData is out of date.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetRecordList structure when an Open Directory client calls dsGetRecordList to get a list of records for a directory node.

The plug-in uses the fInNodeRef field of the sGetRecordList structure to determine the directory node for which the record list is requested, the data list pointed to by fInRecNameList to get the names of records for which information is requested, the data list pointed to by fInRecTypeList to determine the types of records for which information is requested, and the data list pointed to by fInAttributeTypeList to determine the attributes for which information is requested. The plug-in should return only those records whose names match the pattern specified by fInRecNameList. The value of the fInAttributeInfoOnly field determines whether the plug-in should also return attribute values.

Depending on the size of the data buffer pointed to by fInDataBuff and the length of the list of records, the plug-in’s routine for processing sGetRecordList structures may be called multiple times in order to return the complete list. The first time the plug-in’s routine for processing sGetRecordList structures is called, the input value of fIOContinueData is NULL and input value of fInOutRecEntryCount specifies the total number of records that the plug-in should return even if the plug-in’s routine for processing sGetRecordList structures must be called more than once.

If there are records that match the criteria specified by fInRecNameList, fInPatternMatch, fInRecTypeList, and fInAttributeTypeList, plug-in puts the record entries, attribute entries, and attribute values (if fInAttributeInfoOnly is FALSE) in the buffer pointed to by fInDataBuff. It also sets fInOutRecEntryCount to the number of records that have been placed in fInDataBuff and sets fResult to eDSNoErr. If the buffer pointed to by fInDataBuff is too small to hold all of the records, the plug-in sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsGetRecordList again to get another buffer of data. If the buffer pointed to by fInDataBuff contains all of the records or contains the last records in the record list, the plug-in sets fIOContinueData to NULL.

If the plug-in returns before it can get records to place in the buffer pointed to by fInDataBuff, it should set fOutRecEntryCount to zero, set fResult to eDSNoErr, set fIOContinueData to a plug-in–defined value that is not NULL. These settings indicate to the client application that it should call dsGetRecordList again to get the records.

If there are no matching records, the plug-in sets fOutRecEntryCount to zero, fIOContinueData to NULL, and fResult to eDSNoErr, and returns*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataBufferPtr      fInDataBuff;
tDataListPtr        fInRecNameList;
tDirPatternMatch    fInPatternMatch;
tDataListPtr        fInRecTypeList;
tDataListPtr        fInAttribTypeList;
bool                fInAttribInfoOnly;
unsigned long       fOutRecEntryCount;
tContextData        fIOContinueData;
} sGetRecordList;

/*sGetRecordAttributeValueByID

Structure received when an Open Directory client calls dsGetRecordAttributeValueByID.

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
unsigned long           fInAttrValueID;
tAttributeValueEntryPtr fOutEntryPtr;
} sGetRecordAttributeValueByID;
Fields
fType

Always kGetRecordAttributeValueByID.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get the value of the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference that represents the record for which an attribute value is to be obtained. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
fInAttrType

Value of type tDataNodePtr that points to a tDataNode structure containing the type of attribute for which an attribute value is requested.
fInAttrValueID

Value of type unsigned long that specifies the attribute value ID of the attribute value that is to be obtained.
fOutEntryPtr

Value of type tAttributeValueEntryPtr that points to an tAttributeValueEntry structure in which the plug-in places the requested attribute value.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetRecordAttributeValueByID structure when an Open Directory client calls dsGetRecordAttributeValueByID to get the value of an attribute by it attribute value ID.

The plug-in uses the fInRecRef field of the sGetRecordAttributeValueByID structure to determine the record for which the value of an attribute is to be obtained, the fInAttrType field to determine the type of the attribute whose value is to be obtained, and the fInAttrValueID field to determine the ID of the attribute value to get.

If the plug-in can get the specified attribute value, it places the value in the attribute value entry structure pointed to by fOutEntryPtr, sets fResult to eDSNoErr, and returns.

If the plug-in cannot get the attribute’s value, it sets fResult to an appropriate result code as described in “Result Codes” and returns*/
typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
unsigned long           fInValueID;
tAttributeValueEntryPtr fOutEntryPtr;
} sGetRecordAttributeValueByID;

/*sGetRecRefInfo

Structure received when an Open Directory client calls dsGetRecordReferenceInfo.

typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tRecordEntryPtr     fOutRecInfo;
} sGetRecRefInfo;

Fields
fType

Always kGetRecordRefInfo.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get information for the record reference specified by fInRecRef. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference that specifies the record for which information is to be obtained. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
fOutRecInfo

Value of type tRecordEntryPtr that points to a tRecordEntry structure containing the requested information. 
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetRecRefInfo structure when an Open Directory client calls dsGetRecordReferenceInfo to get information about a record.

The plug-in uses the fInRecRef field of the sGetRecRefInfo structure to determine the record for information is to be obtained. The information consists of the record’s name, type, and the number of attributes the record has.

If the plug-in can get the record’s information, it places the information in the record entry structure pointed to by fOutRecInfo, sets fResult to eDSnoErr, and returns.

If the plug-in cannot get the record’s information, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tRecordEntryPtr     fOutRecInfo;
} sGetRecRefInfo;

/*sFlushRecord

Structure received when an Open Directory client calls dsFlushRecord. 

typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReferencefInRecRef;
} sFlushRecord;

Fields
fType

Always kFlushRecord.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to flush the record. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record that is to be flushed. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sFlushRecord structure when an Open Directory client calls dsFlushRecord. 

The plug-in uses the fInRecRef field of the sFlushRecord structure to determine the record that is to be flushed. If the plug-in can write the record, it does so and sets fResult to eDSNoErr, and returns. If the plug-in cannot flush the record, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReference fInRecRef;
} sFlushRecord;

/*sCreateRecord

Structure received when an Open Directory client calls dsCreateRecord or dsCreateRecordAndOpen.

typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataNodePtr        fInRecType;
tDataNodePtr        fInRecName;
bool                fInOpen;
tRecordReference    fOutRecRef;
} sCreateRecord;

Fields
fType

Always kCreateRecord or kCreateRecordAndOpen.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to create the record. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node in which the record is to be created. The directory node reference was created when the client application opened a session with the directory node.
fInRecType

Value of type tDataNodePtr that points to a tDataNode structure containing the type that is to be assigned to the created record.
fInRecName

Value of type tDataNodePtr that points to a tDataNode structure containing the name that is to be assigned to the record that is created.
fInOpen

Boolean whose value is TRUE if the client application wants to create the record and open it. Otherwise, the value of fInOpen is FALSE to indicate that the client application wants to create the record without opening it.
fOutRecRef

Value of type tRecordReference assigned by the DirectoryService daemon and that the plug-in associates with the internal structure the plug-in uses to maintain information about the reference.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sCreateRecord structure when an Open Directory client calls dsCreateRecordor dsCreateRecordAndOpen to create a record.

The plug-in uses the fInNodeRef field of the sCreateRecord structure to determine the directory node in which the record is to be created, the fInRecType field to set the type of the record that is to be created, and the fInRecName field to set the name of the record that is to be created.

If the plug-in can create the new record, it sets fResult to eDSNoErr, and returns.

If the plug-in cannot create the new record, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tDirNodeReference   fInNodeRef;
tDataNodePtr        fInRecType;
tDataNodePtr        fInRecName;
bool                fInOpen;
tRecordReference    fOutRecRef;
} sCreateRecord;

/*sSetRecordType

Structure received when an Open Directory client application calls dsSetRecordType.

typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInNewRecType;
} sSetRecordType;

Fields
fType

Always kSetRecordType.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to set the record’s type. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record whose type is to be set. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
fInNewRecType

Value of type tDataNodePtr that points to a tDataNode structure containing the type that is to be set.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sSetRecordType structure when an Open Directory client calls dsSetRecordType to set a record’s type.

The plug-in uses the fInRecRef field of the sSetRecordType structure to determine the record whose type is to be set.

If the plug-in can set the new type, it sets the record to the new type, sets fResult to eDSNoErr, and returns.

If the plug-in cannot set the new type, it sets fResult to an appropriate result code as described in “Result Codes” and returns.

Note that this structure is deprecated in Mac OS X 10.3 and later and is not supported on LDAP.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInNewRecType;
} sSetRecordType;

/*sGetRecAttribInfo

Structure received when an Open Directory client calls dsGetRecordAttributeInfo. 

typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInAttrType;
tAttributeEntryPtr  fOutAttrInfoPtr;
} sGetRecAttribInfo;

Fields
fType

Always kGetRecordAttributeInfo.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get information about the attribute of the record referred to by fInRecRef. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference that represents the record for which information about an attribute is to be obtained. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
fInAttrType

Value of type tDataNodePtr that points to a tDataNode structure containing the attribute type for which information is requested.
fOutAttrInfoPtr

Value of type tAttributeValueEntryPtr that points to an tAttributeEntry structure containing the requested attribute information.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetRecAttribInfo structure when an Open Directory client calls dsGetRecordAttributeInfo.

The plug-in uses the fInRecRef field of the sGetRecAttribInfo structure to determine the record for which information about an attribute is to be obtained and the fInAttrType field to determine the attribute type for which attribute information is to be obtained. The information includes the number of values the attribute has, the total number of bytes the values use, the maximum size of a value for the specified attribute, and the attribute’s unique signature.

If the plug-in can get the attribute information, it places the information in the attribute entry structure pointed to by fOutAttrInfoPtr, sets fResult to eDSNoErr, and returns.

If the plug-in cannot get the attribute’s information, it sets fResult to an appropriate result code as described in “Result Codes” and returns*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInAttrType;
tAttributeEntryPtr  fOutAttrInfoPtr;
} sGetRecAttribInfo;

/*sCloseRecord

Structure received when an Open Directory client application calls dsCloseRecord.

typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReferencefInRecRef;
} sCloseRecord;
Fields
fType

Always kCloseRecord.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to close the record. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record that is to be closed. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sCloseRecord structure when an Open Directory client calls dsCloseRecord to close a record.

If the record can be closed, the plug-in ensures that any changes for the record that are cached in memory are saved to disk, invalidates the record reference specified in the fInRecRef field, invalidates any attribute list references and any attribute value list references associated with the record, sets fResult to eDSNoErr, and returns.

If the plug-in cannot close the record, it sets fResult to an appropriate result code as described in “Result Codes” and returns*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReference fInRecRef;
} sCloseRecord;

/*sRemoveAttributeValue

Structure received when an Open Directory client calls dsRemoveAttributeValue.

typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInAttrType;
unsigned long       fInAttrValueID;
} sRemoveAttributeValue;

Fields
fType

Always kRemoveAttributeValue.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to remove the value from the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record for which a value is to be removed to an attribute.
fInAttrType

Value of type tDataNodePtr that points to a tDataNode structure containing the type the attribute from which a value is to be removed.
fInAttrValueID

Value of type unsigned long that specifies the ID of the value that is to be removed.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sRemoveAttributeValue structure when an Open Directory client calls dsRemoveAttributeValue to remove a value from an attribute.

The plug-in uses the fInRecRef field of the sRemoveAttributeValue structure to determine the record for which a value is to be removed from an attribute, the fInAttrType field to determine the type of the attribute from which a value is to be removed, and the fInAttrValueID field to determine which attribute value to remove.

If the plug-in can remove the specified value from the specified attribute, it removes the attribute, invalidates any attribute value list references for the removed value, sets fResult to eDSNoErr, and returns. After returning, the plug-in responds with an error to any calls of its ProcessRequest entry point that provide a pointer to an attribute value entry structure for the removed attribute value.

If the plug-in cannot add the attribute value, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32              fType;
sInt32              fResult;
tRecordReference    fInRecRef;
tDataNodePtr        fInAttrType;
unsigned long       fInAttrValueID;
} sRemoveAttributeValue;

/*sRemoveAttribute

Structure received when an Open Directory client calls dsRemoveAttribute.

typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReferencefInRecRef;
tDataNodePtr    fInAttribute;
} sRemoveAttribute;
Fields
fType

Always kRemoveAttribute.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to remove the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record from which the attribute is to be removed.
fInAttribute

Value of type tDataNodePtr that points to a tDataNode structure containing the name of the attribute that is to be removed.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sRemoveAttribute structure when an Open Directory client calls dsRemoveAttribute to remove an attribute from a record.

The plug-in uses the fInRecRef field of the sRemoveAttribute structure to determine the record from which an attribute is to be removed and the fInAttribute field to determine the name of the attribute that is to be removed. 

If the plug-in can remove the attribute, it removes the attribute and all of its values, invalidates any attribute list references that may be active for this attribute, sets fResult to eDSNoErr, and returns. After returning, the plug-in responds with an error to any calls of its ProcessRequest entry point that provide a pointers to an attribute entry structure or an attribute value entry structure for the removed attribute.

If the plug-in cannot remove the attribute, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReference fInRecRef;
tDataNodePtr    fInAttribute;
} sRemoveAttribute;

/*sAddAttributeValue

Structure when an Open Directory client calls dsAddAttributeValue.

typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReferencefInRecRef;
tDataNodePtr    fInAttrType;
tDataNodePtr    fInAttrValue;
} sAddAttributeValue;
Fields
fType

Always kAddAttributeValue.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to add the value to the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record for which a value is to be add to an attribute.
fInAttrType

Value of type tDataNodePtr that points to a value of type tDataNode containing the type of the attribute to which a value is to be added.
fInAttrValue

Value of type tDataNodePtr that points to a value of type tDataNode containing the value that is to be added.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sAddAttributeValue structure when an Open Directory client calls dsAddAttributeValue.

The plug-in should verify that the attribute is capable of having multiple values. It then uses the fInRecRef field of the sAddAttributeValue structure to determine the record that has the attribute to which a value is to be added, the fInAttrType field to determine the type of the attribute to which a value is to be added, and the fInAttrValue field to get the value to that is to be added.

If the plug-in can add the specified value to the specified attribute, it adds the value and creates a unique attribute value ID for it, sets fResult to eDSNoErr, and returns.

If the plug-in cannot add the value to the attribute, it sets fResult to an appropriate result code as described in “Result Codes” and returns*/

typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReference fInRecRef;
tDataNodePtr    fInAttrType;
tDataNodePtr    fInAttrValue;
} sAddAttributeValue;

/*sDoPluginCustomCall

Structure received when an Open Directory client calls dsDoPluginCustomCall.

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirNodeReferencefInNodeRef;
unsigned long   fInRequestCode;
tDataBufferPtr  fInRequestData;
tDataBufferPtr  fOutRequestResponse;
} sDoPlugInCustomCall;
Fields
fType

Always kDoPlugInCustomCall.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that the plug-in responded without error when it processed the sDoPluginCustomCall structure. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInNodeRef

Value of type tDirNodeReference that identifies the directory node session to which fInRequestCode and fInRequestData apply.
fInRequestCode

Value of type unsigned long that contains a request code that has significance to the plug-in.
fInRequestData

Value of type tDataBufferPtr that points to a tDataBuffer structure containing data sent by the client application to the plug-in.
fOutRequestResponse

Value of type tDataBufferPtr that points to a tDataBuffer structure in which the plug-in places data that is to be returned to the client application.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sDoPluginCustomCall structure when an Open Directory client calls dsDoPluginCustomCall to send custom data to the plug-in.

The plug-in verifies that the directory node reference stored in fInNodeRef is valid. It then interprets the value of the fInRequestCode field, parses the value pointed to by the fInRequestData field, and performs an action that is appropriate for the request code. If the plug-in needs to return data to the client application, it stores the data in the tDatabuffer structure pointed to by fOutRequestResponse.

If the plug-in performs the action without error, it sets fResult to eDSNoErr; otherwise, it sets fResult to an appropriate result code as described in “Result Codes.”*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tDirNodeReference fInNodeRef;
unsigned long   fInRequestCode;
tDataBufferPtr  fInRequestData;
tDataBufferPtr  fOutRequestResponse;
} sDoPlugInCustomCall;

/*sDoAttrValueSearch

Structure received when an Open Directory client calls dsDoAttributeValueSearch. 

typedef struct {
uInt32          fType;
sInt32          fResult;
tDirNodeReferencefInNodeRef;
tDataBufferPtr  fOutDataBuff;
tDataListPtr    fInRecTypeList;
tDataNodePtr    fInAttrType;
tDirPatternMatchfInPattMatchType;
tDataNodePtr    fInPatt2Match;
unsigned long   fInOutMatchRecordCount;
tContextData    fIOContinueData;
} sDoAttrValueSearch;

Fields
fType

Always kDoAttributeValueSearch.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to search for the attribute values. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.” If no matches are found, the plug-in should set fResult to eDSNoErr, fInOutMatchRecordCount to zero, and fIOContinueData to NULL.
fInNodeRef

Value of type tDirNodeReference that identifies the directory node for which the search is to be conducted. The directory node reference was created when the client application opened the directory node session.
fOutDataBuff

Value of type tDataBufferPtr that points to the tDataBuffer structure in which the plug-in is to place search results.
fInRecTypeList

Value of type tDataListPtr pointing to a tDataList structure containing the record types that are to be searched. See Standard Record Types and Meta Record Type Constants for possible values. If NULL, set fResult to eDSEmptyRecordTypeList and return.
fInAttrType

Value of type tDataNodePtr pointing to a tDataNode structure containing the attribute types that are to be searched for. See the attribute constants described in the “Constants” section for possible values. If NULL, set fResult to eDSEmptyAttributeType and return.
fInPattMatchType

Value of type tDirPatternMatch that describes the way in which the pattern specified by fInPatt2Match is to be matched. The pattern match type can be a value that the plug-in and application agree upon or a constant defined by Open Directory, as described in the section Pattern Matching Constants.
fInPatt2Match

Value of type tDataNodePtr pointing to a tDataNode structure containing the pattern that is to be matched.
fInOutMatchRecordCount

Value of type unsigned long. The first time the client application calls dsDoAttributeValueSearch, fInOutMatchRecordCount is zero to receive all matching records or is a positive integer value that specifies the total number of records the client application wants to receive across what may be a series of dsDoAttributeValueSearch calls. If the latter, the plug-in should use the initial input value of fInOutMatchRecordCount to limit the total number of matching records it returns. Before returning, the plug-in should set fInOutMatchRecordCount to the number of records it has placed in the buffer pointed to by fOutDataBuff. The plug-in should ignore the input value of fInOutMatchRecordCount whenever it is processing a sDoAttrValueSearch structure that has an fIOContinueData field that is not NULL.
fIOContinueData

Value of type tContextData containing continuation data. For the first in a series of calls to dsDoAttributeValueSearch, the input value is NULL. If the plug-in can store all of the matching records in the buffer pointed to by fOutDataBuff, it sets fIOContinueData to NULL before returning. If there more records than can be stored in the buffer, the plug-in stores as much data as possible and sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoAttributeValueSearch again to get another buffer of data. You may want to include a timestamp in the continuation data and return an error if you determine that fOutContinueData is out of date.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sDoAttrValueSearch structure when an Open Directory client calls dsDoAttributeValueSearch to search for records that have attributes whose values match a pattern.

The plug-in uses the fInNodeRef field of the sDoAttrValueSearch structure to determine the directory node in which the search is to be conducted, the fInRecTypeList field to determine the record types that are to be searched, the fInAttrType field to determine the attribute types that are to be searched, the fInPatt2Match field to get the pattern to match, and the fInPattMatchType field to determine the way in which the pattern is to be compared. If this is the first in what may be a series of calls to get the complete search results, the fIOContinueData field is NULL. Otherwise, fIOContinueData contains a plug-in–defined value that the plug-in uses to provide the context required to resume filling the buffer pointed to by fOutDataBuff with search results.

Depending on the size of the data buffer pointed to by fOutDataBuff and the length of the search results, the plug-in’s routine for processing sDoAttrValueSearch structures may be called multiple times in order to return all of the search results. The first time the plug-in’s routine for processing sDoAttrValueSearch structures is called, the input value of fIOContinueData is NULL and input value of fInOutRecEntryCount specifies the total number of records that the plug-in should return even if the plug-in’s routine for processing sDoAttrValueSearch structures must be called more than once.

If there are records that match the search criteria specified by fInRecTypeList, fInAttrType, fInPattMatchType, and fInPatt2Match, the plug-in puts the record entries, attribute entries, and attribute values in the buffer pointed to by fOutDataBuff. It also sets fInOutMatchRecordCount to the number of records that have been placed in fOutDataBuff and sets fResult to eDSNoErr. If the buffer pointed to by fOutDataBuff is too small to hold all of the data, the plug-in sets fIOContinueData to a plug-in–defined value that the plug-in can use when the client application calls dsDoAttributeValueSearch again to get another buffer of data. If the buffer pointed to by fOutDataBuff contains all of the records or contains the last records in the record list, the plug-in sets fIOContinueData to NULL.

If the plug-in returns before it gets search results to place in the buffer pointed to by fOutDataBuff, it should set fInOutMatchRecordCount to zero, set fResult to eDSNoErr, and set fIOContinueData to a plug-in–defined value that is not NULL. These settings indicate to the client application that it should call dsDoAttributeValueSearch again to get the search results.

If there are no matching records, the plug-in sets fInOutMatchRecordCount to zero, fIOContinueData to NULL, sets fResult to eDSNoErr, and returns.*/

typedef struct {
	UInt32					fType;
	SInt32					fResult;
	tDirNodeReference		fInNodeRef;
	tDataBufferPtr			fOutDataBuff;
	tDataListPtr			fInRecTypeList;
	tDataNodePtr			fInAttrType;
	tDirPatternMatch		fInPattMatchType;
	tDataNodePtr			fInPatt2Match;
	UInt32					fOutMatchRecordCount;
	tContextData			fIOContinueData;
} sDoAttrValueSearch;

/*sGetRecordAttributeValueByValue

Structure received when an Open Directory client calls dsGetRecordAttributeValueByValue.

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
tDataNodePtr            fInAttrValue;
tAttributeValueEntryPtr fOutEntryPtr;
} sGetRecordAttributeValueByValue;
Fields
fType

Always kGetRecordAttributeValueByValue.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to get the value of the attribute. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference that represents the record whose attribute value is to be obtained. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
fInAttrType

Value of type tDataNodePtr that points to a tDataNode structure containing the type of the attribute whose value is requested.
fInAttrValue

Value of type tDataNodePtr that specifies the value that is to be obtained.
fOutEntryPtr

Value of type tAttributeValueEntryPtr that points to an tAttributeValueEntry in which the plug-in is to place the attribute’s value.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sGetRecordAttributeValueByValue structure when an Open Directory client calls dsGetRecordAttributeValueByValue to get the value of an attribute by its value.

The plug-in uses the fInRecRef field of the sGetRecordAttributeValueByValue structure to determine the record for which the value of an attribute is to be obtained, the fInAttrType field to determine the type of the attribute whose value is to be obtained, and the fInAttrValue field to determine which attribute value to obtain.

If the plug-in can get the specified attribute value, it places the value in the attribute value entry structure pointed to by fOutEntryPtr, sets fResult to eDSNoErr, and returns.

If the plug-in cannot get the attribute’s value, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32                  fType;
sInt32                  fResult;
tRecordReference        fInRecRef;
tDataNodePtr            fInAttrType;
tDataNodePtr            fInAttrValue;
tAttributeValueEntryPtr fOutEntryPtr;
} sGetRecordAttributeValueByValue;

/*sDeleteRecord

Structure received when an Open Directory client calls dsDeleteRecord.

typedef struct {
uInt32          fType
sInt32          fResult;
tRecordReferencefInRecRef;
} sDeleteRecord;
Fields
fType

Always kDeleteRecord.
fResult

Value of type uInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to delete the record. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInRecRef

Value of type tRecordReference representing the record that is to be deleted. The plug-in created the value of fInRecRef when it was called to process a request to open the record.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sDeleteRecord structure when an Open Directory client calls dsDeleteRecord to delete a record.

The plug-in uses the fInRecRef field of the sDeleteRecord structure to determine the record that is to be deleted. If the plug-in can delete the record, it invalidates the record reference specified by the fInRecRef field, invalidates any attribute list references and any attribute value list references associated with the record, sets fResult to eDSNoErr, and returns.

If the plug-in cannot delete the record, it sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tRecordReference fInRecRef;
} sDeleteRecord;

/*sCloseAttributeList

Structure received when an Open Directory client calls dsCloseAttributeList.

typedef struct {
uInt32          fType;
sInt32          fResult;
tAttributeListReffInAttributeListRef;
} sCloseAttributeList;

Fields
fType

Always kCloseAttributeList.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to close the specified attribute list reference. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInAttributeListRef

Value of type tAttributeListRef representing the attribute list reference that is to be closed.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sCloseAttributeList structure when an Open Directory client calls dsCloseAttributeList to dispose of an attribute list reference.

If the attribute value list is valid, the plug-in disposes of it, sets fResult to eDSNoErr, and returns. If the attribute list reference is invalid, the plug-in sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32          fType;
sInt32          fResult;
tAttributeListRef fInAttributeListRef;
} sCloseAttributeList;

/*sCloseAttributeValueList

Structure received when an Open Directory client calls dsCloseAttributeValueList.

typedef struct {
uInt32                  fType;
sInt32                  fResult;
tAttributeValueListReff InAttributeValueListRef;
} sCloseAttributeValueList;
Fields
fType

Always kCloseAttributeValueList.
fResult

Value of type sInt32 that the plug-in sets to eDSNoErr before returning to indicate that it was able to close the specified attribute value list reference. If an error occurs, the plug-in sets fResult to a value listed in “Result Codes.”
fInAttributeValueListRef

Value of type tAttributeValueListRef representing the attribute value list reference that is to be closed.
Discussion

The DirectoryService daemon calls a plug-in’s ProcessRequest entry point and passes an sCloseAttributeValueList structure when an Open Directory client calls dsCloseAttributeValueList to dispose of an attribute value list reference.

If the attribute value list reference is valid, the plug-in disposes of it, sets fResult to eDSNoErr, and returns. If the attribute value list reference is invalid, the plug-in sets fResult to an appropriate result code as described in “Result Codes” and returns.*/
typedef struct {
uInt32                  fType;
sInt32                  fResult;
tAttributeValueListRef fInAttributeValueListRef;
} sCloseAttributeValueList;

#endif // __PluginData_H__
