#ifndef FOUNDATION_NSDATAFORMATTER_H
#define FOUNDATION_NSDATAFORMATTER_H

#import <Foundation/NSFormatter.h>
#include <CoreFoundation/CFDateFormatter.h>

#ifdef OS_API_VERSION
	#undef OS_API_VERSION
	#define OS_API_VERSION(a,b) 1
	#define OS_API_VERSION_DEF 1
#endif

#import "/usr/GNUstep/System/Library/Headers/Foundation/NSDateFormatter.h"

#ifdef OS_API_VERSION_DEF

#undef OS_API_VERSION

#define OS_API_VERSION(ADD,REM) (!defined(GS_OPENSTEP_V) || (GS_OPENSTEP_V >=ADD && GS_OPENSTEP_V < REM))//GSVersionMacros.h

	#undef OS_API_VERSION_DEF

#endif



@class NSLocale, NSDate, NSCalendar, NSTimeZone, NSError, NSArray, NSMutableDictionary;

/*NSDateFormatterBehavior

Constants that specify the behavior NSDateFormatter should exhibit. 

typedef enum {
   NSDateFormatterBehaviorDefault = 0,
   NSDateFormatterBehavior10_0    = 1000,
   NSDateFormatterBehavior10_4    = 1040,
} NSDateFormatterBehavior;

Constants
NSDateFormatterBehaviorDefault

Specifies default formatting behavior.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
NSDateFormatterBehavior10_0

Specifies formatting behavior equivalent to that in Mac OS X 10.0.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
NSDateFormatterBehavior10_4

Specifies formatting behavior equivalent for Mac OS X 10.4.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
Availability
Available in Mac OS X v10.4 and later.
Declared In
NSDateFormatter.h*/
typedef enum {
   NSDateFormatterBehaviorDefault = 0,
   NSDateFormatterBehavior10_0    = 1000,
   NSDateFormatterBehavior10_4    = 1040,
} NSDateFormatterBehavior;

/*NSDateFormatterStyle

The following constants specify predefined date and time format styles.

typedef enum {
   NSDateFormatterNoStyle     = kCFDateFormatterNoStyle,
   NSDateFormatterShortStyle  = kCFDateFormatterShortStyle,
   NSDateFormatterMediumStyle = kCFDateFormatterMediumStyle,
   NSDateFormatterLongStyle   = kCFDateFormatterLongStyle,
   NSDateFormatterFullStyle   = kCFDateFormatterFullStyle
} NSDateFormatterStyle;

Constants
NSDateFormatterNoStyle

Specifies no style.

Equal to kCFDateFormatterNoStyle.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
NSDateFormatterShortStyle

Specifies a short style, typically numeric only, such as “11/23/37” or “3:30pm”.

Equal to kCFDateFormatterShortStyle.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
NSDateFormatterMediumStyle

Specifies a medium style, typically with abbreviated text, such as “Nov 23, 1937”.

Equal to kCFDateFormatterMediumStyle.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
NSDateFormatterLongStyle

Specifies a long style, typically with full text, such as “November 23, 1937” or “3:30:32pm”.

Equal to kCFDateFormatterLongStyle.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
NSDateFormatterFullStyle

Specifies a full style with complete details, such as “Tuesday, April 12, 1952 AD” or “3:30:42pm PST”.

Equal to kCFDateFormatterFullStyle.

Available in Mac OS X v10.4 and later.

Declared in NSDateFormatter.h
Discussion

The format for these date and time styles is not exact because they depend on the locale, user preference settings, and the operating system version. Do not use these constants if you want an exact format.
Availability
Available in Mac OS X v10.4 and later.
Declared In
NSDateFormatter.h*/
typedef enum {
   NSDateFormatterNoStyle     = kCFDateFormatterNoStyle,
   NSDateFormatterShortStyle  = kCFDateFormatterShortStyle,
   NSDateFormatterMediumStyle = kCFDateFormatterMediumStyle,
   NSDateFormatterLongStyle   = kCFDateFormatterLongStyle,
   NSDateFormatterFullStyle   = kCFDateFormatterFullStyle
} NSDateFormatterStyle;

@interface NSDateFormatter (OC)

/*setDateStyle:

Sets the date style of the receiver.

- (void)setDateStyle:(NSDateFormatterStyle)style
Parameters
style

The date style of the receiver. For possible values, see NSDateFormatterStyle.
Availability
Available in Mac OS X v10.4 and later.
See Also
– dateStyle.
Declared In
NSDateFormatter.h*/

- (void)setDateStyle:(NSDateFormatterStyle)style;

/*setTimeStyle:

Sets the time style of the receiver.

- (void)setTimeStyle:(NSDateFormatterStyle)style
Parameters
style

The time style for the receiver. For possible values, see NSDateFormatterStyle.
Availability
Available in Mac OS X v10.4 and later.
See Also
– timeStyle
Declared In
NSDateFormatter.h*/
- (void)setTimeStyle:(NSDateFormatterStyle)style;

/*setDefaultFormatterBehavior:

Sets the default formatting behavior for instances of the class.

+ (void)setDefaultFormatterBehavior:(NSDateFormatterBehavior)behavior
Parameters
behavior

The default formatting behavior for instances of the class. For possible values, see NSDateFormatterBehavior.
Availability
Available in Mac OS X v10.4 and later.
See Also
+ defaultFormatterBehavior
– formatterBehavior
– setFormatterBehavior:
Declared In
NSDateFormatter.h*/
+ (void)setDefaultFormatterBehavior:(NSDateFormatterBehavior)behavior;

/* stringFromDate:

Returns a string representation of a given date formatted using the receiver’s current settings.

- (NSString *)stringFromDate:(NSDate *)date
Parameters

date

    The date to format.

Return Value

A string representation of date formatted using the receiver’s current settings.
Availability

    * Available in Mac OS X v10.4 and later.

See Also

    * – dateFromString:

Declared In
NSDateFormatter.h */
- (NSString *)stringFromDate:(NSDate *)date;

@end

//@interface NSDateFormatter (NSDateFormatterCompatibility)
//@end

#endif

