#ifndef OC_FOUNDATION_NSSTRING_H
#define OC_FOUNDATION_NSSTRING_H

#import <limits.h>
#import <Foundation/NSObject.h>
#import <Foundation/NSRange.h>
#import <stdarg.h>


#import "/usr/GNUstep/System/Library/Headers/Foundation/NSString.h"

@class NSData, NSArray, NSDictionary, NSCharacterSet, NSData, NSURL, NSError, NSLocale;

@interface NSString (OC)
@end

@interface NSString (NSStringExtensionMethods)

/*writeToFile:atomically:encoding:error:

Writes the contents of the receiver to a file at a given path using a given encoding. 

- (BOOL)writeToFile:(NSString *)path atomically:(BOOL)useAuxiliaryFile encoding:(NSStringEncoding)enc error:(NSError **)error
Parameters
path

The file to which to write the receiver. If path contains a tilde (~) character, you must expand it with stringByExpandingTildeInPath before invoking this method.
useAuxiliaryFile

If YES, the receiver is written to an auxiliary file, and then the auxiliary file is renamed to path. If NO, the receiver is written directly to path. The YES option guarantees that path, if it exists at all, won’t be corrupted even if the system should crash during writing.
enc

The encoding to use for the output.
error

If there is an error, upon return contains an NSError object that describes the problem. If you are not interested in details of errors, you may pass in NULL.
Return Value

YES if the file is written successfully, otherwise NO (if there was a problem writing to the file or with the encoding).
Discussion

This method overwrites any existing file at path.
Availability
Available in Mac OS X v10.4 and later.
Declared In
NSString.h*/
- (BOOL)writeToFile:(NSString *)path atomically:(BOOL)useAuxiliaryFile encoding:(NSStringEncoding)enc error:(NSError **)error;

/*stringWithContentsOfFile:encoding:error:

Returns a string created by reading data from the file at a given path interpreted using a given encoding.

+ (id)stringWithContentsOfFile:(NSString *)path encoding:(NSStringEncoding)enc error:(NSError **)error
Parameters

path

    A path to a file.
enc

    The encoding of the file at path.
error

    If an error occurs, upon returns contains an NSError object that describes the problem. If you are not interested in possible errors, pass in NULL.

Return Value

A string created by reading data from the file named by path using the encoding, enc. If the file cant be opened or there is an encoding error, returns nil.
Availability

    * Available in Mac OS X v10.4 and later.

See Also

    * ? initWithContentsOfFile:encoding:error:

Declared In
NSString.h*/
+ (id)stringWithContentsOfFile:(NSString *)path encoding:(NSStringEncoding)enc error:(NSError **)error;

@end//NSStringExtensionMethods

#endif//OC_FOUNDATION_NSSTRING_H
