#ifndef MACAPPLICATION_H
#define MACAPPLICATION_H

#ifndef APPLICATIONSERVICES_H
#include <ApplicationServices/ApplicationServices.h>
#endif

#ifndef MENUS_H
#include <HIToolbox/Menus.h>
#endif

#ifndef HIOBJECT_H
#include <HIToolbox/HIObject.h>
#endif



#include <AvailabilityMacros.h>

#if PRAGMA_ONCE
#pragma once
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*Presentation Options
Flags used to control optional behavior of system-provided user interface elements and features.


enum {
   kUIOptionAutoShowMenuBar = 1 << 0,
   kUIOptionDisableAppleMenu = 1 << 2,
   kUIOptionDisableProcessSwitch = 1 << 3,
   kUIOptionDisableForceQuit = 1 << 4,
   kUIOptionDisableSessionTerminate = 1 << 5,
   kUIOptionDisableHide = 1 << 6
};
typedef OptionBits SystemUIOptions;

Constants
kUIOptionAutoShowMenuBar
This flag specifies that the menu bar automatically shows itself when the user moves the mouse into the screen area that would ordinarily be occupied by the menu bar. Only valid for the presentation mode kUIModeAllHidden.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIOptionDisableAppleMenu
This flag disables all items in the Apple menu. Valid for all presentation modes.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIOptionDisableProcessSwitch
This flag disables the Command-Tab and Command-Shift-Tab key sequences to switch the active process, and the global window rotation key sequence selected by the user in the Keyboard preference pane. The function SetFrontProcess may still be used to explicitly switch the active process. Only valid with presentation modes other than kUIModeNormal.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIOptionDisableForceQuit
This flag disables the Command-Option-Escape key sequence and the Force Quit menu item in the Apple menu to open the Force Quit window. Only valid with presentation modes other than kUIModeNormal.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIOptionDisableSessionTerminate
This flag disables the Power key (if present) and the Restart, Shut Down, and Log Out menu items in the Apple menu. Only valid with modes other than kUIModeNormal.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIOptionDisableHide
This flag disables the Hide menu item in the Application menu. Note that this option does not prevent this application from being hidden if Hide Others is selected in some other application.

Available in Mac OS X v10.3 and later.

Declared in MacApplication.h

Discussion
Presentation mode options are used to inhibit or allow certain user interface elements and commands. Your application can specify these options using the function SetSystemUIMode.*/
enum {
   kUIOptionAutoShowMenuBar = 1 << 0,
   kUIOptionDisableAppleMenu = 1 << 2,
   kUIOptionDisableProcessSwitch = 1 << 3,
   kUIOptionDisableForceQuit = 1 << 4,
   kUIOptionDisableSessionTerminate = 1 << 5,
   kUIOptionDisableHide = 1 << 6
};
typedef OptionBits SystemUIOptions;

/*Presentation Modes
Constants used to control the presentation of user interface elements provided by Mac OS X, such as the menu bar and Dock.


enum {
   kUIModeNormal = 0,
   kUIModeContentSuppressed = 1,
   kUIModeContentHidden = 2,
   kUIModeAllSuppressed = 4,
   kUIModeAllHidden = 3,
};
typedef UInt32 SystemUIMode;

Constants
kUIModeNormal
All standard system UI elements are visible.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIModeContentSuppressed
System UI elements positioned in the content area of the screen (the area other than the menu bar) are hidden. However, these elements may automatically show themselves in response to mouse movements or other user activity.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIModeContentHidden
System UI elements positioned in the content area of the screen (the area other than the menu bar) are hidden.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

kUIModeAllSuppressed
All system UI elements (including the menu bar) are hidden. However, these elements may automatically show themselves in response to mouse movements or other user activity.

Available in Mac OS X v10.3 and later.

Declared in MacApplication.h

kUIModeAllHidden
All system UI elements (including the menu bar) are hidden.

Available in Mac OS X v10.2 and later.

Declared in MacApplication.h

Discussion
The presentation mode of an application determines which system-provided user interface elements are visible on the screen. Your application can specify its presentation mode using the function SetSystemUIMode.*/


enum {
   kUIModeNormal = 0,
   kUIModeContentSuppressed = 1,
   kUIModeContentHidden = 2,
   kUIModeAllSuppressed = 4,
   kUIModeAllHidden = 3,
};
typedef UInt32 SystemUIMode;

//func

/*GetApplicationTextEncoding

Returns the application text encoding for Resource Manager resources.

TextEncoding GetApplicationTextEncoding ();
Return Value

See the Text Encoding Conversion Manager documentation for a description of the TextEncoding data type.
Discussion

Your application needs to use the application text encoding when it creates a CFStringRef from text stored in Resource Manager resources. Typically the text uses a Mac encoding such as MacRoman or MacJapanese. 
Availability
Available in CarbonLib 1.2 and later.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/
TextEncoding GetApplicationTextEncoding ();

/*BeginCGContextForApplicationDockTile

Allocates a context reference (CGContextRef). 

CGContextRef BeginCGContextForApplicationDockTile ();
Return Value

A reference to a context reference. See the Quartz 2D documentation for a description of the CGContextRef data type.
Discussion

You can use this context to draw into your application Dock tile with Quartz. You must call the function EndCGContextForApplicationDockTile to lock your application tile in the Dock. Do not call the function CGEndContext for this purpose as it is not designed to work with a context reference for an application Dock tile. 
Availability
Not available in Carbon.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/
CGContextRef BeginCGContextForApplicationDockTile ();

/*EndCGContextForApplicationDockTile

Disposes of the context reference (CGContextRef ) for your application tile and frees the lock on the application Dock tile.

void EndCGContextForApplicationDockTile (
   CGContextRef inContext
);
Parameters
inContext

A reference to the context you want to end. The context is invalid after this call and should no longer be used. 
Discussion

You must call the function EndCGContextForApplicationDockTile when you use the function BeginCGContextForApplicationDockTile. Do not use the function CGEndContext as the context associated with the application’s Dock tile won’t be disposed of and the lock on the application Dock tile won’t be freed. 
Availability
Not available in Carbon.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/
void EndCGContextForApplicationDockTile (
   CGContextRef inContext
);

/*RestoreApplicationDockTileImage

Restores your application Dock icon to the application icon. 

OSStatus RestoreApplicationDockTileImage ();
Return Value

A result code.
Discussion

If you’ve called the functions SetApplicationDockTileImage or OverlayApplicationDockTileImage, you can use the function RestoreApplicationDockTileImage to restore the Dock icon to the original application icon. 
Availability
Not available in Carbon.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/

OSStatus RestoreApplicationDockTileImage ();

/*EndQDContextForApplicationDockTile

Disposes of the QuickDraw graphics port for your application Dock tile and frees the lock on the application Dock tile. 

void EndQDContextForApplicationDockTile (
   CGrafPtr inContext
);
Parameters
inContext

The context to end. The context is invalid after this call and should no longer be used. 
Discussion

You must call the function EndQDContextForApplicationDockTile when you use the function BeginQDContextForApplicationDockTile. Do not use the function DisposePort as the QuickDraw port won’t be disposed of and the lock on the application Dock tile won’t be freed. 
Availability
Not available in Carbon.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/

void EndQDContextForApplicationDockTile (
   CGrafPtr inContext
);

/*BeginQDContextForApplicationDockTile

Allocates a QuickDraw graphics port (CGrafPtr) for your application tile in the dock. 

CGrafPtr BeginQDContextForApplicationDockTile ();
Return Value

A pointer to a QuickDraw graphics port. See the QuickDraw Manager documentation for a description of the CGrafPtr data type.
Discussion

You can use this port to draw into your application Dock tile with QuickDraw. You must call the function EndQDContextForApplicationDockTile when you use the function BeginQDContextForApplicationDockTile. Do not use the function DisposePort as it is not designed to work with a QuickDraw context. 
Availability
Not available in Carbon.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/
CGrafPtr BeginQDContextForApplicationDockTile ();

/*OverlayApplicationDockTileImage

Composites an image with your application's Dock icon.

OSStatus OverlayApplicationDockTileImage (
   CGImageRef inImage
);
Parameters
inImage

A reference to the image you wish to overlay onto your application’s Dock icon. 
Return Value

A result code.
Discussion

You can overlay an image, such as a badge, to indicate the application’s status to the user. 
Availability
Not available in Carbon.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/
OSStatus OverlayApplicationDockTileImage (
   CGImageRef inImage
);

/*CreateCGImageFromPixMaps

Creates an image reference (CGImageRef) from an image and a mask. 

OSStatus CreateCGImageFromPixMaps (
   PixMapHandle inImage,
   PixMapHandle inMask,
   CGImageRef * outImage
);
Parameters
inImage

A handle to the image you want to use to create the image reference. The image should be the same size as the mask. For use in the Dock, the image should be 128 pixels square. Otherwise, the image can be any size. 
inMask

A handle to the mask to use as the alpha channel. The mask should be the same size as the image.
outImage

On return, a pointer to an image reference. 
Return Value

A result code. 
Discussion

The function CreateCGImageFromPixMaps uses the mask as the alpha channel for the resulting image. This allows you to have any level of transparency in the resulting image. You can pass the image reference as a parameter to any Quartz2D drawing function, as well as to Dock tile functions such as the functions SetApplicationDockTileImage and OverlayApplicationDockTileImage. You can use CreateCGImageFromPixMaps to create an image reference for a badge, and then apply the badge to your application Dock icon. 
Availability
Not available in Carbon.
Available in Mac OS X 10.0 and later.
Declared In
MacApplication.h*/
OSStatus CreateCGImageFromPixMaps (
   PixMapHandle inImage,
   PixMapHandle inMask,
   CGImageRef * outImage
);

/*SetSystemUIMode

Sets the presentation mode of the calling application.

OSStatus SetSystemUIMode (
   SystemUIMode inMode,
   SystemUIOptions inOptions
);

Parameters
inMode

The new presentation mode. Pass one of the constants listed in “Presentation Modes.” The presentation mode of an application determines which system-provided user interface elements are visible on the screen.
inOptions

A mask that specifies options controlling how the specified presentation mode behaves. Pass one or more of the flags listed in “Presentation Options,” or zero to indicate that no options are needed. Presentation options are used to inhibit or allow certain user interface elements and commands.
Return Value

A result code.
Discussion

The purpose of this function is to make it easier to implement a dedicated kiosk system, in which the user is not permitted access to certain elements and features in the system user interface. This function gives your application control over the visibility of the Dock and the menu bar, and over various other system-provided user interface features such as process switching, logout, restart, and shutdown.

If your application is frontmost and you call this function to request a new presentation mode, your presentation mode will take effect immediately. If another application becomes frontmost, the presentation mode you requested will no longer be in effect. If your application becomes frontmost again, the presentation mode you previously established will come back into effect.

When the frontmost application uses this function to change its presentation mode, a kEventAppSystemUIModeChanged Carbon event is sent to all applications that have registered for the event. This event is also sent when an application is activated; it contains the newly active application's presentation mode.

In addition to using this function, an application may also specify an initial presentation mode when it is launched by using the LSUIPresentationMode key in its Info.plist file. This key should be of type Number and should have the value of one of the presentation mode constants listed in “Presentation Modes.”
Special Considerations

If your application uses the LSUIElement or LSBackgroundOnly key in its Info.plist file, you should not use this function. The presentation mode of the current login session is determined by the presentation mode of the frontmost application, and applications that use these keys generally do not become the frontmost application.
Availability
Available in Mac OS X v10.2 and later.
See Also
GetSystemUIMode
Declared In
MacApplication.h*/
OSStatus SetSystemUIMode (
   SystemUIMode inMode,
   SystemUIOptions inOptions
);

/*GetSystemUIMode

Gets the presentation mode of the calling application.

void GetSystemUIMode (
   SystemUIMode *outMode,
   SystemUIOptions *outOptions
);

Parameters
outMode

On output, the caller’s presentation mode. Pass NULL if you don't need this information. For a list of possible modes, see “Presentation Modes.” The presentation mode of an application determines which system-provided user interface elements are visible on the screen.
outOptions

On output, the options for the caller’s presentation mode. Pass NULL if you don't need this information. For a list of possible options, see “Presentation Options.” Presentation options are used to inhibit or allow certain user interface elements and commands.
Discussion

This function returns information about the presentation mode of the calling application, not the presentation mode of the current login session. The login session mode may be different, since the login session mode is determined by the presentation mode of the frontmost application. If the calling application is not currently the frontmost application, then its presentation mode will not be in use. To track changes in the login session’s presentation mode, you may handle the kEventAppSystemUIModeChanged Carbon event. 
Availability
Available in Mac OS X v10.2 and later.
See Also
SetSystemUIMode
Declared In
MacApplication.h*/
void GetSystemUIMode (
   SystemUIMode *outMode,
   SystemUIOptions *outOptions
);


#ifdef __cplusplus
}
#endif

#endif
