#ifndef HYS_DNS_UTIL_H
#define HYS_DNS_UTIL_H

#define DNS_STATUS_OK 1//?
//////////////////////////////////

typedef struct {
	uint16_t qdcount;//c
	uint16_t ancount;//c
	uint16_t nscount;//c
	uint16_t arcount;//c
} dns_header_t;

typedef struct {
	char *name;
} dns_domain_name_record_t;//c

typedef struct {
	struct in_addr addr;
} dns_address_record_t;//c

typedef struct {
	struct in6_addr addr;
} dns_in6_address_record_t;//c

typedef struct {
	char *mname;//c
	char *rname;//c
	uint32_t minimum;//c
} dns_SOA_record_t;

typedef struct {
	uint16_t priority;
	uint16_t weight;
	uint16_t port;
	char *target;
} dns_SRV_record_t;//c

typedef struct {
	uint16_t preference;
	char *name;
} dns_MX_record_t;//c

typedef struct {
	char *rmailbx;
	char *emailbx;
} dns_MINFO_record_t;//c

typedef struct {
	char *mailbox;
	char *txtdname;
} dns_RP_record_t;//c

typedef struct {
	char *hostname;//c
} dns_AFSDB_record_t;

typedef struct {
	char * intermediate;//c
} dns_RT_record_t;

typedef struct {
	char *name;//c
} dns_question_t;

typedef struct {
	char *name;//c
	uint16_t dnstype;//c
	uint32_t ttl;//c
	union 	{
		dns_address_record_t *A;//c			
		dns_domain_name_record_t *CNAME;//c
		dns_SOA_record_t *SOA;//c
		dns_domain_name_record_t *PTR;//c
		dns_MINFO_record_t *MINFO;//c
		dns_MX_record_t *MX;//c
		dns_RP_record_t *RP;//c
		dns_RT_record_t *RT;//c
		dns_in6_address_record_t *AAAA;//c
		dns_SRV_record_t *SRV;//c
		dns_AFSDB_record_t *AFSDB;//c
	} data;
} dns_resource_record_t;

typedef struct {
	uint32_t status;//c
	struct sockaddr *server;//c
	dns_header_t *header;//c
	dns_question_t **question;//c
	dns_resource_record_t **answer;//c
	dns_resource_record_t **authority;//c
	dns_resource_record_t **additional;//c
} dns_reply_t;


//func
extern int32_t dns_type_number(const char *t, uint16_t *n);//c
extern int32_t dns_class_number(const char *c, uint16_t *n);//c
extern dns_reply_t *dns_lookup(dns_handle_t dns, const char *name, uint32_t dnsclass, uint32_t dnstype);//c
extern void dns_free_reply(dns_reply_t *r);//c
extern void dns_set_buffer_size(dns_handle_t d, uint32_t len);//c

#endif //HYS_DNS_UTIL_H
