#ifndef HYS_HFS_HFS_FORMAT_H
#define HYS_HFS_HFS_FORMAT_H

#ifdef __cplusplus
extern "C" {
#endif

////////////////
enum {
	kHFSSigWord,//?
	kHFSPlusSigWord,//?
	kHFSXSigWord,//?
	kHFSCatalogFileID,//?
	kHFSRootFolderID,//?
	kHFSFolderRecord,//?
	kHFSPlusFileRecord,//?
	kHFSBinaryCompare,//?
	kHFSPlusFolderRecord,//?
	kHFSFileRecord,//?
	kHFSPlusFileThreadRecord,//?
	kHardLinkFileType,//?
	kHFSFileThreadRecord,//?
	kHFSFolderThreadRecord,//?
	kHFSPlusFolderThreadRecord,//?
	kHFSPlusCreator,//?
	kHFSExtentsFileID,//?
	kBTIndexNode,//?
	kHFSPlusExtentDensity,//?
	kHFSExtentDensity,//?
	kHFSMaxFileNameChars,//?
	kJIJournalInFSMask,//?
	kHFSVolumeJournaledBit,//?
	kHFSMaxVolumeNameChars,//?
	kHFSRootParentID,//?
	kBTHeaderNode,//?
	kBTLeafNode,//?
	kHFSPlusVersion,//?
	kHFSXVersion,//?
};


//////////////////////////////////

#define HFS_INODE_PREFIX	"iNode"//c

#define HFSPLUSMETADATAFOLDER       "\xE2\x90\x80\xE2\x90\x80\xE2\x90\x80\xE2\x90\x80HFS+ Private Data"//c

///////////////////////
enum {
	kHFSVolumeJournaledMask	= 1 << kHFSVolumeJournaledBit,//c
};
//////////////////////////////////////
struct HFSExtentDescriptor{
	u_int16_t 	startBlock;//c
	u_int16_t 	blockCount;//c
};
typedef struct HFSExtentDescriptor HFSExtentDescriptor;
typedef HFSExtentDescriptor HFSExtentRecord[3];//c

struct HFSMasterDirectoryBlock{
	u_int16_t 		drSigWord;//c
	u_int16_t 		drEmbedSigWord;//c
	u_int32_t 		drFndrInfo[8];//c
	u_int16_t 		drAlBlSt;//c
	u_int32_t 		drAlBlkSiz;//c
	HFSExtentRecord 	drCTExtRec;//c
	u_int32_t 		drCTFlSize;//c
	HFSExtentDescriptor drEmbedExtent;//c
	HFSExtentRecord		drXTExtRec;//c
	u_int32_t		drXTFlSize;//c
	u_int8_t 		drVN[kHFSMaxVolumeNameChars + 1];//c
};
typedef struct HFSMasterDirectoryBlock  HFSMasterDirectoryBlock;//?

struct HFSPlusExtentDescriptor{      
	u_int32_t 	startBlock;//c
	u_int32_t 	blockCount;//c
};
typedef struct HFSPlusExtentDescriptor HFSPlusExtentDescriptor;
typedef HFSPlusExtentDescriptor HFSPlusExtentRecord[8];//c

struct HFSPlusForkData {
	HFSPlusExtentRecord 	extents;//c
	u_int64_t 		logicalSize;//c
};
typedef struct HFSPlusForkData HFSPlusForkData;

struct HFSPlusVolumeHeader{
	u_int8_t 	finderInfo[32];//c
	u_int16_t 	signature;	//c
	u_int32_t 	blockSize;//c
	HFSPlusForkData  catalogFile;//c
	HFSPlusForkData extentsFile;//c
	u_int32_t 	attributes;	//c
	u_int16_t 	version;//c
	u_int32_t 	journalInfoBlock;//c
};
typedef struct HFSPlusVolumeHeader  HFSPlusVolumeHeader;

struct BTHeaderRec{
	u_int16_t 	nodeSize;//c
	u_int8_t 	keyCompareType;//c
	u_int32_t 	rootNode;	//c
	u_int32_t 	leafRecords;//c
	u_int32_t 	firstLeafNode;//c
	u_int16_t 	maxKeyLength;//c
};
typedef struct BTHeaderRec BTHeaderRec;

struct BTNodeDescriptor{
	u_int16_t 	numRecords;//c
	u_int32_t	fLink;	//c
	int8_t 		kind;	//c
};
typedef struct BTNodeDescriptor BTNodeDescriptor;

struct HFSCatalogFile{
	u_int32_t 		fileID;//c
	int32_t 		dataLogicalSize;//c
	HFSExtentRecord		dataExtents;//c
	u_int32_t		modifyDate;//c
};
typedef struct HFSCatalogFile HFSCatalogFile;

struct HFSPlusBSDInfo{
	u_int16_t 	fileMode;//c
	u_int32_t 	ownerID;//c
	union {
	    u_int32_t	iNodeNum;//c	
	    u_int32_t	linkCount;	//c
	    u_int32_t	rawDevice;//c
	} special;
};
typedef struct HFSPlusBSDInfo HFSPlusBSDInfo;

struct FndrFileInfo{
	u_int32_t 	fdType;		//c
	u_int32_t 	fdCreator;	//c
};
typedef struct FndrFileInfo FndrFileInfo;

struct HFSPlusCatalogFile{
	u_int32_t 		fileID;//c
	HFSPlusForkData dataFork;//c
	HFSPlusBSDInfo  bsdInfo;//c
	u_int32_t 		contentModDate;//c
	FndrFileInfo userInfo;//c
};
typedef struct HFSPlusCatalogFile HFSPlusCatalogFile;

struct HFSCatalogFolder{
	u_int32_t 		modifyDate;	//c
	u_int32_t		folderID;//c
};
typedef struct HFSCatalogFolder HFSCatalogFolder;

struct HFSPlusCatalogFolder{
	HFSPlusBSDInfo bsdInfo;//c
	u_int32_t 		contentModDate;//c
	u_int32_t 		folderID;	//c
};
typedef struct HFSPlusCatalogFolder HFSPlusCatalogFolder;

#ifndef OC_HFSUniStr255
#define OC_HFSUniStr255

struct HFSUniStr255 {
	u_int16_t	unicode[255];//c
	u_int16_t	length;//c
};
typedef struct HFSUniStr255 HFSUniStr255;

#endif //OC_HFSUniStr255

struct HFSPlusCatalogKey {
	HFSUniStr255 nodeName;//c
	u_int32_t 		parentID;	//c
};
typedef struct HFSPlusCatalogKey HFSPlusCatalogKey;

struct HFSCatalogKey {
	u_int8_t 	nodeName[kHFSMaxFileNameChars + 1];//c
	u_int32_t 	parentID;	//c
};
typedef struct HFSCatalogKey HFSCatalogKey;

struct HFSPlusExtentKey {
	u_int8_t 	forkType;//c
	u_int32_t 	fileID;//c
	u_int32_t 	startBlock;//c
	u_int16_t 	keyLength;//c
};
typedef struct HFSPlusExtentKey HFSPlusExtentKey;

struct HFSExtentKey {
	u_int8_t 	forkType;//c
	u_int32_t 	fileID;//c
	u_int16_t 	startBlock;//c
};
typedef struct HFSExtentKey HFSExtentKey;

//////////////////////////
enum {
	kHFSPlusCatalogKeyMaximumLength = sizeof(HFSPlusCatalogKey) - sizeof(u_int16_t),//c
};

#ifdef __cplusplus
}
#endif

#endif //HYS_HFS_HFS_FORMAT_H

