#ifndef _IOBUFFERMEMORYDESCRIPTOR_H
#define _IOBUFFERMEMORYDESCRIPTOR_H

#include <IOKit/IOMemoryDescriptor.h>

#include <HYS/IOKit/IOBufferMemoryDescriptor.h>

#ifdef __cplusplus
class IOBufferMemoryDescriptor : public IOBufferMemoryDescriptor_HYS,public IOGeneralMemoryDescriptor

{
   OSDeclareDefaultStructors(IOBufferMemoryDescriptor)

public:

IOBufferMemoryDescriptor_initWithRanges
IOBufferMemoryDescriptor_initWithAddress_vm_address_t
IOBufferMemoryDescriptor_initWithAddress


/*initWithOptions


Initializes a memory descriptor with the specified options. 

public

virtual bool initWithOptions(
    IOOptionBits options, 
    vm_size_t capacity, 
    vm_offset_t alignment); 
Parameters
options
See inTaskWithOptions for possible values.
capacity
The number of bytes to allocate.
alignment
The minimum required alignment of the buffer in bytes (1 is the default for no required alignment). For example, pass 256 to get memory allocated at an address with bits 0-7 zero.
Return Value

true if the initialization was successful; false otherwise.*/
virtual bool initWithOptions(
    IOOptionBits options, 
    vm_size_t capacity, 
    vm_offset_t alignment); 

/*inTaskWithPhysicalMask


Creates a memory buffer with memory descriptor for that buffer. 

public

static IOBufferMemoryDescriptor * inTaskWithPhysicalMask( 
    task_t inTask, 
    IOOptionBits options, 
    mach_vm_size_t capacity, 
    mach_vm_address_t physicalMask); 
Parameters
inTask
The task the buffer will be mapped in. Pass NULL to create memory unmapped in any task (for example, for use as a DMA buffer).
options
Options for the allocation:
kIODirectionOut, kIODirectionIn - set the direction of the I/O transfer. 
kIOMemoryPhysicallyContiguous - pass to request memory be physically contiguous. This option is heavily discouraged. The request may fail if memory is fragmented, may cause large amounts of paging activity, and may take a very long time to execute. 
kIOMemoryKernelUserShared - pass to request memory that will be mapped into both the kernel and client applications.
capacity
The number of bytes to allocate.
physicalMask
The buffer will be allocated with pages such that physical addresses will only have bits set present in physicalMask. For example, pass 0x00000000FFFFFFFFULL for a buffer to be accessed by hardware that has 32 address bits.
Return Value

An instance of class IOBufferMemoryDescriptor to be released by the caller, which will free the memory desriptor and associated buffer. 
Discussion 

This method allocates a memory buffer with a given size and alignment in the task's specified address space, and returns a memory descriptor instance representing the memory. It is recommended that memory allocated for I/O or sharing via mapping be created via IOBufferMemoryDescriptor. Options passed with the request specify the kind of memory to be allocated. For example, pageablity and sharing are specified with option bits. This function may block and so should not be called from interrupt level or while a simple lock is held. 

Availability
Available on PowerPC-based Macs running Mac OS X Server only and on all Intel-based Macs running Mac OS X 10.4.8 and above.*/
static IOBufferMemoryDescriptor * inTaskWithPhysicalMask( 
    task_t inTask, 
    IOOptionBits options, 
    mach_vm_size_t capacity, 
    mach_vm_address_t physicalMask); 

/*setLength


Changes the buffer length of the memory descriptor. 

public

virtual void setLength(
    vm_size_t length); 
Parameters
length
The new length to set the buffer length to.
Discussion 

When a new buffer is created, the initial length of the buffer is set to be the same as the capacity. The length can be adjusted with this function for a shorter transfer (there is no need to create more buffer descriptors when you can reuse an existing one, even for different transfer sizes). Note that the specified length must not exceed the capacity of the buffer.*/
virtual void setLength(
    vm_size_t length); 

/*initWithBytes


Initializes a memory descriptor with the provided bytes. 

public

virtual bool initWithBytes(
    const void *bytes, 
    vm_size_t withLength, 
    IODirection withDirection, 
    bool withContiguousMemory = false); 
Parameters
bytes
The data to copy into the buffer.
withLength
The size of the data to copy into the buffer, in bytes.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the IOMemoryDescriptor::prepare and IOMemoryDescriptor::complete methods on some architectures.
withContiguousMemory
If true, the buffer is initialized with a minimum required alignment of the buffer taken from the value of the capacity parameter; if false, the buffer is initialized with no required alignment.
Return Value

true if the initialization was successful; false otherwise.*/
virtual bool initWithBytes(
    const void *bytes, 
    vm_size_t withLength, 
    IODirection withDirection, 
    bool withContiguousMemory = false); 

/*setDirection


Changes the transfer direction of the memory descriptor. 

public

virtual void setDirection(
    IODirection direction); 
Parameters
direction
The new I/O direction to set the descriptor's transfer direction to.
Discussion 

This function allows you to redirect the descriptor's transfer direction. This eliminates the need to destroy and create new buffers when different transfer directions are needed.*/

virtual void setDirection(
    IODirection direction); 

/*withBytes


Creates a memory descriptor preloaded (copied) with the provided bytes. 

public

static IOBufferMemoryDescriptor * withBytes( 
    const void *bytes, 
    vm_size_t withLength, 
    IODirection withDirection, 
    bool withContiguousMemory = false); 
Parameters
bytes
The data to copy into the buffer.
withLength
The size of the data to copy into the buffer, in bytes.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the IOMemoryDescriptor::prepare and IOMemoryDescriptor::complete methods on some architectures.
withContiguousMemory
If true, the buffer is initialized with a minimum required alignment of the buffer taken from the value of the capacity parameter; if false, the buffer is initialized with no required alignment.
Return Value

An instance of class IOBufferMemoryDescriptor to be released by the caller, which will free the memory descriptor and associated buffer. 
Discussion 

The descriptor's length and capacity are set to the input buffer's size.*/
static IOBufferMemoryDescriptor * withBytes( 
    const void *bytes, 
    vm_size_t withLength, 
    IODirection withDirection, 
    bool withContiguousMemory = false); 

/*getCapacity


Gets the memory descriptor's capacity. 

public

virtual vm_size_t getCapacity() const; 
Return Value

The size of the memory descriptor's capacity, in bytes.*/
virtual vm_size_t getCapacity() const; 

/*withCapacity


Creates a memory descriptor with a buffer of the specified size. 

public

static IOBufferMemoryDescriptor * withCapacity( 
    vm_size_t capacity, 
    IODirection withDirection, 
    bool withContiguousMemory = false); 
Parameters
capacity
The number of bytes to allocate.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the IOMemoryDescriptor::prepare and IOMemoryDescriptor::complete methods on some architectures.
withContiguousMemory
If true, the buffer is created with a minimum required alignment of the buffer taken from the value of the capacity parameter; if false, the buffer is created with no required alignment.
Return Value

An instance of class IOBufferMemoryDescriptor to be released by the caller, which will free the memory descriptor and associated buffer. 
Discussion 

The descriptor's length is initially set to the size specified in capacity.*/
static IOBufferMemoryDescriptor * withCapacity( 
    vm_size_t capacity, 
    IODirection withDirection, 
    bool withContiguousMemory = false); 

/*withOptions


Creates a memory descriptor with the specified options and with a buffer of the specified size. 

public

static IOBufferMemoryDescriptor * withOptions(
    IOOptionBits options, 
    vm_size_t capacity, 
    vm_offset_t alignment = 1); 
Parameters
options
See inTaskWithOptions for possible values.
capacity
The number of bytes to allocate.
alignment
The minimum required alignment of the buffer in bytes (1 is the default for no required alignment). For example, pass 256 to get memory allocated at an address with bits 0-7 zero.
Return Value

An instance of class IOBufferMemoryDescriptor to be released by the caller, which will free the memory descriptor and associated buffer. 
Discussion 

The descriptor's length is initially set to the size specified in capacity.*/
static IOBufferMemoryDescriptor * withOptions(
    IOOptionBits options, 
    vm_size_t capacity, 
    vm_offset_t alignment = 1); 

/*inTaskWithOptions


Creates a memory buffer with memory descriptor for that buffer. 
public

static IOBufferMemoryDescriptor * inTaskWithOptions( 
    task_t inTask, 
    IOOptionBits options, 
    vm_size_t capacity, 
    vm_offset_t alignment = 1); 
Parameters
inTask
The task the buffer will be allocated in.
options
Options for the allocation:
kIODirectionOut, kIODirectionIn - set the direction of the I/O transfer. 
kIOMemoryPhysicallyContiguous - pass to request memory be physically contiguous. This option is heavily discouraged. The request may fail if memory is fragmented, may cause large amounts of paging activity, and may take a very long time to execute. 
kIOMemoryPageable - pass to request memory be non-wired (the default for kernel allocated memory is wired). 
kIOMemoryPurgeable - pass to request memory that may later have its purgeable state set with IOMemoryDescriptor::setPurgeable. Only supported for kIOMemoryPageable allocations. 
kIOMemoryKernelUserShared - pass to request memory that will be mapped into both the kernel and client applications.
capacity
The number of bytes to allocate.
alignment
The minimum required alignment of the buffer in bytes (1 is the default for no required alignment). For example, pass 256 to get memory allocated at an address with bits 0-7 zero.
Return Value

An instance of class IOBufferMemoryDescriptor to be released by the caller, which will free the memory descriptor and associated buffer. 
Discussion 

This function allocates a memory buffer with a given size and alignment in the task's specified address space, and returns a memory descriptor instance representing the memory. It is recommended that memory allocated for I/O or sharing via mapping be created using IOBufferMemoryDescriptor. Options passed with the request specify the kind of memory to be allocated. For example, pageability and sharing are specified with option bits. This function may block and so should not be called from interrupt level or while a simple lock is held. 
Availability
Mac OS X v10.2 and above*/
static IOBufferMemoryDescriptor * inTaskWithOptions(
    task_t inTask,
    IOOptionBits options,
    vm_size_t capacity,
    vm_offset_t alignment = 1);

/*getBytesNoCopy


Gets the virtual address of the beginning of the buffer. 
public

virtual void *getBytesNoCopy(); 
Return Value

The virtual address of the beginning of the buffer*/
virtual void *getBytesNoCopy(); 

};
#endif //__cplusplus

#endif//_IOBUFFERMEMORYDESCRIPTOR_H
