
#ifndef _IOKIT_IO_COMMAND_POOL_H_
#define _IOKIT_IO_COMMAND_POOL_H_


//#if defined(KERNEL) && defined(__cplusplus)

#include <kern/kern_types.h>
#include <kern/queue.h>
#include <IOKit/IOCommand.h>
#include <IOKit/IOCommandGate.h>
#include <IOKit/IOService.h>
#include <IOKit/IOWorkLoop.h>


class IOCommandPool : public OSObject
{
   
    OSDeclareDefaultStructors(IOCommandPool)
protected:

/*kIOCommandPoolDefaultSize


The default size of any command pool. 

protected

static const UInt32 kIOCommandPoolDefaultSize = 2; 
Discussion 

kIOCommandPoolDefaultSize is the default size of any command pool. The default size was determined to be the smallest size for which a pool makes sense.*/
static const UInt32 kIOCommandPoolDefaultSize = 2; 

public:

/*returnCommand


public

virtual void returnCommand(
    IOCommand *command); 
Parameters
commmand
The command to place in the pool.
Discussion 

The returnCommand method is used to place an object of type IOCommand into the pool, whether it be the first time, or the 1000th time.*/
virtual void returnCommand(
    IOCommand *command); 

/*withWorkLoop(IOService *, IOWorkLoop *, UInt32)


Should never be used, obsolete. See IOCommandPool::withWorkLoop. 

public

static IOCommandPool *commandPool(
    IOService *inOwner, 
    IOWorkLoop *inWorkLoop, 
    UInt32 inSize = kIOCommandPoolDefaultSize); */
static IOCommandPool *commandPool(
    IOService *inOwner, 
    IOWorkLoop *inWorkLoop, 
    UInt32 inSize = kIOCommandPoolDefaultSize);

/*withWorkLoop(IOWorkLoop *)


Primary factory method for the IOCommandPool class 

public

static IOCommandPool *withWorkLoop(
    IOWorkLoop *inWorkLoop); 
Parameters
inWorkLoop
The workloop that this command pool should synchronize with.
Return Value

Returns a pointer to an instance of IOCommandPool if successful, otherwise NULL. 
Discussion 

The withWorkLoop method is what is known as a factory method. It creates a new instance of an IOCommandPool and returns a pointer to that object.*/
static IOCommandPool *withWorkLoop(
    IOWorkLoop *inWorkLoop); 

/*getCommand


public

virtual IOCommand *getCommand(
    bool blockForCommand = true); 
Parameters
blockForCommand
If the caller would like to have its thread slept until a command is available, it should pass true, else false.
Return Value

If the caller passes true in blockForCommand, getCommand guarantees that the result will be a pointer to an IOCommand object from the pool. If the caller passes false, s/he is responsible for checking whether a non-NULL pointer was returned. 
Discussion 

The getCommand method is used to get a pointer to an object of type IOCommand from the pool.*/
virtual IOCommand *getCommand(
    bool blockForCommand = true); 

private:
};

//#endif   /* defined(KERNEL) && defined(__cplusplus) */

#endif   /* _IOKIT_IO_COMMAND_POOL_H_ */
