#ifndef _IODMACOMMAND_H
#define _IODMACOMMAND_H

#include <IOKit/IOCommand.h>
#include <IOKit/IOMemoryDescriptor.h>
class IOMapper;

#include <HYS/IOKit/IODMACommand.h>

/*kIODMACommandOutputHost32


Output host natural Segment32 output segment function. 

public

#define kIODMACommandOutputHost32  */
#define kIODMACommandOutputHost32  (IODMACommand::OutputHost32)

/*kIODMACommandOutputHost64


Output host natural Segment64 output segment function.

public

#define kIODMACommandOutputHost64  */

#define kIODMACommandOutputHost64   (IODMACommand::OutputHost64)

class IODMACommand : public IOCommand,public IODMACommand_HYS
{
    OSDeclareDefaultStructors(IODMACommand);

public://type


/*Segment32


See Also:
Segment64
MappingOptions
Segment32
SegmentFunction
public

struct Segment32 { 
    UInt32 fIOVMAddr, fLength; 
}; 
Discussion 

A 32-bit I/O bus address/length pair*/

struct Segment32 { 
    UInt32 fIOVMAddr, fLength; 
};

/*Segment64


See Also:
Segment32
MappingOptions
Segment32
SegmentFunction
public

struct Segment64 { 
    UInt64 fIOVMAddr, fLength; 
}; 
Discussion 

A 32-bit I/O bus address/length pair*/
struct Segment64 { 
    UInt64 fIOVMAddr, fLength; 
}; 

/*SegmentFunction


See Also:
Segment32
Segment64
MappingOptions
Segment32
public

typedef bool ( *SegmentFunction)(
    IODMACommand *target, 
    Segment64 segment, 
    void *segments, 
    UInt32 segmentIndex); 
Discussion 

A 32-bit I/O bus address/length pair*/
typedef bool ( *SegmentFunction)(
    IODMACommand *target, 
    Segment64 segment, 
    void *segments, 
    UInt32 segmentIndex); 

/*MappingOptions


See Also:
Segment32
Segment64
Segment32
SegmentFunction
public

enum MappingOptions { 
    kMapped = 0x00000000, 
    kBypassed = 0x00000001, 
    kNonCoherent = 0x00000002, 
    kTypeMask = 0x0000000f,  
    kNoCacheStore = 0x00000010, // Memory in descriptor 
    kOnChip = 0x00000020, // Indicates DMA is on South Bridge 
}; 
Discussion 

A 32-bit I/O bus address/length pair*/
enum MappingOptions { 
    kMapped = 0x00000000, 
    kBypassed = 0x00000001, 
    kNonCoherent = 0x00000002, 
    kTypeMask = 0x0000000f,  
    kNoCacheStore = 0x00000010, // Memory in descriptor 
    kOnChip = 0x00000020, // Indicates DMA is on South Bridge 
	kIterateOnly  = 0x00000040
}; 
	
public://functions

IODMACommand_gen64IOVMSegments
IODMACommand_gen32IOVMSegments
IODMACommand_initWithSpecification
IODMACommand_getMemoryDescriptor
IODMACommand_synchronize
IODMACommand_writeBytes
IODMACommand_clearMemoryDescriptor
IODMACommand_complete
IODMACommand_setMemoryDescriptor 
IODMACommand_prepare

/*OutputHost64


Output host natural Segment64 output segment function. 

public

static bool OutputHost64(
    IODMACommand *target, 
    Segment64 seg,
    void *segs,
    UInt32 ind); */
static bool OutputHost64(
    IODMACommand *target, 
    Segment64 seg,
    void *segs,
    UInt32 ind);

/*withSpecification


Creates and initializes an IODMACommand in one operation. 

public

static IODMACommand * withSpecification(
    SegmentFunction outSegFunc, 
    UInt8 numAddressBits, 
    UInt64 maxSegmentSize, 
    MappingOptions mappingOptions = kMapped, 
    UInt64 maxTransferSize = 0, 
    UInt32 alignment = 1, 
    IOMapper *mapper = 0, 
    void *refCon = 0); 
Parameters
outSegFunc
SegmentFunction to call to output one physical segment. A set of nine commonly required segment functions are provided.
numAddressBits
Number of bits that the hardware uses on its internal address bus. Typically 32 but may be more on modern hardware. A 0 implies no restriction other than that implied by the output segment function.
maxSegmentSize
Maximum allowable size for one segment. Defaults to 0, which means any size.
mappingOptions
The type of mapping that is required to translate an IOMemoryDescriptor into the desired number of bits. For example, if your hardware only supports 32 bits but must run on machines with > 4G of RAM some mapping will be required. Number of bits will be specified in numAddressBits, see below. This parameter can take 3 values: kNonCoherent - used for non-coherent hardware transfers, Mapped - validates that all I/O bus generated addresses are within the number of addressing bits specified, Bypassed - bypassed addressing is required (this is used when the hardware transfers are into coherent memory but no mapping is required). See prepare for failure cases.
maxTransferSize
Maximum size of an entire transfer. Defaults to 0 indicating no maximum.
alignment
Alignment restriction, in bytes, on I/O bus addresses. Defaults to single byte alignment. Not currently implemented.
mapper
For mapping types kMapped and kBypassed mapper is used to define the hardware that will perform the mapping. Defaults to the system mapper.
Return Value

Returns a new IODMACommand object if successfully created and initialized, 0 otherwise. 
Discussion 

Factory function to create and initialize an IODMACommand in one operation.*/
static IODMACommand * withSpecification(
    SegmentFunction outSegFunc, 
    UInt8 numAddressBits, 
    UInt64 maxSegmentSize, 
    MappingOptions mappingOptions = kMapped, 
    UInt64 maxTransferSize = 0, 
    UInt32 alignment = 1, 
    IOMapper *mapper = 0, 
    void *refCon = 0); 

/*OutputHost32


Output host natural Segment32 output segment function. 

public

static bool OutputHost32(
    IODMACommand *target, 
    Segment64 seg,
    void *segs,
    UInt32 ind); */

static bool OutputHost32(
    IODMACommand *target, 
    Segment64 seg,
    void *segs,
    UInt32 ind);

private:
protected:
};

#endif /* !_IODMACOMMAND_H */

