
#ifndef _IOKITUSER_IODATAQUEUE_H
#define _IOKITUSER_IODATAQUEUE_H

#include <sys/cdefs.h>

__BEGIN_DECLS

#include <libkern/OSTypes.h>
#include <IOKit/IOReturn.h>
#include <mach/port.h>

#include <IOKit/IODataQueueShared.h>

/*IODataQueueAllocateNotificationPort


Allocates and returns a new mach port able to receive data available notifications from an IODataQueue. 

mach_port_t IODataQueueAllocateNotificationPort();  
Return Value

Returns a newly allocated mach port on success. On failure, it returns MACH_PORT_NULL. 
Discussion 

This port is intended to be passed down into the kernel and into an IODataQueue to allow it to send the appropriate notification. The returned mach port is allocated with a queue limit of one message. This allows only one mach message to be queued up at a time. The IODataQueue code is written with the restriction in mind and will only queue up a message if no messages alread have been sent.*/
mach_port_t IODataQueueAllocateNotificationPort();  

/*IODataQueuePeek


Peeks at the next entry on the queue. 

IODataQueueEntry *IODataQueuePeek(
    IODataQueueMemory *dataQueue);  
Parameters
dataQueue
The IODataQueueMemory region mapped from the kernel.
Return Value

Returns a pointer to the next IODataQueueEntry if one is available. Zero is returned if the queue is empty. 
Discussion 

This function can be used to look at the next entry which allows the entry to be received without having to copy it with IODataQueueDequeue. In order to do this, call IODataQueuePeek to get the entry. Then call IODataQueueDequeue with a NULL data pointer. That will cause the head to be moved to the next entry, but no memory to be copied.*/
IODataQueueEntry *IODataQueuePeek(
    IODataQueueMemory *dataQueue);  

/*IODataQueueDequeue


Dequeues the next available entry on the queue and copies it into the given data pointer. 

IOReturn IODataQueueDequeue(
    IODataQueueMemory *dataQueue,
    void *data,
    uint32_t *dataSize);  
Parameters
dataQueue
The IODataQueueMemory region mapped from the kernel.
data
A pointer to the data memory region in which to copy the next entry data on the queue. If this parameter is 0 (NULL), it will simply move to the next entry.
dataSize
A pointer to the size of the data parameter. On return, this contains the size of the actual entry data - even if the original size was not large enough.
Return Value

Returns kIOReturnSuccess on success. Other return values possible are: kIOReturnUnderrun - queue is empty, kIOReturnBadArgument - no dataQueue or no dataSize, kIOReturnNoSpace - dataSize is too small for entry. 
Discussion 

This function will dequeue the next available entry on the queue. If a data pointer is provided, it will copy the data into the memory region if there is enough space available as specified in the dataSize parameter. If no data pointer is provided, it will simply move the head value past the current entry.*/
IOReturn IODataQueueDequeue(
    IODataQueueMemory *dataQueue,
    void *data,
    uint32_t *dataSize);  

__END_DECLS

#endif /* _IOKITUSER_IODATAQUEUE_H */
