
#ifndef _IOKIT_IODATAQUEUESHARED_H
#define _IOKIT_IODATAQUEUESHARED_H

#include <libkern/OSTypes.h>
#include <mach/port.h>
#include <mach/message.h>

/*DATA_QUEUE_MEMORY_HEADER_SIZE


#define DATA_QUEUE_MEMORY_HEADER_SIZE  
Discussion 

Represents the size of the data queue memory header independent of the actual size of the queue data itself. The total size of the queue memory is equal to this value plus the size of the queue appendix and the size of the queue data region which is stored in the queueSize field of IODataQueueMeory.*/
#define DATA_QUEUE_MEMORY_HEADER_SIZE  (sizeof(IODataQueueMemory) - sizeof(IODataQueueEntry))

/*DATA_QUEUE_ENTRY_HEADER_SIZE

#define DATA_QUEUE_ENTRY_HEADER_SIZE  
Discussion 

Represents the size of the data queue entry header independent of the actual size of the data in the entry. This is the overhead of each entry in the queue. The total size of an entry is equal to this value plus the size stored in the entry's size field (in IODataQueueEntry).*/

#define DATA_QUEUE_ENTRY_HEADER_SIZE (sizeof(IODataQueueEntry) - sizeof(void *))

/*IODataQueueEntry


Represents an entry within the data queue 

typedef struct _IODataQueueEntry{ 
    UInt32 size; 
    UInt8 data[4]; 
} IODataQueueEntry;  
Fields
size
The size of the following data region.
data
Represents the beginning of the data region. The address of the data field is a pointer to the start of the data region.
Discussion 

This is a variable sized struct. The data field simply represents the start of the data region. The size of the data region is stored in the size field. The whole size of the specific entry is the size of a UInt32 plus the size of the data region.*/
typedef struct _IODataQueueEntry{ 
    UInt32 size; 
    UInt8 data[4]; 
} IODataQueueEntry;  

/*IODataQueueMemory


A struct mapping to the header region of a data queue. 

typedef struct _IODataQueueMemory { 
    UInt32 queueSize; 
    volatile UInt32 head; 
    volatile UInt32 tail; 
    IODataQueueEntry queue[1]; 
} IODataQueueMemory;  
Fields
queueSize
The size of the queue region pointed to by the queue field.
head
The location of the queue head. This field is represented as a byte offset from the beginning of the queue memory region.
tail
The location of the queue tail. This field is represented as a byte offset from the beginning of the queue memory region.
queue
Represents the beginning of the queue memory region. The size of the region pointed to by queue is stored in the queueSize field.
Discussion 

This struct is variable sized. The struct represents the data queue header information plus a pointer to the actual data queue itself. The size of the struct is the combined size of the header fields (3 * sizeof(UInt32)) plus the actual size of the queue region. This size is stored in the queueSize field.*/
typedef struct _IODataQueueMemory { 
    UInt32 queueSize; 
    volatile UInt32 head; 
    volatile UInt32 tail; 
    IODataQueueEntry queue[1]; 
} IODataQueueMemory;  

/*IODataQueueAppendix


A struct mapping to the appendix region of a data queue. 

typedef struct _IODataQueueAppendix { 
    UInt32 version; 
    mach_msg_header_t msgh; 
} IODataQueueAppendix;  
Fields
version
The version of the queue appendix.
port
The notification port associated with this queue.
Discussion 

This struct is variable sized dependent on the version. The struct represents the data queue appendix information.*/
typedef struct _IODataQueueAppendix { 
    UInt32 version; 
    mach_msg_header_t msgh; 
} IODataQueueAppendix;  

#endif //_IOKIT_IODATAQUEUESHARED_H

