#ifndef _IOKIT_IOEVENTSOURCE_H
#define _IOKIT_IOEVENTSOURCE_H

#include <sys/cdefs.h>
#include <libkern/c++/OSObject.h>
#include <IOKit/IOLib.h>
#include <IOKit/system.h>
#include <IOKit/IOWorkLoop.h>
__BEGIN_DECLS
#include <mach/clock_types.h>
#include <kern/clock.h>
__END_DECLS

#include <HYS/IOKit/IOEventSource.h>

#ifdef __cplusplus
class IOEventSource : public OSObject,public IOEventSource_HYS
{
    OSDeclareAbstractStructors(IOEventSource)
    friend class IOWorkLoop;


public://data,type
/*Action


public

typedef void ( *Action)(
    OSObject *owner,
    ...); 
Parameters
owner
Target of the function, can be used as a refcon. The owner is set during initialization. Note if a C++ function was specified this parameter is implicitly the first paramter in the target member function's parameter list.
Discussion 

Placeholder type for C++ function overloading discrimination. As the all event sources require an action and it has to be stored somewhere and be of some type, this is that type.*/

typedef void ( *Action)(
    OSObject *owner,
    ...); 


protected://data,type

/*workLoop


protected

IOWorkLoop *workLoop; 
Discussion 

What is the work-loop for this event source.*/
IOWorkLoop *workLoop; 

/*enabled


protected

bool enabled; 
Discussion 

Is this event source enabled to deliver requests to the work-loop.*/
bool enabled; 

/*owner


protected

OSObject *owner; 
Discussion 

The owner object called when an event has been delivered.*/

OSObject *owner; 

/*action


protected

Action action; 
Discussion 

The action method called when an event has been delivered*/
Action action; 


public://func


/*getWorkLoop


Get'ter for workLoop variable. 
public

virtual IOWorkLoop *getWorkLoop() const; 
Return Value

Returns the value of workLoop.*/
virtual IOWorkLoop *getWorkLoop() const; 


protected: //function

/*init


Primary initializer for the IOEventSource class. 

protected

virtual bool init(
    OSObject *owner,
    IOEventSource::Action action = 0); 
Parameters
owner
Owner of this instance of an event source. Used as the first parameter of the action callout. Owner will generally be an OSObject it doesn't have to be as no member functions will be called directly in it. It can just be a refcon for a client routine.
action
Pointer to C call out function. Action is a pointer to a C function that gets called when this event source has outstanding work. It will usually be called by the checkForWork member function. The first parameter of the action call out will always be the owner, this allows C++ member functions to be used as actions. Defaults to 0.
Return Value

Returns true if the inherited classes and this instance initialize successfully.*/
virtual bool init(
    OSObject *owner,
    IOEventSource::Action action = 0); 

};
#endif //__cplusplus

#endif //_IOKIT_IOEVENTSOURCE_H
