
#ifndef _IOKIT_IOINTERRUPTEVENTSOURCE_H
#define _IOKIT_IOINTERRUPTEVENTSOURCE_H

#include <IOKit/IOEventSource.h>

#ifdef __cplusplus
class IOService;
class IOInterruptEventSource : public IOEventSource
{
OSDeclareDefaultStructors(IOInterruptEventSource)

public:

/*interruptOccurred


Functions that get called by the interrupt controller (see IOService::registerInterrupt). 

public

virtual void interruptOccurred(
    void *,
    IOService *nub,
    int ind); 
Parameters
nub
Where the interrupt originated from.
ind
This interrupt's index within 'nub'.*/
virtual void interruptOccurred(
    void *,
    IOService *nub,
    int ind); 

/*getIntIndex


Get'ter for intIndex interrupt index variable. 

public

virtual int getIntIndex() const; 
Return Value

Returns the value of intIndex.*/

virtual int getIntIndex() const;

/*Action


public

typedef void ( *Action)(
    OSObject *,
    IOInterruptEventSource *,
    int count); 
Parameters
owner
Pointer to client instance.
sender
Pointer to generation interrupt event source.
count
Number of interrupts seen before delivery.
Discussion 

C pointer prototype of functions that are called in a single threaded context when an interrupt occurs.*/
typedef void ( *Action)(
    OSObject *,
    IOInterruptEventSource *,
    int count); 

/*IOInterruptEventAction


public

#define IOInterruptEventAction IOInterruptEventSource::Action 
Discussion 

Backward compatibilty define for the old non-class scoped type definition. See Action.*/
#define IOInterruptEventAction IOInterruptEventSource::Action 


/*interruptEventSource


Factory function for IOInterruptEventSources creation and initialization. 

public

static IOInterruptEventSource * interruptEventSource(
    OSObject *owner, 
    Action action, 
    IOService *provider = 0, 
    int intIndex = 0); 
Parameters
owner
Owning client of the new event source.
action
C function to call when something happens.
provider
IOService that represents the interrupt source. Defaults to 0. When no provider is defined the event source assumes that the client will in some manner call the interruptOccurred method explicitly. This will start the ball rolling for safe delivery of asynchronous events into the driver.
intIndex
The index of the interrupt within the provider's interrupt sources. Defaults to 0, i.e. the first interrupt in the provider.
Return Value

Returns a new interrupt event source if successfully created and initialized, 0 otherwise.*/

static IOInterruptEventSource * interruptEventSource(
    OSObject *owner, 
    Action action, 
    IOService *provider = 0, 
    int intIndex = 0); 

/*enable


Enables event source. 

public

virtual void enable(); 
Discussion 

A subclass implementation is expected to respect the enabled state when checkForWork is called. Calling this function will cause the work loop to be signalled so that a checkForWork is performed.*/
virtual void enable(); 

/*disable


Disables event source. 

public

virtual void disable(); 
Discussion 

A subclass implementation is expected to respect the enabled state when checkForWork is called.*/
virtual void disable(); 

};
#endif //__cplusplus

#endif  //_IOKIT_IOINTERRUPTEVENTSOURCE_H
