
#ifndef _IOMEMORYCURSOR_H
#define _IOMEMORYCURSOR_H

#include <libkern/c++/OSObject.h>
#include <IOKit/IOTypes.h>

class IOMemoryDescriptor;
class IOMemoryCursor : public OSObject
{
    OSDeclareDefaultStructors(IOMemoryCursor)



public://datatype


/*PhysicalSegment


public

struct PhysicalSegment { 
    IOPhysicalAddress location; 
    IOPhysicalLength length; 
}; 
Discussion 

A physical address/length pair.*/
struct PhysicalSegment { 
    IOPhysicalAddress location; 
    IOPhysicalLength length; 
}; 

/*SegmentFunction


public

typedef void ( *SegmentFunction)(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex); 
Parameters
segment
The physical address and length that is next to be output.
segments
Base of the output vector of DMA address length pairs.
segmentIndex
Index to output 'segment' in the 'segments' array.
Discussion 

Pointer to a C function that outputs a single physical segment to an element in the array as defined by the segments and segmentIndex parameters.*/
typedef void ( *SegmentFunction)(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex); 

public://data

/*OutputSegmentFunc


public

#define OutputSegmentFunc IOMemoryCursor::SegmentFunction 
Discussion 

Backward compatibility define for the old non-class scoped type definition. See SegmentFunction.*/
#define OutputSegmentFunc IOMemoryCursor::SegmentFunction

/*IOPhysicalSegment


public

#define IOPhysicalSegment IOMemoryCursor::PhysicalSegment 
Discussion 

Backward compatibility define for the old non-class scoped type definition. See PhysicalSegment.*/
#define IOPhysicalSegment IOMemoryCursor::PhysicalSegment 


protected:


/*maxSegmentSize


protected

IOPhysicalLength maxSegmentSize; 
Discussion 

Maximum size of one segment in a scatter/gather list.*/
IOPhysicalLength maxSegmentSize; 

/*outSeg


protected

SegmentFunction outSeg; 
Discussion 

The action method called when an event has been delivered.*/
SegmentFunction outSeg; 

public://function

/*initWithSpecification


Primary initializer for the IOMemoryCursor class. 

public

virtual bool initWithSpecification(
    SegmentFunction outSegFunc, 
    IOPhysicalLength maxSegmentSize = 0, 
    IOPhysicalLength maxTransferSize = 0, 
    IOPhysicalLength alignment = 1); 
Parameters
outSegFunc
SegmentFunction to call to output one physical segment.
maxSegmentSize
Maximum allowable size for one segment. Defaults to 0.
maxTransferSize
Maximum size of an entire transfer. Defaults to 0 indicating no maximum.
alignment
Alignment restrictions on output physical addresses. Not currently implemented. Defaults to single byte alignment.
Return Value

Returns true if the inherited classes and this instance initialize successfully.*/
virtual bool initWithSpecification(
    SegmentFunction outSegFunc, 
    IOPhysicalLength maxSegmentSize = 0, 
    IOPhysicalLength maxTransferSize = 0, 
    IOPhysicalLength alignment = 1); 

};


class IONaturalMemoryCursor : public IOMemoryCursor
{
    OSDeclareDefaultStructors(IONaturalMemoryCursor)

public://data

/*naturalOutputSegment


public

#define naturalOutputSegment IONaturalMemoryCursor::outputSegment 
Discussion 

Backward compatibility define for the old global function definition. See IONaturalMemoryCursor::outputSegment.*/
#define naturalOutputSegment IONaturalMemoryCursor::outputSegment 

public://function

/*outputSegment


Outputs the given segment into the output segments array in natural byte order. 

public

static void outputSegment(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex); 
Parameters
segment
The physical address and length that is next to be output.
segments
Base of the output vector of DMA address length pairs.
segmentIndex
Index to output 'segment' in the 'segments' array.*/
static void outputSegment(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex); 

/*getPhysicalSegments


Generates a CPU natural physical scatter/gather list given a memory descriptor. 

public

virtual UInt32 getPhysicalSegments(
    IOMemoryDescriptor *descriptor, 
    IOByteCount fromPosition, 
    PhysicalSegment *segments, 
    UInt32 maxSegments, 
    UInt32 maxTransferSize = 0, 
    IOByteCount *transferSize = 0) 
Parameters
descriptor
IOMemoryDescriptor that describes the data associated with an I/O request.
fromPosition
Starting location of the I/O within a memory descriptor.
segments
Pointer to an array of IOMemoryCursor::PhysicalSegments for the output physical scatter/gather list.
maxSegments
Maximum number of segments that can be written to segments array.
maxTransferSize
Maximum transfer size is limited to that many bytes, otherwise it defaults to the maximum transfer size specified when the memory cursor was initialized.
transferSize
Pointer to an IOByteCount variable that can contain the total size of the transfer being described. Defaults to 0 indicating that no transfer size need be returned.
Return Value

If the descriptor is exhausted of memory, a zero is returned, otherwise the number of segments that were filled in is returned. 
Discussion 

Generates a list of physical segments from the given memory descriptor, relative to the current position of the descriptor. Wraps IOMemoryCursor::genPhysicalSegments.*/
virtual UInt32 getPhysicalSegments(
    IOMemoryDescriptor *descriptor, 
    IOByteCount fromPosition, 
    PhysicalSegment *segments, 
    UInt32 maxSegments, 
    UInt32 maxTransferSize = 0, 
    IOByteCount *transferSize = 0);

/*withSpecification


Creates and initializes an IONaturalMemoryCursor in one operation. 

public

static IONaturalMemoryCursor * withSpecification(
    IOPhysicalLength maxSegmentSize, 
    IOPhysicalLength maxTransferSize, 
    IOPhysicalLength alignment = 1); 
Parameters
maxSegmentSize
Maximum allowable size for one segment. Defaults to 0.
maxTransferSize
Maximum size of an entire transfer. Defaults to 0 indicating no maximum.
alignment
Alignment restrictions on output physical addresses. Not currently implemented. Defaults to single byte alignment.
Return Value

Returns a new memory cursor if successfully created and initialized, 0 otherwise. 
Discussion 

Factory function to create and initialize an IONaturalMemoryCursor in one operation. For more information, see IONaturalMemoryCursor::initWithSpecification.*/
static IONaturalMemoryCursor * withSpecification(
    IOPhysicalLength maxSegmentSize, 
    IOPhysicalLength maxTransferSize, 
    IOPhysicalLength alignment = 1); 

};
class IOBigMemoryCursor : public IOMemoryCursor
{
    OSDeclareDefaultStructors(IOBigMemoryCursor)

public://data

/*bigOutputSegment


public

#define bigOutputSegment IOBigMemoryCursor::outputSegment 
Discussion 

Backward compatibility define for the old global function definition. See IOBigMemoryCursor::outputSegment*/
#define bigOutputSegment IOBigMemoryCursor::outputSegment 

public://function

/*outputSegment


Outputs the given segment into the output segments array in big endian byte order. 

public

static void outputSegment(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex); 
Parameters
segment
The physical address and length that is next to be output.
segments
Base of the output vector of DMA address length pairs.
segmentIndex
Index to output 'segment' in the 'segments' array.*/
static void outputSegment(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex);

/*withSpecification


Creates and initializes an IOBigMemoryCursor in one operation. 

public

static IOBigMemoryCursor * withSpecification(
    IOPhysicalLength maxSegmentSize, 
    IOPhysicalLength maxTransferSize, 
    IOPhysicalLength alignment = 1); 
Parameters
maxSegmentSize
Maximum allowable size for one segment. Defaults to 0.
maxTransferSize
Maximum size of an entire transfer. Defaults to 0 indicating no maximum.
alignment
Alignment restrictions on output physical addresses. Not currently implemented. Defaults to single byte alignment.
Return Value

Returns a new memory cursor if successfully created and initialized, 0 otherwise. 
Discussion 

Factory function to create and initialize an IOBigMemoryCursor in one operation. See also IOBigMemoryCursor::initWithSpecification.*/
static IOBigMemoryCursor * withSpecification(
    IOPhysicalLength maxSegmentSize, 
    IOPhysicalLength maxTransferSize, 
    IOPhysicalLength alignment = 1); 

/*getPhysicalSegments


Generates a big endian physical scatter/gather list given a memory descriptor. 

public

virtual UInt32 getPhysicalSegments(
    IOMemoryDescriptor *descriptor, 
    IOByteCount fromPosition, 
    PhysicalSegment *segments, 
    UInt32 maxSegments, 
    UInt32 maxTransferSize = 0, 
    IOByteCount *transferSize = 0) 
Parameters
descriptor
IOMemoryDescriptor that describes the data associated with an I/O request.
fromPosition
Starting location of the I/O within a memory descriptor.
segments
Pointer to an array of IOMemoryCursor::PhysicalSegments for the output physical scatter/gather list.
maxSegments
Maximum number of segments that can be written to segments array.
maxTransferSize
Maximum transfer size is limited to that many bytes, otherwise it defaults to the maximum transfer size specified when the memory cursor was initialized.
transferSize
Pointer to an IOByteCount variable that can contain the total size of the transfer being described. Defaults to 0 indicating that no transfer size need be returned.
Return Value

If the descriptor is exhausted of memory, a zero is returned, otherwise the number of segments that were filled in is returned. 
Discussion 

Generates a list of physical segments from the given memory descriptor, relative to the current position of the descriptor. Wraps IOMemoryCursor::genPhysicalSegments.*/

virtual UInt32 getPhysicalSegments(
    IOMemoryDescriptor *descriptor, 
    IOByteCount fromPosition, 
    PhysicalSegment *segments, 
    UInt32 maxSegments, 
    UInt32 maxTransferSize = 0, 
    IOByteCount *transferSize = 0) ;
};

class IOLittleMemoryCursor : public IOMemoryCursor
{
    OSDeclareDefaultStructors(IOLittleMemoryCursor)

public://data

/*littleOutputSegment


public

#define littleOutputSegment IOLittleMemoryCursor::outputSegment 
Discussion 

Backward compatibility define for the old global function definition. See also IOLittleMemoryCursor::outputSegment.*/

#define littleOutputSegment IOLittleMemoryCursor::outputSegment 

public://function

/*outputSegment


Outputs the given segment into the output segments array in little endian byte order. 

public

static void outputSegment(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex); 
Parameters
segment
The physical address and length that is next to be output.
segments
Base of the output vector of DMA address length pairs.
segmentIndex
Index to output 'segment' in the 'segments' array.*/
static void outputSegment(
    PhysicalSegment segment, 
    void *segments, 
    UInt32 segmentIndex); 

};


//#if defined(__ppc__)

struct IODBDMADescriptor;
class IODBDMAMemoryCursor : public IOMemoryCursor
{
    OSDeclareDefaultStructors(IODBDMAMemoryCursor)

public:

/*getPhysicalSegments


Generates a DBDMA physical scatter/gather list given a memory descriptor. 

public

virtual UInt32 getPhysicalSegments(
    IOMemoryDescriptor *descriptor, 
    IOByteCount fromPosition, 
    IODBDMADescriptor *segments, 
    UInt32 maxSegments, 
    UInt32 maxTransferSize = 0, 
    IOByteCount *transferSize = 0) 
Parameters
descriptor
IOMemoryDescriptor that describes the data associated with an I/O request.
fromPosition
Starting location of the I/O within a memory descriptor.
segments
Pointer to an array of DBDMA descriptors for the output physical scatter/gather list. Be warned no room is left for a preamble in the output array. 'segments' should point to the first memory description slot in a DBDMA command.
maxSegments
Maximum number of segments that can be written to the DBDMA descriptor table.
maxTransferSize
Maximum transfer size is limited to that many bytes, otherwise it defaults to the maximum transfer size specified when the memory cursor was initialized.
transferSize
Pointer to an IOByteCount variable that can contain the total size of the transfer being described. Defaults to 0 indicating that no transfer size need be returned.
Return Value

If the descriptor is exhausted of memory, a zero is returned, otherwise the number of segments that were filled in is returned. 
Discussion 

Generates a list of DBDMA descriptors where the address and length fields are filled in appropriately. But the client is expected to fill in the rest of the DBDMA descriptor as is appropriate for their particular hardware. Wraps IOMemoryCursor::genPhysicalSegments.*/
virtual UInt32 getPhysicalSegments(
    IOMemoryDescriptor *descriptor, 
    IOByteCount fromPosition, 
    IODBDMADescriptor *segments, 
    UInt32 maxSegments, 
    UInt32 maxTransferSize = 0, 
    IOByteCount *transferSize = 0);

/*withSpecification


Creates and initializes an IODBDMAMemoryCursor in one operation. 

public

static IODBDMAMemoryCursor * withSpecification(
    IOPhysicalLength maxSegmentSize, 
    IOPhysicalLength maxTransferSize, 
    IOPhysicalLength alignment = 1); 
Parameters
maxSegmentSize
Maximum allowable size for one segment. Defaults to 0.
maxTransferSize
Maximum size of an entire transfer. Defaults to 0 indicating no maximum.
alignment
Alignment restrictions on output physical addresses. Not currently implemented. Defaults to single byte alignment.
Return Value

Returns a new memory cursor if successfully created and initialized, 0 otherwise. 
Discussion 

Factory function to create and initialize an IODBDMAMemoryCursor in one operation. See also IODBDMAMemoryCursor::initWithSpecification.*/

static IODBDMAMemoryCursor * withSpecification(
    IOPhysicalLength maxSegmentSize, 
    IOPhysicalLength maxTransferSize, 
    IOPhysicalLength alignment = 1); 

};

//#endif //. defined(__ppc__) 

#endif 

