#ifndef _IOMEMORYDESCRIPTOR_H
#define _IOMEMORYDESCRIPTOR_H

#include <sys/cdefs.h>

#include <IOKit/IOTypes.h>
#include <IOKit/IOLocks.h>
#include <libkern/c++/OSContainers.h>

__BEGIN_DECLS
#include <mach/memory_object_types.h>
__END_DECLS

#ifdef __cplusplus
class IOMemoryMap;
class IOMapper;
#endif //__cplusplus



#include <HYS/IOKit/IOMemoryDescriptor.h>

#ifdef __cplusplus
class IOMemoryDescriptor : public OSObject,public IOMemoryDescriptor_HYS
{
   OSDeclareDefaultStructors(IOMemoryDescriptor)
public:

IOMemoryDescriptor_getPhysicalSegment64
IOMemoryDescriptor_getVirtualSegment
IOMemoryDescriptor_redirect

/*withSubRange


Creates an IOMemoryDescriptor to describe a subrange of an existing descriptor. 

public

static IOMemoryDescriptor * withSubRange(
    IOMemoryDescriptor *of, 
    IOByteCount offset, 
    IOByteCount length, 
    IODirection withDirection); 
Parameters
of
The parent IOMemoryDescriptor of which a subrange is to be used for the new descriptor, which will be retained by the subrange IOMemoryDescriptor.
offset
A byte offset into the parent memory descriptor's memory.
length
The length of the subrange.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures. This is used over the direction of the parent descriptor.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of a subrange of the specified memory descriptor. The parent memory descriptor is retained by the new descriptor.*/
static IOMemoryDescriptor * withSubRange(
    IOMemoryDescriptor *of, 
    IOByteCount offset, 
    IOByteCount length, 
    IODirection withDirection); 

/*withPhysicalRanges


Creates an IOMemoryDescriptor to describe one or more physical ranges. 

public

static IOMemoryDescriptor * withPhysicalRanges( 
    IOPhysicalRange *ranges, 
    UInt32 withCount, 
    IODirection withDirection, 
    bool asReference = false); 
Parameters
ranges
An array of IOPhysicalRange structures which specify the physical ranges which make up the memory to be described.
withCount
The member count of the ranges array.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
asReference
If false, the IOMemoryDescriptor object will make a copy of the ranges array, otherwise, the array will be used in situ, avoiding an extra allocation.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of an array of physical memory ranges.*/
static IOMemoryDescriptor * withPhysicalRanges( 
    IOPhysicalRange *ranges, 
    UInt32 withCount, 
    IODirection withDirection, 
    bool asReference = false); 

/*map(task_t, IOVirtualAddress, IOOptionBits, IOByteCount, IOByteCount)


Maps a IOMemoryDescriptor into a task - deprecated, only safe for 32 bit tasks. Use createMappingInTask instead. 

public

virtual IOMemoryMap * map( 
    task_t intoTask, 
    IOVirtualAddress atAddress, 
    IOOptionBits options, 
    IOByteCount offset = 0, 
    IOByteCount length = 0 ); 
Parameters
intoTask
Sets the target task for the mapping. Pass kernel_task for the kernel address space.
atAddress
If a placed mapping is requested, atAddress specifies its address, and the kIOMapAnywhere should not be set. Otherwise, atAddress is ignored.
options
Mapping options are defined in IOTypes.h,
kIOMapAnywhere should be passed if the mapping can be created anywhere. If not set, the atAddress parameter sets the location of the mapping, if it is available in the target map.
kIOMapDefaultCache to inhibit the cache in I/O areas, kIOMapCopybackCache in general purpose RAM.
kIOMapInhibitCache, kIOMapWriteThruCache, kIOMapCopybackCache to set the appropriate caching.
kIOMapReadOnly to allow only read only accesses to the memory - writes will cause and access fault.
kIOMapReference will only succeed if the mapping already exists, and the IOMemoryMap object is just an extra reference, ie. no new mapping will be created.
kIOMapUnique allows a special kind of mapping to be created that may be used with the IOMemoryMap::redirect() API. These mappings will not be shared as is the default - there will always be a unique mapping created for the caller, not an existing mapping with an extra reference.
offset
Is a beginning offset into the IOMemoryDescriptor's memory where the mapping starts. Zero is the default to map all the memory.
length
Is the length of the mapping requested for a subset of the IOMemoryDescriptor. Zero is the default to map all the memory.
Return Value

A reference to an IOMemoryMap object representing the mapping, which can supply the virtual address of the mapping and other information. The mapping may be shared with multiple callers - multiple maps are avoided if a compatible one exists. The IOMemoryMap object returned should be released only when the caller has finished accessing the mapping, as freeing the object destroys the mapping. The IOMemoryMap instance also retains the IOMemoryDescriptor it maps while it exists. 
Discussion 

This is the general purpose method to map all or part of the memory described by a memory descriptor into a task at any available address, or at a fixed address if possible. Caching & read-only options may be set for the mapping. The mapping is represented as a returned reference to a IOMemoryMap object, which may be shared if the mapping is compatible with an existing mapping of the IOMemoryDescriptor. The IOMemoryMap object returned should be released only when the caller has finished accessing the mapping, as freeing the object destroys the mapping.*/
virtual IOMemoryMap * map( 
    task_t intoTask, 
    IOVirtualAddress atAddress, 
    IOOptionBits options, 
    IOByteCount offset = 0, 
    IOByteCount length = 0 ); 

/*setTag


Set the tag for the memory descriptor. 

public

virtual void setTag(
    IOOptionBits tag ); 
Parameters
tag
The tag.
Discussion 

This method sets the tag for the memory descriptor. Tag bits are not interpreted by IOMemoryDescriptor.*/
virtual void setTag(
    IOOptionBits tag ); 

/*getTag


Accessor to the retrieve the tag for the memory descriptor. 

public

virtual IOOptionBits getTag(
    void ); 
Return Value

The tag. 
Discussion 

This method returns the tag for the memory descriptor. Tag bits are not interpreted by IOMemoryDescriptor.*/
virtual IOOptionBits getTag(
    void ); 

/*setMapping


Establishes an already existing mapping. 

public

virtual IOMemoryMap * setMapping( 
    task_t task, 
    IOVirtualAddress mapAddress, 
    IOOptionBits options = 0 ); 
Parameters
task
Address space in which the mapping exists.
mapAddress
Virtual address of the mapping.
options
Caching and read-only attributes of the mapping.
Return Value

A IOMemoryMap object created to represent the mapping. 
Discussion 

This method tells the IOMemoryDescriptor about a mapping that exists, but was created elsewhere. It allows later callers of the map method to share this externally created mapping. The IOMemoryMap object returned is created to represent it. This method is not commonly needed*/
virtual IOMemoryMap * setMapping( 
    task_t task, 
    IOVirtualAddress mapAddress, 
    IOOptionBits options = 0 ); 

/*withRanges


Create an IOMemoryDescriptor to describe one or more virtual ranges. 

public

static IOMemoryDescriptor * withRanges(
    IOVirtualRange *ranges, 
    UInt32 withCount, 
    IODirection withDirection, 
    task_t withTask, 
    bool asReference = false); 
Parameters
ranges
An array of IOVirtualRange structures which specify the virtual ranges in the specified map which make up the memory to be described.
withCount
The member count of the ranges array.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
withTask
The task each of the virtual ranges are mapped into. To map into the kernel's task, pass kernel_task. To map into the task currently running in the kernel, use the task_t value returned by current_task(). When calling this method from a user client method running in the kernel, pass the task_t value that was passed into IOUserClient::initWithTask to map into the user process that initiated the user client.
asReference
If false, the IOMemoryDescriptor object will make a copy of the ranges array, otherwise, the array will be used in situ, avoiding an extra allocation.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of an array of virtual memory ranges each mapped into a specified source task.*/
static IOMemoryDescriptor * withRanges(
    IOVirtualRange *ranges, 
    UInt32 withCount, 
    IODirection withDirection, 
    task_t withTask, 
    bool asReference = false); 

/*initWithRanges


Initializes or reinitializes an IOMemoryDescriptor to describe one or more virtual ranges. 

public

virtual bool initWithRanges(
    IOVirtualRange *ranges, 
    UInt32 withCount, 
    IODirection withDirection, 
    task_t withTask, 
    bool asReference = false) = 0; 
Parameters
ranges
An array of IOVirtualRange structures which specify the virtual ranges in the specified map which make up the memory to be described.
withCount
The member count of the ranges array.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
withTask
The task each of the virtual ranges are mapped into. To map into the kernel's task, pass kernel_task. To map into the task currently running in the kernel, use the task_t value returned by current_task(). When calling this method from a user client method running in the kernel, pass the task_t value that was passed into IOUserClient::initWithTask to map into the user process that initiated the user client.
asReference
If false, the IOMemoryDescriptor object will make a copy of the ranges array, otherwise, the array will be used in situ, avoiding an extra allocation.
Return Value

true on success, false on failure. 
Discussion 

This method initializes an IOMemoryDescriptor for memory consisting of an array of virtual memory ranges each mapped into a specified source task. An IOMemoryDescriptor can be re-used by calling address, IOByteCount withLength, IODirection withDirection, task_t withTask) initWithAddress or initWithRanges again on an existing instance -- note this behavior is not commonly supported in other I/O Kit classes, although it is supported here.*/
virtual bool initWithRanges(
    IOVirtualRange *ranges, 
    UInt32 withCount, 
    IODirection withDirection, 
    task_t withTask, 
    bool asReference = false) = 0; 

/*withAddressRanges


Create an IOMemoryDescriptor to describe one or more virtual ranges. 

public

static IOMemoryDescriptor * withAddressRanges( 
    IOAddressRange *ranges, 
    UInt32 rangeCount, 
    IOOptionBits options, 
    task_t withTask); 
Parameters
ranges
An array of IOAddressRange structures which specify the virtual ranges in the specified map which make up the memory to be described. IOAddressRange is the 64bit version of IOVirtualRange.
rangeCount
The member count of the ranges array.
options
kIOMemoryDirectionMask (options:direction) This nibble indicates the I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures. kIOMemoryAsReference For options:type = Virtual or Physical this indicate that the memory descriptor need not copy the ranges array into local memory. This is an optimisation to try to minimise unnecessary allocations.
task
The task each of the virtual ranges are mapped into. Note that unlike IOMemoryDescriptor::withAddress(), kernel_task memory must be explicitly prepared when passed to this api.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of an array of virtual memory ranges each mapped into a specified source task. Note that unlike IOMemoryDescriptor::withAddress(), kernel_task memory must be explicitly prepared when passed to this api.*/
static IOMemoryDescriptor * withAddressRanges( 
    IOAddressRange *ranges, 
    UInt32 rangeCount, 
    IOOptionBits options, 
    task_t withTask); 

/*withAddressRange


Create an IOMemoryDescriptor to describe one virtual range of the specified map. 

public

static IOMemoryDescriptor * withAddressRange( 
    mach_vm_address_t address, 
    mach_vm_size_t length, 
    IOOptionBits options, 
    task_t task); 
Parameters
address
The virtual address of the first byte in the memory.
withLength
The length of memory.
options
kIOMemoryDirectionMask (options:direction) This nibble indicates the I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
task
The task the virtual ranges are mapped into. Note that unlike IOMemoryDescriptor::withAddress(), kernel_task memory must be explicitly prepared when passed to this api.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of a single virtual memory range mapped into the specified map. Note that unlike IOMemoryDescriptor::withAddress(), kernel_task memory must be explicitly prepared when passed to this api.*/
static IOMemoryDescriptor * withAddressRange( 
    mach_vm_address_t address, 
    mach_vm_size_t length, 
    IOOptionBits options, 
    task_t task); 

/*initWithAddress(vm_address_t, IOByteCount, IODirection, task_t)


Initializes or reinitializes an IOMemoryDescriptor to describe one virtual range of the specified map. 

public

virtual bool initWithAddress(
    vm_address_t address, 
    IOByteCount withLength, 
    IODirection withDirection, 
    task_t withTask) = 0; 
Parameters
address
The virtual address of the first byte in the memory.
withLength
The length of memory.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
withTask
The task the virtual range is mapped into. To map into the kernel's task, pass kernel_task. To map into the task currently running in the kernel, use the task_t value returned by current_task(). When calling this method from a user client method running in the kernel, pass the task_t value that was passed into IOUserClient::initWithTask to map into the user process that initiated the user client.
Return Value

true on success, false on failure. 
Discussion 

This method initializes an IOMemoryDescriptor for memory consisting of a single virtual memory range mapped into the specified map. An IOMemoryDescriptor can be re-used by calling initWithAddress or initWithRanges again on an existing instance -- note this behavior is not commonly supported in other IOKit classes, although it is supported here. */

virtual bool initWithAddress(
    vm_address_t address, 
    IOByteCount withLength, 
    IODirection withDirection, 
    task_t withTask) = 0; 

/*initWithAddress(void *, IOByteCount, IODirection)


Initializes or reinitializes an IOMemoryDescriptor to describe one virtual range of the kernel task. 

public

virtual bool initWithAddress(
    void *address, 
    IOByteCount withLength, 
    IODirection withDirection) = 0; 
Parameters
address
The virtual address of the first byte in the memory.
withLength
The length of memory.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
Return Value

true on success, false on failure. 
Discussion 

This method initializes an IOMemoryDescriptor for memory consisting of a single virtual memory range mapped into the kernel map. An IOMemoryDescriptor can be re-used by calling initWithAddress or initWithRanges again on an existing instance -- note this behavior is not commonly supported in other I/O Kit classes, although it is supported here.*/

virtual bool initWithAddress(
    void *address, 
    IOByteCount withLength, 
    IODirection withDirection) = 0; 

/*getDirection


Accessor to get the direction the memory descriptor was created with. 

public

virtual IODirection getDirection() const; 
Return Value

The direction. 
Discussion 

This method returns the direction the memory descriptor was created with.*/
virtual IODirection getDirection() const; 

/*withAddress(vm_address_t, IOByteCount, IODirection, task_t)


Creates an IOMemoryDescriptor to describe one virtual range of the specified map. 

public

static IOMemoryDescriptor * withAddress(
    vm_address_t address, 
    IOByteCount withLength, 
    IODirection withDirection, 
    task_t withTask); 
Parameters
address
The virtual address of the first byte in the memory.
withLength
The length of memory.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
withTask
The task the virtual range is mapped into. To map into the kernel's task, pass kernel_task. To map into the task currently running in the kernel, use the task_t value returned by current_task(). When calling this method from a user client method running in the kernel, pass the task_t value that was passed into IOUserClient::initWithTask to map into the user process that initiated the user client.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of a single virtual memory range mapped into the specified map. */
static IOMemoryDescriptor * withAddress(
    vm_address_t address, 
    IOByteCount withLength, 
    IODirection withDirection, 
    task_t withTask); 

/*withAddress(void *, IOByteCount, IODirection)


Creates an IOMemoryDescriptor to describe one virtual range of the kernel task. 

public

static IOMemoryDescriptor * withAddress(
    void *address, 
    IOByteCount withLength, 
    IODirection withDirection); 
Parameters
address
The virtual address of the first byte in the memory.
withLength
The length of memory.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of a single virtual memory range mapped into the kernel map.*/
static IOMemoryDescriptor * withAddress(
    void *address, 
    IOByteCount withLength, 
    IODirection withDirection);

/*getPhysicalAddress


Returns the physical address of the first byte in the memory. 

public

IOPhysicalAddress getPhysicalAddress(); 
Return Value

A physical address. 
Discussion 

This method returns the physical address of the first byte in the memory. It is most useful on memory known to be physically contiguous.*/
IOPhysicalAddress getPhysicalAddress(); 

/*map(IOOptionBits)


Maps a IOMemoryDescriptor into the kernel map. 

public

virtual IOMemoryMap * map( 
    IOOptionBits options = 0 ); 
Parameters
options
Mapping options as in the full version of the createMappingInTask method, with kIOMapAnywhere assumed.
Return Value

See the full version of the createMappingInTask method. 
Discussion 

This is a shortcut method to map all the memory described by a memory descriptor into the kernel map at any available address. See the full version of the createMappingInTask method for further details.*/
virtual IOMemoryMap * map( 
    IOOptionBits options = 0 ); 

/*withPhysicalAddress


Creates an IOMemoryDescriptor to describe one physical range. 

public

static IOMemoryDescriptor * withPhysicalAddress( 
    IOPhysicalAddress address, 
    IOByteCount withLength, 
    IODirection withDirection ); 
Parameters
address
The physical address of the first byte in the memory.
withLength
The length of memory.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory consisting of a single physical memory range.*/
static IOMemoryDescriptor * withPhysicalAddress( 
    IOPhysicalAddress address, 
    IOByteCount withLength, 
    IODirection withDirection ); 

/*complete


Completes processing of the memory after an I/O transfer finishes. 

public

virtual IOReturn complete(
    IODirection forDirection = kIODirectionNone) = 0; 
Parameters
forDirection
DEPRECATED The direction of the I/O just completed, or kIODirectionNone for the direction specified by the memory descriptor.
Return Value

An IOReturn code. 
Discussion 

This method should not be called unless a prepare was previously issued; the prepare and complete() must occur in pairs, before and after an I/O transfer involving pageable memory. In 10.3 or greater systems the direction argument to complete is not longer respected. The direction is totally determined at prepare time*/
virtual IOReturn complete(
    IODirection forDirection = kIODirectionNone) = 0; 

/*prepare


Prepares the memory for an I/O transfer. 

public

virtual IOReturn prepare(
    IODirection forDirection = kIODirectionNone) = 0; 
Parameters
forDirection
The direction of the I/O just completed, or kIODirectionNone for the direction specified by the memory descriptor.
Return Value

An IOReturn code. 
Discussion 

This involves paging in the memory, if necessary, and wiring it down for the duration of the transfer. The complete method completes the processing of the memory after the I/O transfer finishes. Note that the prepare call is not thread safe and it is expected that the client will more easily be able to guarantee single threading a particular memory descriptor.*/

virtual IOReturn prepare(
    IODirection forDirection = kIODirectionNone) = 0; 

/*withOptions


Master initialiser for all variants of memory descriptors. 

public

static IOMemoryDescriptor *withOptions(
    void *buffers, 
    UInt32 count, 
    UInt32 offset, 
    task_t task, 
    IOOptionBits options, 
    IOMapper *mapper = 0); 
Parameters
buffers
A pointer to an array of IOVirtualRanges or IOPhysicalRanges if the options:type is Virtual or Physical. For type UPL it is a upl_t returned by the mach/memory_object_types.h apis, primarily used internally by the UBC. 

count
options:type = Virtual or Physical count contains a count of the number of entires in the buffers array. For options:type = UPL this field contains a total length. 

offset
Only used when options:type = UPL, in which case this field contains an offset for the memory within the buffers upl. 

task
Only used options:type = Virtual, The task each of the virtual ranges are mapped into. 

options
kIOMemoryDirectionMask (options:direction) This nibble indicates the I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures. kIOMemoryTypeMask (options:type) kIOMemoryTypeVirtual, kIOMemoryTypePhysical, kIOMemoryTypeUPL Indicates that what type of memory basic memory descriptor to use. This sub-field also controls the interpretation of the buffers, count, offset & task parameters. kIOMemoryAsReference For options:type = Virtual or Physical this indicate that the memory descriptor need not copy the ranges array into local memory. This is an optimisation to try to minimise unnecessary allocations. kIOMemoryBufferPageable Only used by the IOBufferMemoryDescriptor as an indication that the kernel virtual memory is in fact pageable and we need to use the kernel pageable submap rather than the default map. kIOMemoryNoAutoPrepare Indicates that the temporary AutoPrepare of kernel_task memory should not be performed. 

mapper
Which IOMapper should be used to map the in-memory physical addresses into I/O space addresses. Defaults to 0 which indicates that the system mapper is to be used, if present. 

Return Value

The created IOMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMemoryDescriptor for memory it has three main variants: Virtual, Physical & mach UPL. These variants are selected with the options parameter, see below. This memory descriptor needs to be prepared before it can be used to extract data from the memory described. However we temporarily have setup a mechanism that automatically prepares kernel_task memory descriptors at creation time.*/
static IOMemoryDescriptor *withOptions(
    void *buffers, 
    UInt32 count, 
    UInt32 offset, 
    task_t task, 
    IOOptionBits options, 
    IOMapper *mapper = 0); 

/*getPhysicalSegment


Breaks a memory descriptor into its physically contiguous segments. 

public

virtual IOPhysicalAddress getPhysicalSegment(
    IOByteCount offset, 
    IOByteCount *length) = 0; 
Parameters
offset
A byte offset into the memory whose physical address to return.
length
If non-zero, getPhysicalSegment will store here the length of the physically contiguous segement at the given offset.
Return Value

A physical address, or zero if the offset is beyond the length of the memory. 
Discussion 

This method returns the physical address of the byte at the given offset into the memory, and optionally the length of the physically contiguous segment from that offset.*/
virtual IOPhysicalAddress getPhysicalSegment(
    IOByteCount offset, 
    IOByteCount *length) = 0; 

/*writeBytes


Copies data to the memory descriptor's buffer from the specified buffer. 
public

virtual IOByteCount writeBytes(
    IOByteCount offset, 
    const void *bytes,
    IOByteCount withLength); 
Parameters
offset
A byte offset into the memory descriptor's memory.
bytes
The caller supplied buffer to copy the data from.
withLength
The length of the data to copy.
Return Value

The number of bytes copied, zero will be returned if the specified offset is beyond the length of the descriptor. 
Discussion 

This method copies data to the memory descriptor's memory at the given offset, from the caller's buffer.*/
virtual IOByteCount writeBytes(
    IOByteCount offset, 
    const void *bytes,
    IOByteCount withLeng);

/*getLength


Accessor to get the length of the memory descriptor (over all its ranges). 
public

virtual IOByteCount getLength() const; 
Return Value

The byte count. 
Discussion 

This method returns the total length of the memory described by the descriptor, ie. the sum of its ranges' lengths.*/
virtual IOByteCount getLength() const; 

/*readBytes


Copies data from the memory descriptor's buffer to the specified buffer. 
public

virtual IOByteCount readBytes(
    IOByteCount offset, 
    void *bytes,
    IOByteCount withLength); 
Parameters
offset
A byte offset into the memory descriptor's memory.
bytes
The caller supplied buffer to copy the data to.
withLength
The length of the data to copy.
Return Value

The number of bytes copied, zero will be returned if the specified offset is beyond the length of the descriptor. 
Discussion 

This method copies data from the memory descriptor's memory at the given offset, to the caller's buffer.*/
virtual IOByteCount readBytes(
    IOByteCount offset, 
    void *bytes,
    IOByteCount withLength); 

};

class IOMemoryMap : public OSObject,public IOMemoryMap_HYS
{
   OSDeclareDefaultStructors(IOMemoryMap)
public:
 IOMemoryMap_getAddress

/*getMemoryDescriptor


Accessor to the IOMemoryDescriptor the mapping was created from. 

public

virtual IOMemoryDescriptor * getMemoryDescriptor() = 0; 
Return Value

An IOMemoryDescriptor reference, which is valid while the IOMemoryMap object is retained. It should not be released by the caller. 
Discussion 

This method returns the IOMemoryDescriptor the mapping was created from.*/
virtual IOMemoryDescriptor * getMemoryDescriptor() = 0; 

/*getPhysicalSegment


Break a mapping into its physically contiguous segments. 

public

virtual IOPhysicalAddress getPhysicalSegment(
    IOByteCount offset, 
    IOByteCount *length) = 0; 
Parameters
offset
A byte offset into the mapping whose physical address to return.
length
If non-zero, getPhysicalSegment will store here the length of the physically contiguous segement at the given offset.
Return Value

A physical address, or zero if the offset is beyond the length of the mapping. 
Discussion 

This method returns the physical address of the byte at the given offset into the mapping, and optionally the length of the physically contiguous segment from that offset. It functions similarly to IOMemoryDescriptor::getPhysicalSegment.*/
virtual IOPhysicalAddress getPhysicalSegment(
    IOByteCount offset, 
    IOByteCount *length) = 0; 

/*getPhysicalAddress 


Return the physical address of the first byte in the mapping. 

public

IOPhysicalAddress getPhysicalAddress(); 
Return Value

A physical address. 
Discussion 

This method returns the physical address of the first byte in the mapping. It is most useful on mappings known to be physically contiguous.*/


IOPhysicalAddress getPhysicalAddress(); 

/*getLength


Accessor to the length of the mapping. 

public

virtual IOByteCount getLength() = 0; 
Return Value

A byte count. 
Discussion 

This method returns the length of the mapping.*/

virtual IOByteCount getLength() = 0;
 
/*getVirtualAddress


Accessor to the virtual address of the first byte in the mapping. 

public

virtual IOVirtualAddress getVirtualAddress() = 0; 
Return Value

A virtual address. 
Discussion 

This method returns the virtual address of the first byte in the mapping.*/
virtual IOVirtualAddress getVirtualAddress() = 0; 



};

class IOGeneralMemoryDescriptor : public IOMemoryDescriptor,public IOGeneralMemoryDescriptor_HYS
{
    OSDeclareDefaultStructors(IOGeneralMemoryDescriptor);

public:

IOGeneralMemoryDescriptor_getPhysicalSegment
IOGeneralMemoryDescriptor_prepare
IOGeneralMemoryDescriptor_complete
IOGeneralMemoryDescriptor_initWithPhysicalRanges

protected:
private:

};

class IOSubMemoryDescriptor : public IOMemoryDescriptor,public IOSubMemoryDescriptor_HYS
{
    friend class IOMemoryDescriptor;

    OSDeclareDefaultStructors(IOSubMemoryDescriptor);

protected:
public:
IOSubMemoryDescriptor_initWithRanges
IOSubMemoryDescriptor_initWithAddress
IOSubMemoryDescriptor_initWithAddress_vm_address_t
IOSubMemoryDescriptor_prepare
IOSubMemoryDescriptor_complete
IOSubMemoryDescriptor_getPhysicalSegment
IOSubMemoryDescriptor_initSubRange

};
#endif //__cplusplus


#endif//_IOMEMORYDESCRIPTOR_H
