#ifndef _IOMULTIMEMORYDESCRIPTOR_H
#define _IOMULTIMEMORYDESCRIPTOR_H

#include <IOKit/IOMemoryDescriptor.h>
class IOMultiMemoryDescriptor : public IOMemoryDescriptor
{
    OSDeclareDefaultStructors(IOMultiMemoryDescriptor);

protected:
public:

/*withDescriptors(IOMemoryDescriptor **, UInt32, IODirection, bool)


Create an IOMultiMemoryDescriptor to describe a memory area made up of several other IOMemoryDescriptors. 

public

static IOMultiMemoryDescriptor * withDescriptors( 
    IOMemoryDescriptor ** descriptors, 
    UInt32 withCount, 
    IODirection withDirection, 
    bool asReference = false ); 
Parameters
descriptors
An array of IOMemoryDescriptors which make up the memory to be described.
withCount
The object count for the descriptors array.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
asReference
If false, the IOMultiMemoryDescriptor object will make a copy of the descriptors array, otherwise, the array will be used in situ, avoiding an extra allocation.
Return Value

The created IOMultiMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method creates and initializes an IOMultiMemoryDescriptor for memory consisting of a number of other IOMemoryDescriptors, chained end-to-end (in the order they appear in the array) to represent a single contiguous memory buffer. Passing the descriptor array as a reference will avoid an extra allocation. */
static IOMultiMemoryDescriptor * withDescriptors( 
    IOMemoryDescriptor ** descriptors, 
    UInt32 withCount, 
    IODirection withDirection, 
    bool asReference = false ); 

/*initWithDescriptors(IOMemoryDescriptor **, UInt32, IODirection, bool)


Initialize an IOMultiMemoryDescriptor to describe a memory area made up of several other IOMemoryDescriptors. 

public

virtual bool initWithDescriptors( 
    IOMemoryDescriptor ** descriptors, 
    UInt32 withCount, 
    IODirection withDirection, 
    bool asReference = false ); 
Parameters
descriptors
An array of IOMemoryDescriptors which make up the memory to be described.
withCount
The object count for the descriptors array.
withDirection
An I/O direction to be associated with the descriptor, which may affect the operation of the prepare and complete methods on some architectures.
asReference
If false, the IOMultiMemoryDescriptor object will make a copy of the descriptors array, otherwise, the array will be used in situ, avoiding an extra allocation.
Return Value

The created IOMultiMemoryDescriptor on success, to be released by the caller, or zero on failure. 
Discussion 

This method initializes an IOMultiMemoryDescriptor for memory consisting of a number of other IOMemoryDescriptors, chained end-to-end (in the order they appear in the array) to represent a single contiguous memory buffer. Passing the descriptor array as a reference will avoid an extra allocation.*/
virtual bool initWithDescriptors( 
    IOMemoryDescriptor ** descriptors, 
    UInt32 withCount, 
    IODirection withDirection, 
    bool asReference = false ); 

};


#endif /* !_IOMULTIMEMORYDESCRIPTOR_H */
