
#ifndef _IOTIMEREVENTSOURCE
#define _IOTIMEREVENTSOURCE

#include <sys/cdefs.h>
#include <kern/clock.h>
#include <IOKit/IOEventSource.h>
#include <IOKit/IOTypes.h>

#ifdef __cplusplus
class IOTimerEventSource : public IOEventSource
{
  OSDeclareAbstractStructors(IOTimerEventSource);

protected:

/*abstime


protected

AbsoluteTime abstime; 
Discussion 

time to wake up next, see enable.*/
AbsoluteTime abstime; 

/*calloutEntry


protected

void *calloutEntry; 
Discussion 

thread_call entry for preregistered thread callouts*/
void *calloutEntry; 

public://datatype
/*Action


public

typedef void ( *Action)(
    OSObject *owner,
    IOTimerEventSource *sender); 
Parameters
owner
Owning target object. Note by a startling coincidence the first parameter in a C callout is currently used to define the target of a C++ member function.
sender
The object that timed out.
Discussion 

'C' Function pointer defining the callout routine of this event source.*/


typedef void ( *Action)(
    OSObject *owner,
   IOTimerEventSource *sender); 


public: //func



/*setTimeout


Setup a callback at after the delay in decrementer ticks. See wakeAtTime(AbsoluteTime). 

public

virtual IOReturn setTimeout(
    AbsoluteTime interval); 
Parameters
interval
Delay from now to wake up in decrementer ticks.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared.*/ 
virtual IOReturn setTimeout(
    AbsoluteTime interval);

/*setTimeout(mach_timespec_t)


Setup a callback at after the delay in decrementer ticks. See wakeAtTime(AbsoluteTime). 

public

virtual IOReturn setTimeout(
    mach_timespec_t interval); 
Parameters
interval
Delay from now to wake up.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared. */
virtual IOReturn setTimeout(
    mach_timespec_t interval); 

/*setTimeout(UInt32, UInt32)


Setup a callback at after the delay in some unit. See wakeAtTime(AbsoluteTime). 

public

virtual IOReturn setTimeout(
    UInt32 interval, 
    UInt32 scale_factor = kNanosecondScale); 
Parameters
interval
Delay from now to wake up in some defined unit.
scale_factor
Define the unit of interval, default to nanoseconds.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared.*/
virtual IOReturn setTimeout(
    UInt32 interval, 
    UInt32 scale_factor = kNanosecondScale); 



/*setTimeoutMS


Setup a callback at after the delay in milliseconds. See wakeAtTime(AbsoluteTime). 
public

virtual IOReturn setTimeoutMS(
    UInt32 ms); 
Parameters
interval
Delay from now to wake up, time in milliseconds.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared.*/
virtual IOReturn setTimeoutMS(
    UInt32 ms); 

/*timerEventSource


Allocates and returns an initialized timer instance. 
public

static IOTimerEventSource * timerEventSource(
    OSObject *owner,
    Action action = 0); 
Parameters
owner
action*/
static IOTimerEventSource * timerEventSource(
    OSObject *owner,
    Action action = 0); 

/*cancelTimeout


Disable any outstanding calls to this event source. 
public

virtual void cancelTimeout(); 
Discussion 

Clear down any oustanding calls. By the time this function completes it is guaranteed that the action will not be called again.*/
virtual void cancelTimeout(); 

/*setTimeoutUS


Setup a callback at after the delay in microseconds. See wakeAtTime(AbsoluteTime). 

public

virtual IOReturn setTimeoutUS(
    UInt32 us); 
Parameters
interval
Delay from now to wake up, time in microseconds.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared.*/
virtual IOReturn setTimeoutUS(
    UInt32 us); 

/*enable


Enables a call to the action. 

public

virtual void enable(); 
Discussion 

Allows the action function to be called. If the timer event source was disabled while a call was outstanding and the call wasn't cancelled then it will be rescheduled. So a disable/enable pair will disable calls from this event source.*/
virtual void enable(); 

/*disable


Disable a timed callout. 

public

virtual void disable(); 
Discussion 

When disable returns the action will not be called until the next time enable(qv) is called.*/
virtual void disable(); 

/*wakeAtTime


Setup a callback at this absolute time. 

public

virtual IOReturn wakeAtTime(
    AbsoluteTime abstime); 
Parameters
abstime
Absolute Time when to wake up, counted in 'decrementer' units and starts at zero when system boots.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared by init or IOEventSource::setAction (qqv). 
Discussion 

Starts the timer, which will expire at abstime. After it expires, the timer will call the 'action' registered in the init() function. This timer is not periodic, a further call is needed to reset and restart the timer after it expires. */
virtual IOReturn wakeAtTime(
    AbsoluteTime abstime); 

/*wakeAtTime(mach_timespec_t)


Setup a callback at this absolute time. See wakeAtTime(AbsoluteTime). 

public

virtual IOReturn wakeAtTime(
    mach_timespec_t abstime); 
Parameters
abstime
mach_timespec_t of the desired callout time.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared. */
virtual IOReturn wakeAtTime(
    mach_timespec_t abstime); 

/*wakeAtTime(UInt32, UInt32)


Setup a callback at this absolute time. See wakeAtTime(AbsoluteTime). 

public

virtual IOReturn wakeAtTime(
    UInt32 abstime, 
    UInt32 scale_factor = kNanosecondScale); 
Parameters
abstime
Time to wake up in some unit.
scale_factor
Define the unit of abstime, default to nanoseconds.
Return Value

kIOReturnSuccess if everything is fine, kIOReturnNoResources if action hasn't been declared.*/
virtual IOReturn wakeAtTime(
    UInt32 abstime, 
    UInt32 scale_factor = kNanosecondScale); 

/*init


Initializes the timer with an owner, and a handler to call when the timeout expires. 

public

virtual bool init(
    OSObject *owner,
    Action action = 0); 
Parameters
owner
action*/

virtual bool init(
    OSObject *owner,
    Action action = 0);

};
#endif//__cplusplus

#endif  //_IOTIMEREVENTSOURCE
