
#ifndef _IOKIT_IOUSERCLIENT_H
#define _IOKIT_IOUSERCLIENT_H


#include <IOKit/IOTypes.h>
#include <IOKit/IOService.h>
#include <IOKit/OSMessageNotification.h>

#include <HYS/IOKit/IOUserClient.h>

/*kIOUCVariableStructureSize


Constant to denote a variable length structure argument to IOUserClient. 

enum { 
    kIOUCVariableStructureSize = 0xffffffff 
};  
Constants
kIOUCVariableStructureSize
Use in the structures IOExternalMethod, IOExternalAsyncMethod, IOExternalMethodDispatch to specify the size of the structure is variable.*/
enum { 
    kIOUCVariableStructureSize = 0xffffffff 
};  

/*The flags member is an IOOptionBits value which indicates the contents of the
input and output parameters. The possible values for the IOOptionBits flag are:

enum {
    kIOUCTypeMask = 0x0000000f,
    kIOUCScalarIScalarO = 0,
    kIOUCScalarIStructO = 2,
    kIOUCStructIStructO = 3,
    kIOUCScalarIStructI = 4,
};

The count0 and count1 members of the IOExternalMethod struct have different
meanings depending on the value of the flags member. */
enum {
    kIOUCTypeMask = 0x0000000f,
    kIOUCScalarIScalarO = 0,
    kIOUCScalarIStructO = 2,
    kIOUCStructIStructO = 3,
    kIOUCScalarIStructI = 4,
};

/*IOUserClient inside the Kernel
------------------------------
To begin implementing a user client, you'll need to add a class to your kernel
extension which is a subclass of IOUserClient. The definition for IOUserClient
is located in IOUserClient.h, inside Kernel.framework/IOKit.

The first method that gets called in the life of a user client is initWithTask
which is where you put initialization code. (On Intel-based Macs, this is also
where the user client can detect if it's being initialized by an application
running using Rosetta.) Then the start method is called which is where you
should do some sanity checking to make sure that the provider is actually a
member of your driver's family. If this check fails, your start method should
return false which causes the instantiation to fail.

In order for functions to be called in your kernel extension, you must create
an array of IOExternalMethods, which is in essence just an array of function
pointers.

The layout of an IOExternalMethod struct is defined in IOUserClient.h and is
shown below:

struct IOExternalMethod {
    IOService* object;
    IOMethod func;
    IOOptionBits flags;
    IOByteCount count0;
    IOByteCount count1;
};

User clients typically call member functions either of the user client class
itself or of the user client's provider. The actual member function to call is
obtained by IOUserClient calling getTargetAndMethodForIndex. This function
returns pointers to the object and the member function of that object which
should be called. Your array of IOExternalMethod structs can be used by your
implementation of getTargetAndMethodForIndex. This will be discussed in more
detail later.*/
struct IOExternalMethod {
#ifdef __cplusplus
    IOService* object;
    IOMethod func;
#endif
    IOOptionBits flags;
    IOByteCount count0;
    IOByteCount count1;
};

#ifdef __cplusplus
class IOUserClient : public IOService,public IOUserClient_HYS
{
   OSDeclareAbstractStructors(IOUserClient)

public:

IOUserClient_clientHasPrivilege
IOUserClient_initWithTask
IOUserClient_externalMethod
IOUserClient_initWithTask_task_t
IOUserClient_setAsyncReference64 
IOUserClient_clientDied 
IOUserClient_sendAsyncResult64
IOUserClient_getService
IOUserClient_clientHasPrivilege1

/*removeMappingForDescriptor


public

IOMemoryMap * removeMappingForDescriptor(
    IOMemoryDescriptor *memory); 
Parameters
memory
The memory descriptor instance previously returned by the implementation of clientMemoryForType().
Return Value

A reference to the first IOMemoryMap instance found in the list of mappings created by IOUserClient from that passed memory descriptor is returned, or zero if none exist. The caller should release this reference. 
Discussion 

Removes the first mapping created from the memory descriptor returned by clientMemoryForType() from IOUserClient's list of mappings. If such a mapping exists, it is retained and the reference currently held by IOUserClient is returned to the caller.*/
IOMemoryMap * removeMappingForDescriptor(
    IOMemoryDescriptor *memory); 

/*exportObjectToClient


public

virtual IOReturn exportObjectToClient(
    task_t task, 
    OSObject *obj,
    io_object_t *clientObj); 
Parameters
task
The task.
obj
The object we want to export to the client.
clientObj
Returned value is the client's port name.
Discussion 

Makes an arbitrary OSObject available to the client task.*/
virtual IOReturn exportObjectToClient(
    task_t task, 
    OSObject *obj,
    io_object_t *clientObj); 

};
#endif //__cplusplus
//hys add

#ifdef  __APPLEONBOARDAUDIO__
class AudioPowerObject;//AppleOnboardAudio
#endif

#ifdef _IOKIT_IOHIDEVENTSERVICEUSERCLIENT_H
	#include <IOKit/hid/IOHIDEvent.h>
#endif
///////////////

#endif  //_IOKIT_IOUSERCLIENT_H

