
#ifndef _IOATACOMMAND_H
#define _IOATACOMMAND_H

#include <libkern/c++/OSObject.h>
#include <IOKit/IOTypes.h>
#include <IOKit/IOMemoryDescriptor.h>
#include <IOKit/IOCommand.h>
#include "IOATATypes.h"

class IOExtendedLBA;
class IOATACommand;
#include <HYS/IOKit/ata/IOATACommand.h>

/*IOATACompletionFunction


Callback function for ATA disk devices. 

typedef void (IOATACompletionFunction)(
    IOATACommand *command );  */
typedef void (IOATACompletionFunction)(
    IOATACommand *command );

class IOATACommand : public IOCommand ,public IOATACommand_HYS
{

	OSDeclareAbstractStructors( IOATACommand )
	
protected:
private:

public://data

/*refCon


For use by disk drivers, clients of IOATADevice only. IOATADevice and IOATAControllers shall not use this field in any manner. 

public

void* refCon; */
void* refCon;

public://func

/*setTransferChunkSize


Sets the size of transfer between intervening interrupts. 

public

virtual void setTransferChunkSize(
    IOByteCount chunk = kATADefaultSectorSize); 
Discussion 

This is necessary when doing PIO Read/Write Multiple, etc. so the controller knows when to expect an interrupt during multi-sector data transfers.*/
virtual void setTransferChunkSize(
    IOByteCount chunk = kATADefaultSectorSize); 

/*getResult


IOReturn value of the result of this command. 

public

virtual IOReturn getResult (
    void); 
Discussion 

ATA family errors are defined in IOATATypes.h*/
virtual IOReturn getResult (
    void); 

/*setCallbackPtr


Sets the function pointer to call when this command completes. 

public

virtual void setCallbackPtr (
    IOATACompletionFunction *inCompletion); */
virtual void setCallbackPtr (
    IOATACompletionFunction *inCompletion); 

/*setPacketCommand


Makes deep copy of data. 

public

virtual IOReturn setPacketCommand(
    UInt16 packetSizeBytes,
    UInt8 *command); 
Discussion 

ATAPI command packet max size is 16 bytes.*/

virtual IOReturn setPacketCommand(
    UInt16 packetSizeBytes,
    UInt8 *command); 

/*setRegMask


Used when accessing registers or reading registers on an error result. 

public

virtual void setRegMask(
    ataRegMask mask); 
Discussion 

Mask is defined in IOATATypes.h*/
virtual void setRegMask(
    ataRegMask mask); 

/*setOpcode


Sets command opcode as defined in IOATATypes. 

public

virtual void setOpcode(
    ataOpcode inCode); */
virtual void setOpcode(
    ataOpcode inCode);

/*setTimeoutMS


Sets how long to allow this command to complete, in milliseconds, once issued to the hardware. 

public

virtual void setTimeoutMS(
    UInt32 inMs); 
Discussion 

If the time period expires, this command will return with a timeout error.*/
virtual void setTimeoutMS(
    UInt32 inMs); 

/*setByteCount


Sets the byte count for this transaction. 

public

virtual void setByteCount (
    IOByteCount numBytes); 
Discussion 

Should agree with the device command and the memory descriptor in use.*/
virtual void setByteCount (
    IOByteCount numBytes); 

/*setPosition


Sets an offset into the memory descriptor for this transfer. 

public

virtual void setPosition (
    IOByteCount fromPosition); */
virtual void setPosition (
    IOByteCount fromPosition);

/*setUnit


Sets the unit number for this command. 

public

virtual void setUnit(
    ataUnitID inUnit); */
virtual void setUnit(
    ataUnitID inUnit); 

/*zeroCommand


Sets to blank state. 

public

virtual void zeroCommand(
    void); 
Discussion 

You MUST call this method prior to re-use of this object*/
virtual void zeroCommand(
    void); 

/*getActualTransfer


Returns the byte count on the ending result, as best as can be determined by the controller. 

public

virtual IOByteCount getActualTransfer (
    void ); 
Discussion 

May be zero, but partial transfer may have occurred on error in some cases.*/
virtual IOByteCount getActualTransfer (
    void ); 


/*setBuffer


Sets the IIOMemoryDescriptor for this transaction. 

public

virtual void setBuffer (
    IOMemoryDescriptor *inDesc); */

virtual void setBuffer (
    IOMemoryDescriptor *inDesc);

/*setFlags


Sets the flags for this command, as defined in IOATATypes. 

public

virtual void setFlags(
    UInt32 inFlags); */
virtual void setFlags(
    UInt32 inFlags); 

/*getDevice_Head


Performs taskfile access. 

public

virtual UInt8 getDevice_Head (
    void ); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual UInt8 getDevice_Head (
    void ); 

/*setDevice_Head


Performs taskfile access. 

public

virtual void setDevice_Head(
    UInt8 in); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual void setDevice_Head(
    UInt8 in); 

/*getCylHi


Performs taskfile access. 

public

virtual UInt8 getCylHi (
    void ); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual UInt8 getCylHi (
    void ); 

/*getCylLo


Performs taskfile access. 

public

virtual UInt8 getCylLo (
    void ); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual UInt8 getCylLo (
    void ); 

/*setSectorNumber


Performs taskfile access. 

public

virtual void setSectorNumber(
    UInt8 in); 
Discussion 

Registers are named in accordance with ATA Standards conventions*/
virtual void setSectorNumber(
    UInt8 in); 

/*setSectorCount


Performs taskfile access. 

public

virtual void setSectorCount(
    UInt8 in); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual void setSectorCount(
    UInt8 in); 

/*setFeatures


Performs taskfile access. 

public

virtual void setFeatures(
    UInt8 in); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual void setFeatures(
    UInt8 in); 

/*getErrorReg


Performs taskfile access. 

public

virtual UInt8 getErrorReg (
    void ); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/

virtual UInt8 getErrorReg (
    void ); 

/*setCylLo


Performs taskfile access. 

public

virtual void setCylLo (
    UInt8 in); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual void setCylLo (
    UInt8 in); 

/*getSectorNumber


Performs taskfile access. 

public

virtual UInt8 getSectorNumber (
    void ); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual UInt8 getSectorNumber (
    void ); 

/*getSectorCount


Performs taskfile access. 

public

virtual UInt8 getSectorCount (
    void ); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual UInt8 getSectorCount (
    void ); 



/*getStatus


Performs taskfile access. 

public

virtual UInt8 getStatus (
    void ); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/

virtual UInt8 getStatus (
    void ); 

/*setCylHi


Performs taskfile access. 

public

virtual void setCylHi(
    UInt8 in); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual void setCylHi(
    UInt8 in); 

/*setCommand


Performs taskfile access. 

public

virtual void setCommand (
    UInt8 in); 
Discussion 

Registers are named in accordance with ATA Standards conventions.*/
virtual void setCommand (
    UInt8 in); 

};


class IOExtendedLBA : public OSObject,public IOExtendedLBA_HYS
{
	OSDeclareDefaultStructors( IOExtendedLBA )
	
public:
protected:
private:
};




#endif






