
#ifndef __OPEN_SOURCE__
#endif


#ifndef _IOATADEVCONFIG_H
#define _IOATADEVCONFIG_H

#include <libkern/c++/OSObject.h>
#include <IOKit/IOTypes.h>
#include "IOATATypes.h"
#include "IOATABusInfo.h"

class IOATADevConfig : public OSObject {
OSDeclareDefaultStructors( IOATADevConfig )
	
public:

/*initWithBestSelection


Handy initializer. 

public

IOReturn initWithBestSelection(
    const UInt16 *identifyData,
    IOATABusInfo *busInfo); 
Parameters
identifyData
512 Bytes of data obtained from the device via IDENTIFY DEVICE or IDENTIFY PACKET DEVICE command.
busInfo
Pointer to an IOATAbusInfo object obtained from a previous atanub->provideBusInfo() call.
Return Value

Returns kIOSuccess (0) when a matching transfer mode is available between the device and controller. 
Discussion 

Pass the 512-byte result of the Identify Device or Identify Packet Device in endian-order for your platform (byte-swapped on PPC) and the IOATABusInfo object for the bus. The object will initialize all fields and select the best transfer modes that match on bus and device. If the return value was 0 (success or noErr), then a matching mode is supported. Examine the PIO and UDMA/DMA fields and to generate the apropriate SET FEATURES parameters for your drive and send this initialized object to the IOATAController when requesting a speed configuration. Failure of this method means no supported transfer modes matched between bus and device info.*/
IOReturn initWithBestSelection(
    const UInt16 *identifyData,
    IOATABusInfo *busInfo); 

/*atadevconfig


Static creator function. 

public

static IOATADevConfig* atadevconfig(
    void); */
static IOATADevConfig* atadevconfig(
    void); 

/*getPacketConfig


public

atapiConfig getPacketConfig(
    void ); 
Return Value

Returns atapiConfig as defined in IOATATypes.h*/

atapiConfig getPacketConfig(
    void ); 

/*getUltraMode


public

UInt8 getUltraMode(
    void ); 
Return Value

Returns bit-significant map of Ultra mode.*/
UInt8 getUltraMode(
    void ); 

/*getDMACycleTime


public

UInt16 getDMACycleTime(
    void ); 
Return Value

Returns reported multiword DMA cycle time in nanoseconds.*/
UInt16 getDMACycleTime(
    void ); 

/*getDMAMode


public

UInt8 getDMAMode(
    void ); 
Return Value

Returns bit-significant map of DMA mode.*/
UInt8 getDMAMode(
    void ); 

/*getPIOCycleTime


public

UInt16 getPIOCycleTime(
    void ); 
Return Value

Returns reported PIO CycleTime in nanoseconds.*/
UInt16 getPIOCycleTime(
    void ); 

/*bitSigToNumeric


Converts a bit-significant field to a numerical value. 

public

virtual UInt8 bitSigToNumeric(
    UInt16 binary); 
Parameters
binary
the bit significant field.
Return Value

Returns the numerical value of the highest bit set in the field. 
Discussion 

Note that a bit field of 0x00 has no defined result.*/
virtual UInt8 bitSigToNumeric(
    UInt16 binary); 

/*getPIOMode


public

UInt8 getPIOMode(
    void ); 
Return Value

Returns bit-significant map of PIO mode.*/

UInt8 getPIOMode(
    void ); 

/*setPacketConfig


Tells the bus controller whether to wait for packet acceptance or set pending interrupt. 

public

void setPacketConfig (
    atapiConfig packetConfig); 
Parameters
packetConfig
Discussion 

For ATAPI devices, if the device asserts interrupt after the Packet Command when it is ready to accept the packet, set this value to true (mostly older devices). If the device accepts the packet only by asserting DRQ bit in status, then set this value false.*/

void setPacketConfig (
    atapiConfig packetConfig); 

/*setDMACycleTime


public

void setDMACycleTime(
    UInt16 inNS ); 
Parameters
inNS
Reported multiword DMA Cycle time in nanoseconds.*/
void setDMACycleTime(
    UInt16 inNS ); 

/*setPIOCycleTime


public

void setPIOCycleTime(
    UInt16 inNS ); 
Parameters
inNS
PIO cycle time in nanoseconds.*/

void setPIOCycleTime(
    UInt16 inNS ); 

/*setUltraMode


public

void setUltraMode(
    UInt8 inModeBitMap ); 
Parameters
inModeBitMap
Bit-significant map of Ultra mode.*/

void setUltraMode(
    UInt8 inModeBitMap ); 

/*setDMAMode


public

void setDMAMode(
    UInt8 inModeBitMap ); 
Parameters
inModeBitMap
Bit-significant map of DMA mode.*/
void setDMAMode(
    UInt8 inModeBitMap ); 

/*setPIOMode


public

void setPIOMode(
    UInt8 inModeBitMap); 
Parameters
inModeBitMap
Bit-significant map of PIO mode.*/
void setPIOMode(
    UInt8 inModeBitMap); 

protected:
private:
public:
};


#endif /* !_IOATADEVCONFIG_H */
