

#ifndef __OPEN_SOURCE__
#endif

#ifndef _IOATADEVICE_H
#define _IOATADEVICE_H

#include <IOKit/IOService.h>
#include <IOKit/IOTypes.h>
#include "IOATATypes.h"
#include "IOATACommand.h"
#include "IOATABusInfo.h"
#include "IOATADevConfig.h"

class IOATAController;

class IOATADevice : public IOService
{
    OSDeclareDefaultStructors(IOATADevice)

public:

/*provideBusInfo


Finds out the bus capability. 

public

virtual IOReturn provideBusInfo(
    IOATABusInfo *getInfo); 
Parameters
getInfo
A pointer to a valid IOATABusInfo object.
Return Value

Returns kIOSuccess (0) and the getInfo object will be filled out by the bus controller with information about the bus. 
Discussion 

This method finds out the bus capability so the client can choose the features to set and commands to run.*/
virtual IOReturn provideBusInfo(
    IOATABusInfo *getInfo); 

/*allocCommand


Creates IOATACommands. 

public

virtual IOATACommand* allocCommand(
    void ); 
Return Value

Returns null if allocation failed. Retain count is one. 
Discussion 

Device drivers should allocate command objects only through this method.*/

virtual IOATACommand* allocCommand(
    void ); 

/*provideConfig


Finds out what speed the bus has configured for this unit. 

public

virtual IOReturn provideConfig(
    IOATADevConfig *configRequest); 
Parameters
configRequest
Pointer to a valid IOATADevConfig object.
Return Value

Returns kIOSuccess (0) on successful completion and configRequest will contain the configuration information.*/
virtual IOReturn provideConfig(
    IOATADevConfig *configRequest); 

/*selectConfig


Tells the bus what speed to use for your device. 

public

virtual IOReturn selectConfig(
    IOATADevConfig *configRequest); 
Parameters
configRequest
Pointer to a valid and initialized IOATADevConfig object.
Return Value

Returns kIOSuccess (0) if the configuration was succesfully selected. 
Discussion 

This should only be called once during a disk drivers start method before registering its availability, and must be called prior to issuing any data IO transactions.*/
virtual IOReturn selectConfig(
    IOATADevConfig *configRequest); 

/*freeCommand


Releases a command object that is no longer needed. 

public

virtual void freeCommand(
    IOATACommand *inCommand); 
Parameters
inCommand
The command to be released.
Discussion 

Do not free an object in use and do not release the object anymore times than you have retained it.*/

virtual void freeCommand(
    IOATACommand *inCommand); 

/*getUnitID


Determines whether this device is number 0 or 1 (ie, master/slave). 

public

virtual ataUnitID getUnitID(
    void ); 
Return Value

Returns ataUnitID - 0 or 1.*/
virtual ataUnitID getUnitID(
    void ); 

/*getDeviceType


Finds out what kind of device this nub is (ATA or ATAPI). 

public

virtual ataDeviceType getDeviceType(
    void ); 
Return Value

Returns ataDeviceType as defined in IOATATypes.h*/

virtual ataDeviceType getDeviceType(
    void ); 

/*executeCommand

Submits IO requests 

public

virtual IOReturn executeCommand(
    IOATACommand *command); 
Parameters
command
Pointer to a valid IOATACommand with the command to be executed.
Return Value

Returns kIOSuccess (0) if the command was successfully queued in the controller.*/

virtual IOReturn executeCommand(
    IOATACommand *command); 

protected:
private:
};

#endif /* !_IOATABUSNUB_H */
