#ifndef _IOKIT_IOAUDIOSTREAM_H
#define _IOKIT_IOAUDIOSTREAM_H

#include <IOKit/IOService.h>
#include <IOKit/audio/IOAudioEngine.h>
#include <IOKit/audio/IOAudioTypes.h>

class OSSymbol;
class OSArray;
class OSDictionary;
class OSSet;

class IOCommandGate;
class IOAudioControl;

//typedef struct IOAudioClientBuffer;
struct IOAudioClientBuffer;
//typedef struct IOAudioStreamFormatDesc;
struct IOAudioStreamFormatDesc;

#include <HYS/IOKit/audio/IOAudioStream.h>

class IOAudioStream : public IOService,public IOAudioStream_HYS
{
    OSDeclareDefaultStructors(IOAudioStream)
    
    friend class IOAudioEngine;
    friend class IOAudioEngineUserClient;

public: //type

/*AudioIOFunction


public

typedef IOReturn ( *AudioIOFunction)(
    const void *mixBuf,
    void *sampleBuf,
    UInt32 firstSampleFrame,
    UInt32 numSampleFrames,
    const IOAudioStreamFormat *streamFormat,
    IOAudioStream *audioStream); 
Discussion 

The audio IO function pointer is the standard function prototype for various Audio I/O-related callbacks into device drivers from the Core Audio HAL.*/
typedef IOReturn ( *AudioIOFunction)(
    const void *mixBuf,
    void *sampleBuf,
    UInt32 firstSampleFrame,
    UInt32 numSampleFrames,
    const IOAudioStreamFormat *streamFormat,
    IOAudioStream *audioStream);

public://data

/*workLoop


public

IOWorkLoop *workLoop; 
Discussion 

The workloop associated with this stream.*/
IOWorkLoop *workLoop; 

/*gIsMixableKey


public

static const OSSymbol *gIsMixableKey; 
Discussion 

Indicates whether the current format of the audio buffer is mixable. Examples of non-mixable formats include encoded formats such as AC-3.*/
static const OSSymbol *gIsMixableKey; 

/*clientBufferListStart


public

IOAudioClientBuffer *clientBufferListStart; 
Discussion 

The head of a list of audio client buffers.*/

IOAudioClientBuffer *clientBufferListStart; 

/*gBitWidthKey


public

static const OSSymbol *gBitWidthKey; 
Discussion 

Bit width of samples (including padding).*/
static const OSSymbol *gBitWidthKey; 

/*streamIOLock


public

IORecursiveLock *streamIOLock; 
Discussion 

A stream-specific lock.*/
IORecursiveLock *streamIOLock; 

/*direction


public

IOAudioStreamDirection direction; 
Discussion 

The direction of the audio stream.*/
IOAudioStreamDirection direction; 

/*commandGate


public

IOCommandGate *commandGate; 
Discussion 

The command gate associated with this stream.*/
IOCommandGate *commandGate; 

/*startingPosition


public

IOAudioEnginePosition startingPosition; 
Discussion 

The starting position in the sample buffer.*/
IOAudioEnginePosition startingPosition; 

/*mixBufferSize


public

UInt32 mixBufferSize; 
Discussion 

The size of the mix buffer (in bytes)*/
UInt32 mixBufferSize; 

/*audioIOFunctions


public

AudioIOFunction *audioIOFunctions; 
Discussion 

An array of audio IO function callbacks.*/
AudioIOFunction *audioIOFunctions; 

/*availableFormatDictionaries


public

OSArray *availableFormatDictionaries; 
Discussion 

An OSArray of available format dictionaries.*/
OSArray *availableFormatDictionaries; 

/*numAvailableFormats


public

UInt32 numAvailableFormats; 
Discussion 

The number of available formats.*/
UInt32 numAvailableFormats; 

/*sampleBuffer


public

void *sampleBuffer; 
Discussion 

A pointer to the raw sample buffer*/
void *sampleBuffer; 

/*numIOFunctions


public

UInt32 numIOFunctions; 
Discussion 

The number of functions in the audioIOFunctions array.*/
UInt32 numIOFunctions; 

/*clippedPosition


public

IOAudioEnginePosition clippedPosition; 
Discussion 

The position in the sample buffer which has been clipped and is thus available for playback.*/
IOAudioEnginePosition clippedPosition; 

/*clientBufferListEnd


public

IOAudioClientBuffer *clientBufferListEnd; 
Discussion 

The tail of a list of audio client buffers.*/
IOAudioClientBuffer *clientBufferListEnd; 

/*gNumericRepresentationKey


public

static const OSSymbol *gNumericRepresentationKey; 
Discussion 

The numberic representation. Possible values are described in IOAudioStreamNumericRepresentations.*/
static const OSSymbol *gNumericRepresentationKey; 

/*startingChannelID


public

UInt32 startingChannelID; 
Discussion 

The starting channel ID.*/
UInt32 startingChannelID; 

/*streamAllocatedMixBuffer


public

bool streamAllocatedMixBuffer; 
Discussion 

Set to true if the audio stream contains a mix buffer that needs to be freed.*/
bool streamAllocatedMixBuffer; 

/*mixBuffer


public

void *mixBuffer; 
Discussion 

A pointer to the mix buffer*/

void *mixBuffer; 

/*gDriverTagKey


public

static const OSSymbol *gDriverTagKey; 
Discussion 

Driver tag key.*/
static const OSSymbol *gDriverTagKey; 

/*gByteOrderKey


public

static const OSSymbol *gByteOrderKey; 
Discussion 

Byte order of samples within an audio stream. Possible values are described in IOAudioStreamByteOrder.*/
static const OSSymbol *gByteOrderKey; 

/*gDirectionKey


public

static const OSSymbol *gDirectionKey; 
Discussion 

Audio stream direction (possible values are "Output" and "Input").*/
static const OSSymbol *gDirectionKey; 

/*availableFormats


public

IOAudioStreamFormatDesc *availableFormats; 
Discussion 

A list of available stream formats.*/
IOAudioStreamFormatDesc *availableFormats; 

/*gSampleFormatKey


public

static const OSSymbol *gSampleFormatKey; 
Discussion 

The current sample format for this stream.*/
static const OSSymbol *gSampleFormatKey; 

/*gMinimumSampleRateKey


public

static const OSSymbol *gMinimumSampleRateKey; 
Discussion 

Minimum sample rate.*/

static const OSSymbol *gMinimumSampleRateKey; 

/*gBitDepthKey


public

static const OSSymbol *gBitDepthKey; 
Discussion 

Bit depth of samples.*/
static const OSSymbol *gBitDepthKey; 

/*gMaximumSampleRateKey


public

static const OSSymbol *gMaximumSampleRateKey; 
Discussion 

Maximum sample rate.*/
static const OSSymbol *gMaximumSampleRateKey; 

/*maxNumChannels


public

UInt32 maxNumChannels; 
Discussion 

The maximum number of channels of any format provided by this stream.*/

UInt32 maxNumChannels; 

/*userClientList


public

IOAudioClientBuffer *userClientList; 
Discussion 

A list of user clients.*/
IOAudioClientBuffer *userClientList; 

/*numClients


public

UInt32 numClients; 
Discussion 

The current number of clients utilizing this stream.*/
UInt32 numClients; 

/*defaultAudioControls


public

OSSet *defaultAudioControls; 
Discussion 

A set of audion controls.*/
OSSet *defaultAudioControls; 

/*audioEngine


public

IOAudioEngine *audioEngine; 
Discussion 

The audio engine associated with this stream.*/
IOAudioEngine *audioEngine; 

/*streamAvailable


public

bool streamAvailable; 
Discussion 

True if this stream is available.*/
bool streamAvailable; 

/*format


public

IOAudioStreamFormat format; 
Discussion 

An IOAudioStreamFormat object containing the stream's current format.*/
IOAudioStreamFormat format; 


/*gAlignmentKey


public

static const OSSymbol *gAlignmentKey; 
Discussion 

Alignment value for streams that contain padding. Possible values are described in IOAudioStreamAlignments.*/
static const OSSymbol *gAlignmentKey; 

/*gNumChannelsKey


public

static const OSSymbol *gNumChannelsKey; 
Discussion 

The number of channels in this stream.*/
static const OSSymbol *gNumChannelsKey; 

/*sampleBufferSize


public

UInt32 sampleBufferSize; 
Discussion 

The size of the sample buffer (in bytes)*/
UInt32 sampleBufferSize; 

public://function
IOAudioStream_validateFormat
IOAudioStream_setDirection

/*setIOFunction


public

virtual void setIOFunction(
    AudioIOFunction ioFunction); 
Discussion 

Assigns an I/O function to the stream.*/
virtual void setIOFunction(
    AudioIOFunction ioFunction); 

/*clearSampleBuffer


public

virtual void clearSampleBuffer(); 
Discussion 

This function zeroes the sample buffer. You should call this prior to starting the audio engine.*/
virtual void clearSampleBuffer(); 

/*numSampleFramesPerBufferChanged


public

virtual void numSampleFramesPerBufferChanged(); 
Discussion 

This function should be called if you change the number of sample frames in the buffer.*/
virtual void numSampleFramesPerBufferChanged(); 

/*getMixBufferSize


public

virtual UInt32 getMixBufferSize(); 
Discussion 

Returns the size of the current mix buffer.*/
virtual UInt32 getMixBufferSize(); 

/*getStartingChannelID


public

virtual UInt32 getStartingChannelID(); 
Discussion 

Returns the first channel ID for this stream. Each successive channel has an ID that is one higher than the last, up to getStartingChannelID() + getMaxNumChannels() - 1.*/
virtual UInt32 getStartingChannelID(); 

/*getMaxNumChannels


public

virtual UInt32 getMaxNumChannels(); 
Discussion 

Returns the maximum number of channels for any format that this stream supports. The next audio stream created should start at getStartingChannelID() + getMaxNumChannels().*/
virtual UInt32 getMaxNumChannels(); 

/*getMixBuffer


public

virtual void *getMixBuffer(); 
Discussion 

Returns the current mix buffer.*/
virtual void *getMixBuffer(); 

/*stop


public

virtual void stop(
    IOService *provider); 
Discussion 

Stops an audio stream.*/
virtual void stop(
    IOService *provider); 

/*setSampleLatency


public

virtual void setSampleLatency(
    UInt32 numSamples); 
Discussion 

Calls the Audio Engine's setSampleLatency function. This may be overridden on a stream-by-stream basis by subclassing IOAudioStream.*/
virtual void setSampleLatency(
    UInt32 numSamples); 

/*mixOutputSamples


public

virtual IOReturn mixOutputSamples(
    const void *sourceBuf,
    void *mixBuf,
    UInt32 firstSampleFrame,
    UInt32 numSampleFrames,
    const IOAudioStreamFormat *streamFormat,
    IOAudioStream *audioStream); 
Discussion 

Calls the Audio Engine's mixOutputSamples function. This may be overridden on a stream-by-stream basis by subclassing IOAudioStream.*/
virtual IOReturn mixOutputSamples(
    const void *sourceBuf,
    void *mixBuf,
    UInt32 firstSampleFrame,
    UInt32 numSampleFrames,
    const IOAudioStreamFormat *streamFormat,
    IOAudioStream *audioStream); 

/*getFormatExtension


public

virtual const IOAudioStreamFormatExtension *getFormatExtension(); 
Discussion 

Gets the current format extension.*/
virtual const IOAudioStreamFormatExtension *getFormatExtension(); 

/*setStreamAvailable


public

virtual void setStreamAvailable(
    bool available); 
Discussion 

Marks a stream as available or unavailable for use.*/
virtual void setStreamAvailable(
    bool available); 

/*setProperties


public

virtual IOReturn setProperties(
    OSObject *properties); 
Discussion 

Sets properties on a stream.*/
virtual IOReturn setProperties(
    OSObject *properties); 

/*createDictionaryFromFormat


public

static OSDictionary *createDictionaryFromFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    OSDictionary *formatDict = 0); 
Discussion 

Creates an OSDictionary object from audio format values.*/
static OSDictionary *createDictionaryFromFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    OSDictionary *formatDict = 0); 

/*initKeys


public

static void initKeys(); 
Discussion 

Initializes keys to default values.*/
static void initKeys(); 

/*addDefaultAudioControl


public

virtual IOReturn addDefaultAudioControl(
    IOAudioControl *defaultAudioControl); 
Discussion 

Adds a default audio control.*/

virtual IOReturn addDefaultAudioControl(
    IOAudioControl *defaultAudioControl); 

/*setFormatAction


public

static IOReturn setFormatAction(
    OSObject *owner,
    void *arg1,
    void *arg2,
    void *arg3,
    void *arg4); 
Discussion 

Assigns a format action callback. This function will be called when a format change occurs.*/
static IOReturn setFormatAction(
    OSObject *owner,
    void *arg1,
    void *arg2,
    void *arg3,
    void *arg4); 

/*getWorkLoop


public

virtual IOWorkLoop *getWorkLoop() const; 
Discussion 

Returns the workloop associated with the stream.*/
virtual IOWorkLoop *getWorkLoop() const; 

/*free


public

virtual void free(); 
Discussion 

Frees a stream object and its instance variables.*/
virtual void free(); 

/*setMixBuffer


public

virtual void setMixBuffer(
    void *buffer,
    UInt32 size); 
Discussion 

Assigns a mix buffer of a given size to the stream.*/
virtual void setMixBuffer(
    void *buffer,
    UInt32 size); 

/*setIOFunctionList


public

virtual void setIOFunctionList(
    const AudioIOFunction *ioFunctionList,
    UInt32 numFunctions); 
Discussion 

Assigns a list of I/O functions to the stream.*/
virtual void setIOFunctionList(
    const AudioIOFunction *ioFunctionList,
    UInt32 numFunctions); 

/*getStreamAvailable


public

virtual bool getStreamAvailable(); 
Discussion 

Returns the stream's availability as set by setStreamAvailable.*/
virtual bool getStreamAvailable(); 

/*createFormatFromDictionary


public

static IOAudioStreamFormat *createFormatFromDictionary(
    const OSDictionary *formatDict,
    IOAudioStreamFormat *streamFormat = 0,
    IOAudioStreamFormatExtension *formatExtension = 0); 
Discussion 

Creates an audio format value from an OSDictionary object.*/
static IOAudioStreamFormat *createFormatFromDictionary(
    const OSDictionary *formatDict,
    IOAudioStreamFormat *streamFormat = 0,
    IOAudioStreamFormatExtension *formatExtension = 0); 



/*removeDefaultAudioControls


public

virtual void removeDefaultAudioControls(); 
Discussion 

Removes all default audio controls.*/
virtual void removeDefaultAudioControls(); 

/*validateFormat(IOAudioStreamFormat *, IOAudioStreamFormatDesc *)


public

virtual bool validateFormat(
    IOAudioStreamFormat *streamFormat,
    IOAudioStreamFormatDesc *formatDesc); 
Discussion 

Validates an audio format. */
virtual bool validateFormat(
    IOAudioStreamFormat *streamFormat,
    IOAudioStreamFormatDesc *formatDesc); 

/*validateFormat(IOAudioStreamFormat *, IOAudioStreamFormatExtension *, IOAudioStreamFormatDesc *)


public

virtual bool validateFormat(
    IOAudioStreamFormat *streamFormat,
    IOAudioStreamFormatExtension *formatExtension,
    IOAudioStreamFormatDesc *formatDesc); 
Discussion 

Validates an audio format format (with format extension).*/
virtual bool validateFormat(
    IOAudioStreamFormat *streamFormat,
    IOAudioStreamFormatExtension *formatExtension,
    IOAudioStreamFormatDesc *formatDesc); 

/*getNumSampleFramesRead


public

virtual UInt32 getNumSampleFramesRead(); 
Discussion 

Returns the number of sample frames read.*/
virtual UInt32 getNumSampleFramesRead(); 

/*setDefaultNumSampleFramesRead


public

virtual void setDefaultNumSampleFramesRead(
    UInt32); 
Discussion 

Sets the default number of sample frames read.*/

virtual void setDefaultNumSampleFramesRead(
    UInt32); 


/*getSampleBuffer


public

virtual void *getSampleBuffer(); 
Discussion 

Returns the current sample buffer. */
virtual void *getSampleBuffer(); 

/*getSampleBufferSize


public

virtual UInt32 getSampleBufferSize(); 
Discussion 

Returns the size of the current sample buffer.*/

virtual UInt32 getSampleBufferSize(); 

/*getDirection


public

virtual IOAudioStreamDirection getDirection(); 
Discussion 

Gets the direction of a stream.*/
virtual IOAudioStreamDirection getDirection(); 

/*getFormat


public

virtual const IOAudioStreamFormat *getFormat(); 
Discussion 

Returns the current audio stream format.*/
virtual const IOAudioStreamFormat *getFormat(); 

/*hardwareFormatChanged


public

virtual IOReturn hardwareFormatChanged(
    const IOAudioStreamFormat *streamFormat); 
Discussion 

Notifies the Audio HAL that the hardware has requested an audio format change (such as when an external clock source changes rates).*/
virtual IOReturn hardwareFormatChanged(
    const IOAudioStreamFormat *streamFormat); 

/*addAvailableFormat(const IOAudioStreamFormat *, const IOAudioStreamFormatExtension *, const IOAudioSampleRate *, const IOAudioSampleRate *, const AudioIOFunction *, UInt32)


public

virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    const AudioIOFunction *ioFunctionList = NULL,
    UInt32 numFunctions = 0); 
Discussion 

Adds multiple available formats to the list of supported formats in a single call.*/

virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    const AudioIOFunction *ioFunctionList = NULL,
    UInt32 numFunctions = 0); 

/*clearAvailableFormats


public

virtual void clearAvailableFormats(); 
Discussion 

Clears the list of available formats.*/
virtual void clearAvailableFormats(); 

/*setFormat


public

virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    OSDictionary *formatDict,
    bool callDriver = true); 
Discussion 

Sets the current stream format and stream format dictionary. */

virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    OSDictionary *formatDict,
    bool callDriver = true); 

/*setFormat(const IOAudioStreamFormat *, bool)


public

virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    bool callDriver = true); 
Discussion 

Sets the current stream format. */
virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    bool callDriver = true); 

/*setFormat(const IOAudioStreamFormat *, const IOAudioStreamFormatExtension *, bool)


public

virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    bool callDriver = true); 
Discussion 

Sets the current audio format. */

virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    bool callDriver = true); 

/*setFormat(const IOAudioStreamFormat *, const IOAudioStreamFormatExtension *, OSDictionary *, bool)


public

virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    OSDictionary *formatDaict,
    bool callDriver = true); 
Discussion 

Sets the current audio format using a format dictionary. */
virtual IOReturn setFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    OSDictionary *formatDict,
    bool callDriver = true); 

/*setFormat(OSDictionary *)


public

virtual IOReturn setFormat(
    OSDictionary *formatDict); 
Discussion 

Sets the current stream format dictionary.*/
virtual IOReturn setFormat(
    OSDictionary *formatDict);

/*addAvailableFormat(const IOAudioStreamFormat *, const IOAudioSampleRate *, const IOAudioSampleRate *, AudioIOFunction)


public

virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    AudioIOFunction ioFunction); 
Discussion 

Adds a single available sample format to an audio stream. */
virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    AudioIOFunction ioFunction); 

/*addAvailableFormat(const IOAudioStreamFormat *, const IOAudioSampleRate *, const IOAudioSampleRate *, const AudioIOFunction *, UInt32)


public

virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    const AudioIOFunction *ioFunctionList = NULL,
    UInt32 numFunctions = 0); 
Discussion 

Adds a list of available sample formats to an audio stream. */
virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    const AudioIOFunction *ioFunctionList = NULL,
    UInt32 numFunctions = 0);

/*addAvailableFormat(const IOAudioStreamFormat *, const IOAudioStreamFormatExtension *, const IOAudioSampleRate *, const IOAudioSampleRate *, AudioIOFunction)


public

virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    AudioIOFunction ioFunction); 
Discussion 

Adds a single available format to the list of supported formats. 

addAvailableFormat(const IOAudioStreamFormat *, const IOAudioStreamFormatExtension *, const IOAudioSampleRate *, const IOAudioSampleRate *, const AudioIOFunction *, UInt32)


public

virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    const AudioIOFunction *ioFunctionList = NULL,
    UInt32 numFunctions = 0); 
Discussion 

Adds multiple available formats to the list of supported formats in a single call.*/
virtual void addAvailableFormat(
    const IOAudioStreamFormat *streamFormat,
    const IOAudioStreamFormatExtension *formatExtension,
    const IOAudioSampleRate *minRate,
    const IOAudioSampleRate *maxRate,
    AudioIOFunction ioFunction); 

/*setSampleBuffer


public

virtual void setSampleBuffer(
    void *buffer,
    UInt32 size); 
Discussion 

Assigns a sample buffer of a given size to the stream.*/

virtual void setSampleBuffer(
    void *buffer,
    UInt32 size); 

/*initWithAudioEngine


public

virtual bool initWithAudioEngine(
    IOAudioEngine *engine,
    IOAudioStreamDirection dir,
    UInt32 startChannelID,
    const char *streamDescription = NULL,
    OSDictionary *properties = 0); 
Discussion 

Initializes a stream object.*/
virtual bool initWithAudioEngine(
    IOAudioEngine *engine,
    IOAudioStreamDirection dir,
    UInt32 startChannelID,
    const char *streamDescription = NULL,
    OSDictionary *properties = 0); 

/*setTerminalType


public

virtual void setTerminalType(
    const UInt32 terminalType); 
Discussion 

Sets the terminal type of the current stream.*/

virtual void setTerminalType(
    const UInt32 terminalType); 

protected:

/*clipOutputSamples


protected

virtual void clipOutputSamples(
    UInt32 startingSampleFrame,
    UInt32 numSampleFrames); 
Discussion 

Generally, this function calls the audio engine's clipOutputSamples function. This can, however, be overridden on a per-stream basis.*/

virtual void clipOutputSamples(
    UInt32 startingSampleFrame,
    UInt32 numSampleFrames); 

/*readInputSamples


protected

virtual IOReturn readInputSamples(
    IOAudioClientBuffer *clientBuffer,
    UInt32 firstSampleFrame); 
Discussion 

Calls I/O functions to read input samples from hardware.*/
virtual IOReturn readInputSamples(
    IOAudioClientBuffer *clientBuffer,
    UInt32 firstSampleFrame); 

/*processOutputSamples


protected

virtual IOReturn processOutputSamples(
    IOAudioClientBuffer *clientBuffer,
    UInt32 firstSampleFrame,
    UInt32 loopCount,
    bool samplesAvailable); 
Discussion 

Calls functions to mix source material into the mix buffer and, if necessary, clip the results.*/
virtual IOReturn processOutputSamples(
    IOAudioClientBuffer *clientBuffer,
    UInt32 firstSampleFrame,
    UInt32 loopCount,
    bool samplesAvailable); 

/*getNumClients


protected

virtual UInt32 getNumClients(); 
Discussion 

Returns the current number of clients of this stream..*/
virtual UInt32 getNumClients(); 

/*addClient


protected

virtual IOReturn addClient(
    IOAudioClientBuffer *clientBuffer); 
Discussion 

Adds a new client to this stream..*/

virtual IOReturn addClient(
    IOAudioClientBuffer *clientBuffer); 

/*unlockStreamForIO


protected

virtual void unlockStreamForIO(); 
Discussion 

Unlocks the stream for I/O.*/
virtual void unlockStreamForIO(); 

/*clipIfNecessary


protected

virtual void clipIfNecessary(); 
Discussion 

Calls clipOutputSamples if there are frames in the mix buffer that have not been clipped.*/
virtual void clipIfNecessary(); 

/*lockStreamForIO


protected

virtual void lockStreamForIO(); 
Discussion 

Locks the stream for I/O.*/
virtual void lockStreamForIO(); 

/*removeClient


protected

virtual void removeClient(
    IOAudioClientBuffer *clientBuffer); 
Discussion 

Removes a client of this stream.*/
virtual void removeClient(
    IOAudioClientBuffer *clientBuffer); 

/*setStartingChannelNumber


protected

virtual void setStartingChannelNumber(
    UInt32 channelNumber); 
Discussion 

Sets the starting channel number for this stream.*/
virtual void setStartingChannelNumber(
    UInt32 channelNumber); 

/*updateNumClients


protected

virtual void updateNumClients(); 
Discussion 

Iterates the stream's client list and updates the current count of clients.*/
virtual void updateNumClients(); 

/*resetClipInfo


protected

virtual void resetClipInfo(); 
Discussion 

Resets clip position information to zero.*/
virtual void resetClipInfo(); 

};

#endif /* _IOKIT_IOAUDIOSTREAM_H */
