#ifndef _IOKIT_IOFIREWIREAVCLIB_H_
#define _IOKIT_IOFIREWIREAVCLIB_H_

#include <IOKit/IOCFPlugIn.h>
#include <IOKit/firewire/IOFireWireFamilyCommon.h>
#include <IOKit/avc/IOFireWireAVCConsts.h>

#include  <HYS/IOKit/avc/IOFireWireAVCLib.h>

/*IOFireWireAVCLibAsynchronousCommandCallback


Callback called when there is a response to an asynchronous AV/C command, a bus reset, or for other reasons. 

typedef void ( *IOFireWireAVCLibAsynchronousCommandCallback)(
    void *pRefCon,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  
Parameters
pRefCon
Pointer to arbitrary data supplied when the IOFireWireAVCLibAsynchronousCommand object was created.
pCommandObject
Pointer to an IOFireWireAVCLibAsynchronousCommand object passed back in createAVCAsynchronousCommand.*/
typedef void ( *IOFireWireAVCLibAsynchronousCommandCallback)(
    void *pRefCon,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  

/*IOFireWireAVCFrameStatusHandler


Callback called when the consumer/controller has data available for the client. 

typedef void ( *IOFireWireAVCFrameStatusHandler)(
    void *refcon,
    UInt32 mode,
    UInt32 count );  
Parameters
refCon
The refcon supplied when a connection is made.
mode
The current mode (such as SEND, MORE, LAST, etc.).
count
The segment size.*/
typedef void ( *IOFireWireAVCFrameStatusHandler)(
    void *refcon,
    UInt32 mode,
    UInt32 count );  

/*IOFireWireAVCPortStateHandler


Callback called when the connection to a producer changes. 

typedef void ( *IOFireWireAVCPortStateHandler)(
    void *refcon,
    UInt32 state );  
Parameters
refCon
The refcon supplied when a connection is made.
state
The state of the connection (can be Bus Suspended, Bus Resumed, Plug Reconnected, Plug Disconnected, Device Removed).*/
typedef void ( *IOFireWireAVCPortStateHandler)(
    void *refcon,
    UInt32 state ); 

/*IOFWAVCCommandHandlerCallback


Callback called when an incoming AV/C command matching a registered command handler is received. 

typedef IOReturn ( *IOFWAVCCommandHandlerCallback)(
    void *refCon,
    UInt32 generation,
    UInt16 srcNodeID,
    IOFWSpeed speed,
    const UInt8 *command,
    UInt32 cmdLen);  
Parameters
refCon
The refcon supplied when a client is registered.
generation
The FireWire bus generation value at the time the command was received.
srcNodeID
The node ID of the device who sent us this command.
speed
The speed of the AV/C command packet.
command
A pointer to the command bytes.
cmdLen
The length of the AV/C command bytes buffer in bytes.
Return Value

The callback handler should return success if it will send the AV/C response, or an error if it doesn't want to handle the command.*/
typedef IOReturn ( *IOFWAVCCommandHandlerCallback)(
    void *refCon,
    UInt32 generation,
    UInt16 srcNodeID,
    IOFWSpeed speed,
    const UInt8 *command,
    UInt32 cmdLen);  

/*IOFWAVCSubunitPlugHandlerCallback


Callback called when an incoming AV/C command matching a registered command handler is received. 

typedef IOReturn ( *IOFWAVCSubunitPlugHandlerCallback)(
    void *refCon, 
    UInt32 subunitTypeAndID, 
    IOFWAVCPlugTypes plugType, 
    UInt32 plugNum, 
    IOFWAVCSubunitPlugMessages plugMessage, 
    UInt32 messageParams);  
Parameters
refCon
The refcon supplied when a client is registered.
subunitTypeAndID
The subunit type and ID of this plug.
plugType
The type of plug receiving the message.
plugNum
The number of the plug receiving the message.
plugMessage
The plug message.
messageParams
The parameters associated with the plug message.
Return Value

The return value is only pertinent for the kIOFWAVCSubunitPlugMsgSignalFormatModified message. Returns an error if not accepting the sig format change.*/
typedef IOReturn ( *IOFWAVCSubunitPlugHandlerCallback)(
    void *refCon, 
    UInt32 subunitTypeAndID, 
    IOFWAVCPlugTypes plugType, 
    UInt32 plugNum, 
    IOFWAVCSubunitPlugMessages plugMessage, 
    UInt32 messageParams);  

/*IOFWAVCRequestCallback


This callback has been deprecated. Use installAVCCommandHandler instead. 

typedef IOReturn ( *IOFWAVCRequestCallback)(
    void *refCon,
    UInt32 generation,
    UInt16 srcNodeID, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen);  */
typedef IOReturn ( *IOFWAVCRequestCallback)(
    void *refCon,
    UInt32 generation,
    UInt16 srcNodeID, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen);

struct IOFireWireAVCLibUnitInterface {
IUNKNOWN_C_GUTS;   

	int a;//dummy
	int b;//dummy

/*open


Exclusively opens a connection to the in-kernel device. 

IOReturn ( *open)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

Exclusively opens a connection to the in-kernel device. As long as the in-kernel device object is open, no other drivers will be able to open a connection to the device. When open, the device on the bus may disappear, but the in-kernel object representing it will stay instantiated and can begin communicating with the device again if it ever reappears.*/
IOReturn ( *open)(
    void *self );  

/*openWithSessionRef


Opens a connection to a device that is not already open. 

IOReturn ( *openWithSessionRef)(
    void *self,
    IOFireWireSessionRef sessionRef );  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
sessionRef
SessionRef returned from getSessionRef call.
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

Sometimes it is desirable to open multiple user clients on a device. In the case of FireWire sometimes we wish to have both the FireWire User Client and the AV/C User Client open at the same time. The technique to arbitrate this is as follows:
Open normally the device furthest from the root in the I/O Registry. 
Get its sessionRef with the getSessionRef call. 
Open the device further up the chain by calling this method and passing the sessionRef returned from the call in step 2.*/
IOReturn ( *openWithSessionRef)(
    void *self,
    IOFireWireSessionRef sessionRef );  

/*getSessionRef


Opens a connection to a device that is not already open. 

IOFireWireSessionRef ( *getSessionRef)(
    void *self);  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
Return Value

Returns an IOFireWireSessionRef on success. 
Discussion 

Sometimes it is desirable to open multiple user clients on a device. In the case of FireWire sometimes we wish to have both the FireWire User Client and the AV/C User Client open at the same time. The technique to arbitrate this is as follows:
Open normally the device furthest from the root in the I/O Registry. 
Get its sessionRef with the getSessionRef call. 
Open the device further up the chain by calling this method and passing the sessionRef returned from the call in step 2.*/
IOFireWireSessionRef ( *getSessionRef)(
    void *self);  

/*close


Closes an exclusive access to the device. 

void ( *close)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
Discussion 

Closes an exclusive access to the device. When a device is closed it may be unloaded by the kernel. If it is unloaded and then later reappears it will be represented by a different object. You won't be able to use this user client on the new object. The new object will have to be looked up in the I/O Registry and a new user client will have to be opened on it.*/
void ( *close)(
    void *self );  

/*addCallbackDispatcherToRunLoop


Adds a dispatcher for kernel callbacks to the specified run loop. 

IOReturn ( *addCallbackDispatcherToRunLoop)(
    void *self,
    CFRunLoopRef cfRunLoopRef );  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
cfRunLoopRef
Reference to a run loop.
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

The user space portions of the AV/C API communicate with the in-kernel services by messaging the kernel. Similarly, the kernel messages the user space services in response. These responses need to be picked up by a piece of code. This call adds that code to the specified run loop. Most drivers will call this method on the run loop that was created when your task was created. To avoid deadlock you must avoid sleeping (or spin waiting) the run loop to wait for AV/C response. If you do this the dispatcher will never get to run and you will wait forever.*/
IOReturn ( *addCallbackDispatcherToRunLoop)(
    void *self,
    CFRunLoopRef cfRunLoopRef );  

/*removeCallbackDispatcherFromRunLoop


Removes a dispatcher for kernel callbacks to the specified run loop. 

void ( *removeCallbackDispatcherFromRunLoop)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
Discussion 

Undoes the work of addCallbackDispatcherToRunLoop.*/
void ( *removeCallbackDispatcherFromRunLoop)(
    void *self ); 

/*setMessageCallback


Sets callback for user space message routine. 

void ( *setMessageCallback)(
    void *self,
    void *refCon,
    IOFWAVCMessageCallback callback);  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
refCon
RefCon to be returned as first argument of completion routine.
callback
Address of completion routine.
Discussion 

In FireWire and AV/C, bus status messages are delivered via IOKit's message routine. This routine is emulated in user space for AV/C and FireWire messages via this callback. You should register here for bus reset and reconnect messages.*/
void ( *setMessageCallback)(
    void *self,
    void *refCon,
    IOFWAVCMessageCallback callback);  

/*AVCCommand


Sends an AV/C command to the device and returns the response. 

IOReturn ( *AVCCommand)(
    void *self, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen);  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
command
Pointer to command to send.
cmdLen
Length (in bytes) of command.
response
Pointer to place to store the response sent by the device.
responseLen
Pointer to place to store the length of the response. On entry, this parameter contains the size of the response buffer in bytes; on exit, it contains the number of valid bytes in the response buffer.
Discussion 

This function will block until the device returns a response or the kernel driver times out.*/
IOReturn ( *AVCCommand)(
    void *self, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen);  

/*AVCCommandInGeneration


Sends an AV/C command to the device and returns the response. 

IOReturn ( *AVCCommandInGeneration)(
    void *self,
    UInt32 busGeneration, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen);  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
busGeneration
FireWire bus generation that the command is valid in.
command
Pointer to command to send.
cmdLen
Length (in bytes) of command.
response
Pointer to place to store the response sent by the device.
responseLen
Pointer to place to store the length of the response. On entry, this parameter contains the size of the response buffer in bytes; on exit, it contains the number of valid bytes in the response buffer.
Discussion 

Sends an AV/C command to the device and returns the response. The command must complete in the specified bus generation. This function will block until the device returns a response or the kernel driver times out. 

Availability
Interface version 1 or greater.*/
IOReturn ( *AVCCommandInGeneration)(
    void *self,
    UInt32 busGeneration, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen);  

/*getAncestorInterface


Creates a plug-in object for an ancestor (in the I/O Registry) of the AV/C unit and returns an interface to it. 

void * ( *getAncestorInterface)(
    void *self,
    char *object_class,
    REFIID pluginType,
    REFIID iid);  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
object_class
Class name of ancestor of the device to get an interface for.
pluginType
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of plug-in service to be returned for the ancestor.
iid
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of interface to be returned for the created plug-in object.
Return Value

Returns a COM-style interface pointer. Returns 0 upon failure. 

Availability
Interface version 1 or greater.*/
void * ( *getAncestorInterface)(
    void *self,
    char *object_class,
    REFIID pluginType,
    REFIID iid);  

/*getProtocolInterface


Creates a plug-in object for a protocol driver for the FireWire bus the AV/C unit is connected to and returns an interface to it. 

void * ( *getProtocolInterface)(
    void *self,
    REFIID pluginType,
    REFIID iid);  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
pluginType
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of plug-in service to be returned for the created protocol object.
iid
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of interface to be returned for the created protocol device object.
Return Value

Returns a COM-style interface pointer. Returns 0 upon failure. 

Availability
Interface version 1 or greater.*/
void * ( *getProtocolInterface)(
    void *self,
    REFIID pluginType,
    REFIID iid);  

/*getAsyncConnectionPlugCounts


Gets the number of plugs in the producer. 

IOReturn ( *getAsyncConnectionPlugCounts) (
    void *self,
    UInt8 *inputPlugCount,
    UInt8 *outputPlugCount );  
Parameters
self
Pointer to IOFireWireAVCLibUnitInterface.
inputPlugCount
Pointer to the number of input plugs.
outputPlugCount
Pointer to the number of output plugs.*/

IOReturn ( *getAsyncConnectionPlugCounts) (
    void *self,
    UInt8 *inputPlugCount,
    UInt8 *outputPlugCount );  

IOFireWireAVCLibUnitInterface_createConsumerPlug;

/*updateAVCCommandTimeout


Updates an AVCCommand's timeout back to 10 seconds. 

IOReturn ( *updateAVCCommandTimeout)(
    void *self);  
Discussion 

AVCCommands will time out after 10 seconds unless this function is called (from another thread) to update the command's timeout back to 10 seconds. 

Availability
Interface version 2 or greater.*/
IOReturn ( *updateAVCCommandTimeout)(
    void *self);  

/*makeP2PInputConnection


Increments the point-to-point connection count of a unit input plug. 

IOReturn ( *makeP2PInputConnection)(
    void *self,
    UInt32 inputPlug,
    UInt32 chan);  

Availability
Interface version 3 or greater.*/
IOReturn ( *makeP2PInputConnection)(
    void *self,
    UInt32 inputPlug,
    UInt32 chan);  

/*breakP2PInputConnection


Decrements the point-to-point connection count of a unit input plug. 

See Also:
breakLocalP2PInputConnection
IOReturn ( *breakP2PInputConnection)(
    void *self,
    UInt32 inputPlug);  */
IOReturn ( *breakP2PInputConnection)(
    void *self,
    UInt32 inputPlug);  

/*makeP2POutputConnection


Increments the point-to-point connection count of a unit output plug. 

See Also:
makeLocalP2POutputConnection
IOReturn ( *makeP2POutputConnection)(
    void *self,
    UInt32 outputPlug,
    UInt32 chan,
    IOFWSpeed speed);  */
IOReturn ( *makeP2POutputConnection)(
    void *self,
    UInt32 outputPlug,
    UInt32 chan,
    IOFWSpeed speed); 

/*breakP2POutputConnection


Decrements the point-to-point connection count of a unit output plug. 

See Also:
breakLocalP2POutputConnection
IOReturn ( *breakP2POutputConnection)(
    void *self,
    UInt32 outputPlug);  */
IOReturn ( *breakP2POutputConnection)(
    void *self,
    UInt32 outputPlug); 

/*createAVCAsynchronousCommand


Creates an IOFireWireAVCLibAsynchronousCommand object to use with the asynchronous AV/C command functions. 

IOReturn ( *createAVCAsynchronousCommand)(
    void *self, 
    const UInt8 *command, 
    UInt32 cmdLen, 
    IOFireWireAVCLibAsynchronousCommandCallback completionCallback, 
    void *pRefCon, 
    IOFireWireAVCLibAsynchronousCommand **ppCommandObject);  
Parameters
self
Pointer to an IOFireWireAVCLibUnitInterface.
command
Pointer to the command buffer.
cmdLen
The length of the command buffer.
completionCallback
The address of the completion routine.
pRefCon
Pointer to arbitrary data to be returned as the first argument of the callback routine.
ppCommandObject
Pointer to pointer to an IOFireWireAVCLibAsynchronousCommand object to be passed in other asynchronous AV/C command functions.*/
IOReturn ( *createAVCAsynchronousCommand)(
    void *self, 
    const UInt8 *command, 
    UInt32 cmdLen, 
    IOFireWireAVCLibAsynchronousCommandCallback completionCallback, 
    void *pRefCon, 
    IOFireWireAVCLibAsynchronousCommand **ppCommandObject);  

/*AVCAsynchronousCommandSubmit


Issues the asynchronous command on the bus. 

IOReturn ( *AVCAsynchronousCommandSubmit)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  
Parameters
self
Pointer to an IOFireWireAVCLibUnitInterface.
pCommandObject
Pointer to an IOFireWireAVCLibAsynchronousCommand object passed back in createAVCAsynchronousCommand.*/
IOReturn ( *AVCAsynchronousCommandSubmit)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  

/*AVCAsynchronousCommandReinit


Reinitializes an existing IOFireWireAVCLibAsynchronousCommand object, preserving the existing command. 

IOReturn ( *AVCAsynchronousCommandReinit)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  
Parameters
self
Pointer to an IOFireWireAVCLibUnitInterface.
pCommandObject
Pointer to an IOFireWireAVCLibAsynchronousCommand object passed back in createAVCAsynchronousCommand.*/
IOReturn ( *AVCAsynchronousCommandReinit)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  

/*AVCAsynchronousCommandCancel


Cancels a submitted command. 

IOReturn ( *AVCAsynchronousCommandCancel)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  
Parameters
self
Pointer to an IOFireWireAVCLibUnitInterface.
pCommandObject
Pointer to an IOFireWireAVCLibAsynchronousCommand object passed back in createAVCAsynchronousCommand.*/
IOReturn ( *AVCAsynchronousCommandCancel)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  

/*AVCAsynchronousCommandRelease


Releases an IOFireWireAVCLibAsynchronousCommand object. 

IOReturn ( *AVCAsynchronousCommandRelease)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  
Parameters
self
Pointer to an IOFireWireAVCLibUnitInterface.
pCommandObject
Pointer to an IOFireWireAVCLibAsynchronousCommand object passed back in createAVCAsynchronousCommand.*/
IOReturn ( *AVCAsynchronousCommandRelease)(
    void *self,
    IOFireWireAVCLibAsynchronousCommand *pCommandObject);  

/*AVCAsynchronousCommandReinitWithCommandBytes


Reinitializes an existing IOFireWireAVCLibAsynchronousCommand object, replacing the existing command with a new one. 

IOReturn ( *AVCAsynchronousCommandReinitWithCommandBytes)(
    void *self, 
    IOFireWireAVCLibAsynchronousCommand *pCommandObject, 
    const UInt8 *command, 
    UInt32 cmdLen);  
Parameters
self
Pointer to an IOFireWireAVCLibUnitInterface.
pCommandObject
Pointer to an IOFireWireAVCLibAsynchronousCommand object passed back in createAVCAsynchronousCommand.
command
Pointer to the command buffer.
cmdLen
Length of the command buffer.*/
IOReturn ( *AVCAsynchronousCommandReinitWithCommandBytes)(
    void *self, 
    IOFireWireAVCLibAsynchronousCommand *pCommandObject, 
    const UInt8 *command, 
    UInt32 cmdLen);  

 } ;//IOFireWireAVCLibUnitInterface
typedef struct IOFireWireAVCLibUnitInterface IOFireWireAVCLibUnitInterface;

struct _IOFireWireAVCLibProtocolInterface {
	IUNKNOWN_C_GUTS;

/*allocateOutputPlug


Allocates an output plug. 

IOReturn ( *allocateOutputPlug)(
    void *self,
    void *refcon,
    IOFWAVCPCRCallback func,
    UInt32 *plug);  
Parameters
self
Pointer to IOFireWireAVCLibProtocolInterface.
refcon
Arbitrary value passed back as first argument of callback.
func
Callback function when a successful lock transaction to the plug has been performed.
plug
Set to the plug number if a plug is successfully allocated.*/
IOReturn ( *allocateOutputPlug)(
    void *self,
    void *refcon,
    IOFWAVCPCRCallback func,
    UInt32 *plug);  

/*removeCallbackDispatcherFromRunLoop


Removes a dispatcher for kernel callbacks to the specified run loop. 

void ( *removeCallbackDispatcherFromRunLoop)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibProtocolInterface.
Discussion 

Undoes the work of addCallbackDispatcherToRunLoop.*/
void ( *removeCallbackDispatcherFromRunLoop)(
    void *self );  

/*readOutputPlug


Returns the current value of an output plug. 

UInt32 ( *readOutputPlug)(
    void *self,
    UInt32 plug);  
Parameters
self
Pointer to IOFireWireAVCLibProtocolInterface.
plug
Value returned by allocateOutputPlug.*/

UInt32 ( *readOutputPlug)(
    void *self,
    UInt32 plug);  

/*updateOutputPlug


Updates the value of an output plug (simulating a lock transaction). 

IOReturn ( *updateOutputPlug)(
    void *self,
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal);  
Parameters
self
Pointer to IOFireWireAVCLibProtocolInterface.
plug
Value returned by allocateOutputPlug.
oldVal
Value returned by readOutputPlug.
newVal
New value to store in plug if its current value is oldVal.*/
IOReturn ( *updateOutputPlug)(
    void *self,
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal);  

/*addCallbackDispatcherToRunLoop


Adds a dispatcher for kernel callbacks to the specified run loop. 

IOReturn ( *addCallbackDispatcherToRunLoop)(
    void *self,
    CFRunLoopRef cfRunLoopRef );  
Parameters
self
Pointer to IOFireWireAVCLibProtocolInterface.
cfRunLoopRef
Reference to a run loop.
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

The user space portions of the AV/C API communicate with the in-kernel services by messaging the kernel. Similarly, the kernel messages the user space services in response. These responses need to be picked up by a piece of code. This call adds that code to the specified run loop. Most drivers will call this method on the run loop that was created when your task was created. To avoid deadlock you must avoid sleeping (or spin waiting) the run loop to wait for AV/C response. If you do this the dispatcher will never get to run and you will wait forever.*/
IOReturn ( *addCallbackDispatcherToRunLoop)(
    void *self,
    CFRunLoopRef cfRunLoopRef ); 

/*freeOutputPlug


Deallocates an output plug. 

void ( *freeOutputPlug)(
    void *self,
    UInt32 plug);  
Parameters
self
Pointer to IOFireWireAVCLibProtocolInterface.
plug
Value returned by allocateOutputPlug.*/
void ( *freeOutputPlug)(
    void *self,
    UInt32 plug);  

};//_IOFireWireAVCLibProtocolInterface
typedef struct _IOFireWireAVCLibProtocolInterface _IOFireWireAVCLibProtocolInterface;

typedef struct _IOFireWireAVCLibProtocolInterface IOFireWireAVCLibProtocolInterface;//c

struct IOFireWireAVCLibConsumerInterface {
	IUNKNOWN_C_GUTS;
	int a;//dummy
	int b;//dummy

/*setSubunit


Sets the subunit in the producer to which the consumer is making a connection. 


Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
The
8-bit AV/C address of the subunit.*/
void ( *setSubunit)(
    void *self,
    UInt8 subunit );  

/*setRemotePlug


Sets the plug to which the consumer is connecting. 

void ( *setRemotePlug)(
    void *self,
    UInt8 plugNumber );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
plugNumber
The plug number.*/
void ( *setRemotePlug)(
    void *self,
    UInt8 plugNumber );  


/*connectToRemotePlug


Connects to the producer. 

IOReturn ( *connectToRemotePlug)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
Discussion 

This function causes the consumer/controller to send commands to the producer and establish a connection. When the connection is established, setPortStateHandler is called and the status is "connected." */
IOReturn ( *connectToRemotePlug)(
    void *self );  

/*disconnectFromRemotePlug


Disconnects from the remote producer. 

IOReturn ( *disconnectFromRemotePlug)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.*/

IOReturn ( *disconnectFromRemotePlug)(
    void *self ); 

/*setFrameStatusHandler


Sets the callback handler (of type IOFireWireAVCFrameStatusHandler) to be called when the producer sends data to the consumer. 

void ( *setFrameStatusHandler)(
    void *self,
    void *refcon,
    IOFireWireAVCFrameStatusHandler handler );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
refcon
Arbitrary value passed back as first argument of callback.
handler
The consumer's callback function.*/
void ( *setFrameStatusHandler)(
    void *self,
    void *refcon,
    IOFireWireAVCFrameStatusHandler handler );  

/*frameProcessed


Called by the producer to tell the consumer/controller what mode to write into the producer's register. 

void ( *frameProcessed)(
    void *self,
    UInt32 mode );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
mode
The mode to write into the producer's register.*/
void ( *frameProcessed)(
    void *self,
    UInt32 mode );  

/*setMaxPayloadSize


Sets the maximum size of any individual FireWire transaction (an individual block write). 

void ( *setMaxPayloadSize)(
    void *self,
    UInt32 size );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
size
The maximum payload size in bytes.*/
void ( *setMaxPayloadSize)(
    void *self,
    UInt32 size );  


/*setSegmentSize


Sets the maximum size of the producer's segment buffer. 

IOReturn ( *setSegmentSize)(
    void *self,
    UInt32 size );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
size
The maximum size of the segment buffer in bytes.*/
IOReturn ( *setSegmentSize)(
    void *self,
    UInt32 size );  

/*getSegmentSize


Gets the maximum size of the producer's segment buffer. 

UInt32 ( *getSegmentSize)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
Return Value

Returns the size of the segment buffer in bytes. */
UInt32 ( *getSegmentSize)(
    void *self ); 

/*getSegmentBuffer


Returns a pointer to the producer's segment buffer. 

char * ( *getSegmentBuffer)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
Return Value

Returns a pointer to the producer's segment buffer. */
char * ( *getSegmentBuffer)(
    void *self );  


/*setPortStateHandler


Sets the callback handler to report the state of this connection. 

void ( *setPortStateHandler)(
    void *self,
    void *refcon,
    IOFireWireAVCPortStateHandler handler );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
refcon
Arbitrary value passed back as first argument of callback.
handler
The consumer's callback function.
Discussion 

The handler can return one of the following values in its state parameter: Bus Suspended, Bus Resumed, Plug Reconnected, Plug Disconnected, or Device Removed. */
void ( *setPortStateHandler)(
    void *self,
    void *refcon,
    IOFireWireAVCPortStateHandler handler );  


/*setPortFlags


Sets the port flags to the passed in value (currently, there are no flags defined). 

void ( *setPortFlags)(
    void *self,
    UInt32 flags );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
flags
Currently unused.*/
void ( *setPortFlags)(
    void *self,
    UInt32 flags );  

/*clearPortFlags



Clears the port flags (currently, there are no flags defined). 

void ( *clearPortFlags)(
    void *self,
    UInt32 flags );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.
flags
Currently unused.*/
void ( *clearPortFlags)(
    void *self,
    UInt32 flags );  


/*getPortFlags


Gets the current value of the port flags (currently, there are no flags defined). 

UInt32 ( *getPortFlags)(
    void *self );  
Parameters
self
Pointer to IOFireWireAVCLibConsumerInterface.*/
UInt32 ( *getPortFlags)(
    void *self );  

};
typedef struct IOFireWireAVCLibConsumerInterface IOFireWireAVCLibConsumerInterface ;


#endif//_IOKIT_IOFIREWIREAVCLIB_H_
