
#ifndef _IOKIT_IOFIREWIREAVCUNIT_H
#define _IOKIT_IOFIREWIREAVCUNIT_H

#include <IOKit/IOService.h>
#include <IOKit/firewire/IOFWRegs.h>
#include <IOKit/firewire/IOFWAddressSpace.h>
#include <IOKit/firewire/IOFWCommand.h>
#include <IOKit/avc/IOFireWireAVCConsts.h>

class IOFireWireNub;
class IOFireWireAVCCommand;
class IOFireWirePCRSpace;
class IOFireWireAVCUnit;
class IOFireWireAVCSubUnit;
class IOFireWireAVCAsynchronousCommand;
class IOFireWireAVCNub;

#include <HYS/IOKit/avc/IOFireWireAVCUnit.h>
class IOFireWireAVCAsynchronousCommand : public IOCommand,public IOFireWireAVCAsynchronousCommand_HYS
{
    OSDeclareDefaultStructors(IOFireWireAVCAsynchronousCommand)
	friend class IOFireWireAVCUnit;
	
protected:
public:

IOFireWireAVCAsynchronousCommand_isPending
IOFireWireAVCAsynchronousCommand_free
IOFireWireAVCAsynchronousCommand_reinit
IOFireWireAVCAsynchronousCommand_submit
IOFireWireAVCAsynchronousCommand_init
IOFireWireAVCAsynchronousCommand_cancel

protected:
private:
};

class IOFireWireAVCNub : public IOService,public IOFireWireAVCNub_HYS
{
    OSDeclareDefaultStructors(IOFireWireAVCNub)

protected:
private:
public:

/*getDevice


Returns the FireWire device nub that is this object's provider . 

public

IOFireWireNub* getDevice() const ;*/
IOFireWireNub* getDevice() const ;

/*updateAVCCommandTimeout


By default, AVCCommands timeout 10 seconds after receiving an Interim response. This function resets the timeout of the current command to 10 seconds from the current time. Call this repeatedly for AVC commands that take a very long time to execute to prevent premature timeout. 

public

virtual IOReturn updateAVCCommandTimeout() = 0; */
virtual IOReturn updateAVCCommandTimeout() = 0; 

/*AVCCommandInGeneration


Sends an AVC command to the device and stores the response. The command must complete in the specified FireWire bus generation otherwise kIOFireWireBusReset is returned. 

public

virtual IOReturn AVCCommandInGeneration(
    UInt32 generation, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen) = 0; 
Parameters
generation
The bus generation that the command must execute in.
command
Pointer to command to send.
cmdLen
Length of the command.
response
Pointer to place to store the response.
responseLen
Pointer to response length - initialize to the size of the buffer pointed to by response, updated to the number of bytes returned by the device.*/
virtual IOReturn AVCCommandInGeneration(
    UInt32 generation, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen) = 0; 

/*AVCCommand


Sends an AVC command to the device and stores the response. 

public

virtual IOReturn AVCCommand(
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen) = 0; 
Parameters
command
Pointer to command to send.
cmdLen
Length of the command.
response
Pointer to place to store the response.
responseLen
Pointer to response length - initialize to the size of the buffer pointed to by response, updated to the number of bytes returned by the device.*/
virtual IOReturn AVCCommand(
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen) = 0; 
};

class IOFireWireAVCUnit : public IOFireWireAVCNub,public IOFireWireAVCUnit_HYS
{
    OSDeclareDefaultStructors(IOFireWireAVCUnit)

	friend class IOFireWireAVCAsynchronousCommand;
private:
protected:

/*ExpansionData


protected

struct ExpansionData { 
    OSArray *fAVCAsyncCommands; 
    IOFireWireController *fControl; 
    bool enableRobustAVCCommandResponseMatching; 
}; 
Discussion 

This structure is used to expand the capablilties of the class in a binary compatible way*/
struct ExpansionData { 
    OSArray *fAVCAsyncCommands; 
    IOFireWireController *fControl; 
    bool enableRobustAVCCommandResponseMatching; 
}; 

/*fIOFireWireAVCUnitExpansion


protected

ExpansionData *fIOFireWireAVCUnitExpansion; */
ExpansionData *fIOFireWireAVCUnitExpansion;

public:
IOFireWireAVCUnit_AVCAsynchRequestWriteDone
IOFireWireAVCUnit_AVCAsynchDelayDone
IOFireWireAVCUnit_lockAVCAsynchronousCommandLock
IOFireWireAVCUnit_rescanSubUnits
IOFireWireAVCUnit_AVCResponse
IOFireWireAVCUnit_updateSubUnits
IOFireWireAVCUnit_start
IOFireWireAVCUnit_free
IOFireWireAVCUnit_message
IOFireWireAVCUnit_unlockAVCAsynchronousCommandLock
IOFireWireAVCUnit_indexOfAVCAsynchronousCommandObject
IOFireWireAVCUnit_removeAVCAsynchronousCommandObjectAtIndex
IOFireWireAVCUnit_setProperties

/*handleClose


Overrideable method to control the open / close behaviour of an IOService. 

public

virtual void handleClose(
    IOService *forClient, 
    IOOptionBits options ); 
Parameters
forClient
Designates the client of the provider requesting the close.
options
Options for the close, may be interpreted by the implementor of handleOpen.
Discussion 

See IOService for discussion. */
virtual void handleClose(
    IOService *forClient, 
    IOOptionBits options ); 

/*handleOpen


Overrideable method to control the open / close behaviour of an IOService. 

public

virtual bool handleOpen(
    IOService *forClient, 
    IOOptionBits options, 
    void *arg ); 
Parameters
forClient
Designates the client of the provider requesting the open.
options
Options for the open, may be interpreted by the implementor of handleOpen.
Return Value

Return true if the open was successful, false otherwise. 
Discussion 

See IOService for discussion.*/
virtual bool handleOpen(
    IOService *forClient, 
    IOOptionBits options, 
    void *arg ); 

/*matchPropertyTable


Matching language support Match on the following properties of the unit: Vendor_ID GUID Unit_Type and available sub-units, match if the device has at least the requested number of a sub-unit type: AVCSubUnit_0 -> AVCSubUnit_1f 

public

virtual bool matchPropertyTable(
    OSDictionary *table); */
virtual bool matchPropertyTable(
    OSDictionary *table); 

/*AVCCommand


Sends an AVC command to the device and stores the response. 

public

virtual IOReturn AVCCommand(
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 
Parameters
command
Pointer to command to send.
cmdLen
Length of the command.
response
Pointer to place to store the response.
responseLen
Pointer to response length - initialize to the size of the buffer pointed to by response, updated to the number of bytes returned by the device.*/
virtual IOReturn AVCCommand(
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 

/*AVCCommandInGeneration


Sends an AVC command to the device and stores the response. The command must complete in the specified FireWire bus generation otherwise kIOFireWireBusReset is returned. 

public

virtual IOReturn AVCCommandInGeneration(
    UInt32 generation, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 
Parameters
generation
The bus generation that the command must execute in.
command
Pointer to command to send.
cmdLen
Length of the command.
response
Pointer to place to store the response.
responseLen
Pointer to response length - initialize to the size of the buffer pointed to by response, updated to the number of bytes returned by the device.*/
virtual IOReturn AVCCommandInGeneration(
    UInt32 generation, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 

/*updateAVCCommandTimeout


By default, AVCCommands timeout 10 seconds after receiving an Interim response. This function resets the timeout of the current command to 10 seconds from the current time. Call this repeatedly for AVC commands that take a very long time to execute to prevent premature timeout. 

public

virtual IOReturn updateAVCCommandTimeout();*/ 

virtual IOReturn updateAVCCommandTimeout();

};

class IOFireWireAVCSubUnit : public IOFireWireAVCNub,public IOFireWireAVCSubUnit_HYS
{
    OSDeclareDefaultStructors(IOFireWireAVCSubUnit)
	
	friend class IOFireWireAVCAsynchronousCommand;
private:
protected:
public:
IOFireWireAVCSubUnit_message
IOFireWireAVCSubUnit_init

/*matchPropertyTable


Matching language support Match on the following properties of the sub unit: Vendor_ID GUID SubUnit_Type 

public

virtual bool matchPropertyTable(
    OSDictionary *table); */
virtual bool matchPropertyTable(
    OSDictionary *table);

/*AVCCommand


Sends an AVC command to the device and stores the response. 

public

virtual IOReturn AVCCommand(
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 
Parameters
command
Pointer to command to send.
cmdLen
Length of the command.
response
Pointer to place to store the response.
responseLen
Pointer to response length - initialize to the size of the buffer pointed to by response, updated to the number of bytes returned by the device.*/
virtual IOReturn AVCCommand(
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 

/*AVCCommandInGeneration


Sends an AVC command to the device and stores the response. The command must complete in the specified FireWire bus generation otherwise kIOFireWireBusReset is returned. 

public

virtual IOReturn AVCCommandInGeneration(
    UInt32 generation, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 
Parameters
generation
The bus generation that the command must execute in.
command
Pointer to command to send.
cmdLen
Length of the command.
response
Pointer to place to store the response.
responseLen
Pointer to response length - initialize to the size of the buffer pointed to by response, updated to the number of bytes returned by the device.*/
virtual IOReturn AVCCommandInGeneration(
    UInt32 generation, 
    const UInt8 *command,
    UInt32 cmdLen,
    UInt8 *response,
    UInt32 *responseLen); 

/*updateAVCCommandTimeout


By default, AVCCommands timeout 10 seconds after receiving an Interim response. This function resets the timeout of the current command to 10 seconds from the current time. Call this repeatedly for AVC commands that take a very long time to execute to prevent premature timeout. 

public

virtual IOReturn updateAVCCommandTimeout(); */
virtual IOReturn updateAVCCommandTimeout();

/*handleClose


Overrideable method to control the open / close behaviour of an IOService. 

public

virtual void handleClose(
    IOService *forClient, 
    IOOptionBits options ); 
Parameters
forClient
Designates the client of the provider requesting the close.
options
Options for the close, may be interpreted by the implementor of handleOpen.
Discussion 

See IOService for discussion.*/

virtual void handleClose(
    IOService *forClient, 
    IOOptionBits options ); 

/*handleOpen


Overrideable method to control the open / close behaviour of an IOService. 

public

virtual bool handleOpen(
    IOService *forClient, 
    IOOptionBits options, 
    void *arg ); 
Parameters
forClient
Designates the client of the provider requesting the open.
options
Options for the open, may be interpreted by the implementor of handleOpen.
Return Value

Return true if the open was successful, false otherwise. 
Discussion 

See IOService for discussion.*/
virtual bool handleOpen(
    IOService *forClient, 
    IOOptionBits options, 
    void *arg ); 

};


#endif // _IOKIT_IOFIREWIREAVCUNIT_H

