#ifndef _IOKIT_IOFIREWIREPCRSPACE_H
#define _IOKIT_IOFIREWIREPCRSPACE_H

#include <IOKit/firewire/IOFWAddressSpace.h>
#include <IOKit/avc/IOFireWireAVCTargetSpace.h>

/*IOFireWirePCRCallback


Callback called after a successful lock transaction to a plug. 

typedef void ( *IOFireWirePCRCallback)(
    void *refcon,
    UInt16 nodeID,
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal);  
Parameters
refcon
refcon supplied to the IOFireWireFCPSpace when a client is registered
nodeID
is the node originating the request
plugNo
is the plug number
oldVal
is the value the plug used to contain
newVal
is the quad written into the plug*/
typedef void ( *IOFireWirePCRCallback)(
    void *refcon,
    UInt16 nodeID,
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal);  

class IOFireWireBus;

#include <HYS/IOKit/avc/IOFireWirePCRSpace.h>
class IOFireWirePCRSpace : public IOFWPseudoAddressSpace,public IOFireWirePCRSpace_HYS
{
    OSDeclareDefaultStructors(IOFireWirePCRSpace)

protected:
private:
public:

IOFireWirePCRSpace_doWrite
IOFireWireFCPSpace_activate
IOFireWireFCPSpace_deactivate
IOFireWireFCPSpace_allocatePlug
IOFireWireFCPSpace_freePlug
IOFireWireFCPSpace_readPlug
IOFireWireFCPSpace_updatePlug

/*getPCRAddressSpace


returns the IOFireWirePCRSpace object for the given FireWire bus 

public

static IOFireWirePCRSpace *getPCRAddressSpace(
    IOFireWireBus *bus); 
Parameters
bus
The FireWire bus*/
static IOFireWirePCRSpace *getPCRAddressSpace(
    IOFireWireBus *bus); 

/*init


initializes the IOFireWirePCRSpace object 

public

virtual bool init(
    IOFireWireBus *bus); */
virtual bool init(
    IOFireWireBus *bus);

/*clearAllP2PConnections


public

virtual void clearAllP2PConnections(
    void); */
virtual void clearAllP2PConnections(
    void); 

/*updateOutputPlug


updates the value of an output plug (simulating a lock transaction). 

public

virtual IOReturn updateOutputPlug(
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal); 
Parameters
plug
value returned by allocateOutputPlug.
oldVal
value returned by readOutputPlug.
newVal
new value to store in plug if it's current value is oldVal.*/
virtual IOReturn updateOutputPlug(
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal); 

/*updateInputPlug


updates the value of an input plug (simulating a lock transaction). 

public

virtual IOReturn updateInputPlug(
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal); 
Parameters
plug
value returned by allocateInputPlug.
oldVal
value returned by readInputPlug.
newVal
new value to store in plug if it's current value is oldVal.*/
virtual IOReturn updateInputPlug(
    UInt32 plug,
    UInt32 oldVal,
    UInt32 newVal); 

/*readOutputMasterPlug


returns the current value of the output master plug. 

public

virtual UInt32 readOutputMasterPlug(); */

virtual UInt32 readOutputMasterPlug(); 

/*updateInputMasterPlug


updates the value of the master input plug (simulating a lock transaction). 

public

virtual IOReturn updateInputMasterPlug(
    UInt32 oldVal,
    UInt32 newVal); 
Parameters
oldVal
value returned by readInputMasterPlug.
newVal
new value to store in plug if it's current value is oldVal.*/
virtual IOReturn updateInputMasterPlug(
    UInt32 oldVal,
    UInt32 newVal); 

/*updateOutputMasterPlug


updates the value of the master output plug (simulating a lock transaction). 

public

virtual IOReturn updateOutputMasterPlug(
    UInt32 oldVal,
    UInt32 newVal); 
Parameters
oldVal
value returned by readOutputMasterPlug.
newVal
new value to store in plug if it's current value is oldVal.*/
virtual IOReturn updateOutputMasterPlug(
    UInt32 oldVal,
    UInt32 newVal); 

/*readOutputPlug


returns the current value of an output plug. 

public

virtual UInt32 readOutputPlug(
    UInt32 plug); 
Parameters
plug
value returned by allocateOutputPlug.*/
virtual UInt32 readOutputPlug(
    UInt32 plug);

/*readInputPlug


returns the current value of an input plug. 

public

virtual UInt32 readInputPlug(
    UInt32 plug); 
Parameters
plug
value returned by allocateInputPlug.*/
virtual UInt32 readInputPlug(
    UInt32 plug); 

/*allocateOutputPlug


allocates an output plug. 

public

virtual IOReturn allocateOutputPlug(
    void *refcon,
    IOFireWirePCRCallback func,
    UInt32 &plug); 
Parameters
refcon
arbitrary value passed back as first argument of callback.
func
callback function when a successful lock transaction to the plug has been performed
plug
set to the plug number if a plug is successfully allocated*/
virtual IOReturn allocateOutputPlug(
    void *refcon,
    IOFireWirePCRCallback func,
    UInt32 &plug); 

/*allocateInputPlug


allocates an input plug. 

public

virtual IOReturn allocateInputPlug(
    void *refcon,
    IOFireWirePCRCallback func,
    UInt32 &plug); 
Parameters
refcon
arbitrary value passed back as first argument of callback.
func
callback function when a successful lock transaction to the plug has been performed
plug
set to the plug number if a plug is successfully allocated*/
virtual IOReturn allocateInputPlug(
    void *refcon,
    IOFireWirePCRCallback func,
    UInt32 &plug); 

/*readInputMasterPlug


returns the current value of the input master plug. 

public

virtual UInt32 readInputMasterPlug(); */
virtual UInt32 readInputMasterPlug(); 

/*setAVCTargetSpacePointer


public

virtual void setAVCTargetSpacePointer(
    IOFireWireAVCTargetSpace *pAVCTargetSpace); */

virtual void setAVCTargetSpacePointer(
    IOFireWireAVCTargetSpace *pAVCTargetSpace);

/*freeInputPlug


deallocates an input plug. 

public

virtual void freeInputPlug(
    UInt32 plug); 
Parameters
plug
value returned by allocateInputPlug.*/
virtual void freeInputPlug(
    UInt32 plug); 

/*freeOutputPlug


deallocates an output plug. 

public

virtual void freeOutputPlug(
    UInt32 plug); 
Parameters
plug
value returned by allocateOutputPlug.*/
virtual void freeOutputPlug(
    UInt32 plug); 

};

#endif /* _IOKIT_IOFIREWIREPCRSPACE_H */
