#ifndef _IOKIT_IOFWADDRESSSPACE_H
#define _IOKIT_IOFWADDRESSSPACE_H

#include <IOKit/IOMemoryDescriptor.h>
#include <IOKit/firewire/IOFireWireFamilyCommon.h>

class IOFireWireDevice;
class IOFireWireBus;
class IOFireWireController;

#include <HYS/IOKit/firewire/IOFWAddressSpace.h>

/*FWReadCallback


Callback called when a read request packet is received for a 'virtual' firewire address. 

typedef UInt32 ( *FWReadCallback)(
    void *refcon,
    UInt16 nodeID,
    IOFWSpeed &speed, 
    FWAddress addr,
    UInt32 len,
    IOMemoryDescriptor **buf, 
    IOByteCount *offset,
    IOFWRequestRefCon requestRefcon);  
Parameters
nodeID
is the node originating the request
speed
is the FireWire speed of the request, update it if you need to control the speed of the reply, otherwise the response will be the same speed.
addr
is the address the device is requesting to read from
len
is the number of bytes to read
buf
contains the packet data
offset
on return points to the offset into *buf of the packet data
requestRefcon
refcon to pass back if sending a delayed response. Also can be queried for extra info about the request
Return Value

return: kFWResponsePending = -1, Pseudo response, real response sent later. kFWResponseComplete = 0, OK! kFWResponseConflictError = 4, Resource conflict, may retry kFWResponseDataError = 5, Data not available kFWResponseTypeError = 6, Operation not supported kFWResponseAddressError = 7 Address not valid in target device 

A return of kFWResponsePending should be followed at some later time by a call to IOFireWireController::asyncReadResponse*/
typedef UInt32 ( *FWReadCallback)(
    void *refcon,
    UInt16 nodeID,
    IOFWSpeed &speed, 
    FWAddress addr,
    UInt32 len,
    IOMemoryDescriptor **buf, 
    IOByteCount *offset,
    IOFWRequestRefCon requestRefcon);  

/*FWWriteCallback


Callback called when a write request packet is received for a 'virtual' firewire address. 

typedef UInt32 ( *FWWriteCallback)(
    void *refcon,
    UInt16 nodeID,
    IOFWSpeed &speed, 
    FWAddress addr,
    UInt32 len,
    const void *buf,
    IOFWRequestRefCon requestRefcon);  
Parameters
device
is the node originating the request
speed
is the FireWire speed of the request, update it if you need to control the speed of the reply, otherwise the response will be the same speed.
addr
is the address the device is requesting to write to
len
is the number of bytes to write
buf
contains the packet data
requestRefcon
refcon Can be queried for extra info about the request, using IOFireWireController::isLockRequest(), isQuadRequest()
Return Value

return: kFWResponseComplete = 0, OK kFWResponseConflictError = 4, Resource conflict, may retry kFWResponseDataError = 5, Data not available kFWResponseTypeError = 6, Operation not supported kFWResponseAddressError = 7 Address not valid in target device*/
typedef UInt32 ( *FWWriteCallback)(
    void *refcon,
    UInt16 nodeID,
    IOFWSpeed &speed, 
    FWAddress addr,
    UInt32 len,
    const void *buf,
    IOFWRequestRefCon requestRefcon);  

class IOFWAddressSpace;

class IOFWAddressSpaceAux : public OSObject,public IOFWAddressSpaceAux_HYS
{
    OSDeclareDefaultStructors(IOFWAddressSpaceAux)

	friend class IOFWAddressSpace;
	
protected:
private:
public:
IOFWAddressSpaceAux_init
IOFWAddressSpaceAux_free
IOFWAddressSpaceAux_isTrustedNode
IOFWAddressSpaceAux_removeAllTrustedNodes
IOFWAddressSpaceAux_setExclusive
IOFWAddressSpaceAux_removeTrustedNode
IOFWAddressSpaceAux_addTrustedNode
IOFWAddressSpaceAux_isExclusive
IOFWAddressSpaceAux_intersects

};

class IOFWAddressSpace : public OSObject,public IOFWAddressSpace_HYS
{
    OSDeclareAbstractStructors(IOFWAddressSpace)

	friend class IOFWAddressSpaceAux;
private:
protected:

/*ExpansionData


protected

struct ExpansionData { 
    IOFWAddressSpaceAux *fAuxiliary; 
}; 
Discussion 

This structure will be used to expand the capablilties of the class in the future.*/
struct ExpansionData { 
    IOFWAddressSpaceAux *fAuxiliary; 
}; 

/*fIOFWAddressSpaceExpansion


See Also:
reserved
protected

ExpansionData * fIOFWAddressSpaceExpansion; 
Discussion 

Reserved for future use. (Internal use only)*/
ExpansionData * fIOFWAddressSpaceExpansion; 

public:

IOFWAddressSpace_init
IOFWAddressSpace_createAuxiliary
IOFWAddressSpace_free

/*addTrustedNode


Add a trusted node. 

public

inline void addTrustedNode(
    IOFireWireDevice *device ) 
Parameters
device
object pointing to a FireWire node on the bus.
Return Value

none*/
inline void addTrustedNode(
    IOFireWireDevice *device ){};

/*intersects


Checks this address space intersects with the given address range. Currently only supports IOFWPsuedoAddressSpaces. 

public

inline bool intersects(
    IOFWAddressSpace *space ) 
Parameters
space
An address space to compare against
Return Value

True if the address spaces intersect false otherwise*/
inline bool intersects(
    IOFWAddressSpace *space ){}; 

/*isExclusive


Checks if an address space wants exclusive control of its address range 

public

inline bool isExclusive(
    void ) 
Return Value

True if the address space is marked exclusive false otherwise*/
inline bool isExclusive(
    void ){};

/*isTrustedNode


returns true if the node is added as a trusted node 

public

inline bool isTrustedNode(
    UInt16 nodeID ) 
Parameters
nodeID
is the nodeID to verify whether its trusted.
Return Value

false if nodeID is not trusted*/
bool isTrustedNode(
    UInt16 nodeID ) ;

/*doLock


A method for processing a lock request. 

public

virtual UInt32 doLock(
    UInt16 nodeID,
    IOFWSpeed &speed,
    FWAddress addr,
    UInt32 inlen, 
    const UInt32 *newVal,
    UInt32 &outLen,
    UInt32 *oldVal, 
    UInt32 extType,
    IOFWRequestRefCon refcon); 
Parameters
nodeID
FireWire Lock request for nodeID.
speed
at this 'speed'.
addr
with FireWire address 'addr'.
inlen
'inlen' bytes to use.
newVal
new value to write at 'addr' location .
outLen
'outLen' bytes for result.
oldVal
old value read from 'addr' location.
extType
Type like kFWExtendedTCodeCompareSwap.
refcon
Can be queried for extra info about the request.
Return Value

UIn32 returns kFWResponseComplete on success*/
virtual UInt32 doLock(
    UInt16 nodeID,
    IOFWSpeed &speed,
    FWAddress addr,
    UInt32 inlen, 
    const UInt32 *newVal,
    UInt32 &outLen,
    UInt32 *oldVal, 
    UInt32 extType,
    IOFWRequestRefCon refcon); 

/*contains


returns number of bytes starting at addr in this space 

public

virtual UInt32 contains(
    FWAddress addr); 
Return Value

0 if it doesn't contain the address*/
virtual UInt32 contains(
    FWAddress addr); 

/*deactivate


Address space request handler is disabled. 

public

virtual void deactivate(); 
Return Value

none*/
virtual void deactivate(); 

/*activate


Address space is ready for handling requests. 

public

virtual IOReturn activate(); 
Return Value

IOReturn*/
virtual IOReturn activate(); 
    
};

#include <IOKit/firewire/IOFWPseudoAddressSpace.h>
#include <IOKit/firewire/IOFWPhysicalAddressSpace.h>

#endif /* _IOKIT_IOFWADDRESSSPACE */
