
#ifndef _IOKIT_IOFWASYNCSTREAMLISTENER_H
#define _IOKIT_IOFWASYNCSTREAMLISTENER_H

#include <IOKit/firewire/IOFireWireLink.h>
#include <IOKit/firewire/IOFWCommand.h>
#include <IOKit/IOBufferMemoryDescriptor.h>
#include <IOKit/firewire/IOFWDCLProgram.h>

class IOFWAsyncStreamReceiver;
class IOFWAsyncStreamReceivePort;

class IOFWAsyncStreamListener : public OSObject
{
    OSDeclareDefaultStructors(IOFWAsyncStreamListener)

friend class IOFWAsyncStreamReceiver;
friend class IOFireWireController;

public:

/*TurnOnNotification


Turns on client callback notification. 

public

inline void TurnOnNotification();
Return Value

none.*/
inline void TurnOnNotification(){};

/*getFlags


get the flags of listener. 

public

UInt32 getFlags(); 
Parameters
none.
Return Value

flags.*/
UInt32 getFlags(); 

/*setFlags


set flags for the listener. 

public

void setFlags(
    UInt32 flags ); 
Parameters
flags
indicate performance metrics.
Return Value

none.*/
void setFlags(
    UInt32 flags ); 

/*getOverrunCounter


get overrun counter from the DCL program. 

public

UInt32 getOverrunCounter(); 
Parameters
none.
Return Value

returns the counter value.*/
UInt32 getOverrunCounter(); 

/*initAll


Creates an AsyncStream client for an Isoch channel. 

public

bool initAll(
    IOFireWireController *control,
    UInt32 channel,
    FWAsyncStreamReceiveCallback proc,
    void *refcon ); 
Parameters
control
Points to IOFireWireController.
channel
Isoch channel for listening.
proc
Callback on packet reception.
obj
Client's callback object.
Return Value

returns true on success, else false.*/
bool initAll(
    IOFireWireController *control,
    UInt32 channel,
    FWAsyncStreamReceiveCallback proc,
    void *refcon ); 

/*TurnOffNotification


Turns off client callback notification. 

public

inline void TurnOffNotification();
Return Value

none.*/
inline void TurnOffNotification(){};

protected:
private:

/*getReceiver


private

inline IOFWAsyncStreamReceiver *getReceiver();
Discussion 

function getReceiver abstract Returns the Async Stream receiver object which tracks multiple IOFWAsyncStreamListeners for the same Isoc channel.*/
inline IOFWAsyncStreamReceiver *getReceiver(){};

};
#endif // _IOKIT_IOFWASYNCSTREAMLISTENER_H

