
#ifndef _IOKIT_IOFWCOMMAND_H
#define _IOKIT_IOFWCOMMAND_H

#include <IOKit/IOCommand.h>
#include <IOKit/IOLib.h>
#include <IOKit/firewire/IOFireWireFamilyCommon.h>
#include <IOKit/firewire/IOFWSyncer.h>

#define kFWCmdDefaultRetries 3
#define kFWCmdZeroRetries 0
#define kFWCmdReducedRetries 2
#define kFWCmdIncreasedRetries 6

class IOMemoryDescriptor;
class IOSyncer;
class IOFireWireBus;
class IOFireWireController;
class IOFireWireNub;
class IOFWAddressSpace;	//
class IOFWCommand;
class IOFWBusCommand;
class IOFWAsyncStreamCommand;
class IOCommandGate;
class IOFWAsyncPHYCommand;

struct AsyncPendingTrans;

/*IOFWCmdQ


Structure for head of a queue of IOFWCommands 

struct IOFWCmdQ { 
    IOFWCommand *fHead; 
    IOFWCommand *fTail; 
    bool executeQueue(
        bool all); 
    virtual void headChanged(
        IOFWCommand *oldHead);  
    virtual ~IOFWCmdQ() {
        }  void checkProgress(
        void ); 
};  
Fields
fHead
Points to the head of the queue, or NULL if queue is empty
fTail
Points to the tail of the queue, or NULL if queue is empty
headChanged
called when head command is changed, or the command itself changes state.*/

struct IOFWCmdQ { 
    IOFWCommand *fHead; 
    IOFWCommand *fTail; 
    bool executeQueue(
        bool all); 
    virtual void headChanged(
        IOFWCommand *oldHead);  
    virtual ~IOFWCmdQ() {
        }  
		void checkProgress(
        void ); 
};  

#include <HYS/IOKit/firewire/IOFWCommand.h>

class IOFWCommand : public IOCommand,public IOFWCommand_HYS
{
    OSDeclareAbstractStructors(IOFWCommand)

protected:

/*MemberVariables


See Also:
ExpansionData
protected

struct MemberVariables { 
    void *fFWIMRefCon; 
    IOReturn fCompletionStatus; 
    bool fSubmitTimeLatched; 
    AbsoluteTime fSubmitTime; 
    bool fFlush; 
}; 
Discussion 

This structure will be used to expand the capablilties of the class in the future.*/
struct MemberVariables { 
    void *fFWIMRefCon; 
    IOReturn fCompletionStatus; 
    bool fSubmitTimeLatched; 
    AbsoluteTime fSubmitTime; 
    bool fFlush; 
}; 

/*fMembers


See Also:
reserved
protected

MemberVariables * fMembers; 
Discussion 

Reserved for future use. (Internal use only)*/
MemberVariables * fMembers; 

public:
IOFWCommand_initWithController
IOFWCommand_cancel
IOFWCommand_free
IOFWCommand_submit
IOFWCommand_complete
IOFWCommand_startExecution
IOFWCommand_checkProgress
IOFWCommand_updateTimer

/*insertAfter


public

virtual void insertAfter(
    IOFWCommand &prev); 
Parameters
prev
command to insert after
queue
queue command is being added to
Discussion 

inserts a command after the specified one.*/
virtual void insertAfter(
    IOFWCommand &prev); 

/*removeFromQ


public

virtual void removeFromQ(); 
Discussion 

Removes command from current queue.

setHead


public

virtual void setHead(
    IOFWCmdQ &queue); 
Parameters
queue
queue command is being added to
Discussion 

inserts a command at the head of a queue.*/
virtual void removeFromQ(); 

/*setHead


public

virtual void setHead(
    IOFWCmdQ &queue); 
Parameters
queue
queue command is being added to
Discussion 

inserts a command at the head of a queue.*/
virtual void setHead(
    IOFWCmdQ &queue); 

private:
};

class IOFWBusCommand : public IOFWCommand,public IOFWBusCommand_HYS
{
    OSDeclareAbstractStructors(IOFWBusCommand)

protected:
private:
public:
IOFWBusCommand_initWithController
IOFWBusCommand_reinit
IOFWBusCommand_complete

};

class IOFWDelayCommand : public IOFWBusCommand,public IOFWDelayCommand_HYS
{
    OSDeclareDefaultStructors(IOFWDelayCommand)

protected:

public:
IOFWDelayCommand_execute
IOFWDelayCommand_initWithDelay
IOFWDelayCommand_reinit

private:

};

class IOFWUserReadQuadletCommand ;
class IOFWUserWriteCommand ;

class IOFWAsyncCommand : public IOFWCommand,public IOFWAsyncCommand_HYS
{
	OSDeclareAbstractStructors(IOFWAsyncCommand)

protected:
public://data
IOFWAsyncCommand_MemberVariables
IOFWAsyncCommand_fMembers

public://func
IOFWAsyncCommand_initAll
IOFWAsyncCommand_initWithController
IOFWAsyncCommand_initAll_IOFireWireController
IOFWAsyncCommand_createMemberVariables
IOFWAsyncCommand_destroyMemberVariables
IOFWAsyncCommand_reinit
IOFWAsyncCommand_free
IOFWAsyncCommand_reinit_Uint32
IOFWAsyncCommand_updateGeneration
IOFWAsyncCommand_updateNodeID
IOFWAsyncCommand_complete
IOFWAsyncCommand_checkProgress
IOFWAsyncCommand_getAckCode
IOFWAsyncCommand_gotAck
IOFWAsyncCommand_getResponseCode
IOFWAsyncCommand_setAckCode
IOFWAsyncCommand_setRetries
IOFWAsyncCommand_setResponseCode
IOFWAsyncCommand_getMaxRetries
IOFWAsyncCommand_setMaxSpeed

private:

};

class IOFWReadCommand : public IOFWAsyncCommand,public IOFWReadCommand_HYS
{
    OSDeclareDefaultStructors(IOFWReadCommand)

protected:

public:

IOFWReadCommand_reinit
IOFWReadCommand_execute
IOFWReadCommand_gotPacket
IOFWReadCommand_initAll
IOFWReadCommand_initAll_IOFireWireController
IOFWReadCommand_reinit_FWAddress

private:
};


class IOFWReadQuadCommand : public IOFWAsyncCommand,public IOFWReadQuadCommand_HYS
{
    OSDeclareDefaultStructors(IOFWReadQuadCommand)

protected:
public:


IOFWReadQuadCommand_initAll
IOFWReadQuadCommand_reinit
IOFWReadQuadCommand_gotPacket
IOFWReadQuadCommand_execute
IOFWReadQuadCommand_initAll_IOFireWireNub
IOFWReadQuadCommand_reinit_FWAddress

private:
};


class IOFWWriteCommand : public IOFWAsyncCommand,public IOFWWriteCommand_HYS
{

    OSDeclareDefaultStructors(IOFWWriteCommand)

protected:
public:

IOFWWriteCommand_MemberVariables

IOFWWriteCommand_reinit
IOFWWriteCommand_execute
IOFWWriteCommand_gotPacket
IOFWWriteCommand_initWithController
IOFWWriteCommand_free
IOFWWriteCommand_initAll_IOFireWireNub
IOFWWriteCommand_initAll_IOFireWireController
IOFWWriteCommand_reinit_UInt32
IOFWWriteCommand_createMemberVariables
IOFWWriteCommand_destroyMemberVariables

private:
};

class IOFWWriteQuadCommand : public IOFWAsyncCommand,public IOFWWriteQuadCommand_HYS
{

    OSDeclareDefaultStructors(IOFWWriteQuadCommand)

public:

IOFWWriteQuadCommand_MemberVariables

IOFWWriteQuadCommand_reinit
IOFWWriteQuadCommand_gotPacket
IOFWWriteQuadCommand_initAll
IOFWWriteQuadCommand_initWithController
IOFWWriteQuadCommand_createMemberVariables
IOFWWriteQuadCommand_destroyMemberVariables
IOFWWriteQuadCommand_destroyMemoryDescriptor
IOFWWriteQuadCommand_createMemoryDescriptor
IOFWWriteQuadCommand_initAll_IOFireWireNub
IOFWWriteQuadCommand_setQuads
IOFWWriteQuadCommand_free
IOFWWriteQuadCommand_reinit_UInt32
IOFWWriteQuadCommand_execute


protected:
private:
};

class IOFWCompareAndSwapCommand : public IOFWAsyncCommand,public IOFWCompareAndSwapCommand_HYS
{
    OSDeclareDefaultStructors(IOFWCompareAndSwapCommand)

protected:
public:
IOFWCompareAndSwapCommand_MemberVariables
IOFWCompareAndSwapCommand_fMembersfMembers

IOFWCompareAndSwapCommand_initWithController
IOFWCompareAndSwapCommand_createMemoryDescriptor
IOFWCompareAndSwapCommand_destroyMemberVariables
IOFWCompareAndSwapCommand_locked
IOFWCompareAndSwapCommand_createMemberVariables
IOFWCompareAndSwapCommand_initAll
IOFWCompareAndSwapCommand_setInputVals
IOFWCompareAndSwapCommand_initAll_IOFireWireController
IOFWCompareAndSwapCommand_execute
IOFWCompareAndSwapCommand_gotPacket
IOFWCompareAndSwapCommand_free
IOFWCompareAndSwapCommand_destroyMemoryDescriptor
IOFWCompareAndSwapCommand_reinit
IOFWCompareAndSwapCommand_reinit_UInt32

protected:
private:
};

class IOFWAsyncStreamCommand : public IOFWCommand,public IOFWAsyncStreamCommand_HYS
{
	friend class IOFireWireUserClient ;

	OSDeclareDefaultStructors(IOFWAsyncStreamCommand)

protected:
public:
IOFWAsyncStreamCommand_execute
IOFWAsyncStreamCommand_initAll
IOFWAsyncStreamCommand_gotAck
IOFWAsyncStreamCommand_reinit
IOFWAsyncStreamCommand_free
IOFWAsyncStreamCommand_complete

private:
};

class IOFWAsyncPHYCommand : public IOFWCommand,public IOFWAsyncPHYCommand_HYS
{
	friend class IOFireWireUserClient;

	OSDeclareDefaultStructors( IOFWAsyncPHYCommand )

protected:
public:
IOFWAsyncPHYCommand_initAll
IOFWAsyncPHYCommand_reinit
IOFWAsyncPHYCommand_free
IOFWAsyncPHYCommand_complete
IOFWAsyncPHYCommand_setRetries
IOFWAsyncPHYCommand_gotAck
IOFWAsyncPHYCommand_getResponseCode
IOFWAsyncPHYCommand_execute
IOFWAsyncPHYCommand_setAckCode
IOFWAsyncPHYCommand_getAckCode
IOFWAsyncPHYCommand_setResponseCode
IOFWAsyncPHYCommand_gotPacket

private:
};

#endif /* _IOKIT_IOFWCOMMAND_H */
