#ifndef _IOKIT_IOFWPSEUDOADDRESSSPACE_H
#define _IOKIT_IOFWPSEUDOADDRESSSPACE_H

#include <IOKit/firewire/IOFWAddressSpace.h>

class IOFWPseudoAddressSpace;

#include <HYS/IOKit/firewire/IOFWPseudoAddressSpace.h>

class IOFWPseudoAddressSpaceAux : public IOFWAddressSpaceAux,public IOFWPseudoAddressSpaceAux_HYS
{
    OSDeclareDefaultStructors(IOFWPseudoAddressSpaceAux)

	friend class IOFWAddressSpace;
	friend class IOFWPseudoAddressSpace;
	friend class IOFireWireController;
		
protected:
public:
IOFWPseudoAddressSpaceAux_init
IOFWPseudoAddressSpaceAux_free
IOFWPseudoAddressSpaceAux_createMemberVariables
IOFWPseudoAddressSpaceAux_destroyMemberVariables
IOFWPseudoAddressSpaceAux_setARxReqIntCompleteHandler
IOFWPseudoAddressSpaceAux_handleARxReqIntComplete
IOFWPseudoAddressSpaceAux_intersects

private:
};


class IOFWPseudoAddressSpace : public IOFWAddressSpace,public IOFWPseudoAddressSpace_HYS
{
    OSDeclareDefaultStructors(IOFWPseudoAddressSpace)

	friend class IOFWPseudoAddressSpaceAux;
	friend class IOFireWireController;
	
protected:
private:
public:
IOFWPseudoAddressSpace_allocatedAddresses

IOFWPseudoAddressSpace_allocateAddress
IOFWPseudoAddressSpace_freeAddress
IOFWPseudoAddressSpace_free
IOFWPseudoAddressSpace_createAuxiliary

/*setARxReqIntCompleteHandler


Installs a callback to receive notification, when FWIM has completed ARxReqInt processing and no incoming packets are left in the queue. 

public

inline void setARxReqIntCompleteHandler(
    void *refcon,
    IOFWARxReqIntCompleteHandler handler ) 
Parameters
refcon
Client's callback object.
handler
Client callback to be invoked, at the end of interrupt processing.
Return Value

none.*/
inline void setARxReqIntCompleteHandler(
    void *refcon,
    IOFWARxReqIntCompleteHandler handler ) {};

/*simpleRWFixed


Create a Read/Write fixed address space at top of kCSRRegisterSpaceBaseAddressHi. 

public

static IOFWPseudoAddressSpace * simpleRWFixed(
    IOFireWireBus *control,
    FWAddress addr,
    UInt32 len,
    const void *data ); 
Parameters
control
Points to IOFireWireBus object.
addr
Points to starting address for the Pseudo Address Space.
len
Length of the address range.
data
The virtual address of the first byte in the memory.
Return Value

returns valid IOFWPseudoAddressSpace on success, null on failure*/
static IOFWPseudoAddressSpace * simpleRWFixed(
    IOFireWireBus *control,
    FWAddress addr,
    UInt32 len,
    const void *data ); 

/*simpleReadFixed


Create an address space object to handle fixed read-only memory (eg. the local ROM) handles everything itself 

public

static IOFWPseudoAddressSpace* simpleReadFixed( 
    IOFireWireBus *bus, 
    FWAddress addr, 
    UInt32 len, 
    const void *data); 
Parameters
bus
Points to IOFireWireBus object.
addr
Points to starting address for the Pseudo Address Space.
len
Length of the Pseudo Address Space.
data
The virtual address of the first byte in the memory.
Return Value

returns valid IOFWPseudoAddressSpace on success, null on failure*/
static IOFWPseudoAddressSpace* simpleReadFixed( 
    IOFireWireBus *bus, 
    FWAddress addr, 
    UInt32 len, 
    const void *data); 

/*simpleRW(IOFireWireBus *, FWAddress *, IOMemoryDescriptor *)


Create an address space object to handle r/w memory handles everything itself 

public

static IOFWPseudoAddressSpace* simpleRW( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    IOMemoryDescriptor *data); 
Parameters
bus
Points to IOFireWireBus object.
addr
Points to starting address for the Pseudo Address Space.
data
The virtual address of the first byte in the memory.
Return Value

returns valid IOFWPseudoAddressSpace on success, null on failure */
static IOFWPseudoAddressSpace* simpleRW( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    IOMemoryDescriptor *data); 

/*simpleRW(IOFireWireBus *, FWAddress *, UInt32, void *)


Create an address space object to handle r/w memory handles everything itself 

public

static IOFWPseudoAddressSpace* simpleRW( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    UInt32 len, 
    void *data); 
Parameters
bus
Points to IOFireWireBus object.
addr
Points to starting address for the Pseudo Address Space.
len
Length of the Pseudo Address Space.
data
The virtual address of the first byte in the memory.
Return Value

returns valid IOFWPseudoAddressSpace on success, null on failure*/
static IOFWPseudoAddressSpace* simpleRW( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    UInt32 len, 
    void *data); 

/*initAll


Initialize an address space object to handle r/w memory 

public

virtual bool initAll( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    UInt32 len, 
    FWReadCallback reader, 
    FWWriteCallback writer, 
    void *refcon); 
Parameters
bus
Points to IOFireWireBus object.
addr
Points to starting address for the Pseudo Address Space.
len
Length of the Pseudo Address Space.
reader
Callback handler for incoming Read.
writer
Callback handler for incoming Write.
refcon
Client's callback object.
Return Value

returns true on success, false on failure*/
virtual bool initAll( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    UInt32 len, 
    FWReadCallback reader, 
    FWWriteCallback writer, 
    void *refcon); 

/*simpleWriter


A method for processing an address space write request 

public

static UInt32 simpleWriter( 
    void *refcon, 
    UInt16 nodeID, 
    IOFWSpeed& speed, 
    FWAddress addr, 
    UInt32 len, 
    const void *buf, 
    IOFWRequestRefCon reqrefcon); 
Parameters
refcon
Client's callback object.
nodeID
FireWire Write to nodeID.
speed
at this 'speed'.
addr
with FireWire address 'addr'.
len
write 'len' bytes to nodeID.
buf
obtain bytes from location given by 'buf'.
reqrefcon
Can be queried for extra info about the request.
Return Value

UIn32 returns kFWResponseComplete on success*/
static UInt32 simpleWriter( 
    void *refcon, 
    UInt16 nodeID, 
    IOFWSpeed& speed, 
    FWAddress addr, 
    UInt32 len, 
    const void *buf, 
    IOFWRequestRefCon reqrefcon); 

/*simpleRead


Create an address space object to handle read-only memory (eg. the local ROM) handles everything itself 

public

static IOFWPseudoAddressSpace* simpleRead( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    UInt32 len, 
    const void *data); 
Parameters
bus
Points to IOFireWireBus object.
addr
Points to starting address for the Pseudo Address Space.
len
Length of the Pseudo Address Space.
data
The virtual address of the first byte in the memory.
Return Value

returns valid IOFWPseudoAddressSpace on success, null on failure*/
static IOFWPseudoAddressSpace* simpleRead( 
    IOFireWireBus *bus, 
    FWAddress *addr, 
    UInt32 len, 
    const void *data); 

/*doRead


A method for processing an address space read request 

public

virtual UInt32 doRead( 
    UInt16 nodeID, 
    IOFWSpeed & speed, 
    FWAddress addr, 
    UInt32 len, 
    IOMemoryDescriptor ** buf, 
    IOByteCount *offset, 
    IOFWRequestRefCon reqrefcon); 
Parameters
nodeID
FireWire Read from nodeID.
speed
at this 'speed'.
addr
with FireWire address 'addr'.
len
read 'len' bytes from nodeID.
buf
points to a memory descriptor containing the packet data.
offset
start from this 'offset' in 'buf'.
reqrefcon
Can be queried for extra info about the request.
Return Value

UIn32 returns kFWResponseComplete on success*/
virtual UInt32 doRead( 
    UInt16 nodeID, 
    IOFWSpeed & speed, 
    FWAddress addr, 
    UInt32 len, 
    IOMemoryDescriptor ** buf, 
    IOByteCount *offset, 
    IOFWRequestRefCon reqrefcon); 

/*contains


returns number of bytes starting at addr in this space 

public

virtual UInt32 contains(
    FWAddress addr); 
Return Value

0 if it doesn't contain the address*/
virtual UInt32 contains(
    FWAddress addr); 

/*doWrite


A method for processing an address space write request 

public

virtual UInt32 doWrite( 
    UInt16 nodeID, 
    IOFWSpeed& speed, 
    FWAddress addr, 
    UInt32 len, 
    const void *buf, 
    IOFWRequestRefCon reqrefcon); 
Parameters
nodeID
FireWire Write to nodeID.
speed
at this 'speed'.
addr
with FireWire address 'addr'.
len
write 'len' bytes to nodeID.
buf
obtain bytes from location given by 'buf'.
reqrefcon
Can be queried for extra info about the request.
Return Value

UIn32 returns kFWResponseComplete on success*/
virtual UInt32 doWrite( 
    UInt16 nodeID, 
    IOFWSpeed& speed, 
    FWAddress addr, 
    UInt32 len, 
    const void *buf, 
    IOFWRequestRefCon reqrefcon); 

/*simpleReader


A method for processing an address space read request 

public

static UInt32 simpleReader( 
    void *refcon, 
    UInt16 nodeID, 
    IOFWSpeed & speed, 
    FWAddress addr, 
    UInt32 len, 
    IOMemoryDescriptor ** buf, 
    IOByteCount *offset, 
    IOFWRequestRefCon reqrefcon); 
Parameters
refcon
Client's callback object.
nodeID
FireWire Read from nodeID.
speed
at this 'speed'.
addr
with FireWire address 'addr'.
len
read 'len' bytes from nodeID.
buf
points to a memory descriptor containing the packet data.
offset
start from this 'offset' in 'buf'.
reqrefcon
Can be queried for extra info about the request.
Return Value

UIn32 returns kFWResponseComplete on success*/
static UInt32 simpleReader( 
    void *refcon, 
    UInt16 nodeID, 
    IOFWSpeed & speed, 
    FWAddress addr, 
    UInt32 len, 
    IOMemoryDescriptor ** buf, 
    IOByteCount *offset, 
    IOFWRequestRefCon reqrefcon); 

/*initFixed


Initialize a fixed address space at top of kCSRRegisterSpaceBaseAddressHi 

public

virtual bool initFixed( 
    IOFireWireBus *bus, 
    FWAddress addr, 
    UInt32 len, 
    FWReadCallback reader, 
    FWWriteCallback writer, 
    void *refcon); 
Parameters
bus
Points to IOFireWireBus object.
addr
Points to starting address for the Pseudo Address Space.
reader
Callback handler for incoming Read.
writer
Callback handler for incoming Write.
refcon
Client's callback object.
Return Value

returns true on success, false on failure*/
virtual bool initFixed( 
    IOFireWireBus *bus, 
    FWAddress addr, 
    UInt32 len, 
    FWReadCallback reader, 
    FWWriteCallback writer, 
    void *refcon); 

};

#endif//_IOKIT_IOFWPSEUDOADDRESSSPACE_H
