#ifndef __IOFireWireLib_H__
#define __IOFireWireLib_H__


#include <CoreFoundation/CoreFoundation.h>
#include <IOKit/IOCFPlugIn.h>
#include <IOKit/firewire/IOFireWireFamilyCommon.h>

#include <HYS/IOKit/firewire/IOFireWireLib.h>

/*IOFireWirePseudoAddressSpaceReadHandler


Handles read requests to pseudo address spaces. 

typedef UInt32 ( *IOFireWirePseudoAddressSpaceReadHandler)( 
    IOFireWireLibPseudoAddressSpaceRef addressSpace, 
    FWClientCommandID commandID, 
    UInt32 packetLen, 
    UInt32 packetOffset, 
    UInt16 srcNodeID, // nodeID of requester 
    UInt32 destAddressHi, // destination on this node 
    UInt32 destAddressLo, 
    void *refCon);  
Parameters
addressSpace
The address space to which the request is being made.
commandID
An FWClientCommandID which should be passed to ClientCommandIsComplete when the buffer has been filled in.
packetLen
Number of bytes requested.
packetOffset
Number of bytes from beginning of address space backing store.
srcNodeID
NodeID of the requester.
destAddressHi
High 16 bits of destination address on this computer.
destAddressLo
Low 32 bits of destination address on this computer.
refCon
User-specified reference number passed in when the address space was created.
Discussion 

This callback is called to handle read requests to pseudo address spaces. This function should fill in the specified area in the pseudo address space backing store and call ClientCommandIsComplete with the specified command ID.*/
typedef UInt32 ( *IOFireWirePseudoAddressSpaceReadHandler)( 
    IOFireWireLibPseudoAddressSpaceRef addressSpace, 
    FWClientCommandID commandID, 
    UInt32 packetLen, 
    UInt32 packetOffset, 
    UInt16 srcNodeID, // nodeID of requester 
    UInt32 destAddressHi, // destination on this node 
    UInt32 destAddressLo, 
    void *refCon);  

/*IOFireWirePseudoAddressSpaceWriteHandler


Callback called to handle write requests to a pseudo address space. 

typedef UInt32 ( *IOFireWirePseudoAddressSpaceWriteHandler)( 
    IOFireWireLibPseudoAddressSpaceRef addressSpace, 
    FWClientCommandID commandID, 
    UInt32 packetLen, 
    void *packet, 
    UInt16 srcNodeID, // nodeID of sender 
    UInt32 destAddressHi, // destination on this node 
    UInt32 destAddressLo, 
    void *refCon);  
Parameters
addressSpace
The address space to which the write is being made.
commandID
An FWClientCommandID to be passed to ClientCommandIsComplete().
packetLen
Length in bytes of incoming packet.
packet
Pointer to the received data.
srcNodeID
Node ID of the sender.
destAddressHi
High 16 bits of destination address on this computer.
destAddressLo
Low 32 bits of destination address on this computer.
refCon
User-specified reference number passed in when the address space was created.*/
typedef UInt32 ( *IOFireWirePseudoAddressSpaceWriteHandler)( 
    IOFireWireLibPseudoAddressSpaceRef addressSpace, 
    FWClientCommandID commandID, 
    UInt32 packetLen, 
    void *packet, 
    UInt16 srcNodeID, // nodeID of sender 
    UInt32 destAddressHi, // destination on this node 
    UInt32 destAddressLo, 
    void *refCon);  

/*IOFireWirePseudoAddressSpaceSkippedPacketHandler


Callback called when incoming packets have been dropped from the internal queue. 

typedef void ( *IOFireWirePseudoAddressSpaceSkippedPacketHandler)( 
    IOFireWireLibPseudoAddressSpaceRef addressSpace, 
    FWClientCommandID commandID, 
    UInt32 skippedPacketCount);  
Parameters
addressSpace
The address space which dropped the packet(s).
commandID
An FWClientCommandID to be passed to ClientCommandIsComplete().
skippedPacketCount
The number of skipped packets.*/
typedef void ( *IOFireWirePseudoAddressSpaceSkippedPacketHandler)( 
    IOFireWireLibPseudoAddressSpaceRef addressSpace, 
    FWClientCommandID commandID, 
    UInt32 skippedPacketCount);  

/*IOFireWireBusResetHandler


Called when a bus reset has occured, but before FireWire has completed configuring the bus. 

typedef void ( *IOFireWireBusResetHandler)( 
    IOFireWireLibDeviceRef interface, 
    FWClientCommandID commandID );  // parameters may change 
Parameters
interface
A reference to the device on which the callback was installed.
commandID
An FWClientCommandID to be passed to ClientCommandIsComplete().*/
typedef void ( *IOFireWireBusResetHandler)( 
    IOFireWireLibDeviceRef interface, 
    FWClientCommandID commandID );  // parameters may change 

/*IOFWAsyncStreamListenerSkippedPacketHandler


Callback called when incoming packets have been dropped from the internal queue 

typedef void ( *IOFWAsyncStreamListenerSkippedPacketHandler)( 
    IOFWAsyncStreamListenerInterfaceRef listener, 
    FWClientCommandID commandID, 
    UInt32 skippedPacketCount);  
Parameters
listener
The listener which dropped the packets
commandID
An FWClientCommandID to be passed to ClientCommandIsComplete()
skippedPacketCount
The number of skipped packets*/
typedef void ( *IOFWAsyncStreamListenerSkippedPacketHandler)( 
    IOFWAsyncStreamListenerInterfaceRef listener, 
    FWClientCommandID commandID, 
    UInt32 skippedPacketCount); 

/*IOFWAsyncStreamListenerHandler


Callback called to handle Async Stream packets. 

typedef UInt32 ( *IOFWAsyncStreamListenerHandler)( 
    IOFWAsyncStreamListenerInterfaceRef listener, 
    FWClientCommandID commandID, 
    UInt32 size, 
    void *packet, 
    void *refCon);  
Parameters
listener
The listener which received the callback
commandID
An FWClientCommandID to be passed to ClientCommandIsComplete()
packet
Pointer to the received data
refCon
user specified reference number passed in when async stream interface is created*/
typedef UInt32 ( *IOFWAsyncStreamListenerHandler)( 
    IOFWAsyncStreamListenerInterfaceRef listener, 
    FWClientCommandID commandID, 
    UInt32 size, 
    void *packet, 
    void *refCon);  

/*IOFireWireBusResetDoneHandler


Called when a bus reset has occured and FireWire has completed configuring the bus. 

typedef void ( *IOFireWireBusResetDoneHandler)( 
    IOFireWireLibDeviceRef interface, 
    FWClientCommandID commandID );  // parameters may change 
Parameters
interface
A reference to the device on which the callback was installed.
commandID
An FWClientCommandID to be passed to ClientCommandIsComplete().*/
typedef void ( *IOFireWireBusResetDoneHandler)( 
    IOFireWireLibDeviceRef interface, 
    FWClientCommandID commandID );  // parameters may change 

/*IOFireWireLibCommandCallback


Callback called when an asynchronous command has completed executing. 

typedef void ( *IOFireWireLibCommandCallback)( 
    void *refCon, 
    IOReturn completionStatus);  
Parameters
refCon
A user-specified reference value set before command object was submitted.*/
typedef void ( *IOFireWireLibCommandCallback)( 
    void *refCon, 
    IOReturn completionStatus);  

/*IOFireWireLibIRMAllocationLostNotificationProc


Callback called when an IOFireWireLibIRMAllocationRef fails to reclaim IRM resources after a bus-reset 

typedef void ( *IOFireWireLibIRMAllocationLostNotificationProc)(
    IOFireWireLibIRMAllocationRef irmAllocation,
    void *refCon);  */
typedef void ( *IOFireWireLibIRMAllocationLostNotificationProc)(
    IOFireWireLibIRMAllocationRef irmAllocation,
    void *refCon); 

//function
//struct

struct IOFireWireDeviceInterface_t {
	IUNKNOWN_C_GUTS ;

/*GetDevice


Gets the I/O Kit service to which this interface is connected. 

io_object_t ( *GetDevice)(
    IOFireWireLibDeviceRef self);  
Parameters
self
The device interface to use.
Return Value

Returns an io_object_t corresponding to the device the interface is using.*/
io_object_t ( *GetDevice)(
    IOFireWireLibDeviceRef self);  

/*GetCycleTime


Get bus cycle time. 

IOReturn ( *GetCycleTime)(
    IOFireWireLibDeviceRef self,
    UInt32 *outCycleTime);  
Parameters
self
The device interface to use.
outCycleTime
A pointer to a UInt32 to hold the result
Return Value

An IOReturn error code.*/
IOReturn ( *GetCycleTime)(
    IOFireWireLibDeviceRef self,
    UInt32 *outCycleTime);  

/*GetLocalNodeID


(Obsolete) Get local node ID. 

IOReturn ( *GetLocalNodeID)(
    IOFireWireLibDeviceRef self,
    UInt16 *outLocalNodeID);  
Parameters
self
The device interface to use.
outNodeID
A pointer to a UInt16 to hold the local device node ID
Return Value

An IOReturn error code. 
Discussion 

Obsolete -- Please use GetBusGeneration() and GetLocalNodeIDWithGeneration() in interface v4.*/
IOReturn ( *GetLocalNodeID)(
    IOFireWireLibDeviceRef self,
    UInt16 *outLocalNodeID);  

/*Open


Opens the connected device for exclusive access. 

IOReturn ( *Open)(
    IOFireWireLibDeviceRef self);  
Parameters
self
The device interface to use.
Return Value

Returns an IOReturn error code. 
Discussion 

When you have the device open using this method, all accesses by other clients of this device will be denied until Close() is called.*/
IOReturn ( *Open)(
    IOFireWireLibDeviceRef self);  

/*OpenWithSessionRef


Gives this interface access to a device that is already open. 

IOReturn ( *OpenWithSessionRef)(
    IOFireWireLibDeviceRef self,
    IOFireWireSessionRef sessionRef);  
Parameters
self
The device interface to use.
IOFireWireSessionRef
The sessionRef returned from the client who has the device open.
Return Value

Returns an IOReturn error code. 
Discussion 

This is an open function which allows this interface to have access to the device when already opened. The service which has already opened the device must be able to provide an IOFireWireSessionRef.*/
IOReturn ( *OpenWithSessionRef)(
    IOFireWireLibDeviceRef self,
    IOFireWireSessionRef sessionRef);  

/*Close


Releases exclusive access to the device. 

void ( *Close)(
    IOFireWireLibDeviceRef self);  
Parameters
self
The device interface to use.*/
void ( *Close)(
    IOFireWireLibDeviceRef self);  

/*CompareSwap


Perform synchronous lock operation 

IOReturn ( *CompareSwap)(
    IOFireWireLibDeviceRef self,
    io_object_t device,
    const FWAddress *addr,
    UInt32 cmpVal,
    UInt32 newVal,
    Boolean failOnReset,
    UInt32 generation);  
Parameters
self
The device interface to use.
device
The service (representing an attached FireWire device) to which to write. For 48-bit, device relative addressing, pass the service used to create the device interface. This can be obtained by calling GetDevice(). For 64-bit absolute addressing, pass 0. Other values are unsupported.
addr
Command target address
cmpVal
The check/compare value
newVal
Value to set
failOnReset
Pass true if the command should only be executed during the FireWire bus generation specified in 'generation'. Pass false to ignore the generation parameter. The generation can be obtained by calling GetBusGeneration(). Must be 'true' when using 64-bit addressing.
generation
The FireWire bus generation during which the command should be executed. Ignored if failOnReset is false. Must be a valid generation number when using 64-bit absolute addressing.
Return Value

An IOReturn error code*/
IOReturn ( *CompareSwap)(
    IOFireWireLibDeviceRef self,
    io_object_t device,
    const FWAddress *addr,
    UInt32 cmpVal,
    UInt32 newVal,
    Boolean failOnReset,
    UInt32 generation);  

/*ReadQuadlet


Performs synchronous quadlet read. 

IOReturn ( *ReadQuadlet)(
    IOFireWireLibDeviceRef self, 
    io_object_t device, 
    const FWAddress *addr, 
    UInt32 *val, 
    Boolean failOnReset, 
    UInt32 generation);  
Parameters
self
The device interface to use.
device
The service (representing an attached FireWire device) to read. For 48-bit, device relative addressing, pass the service used to create the device interface. This can be obtained by calling GetDevice(). For 64-bit absolute addressing, pass 0. Other values are unsupported.
addr
Command target address.
value
A pointer to where to data should be stored.
failOnReset
Pass true if the command should only be executed during the FireWire bus generation specified in generation. Pass false to ignore the generation parameter. The generation can be obtained by calling GetBusGeneration().
generation
The FireWire bus generation during which the command should be executed. Ignored if failOnReset is false.
Return Value

Returns an IOReturn error code.*/
IOReturn ( *ReadQuadlet)(
    IOFireWireLibDeviceRef self, 
    io_object_t device, 
    const FWAddress *addr, 
    UInt32 *val, 
    Boolean failOnReset, 
    UInt32 generation);  

/*CreateRemoteIsochPort


Creates a remote isochronous port object and returns an interface to it. 

IOFireWireLibRemoteIsochPortRef ( *CreateRemoteIsochPort)( 
    IOFireWireLibDeviceRef self, 
    Boolean inTalking, 
    REFIID iid);  
Parameters
self
The device interface to use.
inTalking
Pass true if this port represents an isochronous talker. Pass false if this port represents an isochronous listener.
iid
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of interface to be returned for the created remote isochronous port object.
Return Value

Returns an IOFireWireLibRemoteIsochPortRef, 0 upon failure. 
Discussion 

A remote isochronous port object is an abstract entity used to represent a remote talker or listener device on an isochronous channel. 

Availability
This function is available in IOFireWireDeviceInterface_v2 and later.*/
IOFireWireLibRemoteIsochPortRef ( *CreateRemoteIsochPort)( 
    IOFireWireLibDeviceRef self, 
    Boolean inTalking, 
    REFIID iid); 

/*CreateLocalIsochPort


Creates a local isochronous port object and returns an interface to it. 

IOFireWireLibLocalIsochPortRef ( *CreateLocalIsochPort)( 
    IOFireWireLibDeviceRef self, 
    Boolean inTalking, 
    DCLCommand *inDCLProgram, 
    UInt32 inStartEvent, 
    UInt32 inStartState, 
    UInt32 inStartMask, 
    IOVirtualRange inDCLProgramRanges[], // optional optimization parameters 
    UInt32 inDCLProgramRangeCount, 
    IOVirtualRange inBufferRanges[], 
    UInt32 inBufferRangeCount, 
    REFIID iid);  
Parameters
self
The device interface to use.
inTalking
Pass true if this port represents an isochronous talker. Pass false if this port represents an isochronous listener.
inDCLProgram
A pointer to the first DCL command struct of the DCL program to be compiled and used to send or receive data on this port.
inStartEvent
Start event: 0 or kFWDCLCycleEvent or kFWDCLSyBitsEvent.
inStartState
Start state bits. For kFWDCLCycleEvent specifies the cycle to start the DMA on. For kFWDCLSyBitsEvent specifies the packet sync field value for the first packet to receive.
inStartMask
Start mask bits. For kFWDCLCycleEvent specifies a mask for the start cycle: the DMA will start when currentCycle & inStartMask == inStartEvent & inStartMask. For kFWDCLSyBitsEvent specifies a mask for the sync field: the DMA will start when packet sync == inStartEvent & inStartMask.
inDCLProgramRanges
This is an optional optimization parameter which can be used to decrease the time the local port object spends determining which set of virtual ranges the passed DCL program occupies. Pass a pointer to an array of IOVirtualRange structs or nil to ignore this parameter.
inDCLProgramRangeCount
The number of virtual ranges passed to inDCLProgramRanges. Pass 0 for none.
inBufferRanges
This is an optional optimization parameter which can be used to decrease the time the local port object spends determining which set of virtual ranges the data buffers referenced by the passed DCL program occupy. Pass a pointer to an array of IOVirtualRange structs or nil to ignore this parameter.
inBufferRangeCount
The number of virtual ranges passed to inBufferRanges. Pass 0 for none.
iid
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of interface to be returned for the created object.
Return Value

Returns an IOFireWireLibLocalIsochPortRef, 0 upon failure. 
Discussion 

A local isochronous port object is an abstract entity used to represent a talking or listening endpoint in the local machine. 

Availability
This function is available in IOFireWireDeviceInterface_v2 and later.*/
IOFireWireLibLocalIsochPortRef ( *CreateLocalIsochPort)( 
    IOFireWireLibDeviceRef self, 
    Boolean inTalking, 
    DCLCommand *inDCLProgram, 
    UInt32 inStartEvent, 
    UInt32 inStartState, 
    UInt32 inStartMask, 
    IOVirtualRange inDCLProgramRanges[], // optional optimization parameters 
    UInt32 inDCLProgramRangeCount, 
    IOVirtualRange inBufferRanges[], 
    UInt32 inBufferRangeCount, 
    REFIID iid);  

/*CreateIsochChannel


Creates an isochronous channel object and returns an interface to it. 

IOFireWireLibIsochChannelRef ( *CreateIsochChannel)( 
    IOFireWireLibDeviceRef self, 
    Boolean doIrm, 
    UInt32 packetSize, 
    IOFWSpeed prefSpeed, 
    REFIID iid );  
Parameters
self
The device interface to use.
doIRM
Controls whether the channel automatically performs IRM operations. Pass true if the channel should allocate its channel and bandwidth with the IRM. Pass false to ignore the IRM.
packetSize
Size in bytes of packets being sent or received with this channel. This is automatically translated into a bandwidth allocation appropriate for the speed passed in prefSpeed.
prefSpeed
The preferred bus speed of this channel.
iid
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of interface to be returned for the created object.
Return Value

Returns an IOFireWireLibIsochChannelRef, 0 upon failure. 
Discussion 

An isochronous channel object is an abstract entity used to represent a FireWire isochronous channel. 

Availability
This function is available in IOFireWireDeviceInterface_v2 and later.*/
IOFireWireLibIsochChannelRef ( *CreateIsochChannel)( 
    IOFireWireLibDeviceRef self, 
    Boolean doIrm, 
    UInt32 packetSize, 
    IOFWSpeed prefSpeed, 
    REFIID iid );  

/*RemoveIsochCallbackDispatcherFromRunLoop


Removes an IOFireWireLib-added run loop event source. 

void ( *RemoveIsochCallbackDispatcherFromRunLoop)( 
    IOFireWireLibDeviceRef self);  
Parameters
self
The device interface to use.
Discussion 

Reverses the effects of AddIsochCallbackDispatcherToRunLoop(). This method removes the run loop event source that was added to the specified run loop preventing any future callbacks from being called. 

Availability
This function is available in IOFireWireDeviceInterface_v3 and later.*/
void ( *RemoveIsochCallbackDispatcherFromRunLoop)( 
    IOFireWireLibDeviceRef self);  

/*AddIsochCallbackDispatcherToRunLoop


Adds an event source for the isochronous callback dispatcher to the specified CFRunLoop. 

IOReturn ( *AddIsochCallbackDispatcherToRunLoop)( 
    IOFireWireLibDeviceRef self, 
    CFRunLoopRef inRunLoop);  
Parameters
self
The device interface to use.
inRunLoop
A CFRunLoopRef for the run loop to which the event loop source should be added.
Return Value

Returns an IOReturn error code. 
Discussion 

Isochronous related callbacks will not function before this function is called. This function is similar to AddCallbackDispatcherToRunLoop. The passed CFRunLoop can be different from that passed to AddCallbackDispatcherToRunLoop. 

Availability
This function is available in IOFireWireDeviceInterface_v2 and later.*/
IOReturn ( *AddIsochCallbackDispatcherToRunLoop)( 
    IOFireWireLibDeviceRef self, 
    CFRunLoopRef inRunLoop);  

/*RemoveCallbackDispatcherFromRunLoop


Reverses the effects of AddCallbackDispatcherToRunLoop(). 

const void ( *RemoveCallbackDispatcherFromRunLoop)(
    IOFireWireLibDeviceRef self);  
Parameters
self
The device interface to use.
Discussion 

This method removes the run loop event source that was added to the specified run loop preventing any future callbacks from being called*/
const void ( *RemoveCallbackDispatcherFromRunLoop)(
    IOFireWireLibDeviceRef self);  

/*AddCallbackDispatcherToRunLoop


Installs the proper run loop event source to allow callbacks to function. 

const IOReturn ( *AddCallbackDispatcherToRunLoop)(
    IOFireWireLibDeviceRef self,
    CFRunLoopRef inRunLoop);  
Parameters
self
The device interface to use.
inRunLoop
The run loop on which to install the event source.
Discussion 

This method must be called before callback notifications for this interface, or any interfaces created using this interface, can function.*/
const IOReturn ( *AddCallbackDispatcherToRunLoop)(
    IOFireWireLibDeviceRef self,
    CFRunLoopRef inRunLoop);  

/*GetGenerationAndNodeID


(Obsolete) Get bus generation and remote device node ID. 

IOReturn ( *GetGenerationAndNodeID)(
    IOFireWireLibDeviceRef self,
    UInt32 *outGeneration,
    UInt16 *outNodeID);  
Parameters
self
The device interface to use.
outGeneration
A pointer to a UInt32 to hold the generation result
outNodeID
A pointer to a UInt16 to hold the remote device node ID
Return Value

An IOReturn error code. 
Discussion 

Obsolete -- Please use GetBusGeneration() and/or GetRemoteNodeID() in interface v4.*/
IOReturn ( *GetGenerationAndNodeID)(
    IOFireWireLibDeviceRef self,
    UInt32 *outGeneration,
    UInt16 *outNodeID);  

/*CreatePseudoAddressSpace


Creates a pseudo address space object and returns an interface to it. This will create a pseudo address space (software-backed) on the local machine. 

IOFireWireLibPseudoAddressSpaceRef ( *CreatePseudoAddressSpace)( 
    IOFireWireLibDeviceRef self, 
    UInt32 inSize, 
    void *inRefCon, 
    UInt32 inQueueBufferSize, 
    void *inBackingStore, 
    UInt32 inFlags, 
    REFIID iid);  
Parameters
self
The device interface to use.
inSize
The size in bytes of this address space
inRefCon
A user specified reference value. This will be passed to all callback functions.
inQueueBufferSize
The size of the queue which receives packets from the bus before they are handed to the client and/or put in the backing store. A larger queue can help eliminate dropped packets when receiving large bursts of data. When a packet is received which can not fit into the queue, the packet dropped callback will be called.
inBackingStore
An optional block of allocated memory representing the contents of the address space.
inFlags
A UInt32 with bits set corresponding to the flags that should be set for this address space. 
kFWAddressSpaceNoFlags -- All flags off
kFWAddressSpaceNoWriteAccess -- Write access to this address space will be disallowed. Setting this flag also disables compare/swap transactions on this address space.
kFWAddressSpaceNoReadAccess -- Read access access to this address space will be disallowed. Setting this flag also disables compare/swap transactions on this address space.
kFWAddressSpaceAutoWriteReply -- Writes will be made automatically, directly modifying the contents of the backing store. The user process will not be notified of writes.
kFWAddressSpaceAutoReadReply -- Reads to this address space will be answered automagically using the contents of the backing store. The user process will not be notified of reads.
kFWAddressSpaceAutoCopyOnWrite -- Writes to this address space will be made directly to the backing store at the same time the user process is notified of a write.
iid
An ID number, of type CFUUIDBytes (see CFUUID.h), identifying the type of interface to be returned for the created pseudo address space object.
Return Value

An IOFireWireLibPseudoAddressSpaceRef. Returns 0 upon failure*/
IOFireWireLibPseudoAddressSpaceRef ( *CreatePseudoAddressSpace)( 
    IOFireWireLibDeviceRef self, 
    UInt32 inSize, 
    void *inRefCon, 
    UInt32 inQueueBufferSize, 
    void *inBackingStore, 
    UInt32 inFlags, 
    REFIID iid);  

};
typedef struct IOFireWireDeviceInterface_t IOFireWireDeviceInterface;
typedef IOFireWireDeviceInterface IOFireWireUnitInterface;
typedef IOFireWireDeviceInterface IOFireWireNubInterface ;

struct IOFireWirePseudoAddressSpaceInterface_t {
	IUNKNOWN_C_GUTS ;
/*GetFWAddress


Gets the FireWire address of this address space. 

void ( *GetFWAddress)(
    IOFireWireLibPseudoAddressSpaceRef self,
    FWAddress *outAddr);  
Parameters
self
Returns the pseudo address interface to use.*/
void ( *GetFWAddress)(
    IOFireWireLibPseudoAddressSpaceRef self,
    FWAddress *outAddr);  

/*SetWriteHandler


Sets the callback that should be called to handle write accesses to the corresponding address space. 

const IOFireWirePseudoAddressSpaceWriteHandler ( *SetWriteHandler)(
    IOFireWireLibPseudoAddressSpaceRef self,
    IOFireWirePseudoAddressSpaceWriteHandler inWriter);  
Parameters
self
The address space interface to use.
inWriter
The callback to set.
Return Value

Returns the callback that was previously set or nil for none.*/
const IOFireWirePseudoAddressSpaceWriteHandler ( *SetWriteHandler)(
    IOFireWireLibPseudoAddressSpaceRef self,
    IOFireWirePseudoAddressSpaceWriteHandler inWriter);  

/*SetSkippedPacketHandler


Sets the callback that should be called when incoming packets are dropped by the address space. 

const IOFireWirePseudoAddressSpaceSkippedPacketHandler ( *SetSkippedPacketHandler)(
    IOFireWireLibPseudoAddressSpaceRef self,
    IOFireWirePseudoAddressSpaceSkippedPacketHandler inHandler);  
Parameters
self
The address space interface to use.
inHandler
The callback to set.
Return Value

Returns the callback that was previously set or nil for none.*/
const IOFireWirePseudoAddressSpaceSkippedPacketHandler ( *SetSkippedPacketHandler)(
    IOFireWireLibPseudoAddressSpaceRef self,
    IOFireWirePseudoAddressSpaceSkippedPacketHandler inHandler);  

/*SetReadHandler


Sets the callback that should be called to handle read accesses to the corresponding address space. 

const IOFireWirePseudoAddressSpaceReadHandler ( *SetReadHandler)(
    IOFireWireLibPseudoAddressSpaceRef self,
    IOFireWirePseudoAddressSpaceReadHandler inReader);  
Parameters
self
The address space interface to use.
inReader
The callback to set.
Return Value

Returns the callback that was previously set or nil for none.*/
const IOFireWirePseudoAddressSpaceReadHandler ( *SetReadHandler)(
    IOFireWireLibPseudoAddressSpaceRef self,
    IOFireWirePseudoAddressSpaceReadHandler inReader);  

/*TurnOnNotification


Tries to turn on packet notifications for this address space. 

Boolean ( *TurnOnNotification)(
    IOFireWireLibPseudoAddressSpaceRef self);  
Parameters
self
The address space interface to use.
Return Value

Returns true upon success.*/
Boolean ( *TurnOnNotification)(
    IOFireWireLibPseudoAddressSpaceRef self);  

/*TurnOffNotification


Forces packet notification off. 

void ( *TurnOffNotification)(
    IOFireWireLibPseudoAddressSpaceRef self);  
Parameters
self
The pseudo address interface to use.*/
void ( *TurnOffNotification)(
    IOFireWireLibPseudoAddressSpaceRef self);  

/*GetBuffer


Gets a pointer to the backing store for this address space. 

void* ( *GetBuffer)(
    IOFireWireLibPseudoAddressSpaceRef self);  
Parameters
self
The address space interface to use.
Return Value

Returns a pointer to the backing store of this pseudo address space. Returns nil if none.*/
void* ( *GetBuffer)(
    IOFireWireLibPseudoAddressSpaceRef self);  

/*ClientCommandIsComplete


Notifies the address space that a packet notification handler has completed. 

void ( *ClientCommandIsComplete)(
    IOFireWireLibPseudoAddressSpaceRef self,
    FWClientCommandID commandID,
    IOReturn status);  
Parameters
self
The address space interface to use.
commandID
The ID of the packet notification being completed. This is the same ID that was passed when a packet notification handler is called.
status
Returns the completion status of the packet handler.
Discussion 

Packet notifications are received one at a time, in order. This function must be called after a packet handler has completed its work.*/
void ( *ClientCommandIsComplete)(
    IOFireWireLibPseudoAddressSpaceRef self,
    FWClientCommandID commandID,
    IOReturn status);  

};
typedef struct IOFireWirePseudoAddressSpaceInterface_t IOFireWirePseudoAddressSpaceInterface;


#endif //__IOFireWireLib_H__
