
#ifndef _IOKIT_HID_IOHIDBASE_H_
#define _IOKIT_HID_IOHIDBASE_H_

#include <IOKit/hid/IOHIDKeys.h>

__BEGIN_DECLS

/*IOHIDDeviceRef


typedef struct __IOHIDDevice * IOHIDDeviceRef;  
Discussion 

This is the type of a reference to the IOHIDDevice.*/
typedef struct __IOHIDDevice * IOHIDDeviceRef;  

/*IOHIDTransactionOption


Options to be used in conjuntion with an IOHIDDeviceTransactionInterface. 

enum { 
    kIOHIDTransactionOptionDefaultOutputValue = 0x0001 
};  
Constants
kIOHIDTransactionOptionDefaultOutputValue
Option to set the default element value to be used with an IOHIDDeviceTransactionInterface of direction kIOHIDTransactionDirectionTypeOutput.*/
enum { 
    kIOHIDTransactionOptionDefaultOutputValue = 0x0001 
};  

/*IOHIDElementRef


typedef struct __IOHIDElement * IOHIDElementRef;  
Discussion 

This is the type of a reference to the IOHIDElement.*/
typedef struct __IOHIDElement * IOHIDElementRef;  

/*IOHIDValueRef


typedef struct __IOHIDValue * IOHIDValueRef;  
Discussion 

This is the type of a reference to the IOHIDValue.*/
typedef struct __IOHIDValue * IOHIDValueRef;  

/*IOHIDTransactionDirectionType


Direction for an IOHIDDeviceTransactionInterface. 

See Also:
IOHIDTransactionDirectionType
enum { 
    kIOHIDTransactionDirectionTypeInput, 
    kIOHIDTransactionDirectionTypeOutput
}: */
enum { 
    kIOHIDTransactionDirectionTypeInput, 
    kIOHIDTransactionDirectionTypeOutput
};

/*IOHIDTransactionDirectionType


Direction for an IOHIDDeviceTransactionInterface. 

See Also:
IOHIDTransactionDirectionType
typedef uint32_t IOHIDTransactionDirectionType;  
Constants
kIOHIDTransactionDirectionTypeInput
Transaction direction used for requesting element values from a device.
kIOHIDTransactionDirectionTypeOutput
Transaction direction used for dispatching element values to a device.*/
typedef uint32_t IOHIDTransactionDirectionType;  

/*IOHIDValueCallback


typedef void ( *IOHIDValueCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    IOHIDValueRef value);  
Parameters
context
void * pointer to more data.
result
Completion result of desired operation.
sender
Interface instance sending the completion routine.
value
IOHIDValueRef containing the returned element value.
Discussion 

Type and arguments of callout C function that is used when an element value completion routine is called.*/
typedef void ( *IOHIDValueCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    IOHIDValueRef value);  

/*IOHIDReportCallback


typedef void ( *IOHIDReportCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    IOHIDReportType type, 
    uint32_t reportID, 
    uint8_t *report, 
    CFIndex reportLength);  
Parameters
target
void * pointer to your data, often a pointer to an object.
result
Completion result of desired operation.
refcon
void * pointer to more data.
sender
Interface instance sending the completion routine.
type
The type of the report that was completed.
reportID
The ID of the report that was completed.
report
Pointer to the buffer containing the contents of the report.
reportLength
Size of the buffer received upon completion.
Discussion 

Type and arguments of callout C function that is used when a HID report completion routine is called.*/
typedef void ( *IOHIDReportCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    IOHIDReportType type, 
    uint32_t reportID, 
    uint8_t *report, 
    CFIndex reportLength); 

/*IOHIDCallback


typedef void ( *IOHIDCallback)( 
    void *context, 
    IOReturn result, 
    void *sender);  
Parameters
target
void * pointer to your data, often a pointer to an object.
result
Completion result of desired operation.
refcon
void * pointer to more data.
sender
Interface instance sending the completion routine.
Discussion 

Type and arguments of callout C function that is used when a completion routine is called.*/
typedef void ( *IOHIDCallback)( 
    void *context, 
    IOReturn result, 
    void *sender);  

/*IOHIDValueMultipleCallback


typedef void ( *IOHIDValueMultipleCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    CFDictionaryRef multiple);  
Parameters
context
void * pointer to more data.
result
Completion result of desired operation.
sender
Interface instance sending the completion routine.
multiple
CFDictionaryRef containing the returned element key value pairs.
Discussion 

Type and arguments of callout C function that is used when an element value completion routine is called.*/
typedef void ( *IOHIDValueMultipleCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    CFDictionaryRef multiple);  

/*IOHIDDeviceCallback


typedef void ( *IOHIDDeviceCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    IOHIDDeviceRef device);  
Parameters
context
void * pointer to more data.
result
Completion result of desired operation.
device
IOHIDDeviceRef containing the sending device.
Discussion 

Type and arguments of callout C function that is used when a device routine is called.*/
typedef void ( *IOHIDDeviceCallback) ( 
    void *context, 
    IOReturn result, 
    void *sender, 
    IOHIDDeviceRef device);  

/*IOHIDValueScaleType


Describes different types of scaling that can be performed on element values. 

See Also:
IOHIDValueScaleType
enum { 
    kIOHIDValueScaleTypeCalibrated, 
    kIOHIDValueScaleTypePhysical 
};  */
enum { 
    kIOHIDValueScaleTypeCalibrated, 
    kIOHIDValueScaleTypePhysical 
}; 

/*IOHIDValueScaleType


Describes different types of scaling that can be performed on element values. 

See Also:
IOHIDValueScaleType
typedef uint32_t IOHIDValueScaleType;  
Constants
kIOHIDValueScaleTypeCalibrated
Type for value that is scaled with respect to the calibration properties.
kIOHIDValueScaleTypePhysical
Type for value that is scaled with respect to the physical min and physical max of the element.*/
typedef uint32_t IOHIDValueScaleType;  

__END_DECLS
#endif // _IOKIT_HID_IOHIDBASE_H_ 
