
#ifndef _IOKIT_HID_IOHIDDEVICE_H
#define _IOKIT_HID_IOHIDDEVICE_H

#include <IOKit/IOService.h>
#include <IOKit/IOMessage.h>
#include <IOKit/IOBufferMemoryDescriptor.h>
#include <IOKit/hidsystem/IOHIDDescriptorParser.h>
#include <IOKit/hid/IOHIDKeys.h>

#ifdef __cplusplus
class   IOHIDSystem;
class   IOHIDPointing;
class   IOHIDKeyboard;
class   IOHIDConsumer;
class   IOHIDElementPrivate;
class   IOHIDEventQueue;
class   IOHIDInterface;
#endif //__cplusplus

struct  IOHIDReportHandler;

#ifdef __cplusplus
class IOHIDDevice : public IOService
{
    OSDeclareDefaultStructors( IOHIDDevice )
public:

/*handleReport


Handle an asynchronous report received from the HID device. 

public

virtual IOReturn handleReport( 
    IOMemoryDescriptor *report, 
    IOHIDReportType reportType = kIOHIDReportTypeInput, 
    IOOptionBits options = 0 ); 
Parameters
report
A memory descriptor that describes the report.
reportType
The type of report.
options
Options to specify the request. No options are currently defined, and the default value is 0.
Return Value

kIOReturnSuccess on success, or an error return otherwise.*/

virtual IOReturn handleReport( 
    IOMemoryDescriptor *report, 
    IOHIDReportType reportType = kIOHIDReportTypeInput, 
    IOOptionBits options = 0 ); 

private:
protected:

/*handleStop


Quiesce the hardware and stop the driver. 

protected

virtual void handleStop(
    IOService *provider ); 
Parameters
provider
The provider argument passed to stop().
Discussion 

IOHIDDevice will call this method from stop() to signal that the hardware should be quiesced and the driver stopped. A subclass that overrides this method should end its implementation by calling the version in super.*/
virtual void handleStop(
    IOService *provider ); 

/*handleStart


Prepare the hardware and driver to support I/O operations. 

protected

virtual bool handleStart(
    IOService *provider ); 
Parameters
provider
The provider argument passed to start().
Return Value

True on success, or false otherwise. Returning false will cause start() to fail and return false. 
Discussion 

IOHIDDevice will call this method from start() before any I/O operations are issued to the concrete subclass. Methods such as newReportDescriptor() are only called after handleStart() has returned true. A subclass that overrides this method should begin its implementation by calling the version in super, and then check the return value.*/
virtual bool handleStart(
    IOService *provider ); 

};
#endif //__cplusplus

#endif//_IOKIT_HID_IOHIDDEVICE_H
