
#ifndef _IOKIT_HID_IOHIDDEVICEPLUGIN_H
#define _IOKIT_HID_IOHIDDEVICEPLUGIN_H

#include <sys/cdefs.h>
#include <CoreFoundation/CoreFoundation.h>
#if COREFOUNDATION_CFPLUGINCOM_SEPARATE
#include <CoreFoundation/CFPlugInCOM.h>
#endif

#include <IOKit/IOTypes.h>
#include <IOKit/IOReturn.h>
#include <IOKit/IOCFPlugIn.h>
#include <IOKit/hid/IOHIDBase.h>
#include <IOKit/hid/IOHIDKeys.h>
#include <IOKit/hid/IOHIDLibObsolete.h>

__BEGIN_DECLS

/*kIOHIDDeviceDeviceInterfaceID


#define kIOHIDDeviceDeviceInterfaceID CFUUIDGetConstantUUIDWithBytes(NULL, \ 
    0x47, 0x4b, 0xdc, 0x8e, 0x9f, 0x4a, 0x11, 0xda, \ 
    0xb3, 0x66, 0x00, 0x0d, 0x93, 0x6d, 0x06, 0xd2 ) 
Discussion 

This UUID constant is used to obtain a device interface corresponding to an IOHIDDevice service in the kernel. The type of this device interface is IOHIDDeviceDeviceInterface. This device interface is obtained after the IOCFPlugInInterface for the service itself has been obtained. 

Note: Please note that subsequent calls to QueryInterface with the UUID kIOHIDDeviceTransactionInterfaceID, will return a retained instance of an existing IOHIDDeviceTransactionInterface. 

Example: 
    
    IOCFPluginInterface **          iodev;  // obtained earlier
    
    IOHIDDeviceDeviceInterface **   dev;    // fetching this now
    IOReturn                        err;
    
    err = (*iodev)->QueryInterface(iodev,
                                    CFUUIDGetUUIDBytes(kIOHIDDeviceDeviceInterfaceID),
                                    (LPVoid)&dev);
    */
#define kIOHIDDeviceDeviceInterfaceID CFUUIDGetConstantUUIDWithBytes(NULL, \
    0x47, 0x4b, 0xdc, 0x8e, 0x9f, 0x4a, 0x11, 0xda, \
    0xb3, 0x66, 0x00, 0x0d, 0x93, 0x6d, 0x06, 0xd2 )

/*kIOHIDDeviceQueueInterfaceID


#define kIOHIDDeviceQueueInterfaceID CFUUIDGetConstantUUIDWithBytes(NULL, \ 
    0x2e, 0xc7, 0x8b, 0xdb, 0x9f, 0x4e, 0x11, 0xda, \ 
    0xb6, 0x5c, 0x00, 0x0d, 0x93, 0x6d, 0x06, 0xd2) 
Discussion 

This UUID constant is used to obtain a queue interface corresponding to an IOHIDDevice service in the kernel. The type of this queue interface is IOHIDDeviceQueueInterface. This device interface is obtained after the device interface for the service itself has been obtained. 

Note: Please note that subsequent calls to QueryInterface with the UUID kIOHIDDeviceQueueInterfaceID, will return a retained instance of a new IOHIDDeviceQueueInterface. 

Example: 
    
    IOCFPluginInterface **          iodev; 	// obtained earlier
    
    IOHIDDeviceQueueInterface **    intf;   // fetching this now
    IOReturn                        err;
    
    err = (*iodev)->QueryInterface(iodev,
                                CFUUIDGetUUIDBytes(kIOHIDDeviceQueueInterfaceID),
                                (LPVoid)&intf);*/
#define kIOHIDDeviceQueueInterfaceID CFUUIDGetConstantUUIDWithBytes(NULL, \
    0x2e, 0xc7, 0x8b, 0xdb, 0x9f, 0x4e, 0x11, 0xda, \
    0xb6, 0x5c, 0x00, 0x0d, 0x93, 0x6d, 0x06, 0xd2) 

/*kIOHIDDeviceTransactionInterfaceID


#define kIOHIDDeviceTransactionInterfaceID CFUUIDGetConstantUUIDWithBytes(NULL, \ 
    0x1f, 0x2e, 0x78, 0xfa, 0x9f, 0xfa, 0x11, 0xda, \ 
    0x90, 0xb4, 0x00, 0x0d, 0x93, 0x6d, 0x06, 0xd2) 
Discussion 

This UUID constant is used to obtain a transaction interface corresponding to an IOHIDDevice service in the kernel. The type of this queue interface is IOHIDDeviceTransactionInterface. This device interface is obtained after the device interface for the service itself has been obtained. 

Note: Please note that subsequent calls to QueryInterface with the UUID kIOHIDDeviceTransactionInterfaceID, will return a retained instance of a new IOHIDDeviceTransactionInterface. 

Example: 
    
    IOCFPluginInterface **              iodev;  // obtained earlier
    
    IOHIDDeviceTransactionInterface	**  intf;   // fetching this now
    IOReturn                            err;
    
    err = (*iodev)->QueryInterface(iodev,
                                CFUUIDGetUUIDBytes(kIOHIDDeviceTransactionInterfaceID),
                                (LPVoid)&intf);
    */
#define kIOHIDDeviceTransactionInterfaceID CFUUIDGetConstantUUIDWithBytes(NULL, \
    0x1f, 0x2e, 0x78, 0xfa, 0x9f, 0xfa, 0x11, 0xda, \
    0x90, 0xb4, 0x00, 0x0d, 0x93, 0x6d, 0x06, 0xd2)

struct IOHIDDeviceDeviceInterface {
   IUNKNOWN_C_GUTS;

/*open


Opens the IOHIDDevice. 

IOReturn ( *open)(
    void *self,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
options
Option bits to be passed down to the user client.
Return Value

Returns kIOReturnSuccess if successful, some other mach error if the connection is no longer valid. 
Discussion 

Before the client can issue commands that change the state of the device, it must have succeeded in opening the device. This establishes a link between the client's task and the actual device. To establish an exclusive link use the kIOHIDOptionsTypeSeizeDevice option.*/
IOReturn ( *open)(
    void *self,
    IOOptionBits options);  

/*close


Closes the task's connection to the IOHIDDevice. 

IOReturn ( *close)(
    void *self,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
options
Option bits to be passed down to the user client.
Return Value

Returns kIOReturnSuccess if successful, kIOReturnNoDevice if there is no connection to an IOService. 
Discussion 

Releases the client's access to the IOHIDDevice.*/
IOReturn ( *close)(
    void *self,
    IOOptionBits options); 

/*getProperty


Obtains a property related to the IOHIDDevice. 

IOReturn ( *getProperty)(
    void *self,
    CFStringRef key,
    CFTypeRef *pProperty);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
key
CFStringRef key
pProperty
Pointer to a CFTypeRef property.
Return Value

Returns kIOReturnSuccess if successful. 
Discussion 

Property keys are prefixed by kIOHIDDevice and declared in IOHIDKeys.h.*/
IOReturn ( *getProperty)(
    void *self,
    CFStringRef key,
    CFTypeRef *pProperty);  

/*setProperty


Sets a property related to the IOHIDDevice. 

IOReturn ( *setProperty)(
    void *self,
    CFStringRef key,
    CFTypeRef property);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
key
CFStringRef key
property
CFTypeRef property.
Return Value

Returns kIOReturnSuccess if successful. 
Discussion 

Property keys are prefixed by kIOHIDDevice and declared in IOHIDKeys.h.*/
IOReturn ( *setProperty)(
    void *self,
    CFStringRef key,
    CFTypeRef property);  

/*getAsyncEventSource


Obtains the event source for this IOHIDDeviceDeviceInterface instance. 

IOReturn ( *getAsyncEventSource)(
    void *self,
    CFTypeRef *pSource);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
pSource
Pointer to a CFType to return the run loop event source.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

The returned event source can be of type CFRunLoopSourceRef or CFRunLoopTimerRef.*/
IOReturn ( *getAsyncEventSource)(
    void *self,
    CFTypeRef *pSource);  

/*copyMatchingElements

Obtains a CFArrayRef containing the IOHIDDeviceDeviceInterface elements that match the passed matching dictionary. 

IOReturn ( *copyMatchingElements)(
    void *self,
    CFDictionaryRef matchingDict,
    CFArrayRef *pElements,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
matchingDict
CFDictionaryRef containing the element properties to match on.
pElements
CFArrayRef containing matched elements.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

Objects contained in the returned array are of type IOHIDElementRef. Please see IOHIDElement.h for additional API information. Elemenet properties are prefixed by kIOHIDElement and declared in IOHIDKeys.h.*/
IOReturn ( *copyMatchingElements)(
    void *self,
    CFDictionaryRef matchingDict,
    CFArrayRef *pElements,
    IOOptionBits options);  

/*setValue


Sets the value for an element. 

IOReturn ( *setValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef value, 
    uint32_t timeout,
    IOHIDValueCallback callback,
    void *context,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
element
IOHIDElementRef referencing the element of interest.
value
IOHIDValueRef containing element value to be set.
timeout
Time in milliseconds to wait before aborting request.
callback
Callback of type IOHIDValueCallback to be used after report data has been sent to the device. If null, this method will behave synchronously.
context
Pointer to data to be passed to the callback.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

If setting multiple element values, please consider using an IOHIDDeviceTransactionInterface with the kIOHIDTransactionDirectionTypeOutput direction. 
Note: In order to make use of asynchronous behavior, the event source obtained using getAsyncEventSource must be added to a run loop*/
IOReturn ( *setValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef value, 
    uint32_t timeout,
    IOHIDValueCallback callback,
    void *context,
    IOOptionBits options);  

/*getValue


Obtains the current value for an element. 

IOReturn ( *getValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef *pValue, 
    uint32_t timeout,
    IOHIDValueCallback callback,
    void *context,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
element
IOHIDElementRef referencing the element of interest.
pValue
Pointer to a IOHIDValueRef to return the element value.
timeout
Time in milliseconds to wait before aborting request.
callback
Callback of type IOHIDReportCallback to be used when element value has been received from the device. If null, this method will behave synchronously.
context
Pointer to data to be passed to the callback.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

If an element of type kIOHIDElementTypeFeature is passed, this method will issue a request to the IOHIDDevice. Otherwise, this will return the last value reported by the IOHIDDevice. If requesting multiple feature element values, please consider using an IOHIDDeviceTransactionInterface with the kIOHIDTransactionDirectionTypeInput direction. 
Note: In order to make use of asynchronous behavior, the event source obtained using getAsyncEventSource must be added to a run loop.*/
IOReturn ( *getValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef *pValue, 
    uint32_t timeout,
    IOHIDValueCallback callback,
    void *context,
    IOOptionBits options);  

/*setInputReportCallback


Sets the input report callback to be used when data is received from the Input pipe. 

IOReturn ( *setInputReportCallback)(
    void *self,
    uint8_t *report,
    CFIndex reportLength, 
    IOHIDReportCallback callback,
    void *context,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
report
Pointer to a pre-allocated buffer to be filled and passed back via the callback.
reportLength
Length of the report buffer.
callback
Callback of type IOHIDReportCallback to be used when report data has been receieved by the IOHIDDevice.
context
Pointer to data to be passed to the callback.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

In order to function properly, the event source obtained using getAsyncEventSource must be added to a run loop.*/
IOReturn ( *setInputReportCallback)(
    void *self,
    uint8_t *report,
    CFIndex reportLength, 
    IOHIDReportCallback callback,
    void *context,
    IOOptionBits options);  

/*setReport


Sends a report of type kIOHIDReportTypeOutput or kIOHIDReportTypeFeature to the IOHIDDevice. 

IOReturn ( *setReport)(
    void *self,
    IOHIDReportType reportType,
    uint32_t reportID,
    const uint8_t *report,
    CFIndex reportLength, 
    uint32_t timeout,
    IOHIDReportCallback callback,
    void *context,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
reportType
The report type.
reportID
The report id.
report
Pointer to a buffer containing the report data to be sent.
reportLength
Length of the report buffer.
timeout
Timeout in milliseconds for issuing the setReport.
callback
Callback of type IOHIDReportCallback to be used after report data has been sent to the device. If null, this method will behave synchronously.
context
Pointer to data to be passed to the callback.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

This method is useful if specific knowledge of the unparsed report is known to the caller. Otherwise, using an IOHIDDeviceTransactionInterface with the kIOHIDTransactionDirectionTypeOutput direction is recommended. 
Note: In order to make use of asynchronous behavior, the event source obtained using getAsyncEventSource must be added to a run loop.*/
IOReturn ( *setReport)(
    void *self,
    IOHIDReportType reportType,
    uint32_t reportID,
    const uint8_t *report,
    CFIndex reportLength, 
    uint32_t timeout,
    IOHIDReportCallback callback,
    void *context,
    IOOptionBits options);  

/*getReport


Obtains a report of type kIOHIDReportTypeInput or kIOHIDReportTypeFeature from the IOHIDDevice. 

IOReturn ( *getReport)(
    void *self,
    IOHIDReportType reportType,
    uint32_t reportID,
    uint8_t *report,
    CFIndex *pReportLength, 
    uint32_t timeout,
    IOHIDReportCallback callback,
    void *context,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceDeviceInterface.
reportType
The report type.
reportID
The report id.
report
Pointer to a pre-allocated buffer to be filled.
reportLength
Length of the report buffer. When finished, this will contain the actual length of the report.
timeout
Timeout in milliseconds for issuing the getReport.
callback
Callback of type IOHIDReportCallback to be used when report data has been received from the device. If null, this method will behave synchronously.
context
Pointer to data to be passed to the callback.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

This method is useful if specific knowledge of the unparsed report is known to the caller. Otherwise, using an IOHIDDeviceTransactionInterface with the kIOHIDTransactionDirectionTypeInput direction is recommended. 
Note: In order to make use of asynchronous behavior, the event source obtained using getAsyncEventSource must be added to a run loop.*/
IOReturn ( *getReport)(
    void *self,
    IOHIDReportType reportType,
    uint32_t reportID,
    uint8_t *report,
    CFIndex *pReportLength, 
    uint32_t timeout,
    IOHIDReportCallback callback,
    void *context,
    IOOptionBits options);  

};
typedef struct IOHIDDeviceDeviceInterface IOHIDDeviceDeviceInterface;

struct IOHIDDeviceTransactionInterface {
  IUNKNOWN_C_GUTS;

/*getAsyncEventSource


Obtains the event source for this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *getAsyncEventSource)(
    void *self,
    CFTypeRef *pSource);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
pSource
Pointer to a CFType to return the run loop event source.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

The returned event source can be of type CFRunLoopSourceRef or CFRunLoopTimerRef.*/
IOReturn ( *getAsyncEventSource)(
    void *self,
    CFTypeRef *pSource);  

/*setDirection


Sets the direction for this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *setDirection)(
    void *self,
    IOHIDTransactionDirectionType direction,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
direction
Transaction direction of type IOHIDTransactionDirectionType.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

Direction constants are declared in IOHIDTransactionDirectionType. Changing directions is useful when dealing with elements of type kIOHIDElementTypeFeature as you use the transaction to both set and get element values.*/
IOReturn ( *setDirection)(
    void *self,
    IOHIDTransactionDirectionType direction,
    IOOptionBits options);  

/*getDirection


Obtains the direction for this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *getDirection)(
    void *self,
    IOHIDTransactionDirectionType *pDirection);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
pDirection
Pointer to a IOHIDTransactionDirectionType to obtain transaction direction.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

Direction constants are declared in IOHIDTransactionDirectionType.*/
IOReturn ( *getDirection)(
    void *self,
    IOHIDTransactionDirectionType *pDirection);  

/*addElement


Adds an element to this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *addElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
element
IOHIDElementRef referencing the element to be added to the transaction.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *addElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  

/*removeElement


Removes an element from this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *removeElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
element
IOHIDElementRef referencing the element to be removed from the transaction.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *removeElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  

/*containsElement


Checks whether an element has been added to this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *containsElement)(
    void *self,
    IOHIDElementRef element,
    Boolean *pValue,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
element
IOHIDElementRef referencing the element to be be found in the transaction.
pValue
Pointer to a Boolean to return whether or not the element was found in the transaction.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *containsElement)(
    void *self,
    IOHIDElementRef element,
    Boolean *pValue,
    IOOptionBits options);  

/*setValue


Sets the transaction value for an element in this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *setValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef value,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
element
IOHIDElementRef referencing the element of interest.
value
IOHIDValueRef referencing element value to be used in the transaction.
options
See IOHIDTransactionOption.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

This method is intended for use with transaction of direction kIOHIDTransactionDirectionTypeOutput. Use the kIOHIDTransactionOptionDefaultOutputValue option to set the default element value.*/
IOReturn ( *setValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef value,
    IOOptionBits options);  

/*getValue


Obtains the transaction value for an element in this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *getValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef *pValue,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
element
IOHIDElementRef referencing the element of interest.
pValue
Pointer to an IOHIDValueRef to return the element value of the transaction.
options
See IOHIDTransactionOption.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

Use the kIOHIDTransactionOptionDefaultOutputValue option to get the default element value.*/
IOReturn ( *getValue)(
    void *self,
    IOHIDElementRef element,
    IOHIDValueRef *pValue,
    IOOptionBits options);  

/*commit


Commits element transaction to an IOHIDDevice in this IOHIDDeviceTransactionInterface instance. 

IOReturn ( *commit)(
    void *self,
    uint32_t timeout,
    IOHIDCallback callback,
    void *context,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
timeout
Timeout in milliseconds for issuing the transaction.
callback
Callback of type IOHIDCallback to be used when transaction has been completed. If null, this method will behave synchronously.
context
Pointer to data to be passed to the callback.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

In regards to kIOHIDTransactionDirectionTypeOutput direction, default element values will be used if element values are not set. If neither are set, that element will be omitted from the commit. After a transaction is committed, transaction element values will be cleared and default values preserved. 
Note: It is possible for elements from different reports to be present in a given transaction causing a commit to transcend multiple reports. Keep this in mind when setting a timeout.*/
IOReturn ( *commit)(
    void *self,
    uint32_t timeout,
    IOHIDCallback callback,
    void *context,
    IOOptionBits options);  

/*clear


Clears element transaction values for an IOHIDDeviceTransactionInterface. 

IOReturn ( *clear)(
    void *self,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

In regards to kIOHIDTransactionDirectionTypeOutput direction, default element values will be preserved.*/

IOReturn ( *clear)(
    void *self,
    IOOptionBits options); 

};
typedef struct IOHIDDeviceTransactionInterface IOHIDDeviceTransactionInterface;

struct IOHIDDeviceQueueInterface {
    IUNKNOWN_C_GUTS;

/*getAsyncEventSource


Obtains the event source for this IOHIDDeviceQueueInterface instance. 

IOReturn ( *getAsyncEventSource)(
    void *self,
    CFTypeRef *pSource);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
pSource
Pointer to a CFType to return the run loop event source.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

The returned event source can be of type CFRunLoopSourceRef or CFRunLoopTimerRef.*/
IOReturn ( *getAsyncEventSource)(
    void *self,
    CFTypeRef *pSource);  

/*setDepth


Sets the depth for this IOHIDDeviceQueueInterface instance. 

IOReturn ( *setDepth)(
    void *self,
    uint32_t depth,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceTransactionInterface.
depth
The maximum number of elements in the queue before the oldest elements in the queue begin to be lost.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

Regardless of element value size, queue will guarantee n=depth elements will be serviced.*/
IOReturn ( *setDepth)(
    void *self,
    uint32_t depth,
    IOOptionBits options);  

/*getDepth


Obtains the queue depth for this IOHIDDeviceQueueInterface instance. 

IOReturn ( *getDepth)(
    void *self,
    uint32_t *pDepth);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
pDepth
Pointer to a uint32_t to obtain the number of elements that can be serviced by the queue.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *getDepth)(
    void *self,
    uint32_t *pDepth);  

/*addElement


Adds an element to this IOHIDDeviceQueueInterface instance. 

IOReturn ( *addElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
element
IOHIDElementRef referencing the element to be added to the queue.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *addElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  

/*removeElement


Removes an element from this IOHIDDeviceQueueInterface instance. 

IOReturn ( *removeElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
element
IOHIDElementRef referencing the element to be removed from the queue.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *removeElement)(
    void *self,
    IOHIDElementRef element,
    IOOptionBits options);  

/*containsElement


Determines whether an element has been added to this IOHIDDeviceQueueInterface instance. 

IOReturn ( *containsElement)(
    void *self,
    IOHIDElementRef element,
    Boolean *pValue,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
element
IOHIDElementRef referencing the element to be be found in the queue.
pValue
Pointer to a Boolean to return whether or not the element was found in the queue.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *containsElement)(
    void *self,
    IOHIDElementRef element,
    Boolean *pValue,
    IOOptionBits options); 

/*start


Starts element value delivery to the queue. 

IOReturn ( *start)(
    void *self,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *start)(
    void *self,
    IOOptionBits options);  

/*stop


Stops element value delivery to the queue. 

IOReturn ( *stop)(
    void *self,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful.*/
IOReturn ( *stop)(
    void *self,
    IOOptionBits options);  

/*setValueAvailableCallback


Sets callback to be used when the queue transitions to non-empty. 

IOReturn ( *setValueAvailableCallback)(
    void *self,
    IOHIDCallback callback,
    void *context);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
callback
Callback of type IOHIDCallback to be used when data is placed on the queue.
context
Pointer to data to be passed to the callback.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful or a kern_return_t if unsuccessful. 
Discussion 

In order to make use of asynchronous behavior, the event source obtained using getAsyncEventSource must be added to a run loop.*/
IOReturn ( *setValueAvailableCallback)(
    void *self,
    IOHIDCallback callback,
    void *context);  

/*copyNextValue


Dequeues a retained copy of an element value from the head of an IOHIDDeviceQueueInterface. 

IOReturn ( *copyNextValue)(
    void *self,
    IOHIDValueRef *pValue,
    uint32_t timeout,
    IOOptionBits options);  
Parameters
self
Pointer to the IOHIDDeviceQueueInterface.
pValue
Pointer to a IOHIDValueRef to return the value at the head of the queue.
timeout
Timeout in milliseconds before aborting an attempt to dequeue a value from the head of a queue.
options
Reserved for future use. Ignored in current implementation. Set to zero.
Return Value

Returns kIOReturnSuccess if successful, kIOReturnUnderrun if data is unavailble, or a kern_return_t if unsuccessful. 
Discussion 

Because the value is a retained copy, it is up to the caller to release the value using CFRelease. Use with setValueCallback to avoid polling the queue for data.*/
IOReturn ( *copyNextValue)(
    void *self,
    IOHIDValueRef *pValue,
    uint32_t timeout,
    IOOptionBits options);  

};
typedef struct IOHIDDeviceQueueInterface IOHIDDeviceQueueInterface;

__END_DECLS

#endif /* _IOKIT_HID_IOHIDDEVICEPLUGIN_H */
