
#ifndef _IOKIT_HID_IOHIDELEMENT_H
#define _IOKIT_HID_IOHIDELEMENT_H

#include <libkern/c++/OSArray.h>
#include <libkern/c++/OSData.h>
#include <IOKit/hid/IOHIDKeys.h>

#include <CoreFoundation/CoreFoundation.h>
#include <IOKit/hid/IOHIDBase.h>

#include <HYS/IOKit/hid/IOHIDElement.h>

/*IOHIDElementGetProperty


Returns the an element property. 

CF_EXPORT CFTypeRef IOHIDElementGetProperty(
    IOHIDElementRef element,
    CFStringRef key) ;  
Parameters
element
The element to be queried. If this parameter is not a valid IOHIDElementRef, the behavior is undefined.
key
The key to be used when querying the element.
Return Value

Returns the property. 
Discussion 

Property keys are prefixed by kIOHIDElement and declared in IOHIDKeys.h. 

Availability
Introduced in Mac OS X v10.5.*/
CF_EXPORT CFTypeRef IOHIDElementGetProperty(
    IOHIDElementRef element,
    CFStringRef key) ; 

/*IOHIDElementGetTypeID


Returns the type identifier of all IOHIDElement instances. 

CF_EXPORT CFTypeID IOHIDElementGetTypeID(
    void) ;  

Availability
Introduced in Mac OS X v10.5.*/
CF_EXPORT CFTypeID IOHIDElementGetTypeID(
    void) ;  


/*IOHIDElementGetReportID


Returns the report ID for the element. 

CF_EXPORT uint32_t IOHIDElementGetReportID(
    IOHIDElementRef element) ;  
Parameters
element
The element to be queried. If this parameter is not a valid IOHIDElementRef, the behavior is undefined.
Return Value

Returns the report ID. 
Discussion 

The report ID represents what report this particular element belongs to. 

Availability
Introduced in Mac OS X v10.5.*/
CF_EXPORT uint32_t IOHIDElementGetReportID(
    IOHIDElementRef element) ;  

/*IOHIDElementGetType


Retrieves the type for the element. 

CF_EXPORT IOHIDElementType IOHIDElementGetType(
    IOHIDElementRef element) ;  
Parameters
element
The element to be queried. If this parameter is not a valid IOHIDElementRef, the behavior is undefined.
Return Value

Returns the IOHIDElementType for the element. 

Availability
Introduced in Mac OS X v10.5.*/
CF_EXPORT IOHIDElementType IOHIDElementGetType(
    IOHIDElementRef element) ;  

/*IOHIDElementGetCookie


Retrieves the cookie for the element. 

CF_EXPORT IOHIDElementCookie IOHIDElementGetCookie(
    IOHIDElementRef element) ;  
Parameters
element
The element to be queried. If this parameter is not a valid IOHIDElementRef, the behavior is undefined.
Return Value

Returns the IOHIDElementCookie for the element. 
Discussion 

The IOHIDElementCookie represent a unique identifier for an element within a device. 

Availability
Introduced in Mac OS X v10.5.*/
CF_EXPORT IOHIDElementCookie IOHIDElementGetCookie(
    IOHIDElementRef element) ;  

#ifdef __cplusplus
class IOHIDElement: public OSObject,public IOHIDElement_HYS
{
    OSDeclareAbstractStructors( IOHIDElement )
 
public:

};
#endif //__cplusplus

#endif //_IOKIT_HID_IOHIDELEMENT_H

