
#ifndef __IOHIDDescriptorParser__
#define __IOHIDDescriptorParser__

#include <IOKit/IOTypes.h>
#include <IOKit/hidsystem/IOHIDUsageTables.h>

#include <HYS/IOKit/hidsystem/IOHIDDescriptorParser.h>

#ifdef __cplusplus
extern "C" {
#endif

/*HIDUsageAndPage


The HIDUsageAndPage data structure is used by HID clients when obtaining status of buttons to hold the usage page and usage of a button that is down. 

See Also:
HIDUsageAndPage
HIDUsageAndPagePtr
struct HIDUsageAndPage { 
    HIDUsage usage; 
    HIDUsage usagePage; 
};  
Discussion 

Clients use the HIDUSageAndPage structure with the HIDGetButtonsEx function to obtain both the usage page and usage identifiers of each button that is down.*/
struct HIDUsageAndPage { 
    HIDUsage usage; 
    HIDUsage usagePage; 
};  

/*HIDUsageAndPage


The HIDUsageAndPage data structure is used by HID clients when obtaining status of buttons to hold the usage page and usage of a button that is down. 

See Also:
HIDUsageAndPage
HIDUsageAndPagePtr
typedef struct HIDUsageAndPage HIDUsageAndPage, *HIDUsageAndPagePtr;  
Fields
usage
Specifies the usage identifier within the usage page specified by usagePage of a button that is down.
usagePage
Specifies the usage page identifier of a button that is down.
Discussion 

Clients use the HIDUSageAndPage structure with the HIDGetButtonsEx function to obtain both the usage page and usage identifiers of each button that is down.*/
typedef struct HIDUsageAndPage HIDUsageAndPage, *HIDUsageAndPagePtr;  

/*HIDCaps


The HIDCaps data structure is used by HID clients to hold the capabilities of a HID device. 

See Also:
HIDCaps
HIDCapsPtr
struct HIDCaps { 
    HIDUsage usage; 
    HIDUsage usagePage; 
    ByteCount inputReportByteLength; 
    ByteCount outputReportByteLength; 
    ByteCount featureReportByteLength; 
    UInt32 numberCollectionNodes; 
    UInt32 numberInputButtonCaps; 
    UInt32 numberInputValueCaps; 
    UInt32 numberOutputButtonCaps; 
    UInt32 numberOutputValueCaps; 
    UInt32 numberFeatureButtonCaps; 
    UInt32 numberFeatureValueCaps; 
};  
Discussion 

This structure holds the parsed capabilities and data maximums returned for a device by the HIDGetCaps function.*/
struct HIDCaps { 
    HIDUsage usage; 
    HIDUsage usagePage; 
    ByteCount inputReportByteLength; 
    ByteCount outputReportByteLength; 
    ByteCount featureReportByteLength; 
    UInt32 numberCollectionNodes; 
    UInt32 numberInputButtonCaps; 
    UInt32 numberInputValueCaps; 
    UInt32 numberOutputButtonCaps; 
    UInt32 numberOutputValueCaps; 
    UInt32 numberFeatureButtonCaps; 
    UInt32 numberFeatureValueCaps; 
};  

/*HIDCaps


The HIDCaps data structure is used by HID clients to hold the capabilities of a HID device. 

See Also:
HIDCaps
HIDCapsPtr
typedef struct HIDCaps HIDCaps, * HIDCapsPtr;  
Fields
usage
Specifies the specific class of functionality that this device provides. This value is dependent and specific to the value provided in the usagePage field. For example, a keyboard could have a usagePage of kHIDUsagePage_Generic and a usage of kHIDUsage_Generic_Keyboard.
usagePage
Specifies the usage page identifier for this top level collection.
inputReportByteLength
Specifies the maximum length, in bytes, of an input report for this device, including the report ID which is unilaterally prepended to the device data.
outputReportByteLength
Specifies the maximum length, in bytes, of an output report for this device, including the report ID which is unilaterally prepended to the device data.
featureReportByteLength
Specifies the maximum length, in bytes, of a feature report for this device, including the report ID which is unilaterally prepended to the device data.
numberCollectionNodes
Specifies the number of HIDCollectionNode structures that are returned for this top level collection by the HIDGetConnectionNodes function.
numberInputButtonCaps
Specifies the number of input buttons.
numberInputValueCaps
Specifies the number of input values.
numberOutputButtonCaps
Specifies the number of output buttons.
numberOutputValueCaps
Specifies the number of output values
numberFeatureButtonCaps
Specifies the number of feature buttons.
numberFeatureValueCaps
Specifies the number of feature values.
Discussion 

This structure holds the parsed capabilities and data maximums returned for a device by the HIDGetCaps function.*/
typedef struct HIDCaps HIDCaps, * HIDCapsPtr;  

//function

/*HIDOpenReportDescriptor


The HIDOpenReportDescriptor function allocates the memory the parser needs to handle the given report descriptor, and then parses the report descriptor. 

extern OSStatus HIDOpenReportDescriptor (
    void *hidReportDescriptor, 
    ByteCount descriptorLength, 
    HIDPreparsedDataRef *preparsedDataRef, 
    UInt32 flags);  
Parameters
hidReportDescriptor
Contains a pointer to the actual HID report descriptor from the USB device's firmware
descriptorLength
The length of the HID report descriptor
preparsedDataRef
Preparsed data reference to be used for subsequent function calls
flags
Flags for this runction are kHIDFlag_StrictErrorChecking = 0x00000001
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success. 
Discussion 

When the parsed information is no longer needed, clients should call the HIDCloseReportDescriptor function.*/
extern OSStatus HIDOpenReportDescriptor (
    void *hidReportDescriptor, 
    ByteCount descriptorLength, 
    HIDPreparsedDataRef *preparsedDataRef, 
    UInt32 flags);  

/*HIDCloseReportDescriptor


Disposes of the memory the parser allocated for the HIDOpenReportDescriptor function. 

extern OSStatus HIDCloseReportDescriptor (
    HIDPreparsedDataRef preparsedDataRef);  
Parameters
hidReportDescriptor
Contains a pointer to the actual HID report descriptor from the USB device's firmware
preparsedDataRef
Preparsed data reference for the report that is returned by the HIDOpenReportDescriptor function. After making a call to the HIDCloseReportDescriptor function, the preparsedDataRef is invalid and should not be used.
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success.*/
extern OSStatus HIDCloseReportDescriptor (
    HIDPreparsedDataRef preparsedDataRef); 

/*HIDGetCapabilities


Returns the capabilities of a HID device based on the given preparsed data. 

extern OSStatus HIDGetCapabilities (
    HIDPreparsedDataRef preparsedDataRef, 
    HIDCapabilitiesPtr capabilities);  
Parameters
preparsedDataRef
Preparsed data reference for the report that is retuned by the HIDOpenReportDescriptor function
capabilities
Points to a caller allocated buffer, that upon return contains the parsed capability information for this HID device.
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success.*/
extern OSStatus HIDGetCapabilities (
    HIDPreparsedDataRef preparsedDataRef, 
    HIDCapabilitiesPtr capabilities);  

/*HIDGetButtonCapabilities


Returns the button capabilities structures for a HID device based on the given preparsed data. 

extern OSStatus HIDGetButtonCapabilities (
    HIDReportType reportType, 
    HIDButtonCapabilitiesPtr buttonCaps, 
    UInt32 *buttonCapsSize, 
    HIDPreparsedDataRef preparsedDataRef);  
Parameters
reportType
Specifies the type of report for which to retrieve the scaled value. This parameter must be one of the following: kHIDInputReport, kHIDOutputReport, or kHIDFeatureReport
buttonCaps
Points to a caller-allocated buffer that will contain, on return, an array of HIDButtonCapabilities structures. The structures contain information for all buttons that meet the search criteria
buttonCapsSize
Contains the size of the buttonCaps array passed in to the function and is set to the number of elements actually placed in the array after the call completes.
preparsedDataRef
Preparsed data reference for the report that is retuned by the HIDOpenReportDescriptor function
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success.*/
extern OSStatus HIDGetButtonCapabilities (
    HIDReportType reportType, 
    HIDButtonCapabilitiesPtr buttonCaps, 
    UInt32 *buttonCapsSize, 
    HIDPreparsedDataRef preparsedDataRef);  

/*HIDGetValueCapabilities


The HIDGetValueCapabilities function retrieves the capabilities for all values for a specified top level collection. 

extern OSStatus HIDGetValueCapabilities (
    HIDReportType reportType, 
    HIDValueCapabilitiesPtr valueCaps, 
    UInt32 *valueCapsSize, 
    HIDPreparsedDataRef preparsedDataRef);  
Parameters
reportType
Specifies the type of report for which to retrieve the value capabilities. This parameter must be one of the following: kHIDInputReport, kHIDOutputReport, or kHIDFeatureReport.
valueCaps
On return, points to a caller-allocated buffer that contains an array of HIDValueCapabilities structures containing information for all values in the top level collection.
valueCapsSize
On input, specifies the size in array elements of the buffer provided in the valueCaps parameter. On output, this parameter is set to the actual number of elements that were returned in the buffer provided in the valueCaps parameter, if the function completed without error. The correct length necessary to retrieve the value capabilities can be found in the capability data returned for the device by the HIDGetCapabilities function.
preparsedDataRef
Preparsed data reference for the report that is retuned by the HIDOpenReportDescriptor function
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success. 
Discussion 

The HIDGetValueCapabilities function retrieves the capability data for all values in a top level collection without regard for the usage, usage page or collection of the value. To retrieve value capabilities for a specific usage, usage page or collection, use the HIDGetSpecificValueCapabilities function.*/
extern OSStatus HIDGetValueCapabilities (
    HIDReportType reportType, 
    HIDValueCapabilitiesPtr valueCaps, 
    UInt32 *valueCapsSize, 
    HIDPreparsedDataRef preparsedDataRef);  

#ifdef __cplusplus
}
#endif


#endif//__IOHIDDescriptorParser__
