
#ifndef _IOKIT_IOI2CINTERFACE_H
#define _IOKIT_IOI2CINTERFACE_H


#include <IOKit/IOService.h>//add IOService
#include <HYS/IOKit/i2c/IOI2CInterface.h>

/*IOI2CRequest


A structure defining an I2C bus transaction. 

struct IOI2CRequest { 
    UInt64 __reservedA; 
    IOReturn result; 
    IOI2CRequestCompletion completion; 
    IOOptionBits commFlags; 
    uint64_t minReplyDelay; 
    UInt8 sendAddress; 
    UInt8 sendSubAddress; 
    UInt8 __reservedB[2]; 
    IOOptionBits sendTransactionType; 
    vm_address_t sendBuffer; 
    IOByteCount sendBytes; 
    UInt8 replyAddress; 
    UInt8 replySubAddress; 
    UInt8 __reservedC[2]; 
    IOOptionBits replyTransactionType; 
    vm_address_t replyBuffer; 
    IOByteCount replyBytes; 
    UInt32 __reservedD[16]; 
};  
Fields
__reservedA
Set to zero.
result
The result of the transaction. Common errors are kIOReturnNoDevice if there is no device responding at the given address, kIOReturnUnsupportedMode if the type of transaction is unsupported on the requested bus.
completion
A completion routine to be executed when the request completes. If NULL is passed, the request is synchronous, otherwise it may execute asynchronously.
commFlags
Flags that modify the I2C transaction type. The following flags are defined:
kIOI2CUseSubAddressCommFlag Transaction includes a subaddress.
minReplyDelay
Minimum delay as absolute time between send and reply transactions.
sendAddress
I2C address to write.
sendSubAddress
I2C subaddress to write.
__reservedB
Set to zero.
sendTransactionType
The following types of transaction are defined for the send part of the request:
kIOI2CNoTransactionType No send transaction to perform. 
kIOI2CSimpleTransactionType Simple I2C message. 
kIOI2CCombinedTransactionType Combined format I2C R/~W transaction. 
sendBuffer
Pointer to the send buffer.
sendBytes
Number of bytes to send. Set to actual bytes sent on completion of the request.
replyAddress
I2C Address from which to read.
replySubAddress
I2C Address from which to read.
__reservedC
Set to zero.
replyTransactionType
The following types of transaction are defined for the reply part of the request:
kIOI2CNoTransactionType No reply transaction to perform. 
kIOI2CSimpleTransactionType Simple I2C message. 
kIOI2CDDCciReplyTransactionType DDC/ci message (with embedded length). See VESA DDC/ci specification. 
kIOI2CCombinedTransactionType Combined format I2C R/~W transaction. 
replyBuffer
Pointer to the reply buffer.
replyBytes
Max bytes to reply (size of replyBuffer). Set to actual bytes received on completion of the request.
__reservedD
Set to zero.
Discussion 

This structure is used to request an I2C transaction consisting of a send (write) to and reply (read) from a device, either of which is optional, to be carried out atomically on an I2C bus.*/
struct IOI2CRequest { 
    UInt64 __reservedA; 
    IOReturn result; 
    IOI2CRequestCompletion completion; 
    IOOptionBits commFlags; 
    uint64_t minReplyDelay; 
    UInt8 sendAddress; 
    UInt8 sendSubAddress; 
    UInt8 __reservedB[2]; 
    IOOptionBits sendTransactionType; 
    vm_address_t sendBuffer; 
    IOByteCount sendBytes; 
    UInt8 replyAddress; 
    UInt8 replySubAddress; 
    UInt8 __reservedC[2]; 
    IOOptionBits replyTransactionType; 
    vm_address_t replyBuffer; 
    IOByteCount replyBytes; 
    UInt32 __reservedD[16]; 
};  

/*IOI2CBusTiming


A structure defining low level timing for an I2C bus. 

struct IOI2CBusTiming { 
    AbsoluteTime bitTimeout; 
    AbsoluteTime byteTimeout; 
    AbsoluteTime acknowledgeTimeout; 
    AbsoluteTime startTimeout; 
    AbsoluteTime holdTime; 
    AbsoluteTime riseFallTime; 
    UInt32 __reservedA[8]; 
};  
Fields
bitTimeout
Maximum time a slave can delay (by pulling the clock line low) a single bit response.
byteTimeout
Maximum time a slave can delay (by pulling the clock line low) the first bit of a byte response.
acknowledgeTimeout
Maximum time to wait for a slave to respond with an ACK after writing a byte.
startTimeout
Maximum time to wait for a slave to respond after a start signal.
riseFallTime
Time to wait after any change in output signal.
__reservedA
Set to zero.
Discussion 

This structure is used to specify timeouts and pulse widths for an I2C bus implementation.*/
struct IOI2CBusTiming { 
    AbsoluteTime bitTimeout; 
    AbsoluteTime byteTimeout; 
    AbsoluteTime acknowledgeTimeout; 
    AbsoluteTime startTimeout; 
    AbsoluteTime holdTime; 
    AbsoluteTime riseFallTime; 
    UInt32 __reservedA[8]; 
}; 
typedef struct IOI2CBusTiming IOI2CBusTiming;

//#ifndef KERNEL


//#else
#ifdef __cplusplus

class IOI2CInterface : public IOService,public IOI2CInterface_HYS
{
    OSDeclareDefaultStructors(IOI2CInterface)

protected:

public:

IOI2CInterface_registerI2C
IOI2CInterface_newUserClient

};

#endif//__cplusplus

//#endif /* KERNEL */

#endif //_IOKIT_IOI2CINTERFACE_H

