
#ifndef _IOETHERNETINTERFACE_H
#define _IOETHERNETINTERFACE_H

//#if defined(KERNEL) && defined(__cplusplus)

#include <IOKit/network/IONetworkInterface.h>
#include <IOKit/network/IOEthernetController.h>
#include <IOKit/network/IOEthernetStats.h>

#include <HYS/IOKit/network/IOEthernetInterface.h>

/*kIOActivePacketFilters


A property of IOEthernetInterface objects.

#define kIOActivePacketFilters "IOActivePacketFilters" 
Discussion 

The kIOActivePacketFilters property has an OSDictionary value that describes the current set of packet filters that have been successfully activated. Each entry in the dictionary is a key/value pair consisting of the filter group name, and an OSNumber describing the set of active filters for that group. Entries in this dictionary will mirror those in kIORequiredPacketFilters if the controller has reported success for all filter change requests from the IOEthernetInterface object.*/
#define kIOActivePacketFilters "IOActivePacketFilters" 

/*kIORequiredPacketFilters


A property of IOEthernetInterface objects.

#define kIORequiredPacketFilters "IORequiredPacketFilters" 
Discussion 

The kIORequiredPacketFilters property has an OSDictionary value that describes the current set of required packet filters. Each entry in the dictionary is a key/value pair consisting of the filter group name, and an OSNumber describing the set of required filters for that group.*/
#define kIORequiredPacketFilters "IORequiredPacketFilters" 

/*kIOMulticastAddressList


A property of IOEthernetInterface objects.

#define kIOMulticastAddressList "IOMulticastAddressList" 
Discussion 

The kIOMulticastAddressList property is an OSData object that describes the list of multicast addresses that are being used by the controller to match against the destination address of an incoming frame.*/
#define kIOMulticastAddressList "IOMulticastAddressList" 

/* kIOEthernetInterfaceClass

The name of the IOEthernetInterface class.

#define kIOEthernetInterfaceClass "IOEthernetInterface"  */
#define kIOEthernetInterfaceClass "IOEthernetInterface" 

#ifdef __cplusplus
class IOEthernetInterface : public IONetworkInterface,public IOEthernetInterface_HYS
{
    OSDeclareDefaultStructors( IOEthernetInterface )



private:
IOEthernetInterface_ExpansionData

/*_reserved


See Also:
reserved
private

ExpansionData * _reserved; 
Discussion 

Reserved for future use. (Internal use only)*/
ExpansionData * _reserved; 

protected:

/*performCommand


Handles an ioctl command sent to the Ethernet interface. 

protected

virtual SInt32 performCommand(
    IONetworkController *controller, 
    UInt32 cmd, 
    void *arg0, 
    void *arg1); 
Parameters
controller
The controller object.
cmd
The ioctl command code.
arg0
Command argument 0. Generally a pointer to an ifnet structure associated with the interface.
arg1
Command argument 1.
Return Value

Returns a BSD return value defined in bsd/sys/errno.h. 
Discussion 

This method handles socket ioctl commands sent to the Ethernet interface from DLIL. Commands recognized and processed by this method are SIOCSIFADDR, SIOCSIFFLAGS, SIOCADDMULTI, and SIOCDELMULTI. Other commands are passed to the superclass.(*/
virtual SInt32 performCommand(
    IONetworkController *controller, 
    UInt32 cmd, 
    void *arg0, 
    void *arg1); 

/*controllerWillClose


A notification that the interface will close the network controller. 

protected

virtual void controllerWillClose(
    IONetworkController *controller); 
Parameters
controller
The controller that is about to be closed.
Discussion 

This method will simply call super to propagate the method call. This method is called with the arbitration lock held.*/
virtual void controllerWillClose(
    IONetworkController *controller); 

/*controllerDidOpen


A notification that the interface has opened the network controller. 

protected

virtual bool controllerDidOpen(
    IONetworkController *controller); 
Parameters
controller
The controller object that was opened.
Return Value

Returns true on success, false otherwise. Returning false will cause the controller to be closed, and any pending client opens to be rejected. 
Discussion 

This method will be called by IONetworkInterface after a network controller has accepted an open from this interface object. IOEthernetInterface will first call the implementation in its superclass, then inspect the controller through properties published in the registry. This method is called with the arbitration lock held.*/
virtual bool controllerDidOpen(
    IONetworkController *controller); 

/*free


Frees the IOEthernetInterface instance. 

protected

virtual void free(); 
Discussion 

The memory allocated for the arpcom structure is released, followed by a call to super::free().*/
virtual void free(); 

/*controllerWillChangePowerState


Handles a notification that the network controller servicing this interface object is about to transition to a new power state. 

protected

virtual IOReturn controllerWillChangePowerState( 
    IONetworkController *controller, 
    IOPMPowerFlags flags, 
    UInt32 stateNumber, 
    IOService *policyMaker); 
Parameters
controller
The network controller object.
flags
Flags that describe the capability of the controller in the new power state.
stateNumber
An index to a state in the network controller's power state array that the controller is switching to.
policyMaker
A reference to the network controller's policy-maker, and is also the originator of this notification.
Return Value

Always returns kIOReturnSuccess. 
Discussion 

If the controller is about to transition to an unusable state, and it is currently enabled, then the disable() method on the controller is called.*/
virtual IOReturn controllerWillChangePowerState( 
    IONetworkController *controller, 
    IOPMPowerFlags flags, 
    UInt32 stateNumber, 
    IOService *policyMaker); 

/*controllerDidChangePowerState


Handles a notification that the network controller servicing this interface object has transitioned to a new power state. 

protected

virtual IOReturn controllerDidChangePowerState( 
    IONetworkController *controller, 
    IOPMPowerFlags flags, 
    UInt32 stateNumber, 
    IOService *policyMaker); 
Parameters
controller
The network controller object.
flags
Flags that describe the capability of the controller in the new power state.
stateNumber
An index to a state in the network controller's power state array that the controller has switched to.
policyMaker
A reference to the network controller's policy-maker, and is also the originator of this notification.
Return Value

Always returns kIOReturnSuccess. 
Discussion 

If the controller did transition to a usable state, and it was previously disabled due to a previous power change, then it is re-enabled.*/
virtual IOReturn controllerDidChangePowerState( 
    IONetworkController *controller, 
    IOPMPowerFlags flags, 
    UInt32 stateNumber, 
    IOService *policyMaker); 

public:

IOEthernetInterface_setFilters
IOEthernetInterface_getFilters
IOEthernetInterface_initIfnetParams
IOEthernetInterface_performGatedCommand
IOEthernetInterface_syncSIOCSIFADDR
IOEthernetInterface_syncSIOCSIFFLAGS
IOEthernetInterface_syncSIOCADDMULTI
IOEthernetInterface_syncSIOCDELMULTI
IOEthernetInterface_syncSIOCSIFMTU
IOEthernetInterface_syncSIOCGIFDEVMTU
IOEthernetInterface_syncSIOCSIFLLADDR
IOEthernetInterface_enableController
IOEthernetInterface_disableFilter
IOEthernetInterface_enableFilter
IOEthernetInterface_setupMulticastFilter
IOEthernetInterface_enableFilter_Wrapper
IOEthernetInterface_willTerminate
IOEthernetInterface_attachToDataLinkLayer
IOEthernetInterface__fixupVlanPacket
IOEthernetInterface_feedPacketInputTap
IOEthernetInterface_feedPacketOutputTap

/*setProperties


Handles a request to set Ethernet interface properties from kernel or non-kernel clients. 

public

virtual IOReturn setProperties(
    OSObject *properties ); 
Parameters
properties
An OSDictionary containing a collection of properties.
Return Value

Returns kIOReturnUnsupported if the interface did not recognize any of the properties provided. Otherwise, the return code will be kIOReturnSuccess to indicate no errors, or an IOReturn error code to indicate that an error occurred while handling one of the properties. 
Discussion 

For non-kernel clients, the preferred access mechanism is through a user client connection.*/
virtual IOReturn setProperties(
    OSObject *properties ); 

/*init


Initializes an IOEthernetInterface instance. 

public

virtual bool init(
    IONetworkController *controller ); 
Parameters
controller
A network controller object that will service the interface object being initialized.
Return Value

Returns true on success, false otherwise. 
Discussion 

Instance variables are initialized, and an arpcom structure is allocated.*/
virtual bool init(
    IONetworkController *controller ); 

/*getNamePrefix


Returns a string containing the prefix to use when creating a BSD name for this interface. 

public

virtual const char * getNamePrefix() const; 
Return Value

Returns a pointer to a constant C string "en". Therefore, Ethernet interfaces will be registered with BSD as en0, en1, etc. 
Discussion 

The BSD name for each interface object is created by concatenating a string returned by this method, with an unique unit number assigned by IONetworkStack.*/
virtual const char * getNamePrefix() const; 

};
#endif //__cplusplus
//#endif //defined(KERNEL) && defined(__cplusplus) 

#endif //_IOETHERNETINTERFACE_H
