
#ifndef _IOGATEDOUTPUTQUEUE_H
#define _IOGATEDOUTPUTQUEUE_H

#include <IOKit/IOWorkLoop.h>
#include <IOKit/IOCommandGate.h>
#include <IOKit/IOInterruptEventSource.h>
#include <IOKit/network/IOBasicOutputQueue.h>

#include <HYS/IOKit/network/IOGatedOutputQueue.h>
class IOGatedOutputQueue : public IOBasicOutputQueue,public IOGatedOutputQueue_HYS
{
    OSDeclareDefaultStructors( IOGatedOutputQueue )

private:
protected:

/*scheduleServiceThread


Overrides the method inherited from IOOutputQueue. 

protected

virtual bool scheduleServiceThread(
    void *param); 
Return Value

Returns true if a thread was successfully scheduled to service the queue.*/
virtual bool scheduleServiceThread(
    void *param); 

/*output


Transfers all packets in the mbuf queue to the target. 

protected

virtual void output(
    IOMbufQueue *queue,
    UInt32 *state); 
Parameters
queue
A queue of output packets.
state
Return a state bit defined by IOBasicOutputQueue that declares the new state of the queue following this method call. A kStateStalled is returned if the queue should stall, otherwise 0 is returned.*/
virtual void output(
    IOMbufQueue *queue,
    UInt32 *state); 

/*free


Frees the IOGatedOutputQueue object. 

protected

virtual void free(); 
Discussion 

Release allocated resources, then call super::free().*/
virtual void free(); 

public:
IOGatedOutputQueue_restartDeferredOutput
IOGatedOutputQueue_gatedOutput

/*withTarget(OSObject *, IOOutputAction, IOWorkLoop *, UInt32)


Factory method that constructs and initializes an IOGatedOutputQueue object. 

public

static IOGatedOutputQueue * withTarget(
    OSObject *target, 
    IOOutputAction action, 
    IOWorkLoop *workloop, 
    UInt32 capacity = 0); 
Parameters
target
The object that will handle packets removed from the queue.
action
The function that will handle packets removed from the queue.
workloop
A workloop object. An IOCommandGate object is created and added to this workloop as an event source.
capacity
The initial capacity of the output queue.
Return Value

Returns an IOGatedOutputQueue object on success, or 0 otherwise.*/
static IOGatedOutputQueue * withTarget(
    OSObject *target, 
    IOOutputAction action, 
    IOWorkLoop *workloop, 
    UInt32 capacity = 0); 

/*init


Initializes an IOGatedOutputQueue object. 

public

virtual bool init(
    OSObject *target, 
    IOOutputAction action, 
    IOWorkLoop *workloop, 
    UInt32 capacity = 0); 
Parameters
target
The object that will handle packets removed from the queue, and is usually a subclass of IONetworkController.
action
The function that will handle packets removed from the queue.
workloop
A workloop object. An IOCommandGate object is created and added to this workloop as an event source.
capacity
The initial capacity of the output queue.
Return Value

Returns true if initialized successfully, false otherwise.*/

virtual bool init(
    OSObject *target, 
    IOOutputAction action, 
    IOWorkLoop *workloop, 
    UInt32 capacity = 0); 

/*withTarget(IONetworkController *, IOWorkLoop *, UInt32)


Factory method that constructs and initializes an IOGatedOutputQueue object. 

public

static IOGatedOutputQueue * withTarget(
    IONetworkController *target, 
    IOWorkLoop *workloop, 
    UInt32 capacity = 0); 
Parameters
target
An IONetworkController object that will handle packets removed from the queue.
workloop
A workloop object. An IOCommandGate object is created and added to this workloop as an event source.
capacity
The initial capacity of the output queue.
Return Value

Returns an IOGatedOutputQueue object on success, or 0 otherwise.*/
static IOGatedOutputQueue * withTarget(
    IONetworkController *target, 
    IOWorkLoop *workloop, 
    UInt32 capacity = 0); 

};


#endif //_IOGATEDOUTPUTQUEUE_H
