

#ifndef _IOKIT_NETWORK_IOMBUFMEMORYCURSOR_H
#define _IOKIT_NETWORK_IOMBUFMEMORYCURSOR_H

#include <IOKit/IOMemoryCursor.h>
#include <HYS/IOKit/network/IOMbufMemoryCursor.h>

class IOMbufMemoryCursor : public IOMemoryCursor,public IOMbufMemoryCursor_HYS
{
    OSDeclareDefaultStructors(IOMbufMemoryCursor)

protected:

public:
IOMbufMemoryCursor_initWithSpecification_OutputSegmentFunc

/*getAndResetCoalesceCount


Returns a count of the total number of mbuf chains coalesced by genPhysicalSegments(). 

public

UInt32 getAndResetCoalesceCount(); 
Return Value

Returns the coalesce count. 
Discussion 

This method returns a count of the total number of mbuf chains coalesced by genPhysicalSegments(). The counter is then reset to 0.*/
UInt32 getAndResetCoalesceCount(); 

/*genPhysicalSegments


Generates a physical scatter/gather list given a mbuf packet. 

public

virtual UInt32 genPhysicalSegments(
    mbuf_t packet,
    void *vector, 
    UInt32 maxSegs,
    bool doCoalesce); 
Parameters
packet
The mbuf packet.
vector
Void pointer to base of output physical scatter/gather list. Always passed directly onto the OutputSegmentFunc without interpretation by the cursor.
maxSegs
Maximum number of segments that can be written to segments array.
doCoalesce
Set to true to perform coalescing when the required number of segments exceeds the specified limit, otherwise abort and return 0.
Return Value

Returns the number of segments that were filled in, or 0 if an error occurred. 
Discussion 

Generates a list of physical segments from the given mbuf.*/
virtual UInt32 genPhysicalSegments(
    mbuf_t packet,
    void *vector, 
    UInt32 maxSegs,
    bool doCoalesce); 

/*initWithSpecification


Primary initializer for the IOMbufMemoryCursor class. 

public

virtual bool initWithSpecification(
    IOMemoryCursor::SegmentFunction outSeg, 
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 
Parameters
outSeg
Function to call to output one physical segment.
maxSegmentSize
Maximum allowable size for one segment.
maxNumSegments
Maximum number of segments.
Return Value

Returns true if the inherited classes and this instance initialized successfully.*/
virtual bool initWithSpecification(
    IOMemoryCursor::SegmentFunction outSeg, 
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 

};


class IOMbufNaturalMemoryCursor : public IOMbufMemoryCursor
{
    OSDeclareDefaultStructors(IOMbufNaturalMemoryCursor)

public:

/*getPhysicalSegmentsWithCoalesce


Generates a cpu natural physical scatter/gather list from a given mbuf. 

public

UInt32 getPhysicalSegmentsWithCoalesce(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 
Parameters
packet
The mbuf packet.
vector
Pointer to an array of IOPhysicalSegments for the output physical scatter/gather list.
numVectorSegments
Maximum number of IOPhysicalSegments accepted.
Return Value

Returns the number of segments that were filled in, or 0 if an error occurred. 
Discussion 

Generate a cpu natural physical scatter/gather list from a given mbuf. Coalesce mbuf chain when the number of segments in the scatter/gather list exceeds numVectorSegments.*/
UInt32 getPhysicalSegmentsWithCoalesce(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 

/*getPhysicalSegments


Generates a cpu natural physical scatter/gather list from a given mbuf. 

public

UInt32 getPhysicalSegments(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 
Parameters
packet
The mbuf packet.
vector
Pointer to an array of IOPhysicalSegments for the output physical scatter/gather list.
numVectorSegments
Maximum number of IOPhysicalSegments accepted.
Return Value

Returns the number of segments that were filled in, or 0 if an error occurred.*/

UInt32 getPhysicalSegments(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 

/*withSpecification


Factory function that creates and initializes an IOMbufNaturalMemoryCursor in one operation. 

public

static IOMbufNaturalMemoryCursor * withSpecification(
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 
Parameters
maxSegmentSize
Maximum allowable size for one segment.
maxNumSegments
Maximum number of segments.
Return Value

Returns a new mbuf cursor if successfully created and initialized, 0 otherwise. 
Discussion 

See also IOMbufMemoryCursor::initWithSpecification.*/
static IOMbufNaturalMemoryCursor * withSpecification(
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 
};


class IOMbufBigMemoryCursor : public IOMbufMemoryCursor
{
    OSDeclareDefaultStructors(IOMbufBigMemoryCursor)

public:

/*getPhysicalSegmentsWithCoalesce


Generates a big endian physical scatter/gather list from a given mbuf. 

public

UInt32 getPhysicalSegmentsWithCoalesce(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 
Parameters
packet
The mbuf packet.
vector
Pointer to an array of IOPhysicalSegments for the output physical scatter/gather list.
numVectorSegments
Maximum number of IOPhysicalSegments accepted.
Return Value

Returns the number of segments that were filled in, or 0 if an error occurred. 
Discussion 

Generate a big endian physical scatter/gather list from a given mbuf. Coalesce mbuf chain when the number of segments in the scatter/gather list exceeds numVectorSegments.*/
UInt32 getPhysicalSegmentsWithCoalesce(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 

/*getPhysicalSegments


Generates a big endian physical scatter/gather list from a given mbuf. 

public

UInt32 getPhysicalSegments(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 
Parameters
packet
The mbuf packet.
vector
Pointer to an array of IOPhysicalSegments for the output physical scatter/gather list.
numVectorSegments
Maximum number of IOPhysicalSegments accepted.
Return Value

Returns the number of segments that were filled in, or 0 if an error occurred.*/
UInt32 getPhysicalSegments(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 


/*withSpecification


Factory function that creates and initializes an IOMbufBigMemoryCursor in one operation. 

public

static IOMbufBigMemoryCursor * withSpecification(
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 
Parameters
maxSegmentSize
Maximum allowable size for one segment.
maxNumSegments
Maximum number of segments.
Return Value

Returns a new mbuf cursor if successfully created and initialized, 0 otherwise. 
Discussion 

See also IOMbufMemoryCursor::initWithSpecification.*/
static IOMbufBigMemoryCursor * withSpecification(
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 

};

class IOMbufLittleMemoryCursor : public IOMbufMemoryCursor
{
    OSDeclareDefaultStructors(IOMbufLittleMemoryCursor)

public:

/*withSpecification


Factory function that creates and initializes an IOMbufLittleMemoryCursor in one operation. 

public

static IOMbufLittleMemoryCursor * withSpecification(
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 
Parameters
maxSegmentSize
Maximum allowable size for one segment.
maxNumSegments
Maximum number of segments.
Return Value

Returns a new mbuf cursor if successfully created and initialized, 0 otherwise. 
Discussion 

See also IOMbufMemoryCursor::initWithSpecification.*/
static IOMbufLittleMemoryCursor * withSpecification(
    UInt32 maxSegmentSize, 
    UInt32 maxNumSegments); 

/*getPhysicalSegmentsWithCoalesce


Generates a little endian physical scatter/gather list from a given mbuf. 

public

UInt32 getPhysicalSegmentsWithCoalesce(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 
Parameters
packet
The mbuf packet.
vector
Pointer to an array of IOPhysicalSegments for the output physical scatter/gather list.
numVectorSegments
Maximum number of IOPhysicalSegments accepted.
Return Value

Returns the number of segments that were filled in, or 0 if an error occurred. 
Discussion 

Generate a little endian physical scatter/gather list from a given mbuf. Coalesce mbuf chain when the number of segments in the scatter/gather list exceeds numVectorSegments.*/
UInt32 getPhysicalSegmentsWithCoalesce(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 

/*getPhysicalSegments


Generates a little endian physical scatter/gather list from a given mbuf. 

public

UInt32 getPhysicalSegments(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 
Parameters
packet
The mbuf packet.
vector
Pointer to an array of IOPhysicalSegments for the output physical scatter/gather list.
numVectorSegments
Maximum number of IOPhysicalSegments accepted.
Return Value

Returns the number of segments that were filled in, or 0 if an error occurred.*/

UInt32 getPhysicalSegments(
    mbuf_t packet, 
    struct IOMemoryCursor::PhysicalSegment *vector, 
    UInt32 numVectorSegments = 0); 

};

//#ifdef __ppc__

struct IODBDMADescriptor;



class IOMbufDBDMAMemoryCursor : public IOMbufMemoryCursor
{
    OSDeclareDefaultStructors(IOMbufDBDMAMemoryCursor)

public:

};

//#endif //__ppc__ 

#endif

