
#ifndef _IONETWORKDATA_H
#define _IONETWORKDATA_H

//#ifdef KERNEL

/*NetworkDataBufferTypes


The types of data buffers that can be managed by an IONetworkData object. 

enum { 
    kIONetworkDataBufferTypeInternal = 0, 
    kIONetworkDataBufferTypeExternal, 
    kIONetworkDataBufferTypeNone 
};  
Constants
kIONetworkDataBufferTypeInternal
An internal data buffer allocated by the init() method.
kIONetworkDataBufferTypeExternal
An external (persistent) data buffer.
kIONetworkDataBufferTypeNone
No data buffer. The only useful action perfomed by an IONetworkData object with this buffer type is to call the access notification handler.*/
enum { 
    kIONetworkDataBufferTypeInternal = 0, 
    kIONetworkDataBufferTypeExternal, 
    kIONetworkDataBufferTypeNone 
};  

/*kIONetworkDataSize


A property of IONetworkData objects.

#define kIONetworkDataSize "Size" 
Discussion 

The kIONetworkDataSize property is an OSNumber that describes the size of the data buffer of an IONetworkData object.*/
#define kIONetworkDataSize "Size" 

/*kIONetworkDataAccessTypes


A property of IONetworkData objects.

#define kIONetworkDataAccessTypes "Access Types" 
Discussion 

The kIONetworkDataAccessTypes property is an OSNumber that describes the supported access types of an IONetworkData object.*/

#define kIONetworkDataAccessTypes "Access Types" 

/*kIONetworkDataBytes


A property of IONetworkData objects.

#define kIONetworkDataBytes "Data" 
Discussion 

The kIONetworkDataBytes property is an OSData that describes the data buffer of an IONetworkData object. This property is present only if kIONetworkDataAccessTypeSerialize access is supported.*/
#define kIONetworkDataBytes "Data" 

/*kIONetworkDataBasicAccessTypes


#define kIONetworkDataBasicAccessTypes \ 
    (kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize) 
Discussion 

The default access types supported by an IONetworkData object. Allow read() and serialize().*/

#define kIONetworkDataBasicAccessTypes \
    (kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize) 

/*NetworkDataAccessTypes


Constants that describe access types. 

enum { 
    kIONetworkDataAccessTypeRead = 0x01, 
    kIONetworkDataAccessTypeWrite = 0x02, 
    kIONetworkDataAccessTypeReset = 0x04, 
    kIONetworkDataAccessTypeSerialize = 0x08, 
    kIONetworkDataAccessTypeMask = 0xff 
};  
Constants
kIONetworkDataAccessTypeRead
Read access.
kIONetworkDataAccessTypeWrite
Write access.
kIONetworkDataAccessTypeReset
Reset access.
kIONetworkDataAccessTypeSerialize
Serialization access.*/
enum { 
    kIONetworkDataAccessTypeRead = 0x01, 
    kIONetworkDataAccessTypeWrite = 0x02, 
    kIONetworkDataAccessTypeReset = 0x04, 
    kIONetworkDataAccessTypeSerialize = 0x08, 
    kIONetworkDataAccessTypeMask = 0xff 
};  

#include <libkern/c++/OSSymbol.h>
#include <libkern/c++/OSSerialize.h>

#include <HYS/IOKit/network/IONetworkData.h>
#ifdef __cplusplus
class IONetworkData : public OSObject,public IONetworkData_HYS
{
    OSDeclareDefaultStructors( IONetworkData )

public://data

/*Action


Defines a C function that may be called by an IONetworkData object when one of its access methods is called. 

public

typedef IOReturn ( *Action)(
    void *target, 
    void *param, 
    IONetworkData *data, 
    UInt32 accessType, 
    void *buffer, 
    UInt32 *bufferSize, 
    UInt32 offset); 
Parameters
target
The target of the notification.
param
A parameter that was provided when the notification handler was registered.
data
The IONetworkData object being accessed, and the sender of the notification.
accessType
A bit will be set indicating the type of access which triggered the notification.
buffer
Pointer to the accessor's buffer. Only valid for read() and write() accesses.
bufferSize
Pointer to the size of the accessor's buffer.
offset
An offset from the start of the data buffer to begin reading or writing.*/
typedef IOReturn ( *Action)(
    void *target, 
    void *param, 
    IONetworkData *data, 
    UInt32 accessType, 
    void *buffer, 
    UInt32 *bufferSize, 
    UInt32 offset); 

Action _tapAction;//c

protected://function

/*free


Frees the IONetworkData object. 

protected

virtual void free(); */

 virtual void free(); 

/*writeBytes


Writes to the data buffer with data from a source buffer provided by the caller. 

protected

virtual bool writeBytes(
    const void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset = 0); 
Parameters
srcBuffer
Pointer to a source buffer provided by the caller.
srcBufferSize
The size of the source buffer.
writeOffset
A byte offset from the start of the data buffer to begin writting.
Return Value

Returns true if the operation was successful, false otherwise.*/
virtual bool writeBytes(
    const void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset = 0); 

/*readBytes


Reads from the data buffer and copies the data to a destination buffer provided by the caller. 

protected

virtual bool readBytes(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset = 0) const; 
Parameters
dstBuffer
Pointer to the destination buffer.
dstBufferSize
Pointer to an integer containing the size of the destination buffer. And is overwritten by this method with the actual number of bytes copied to the destination buffer.
readOffset
A byte offset from the start of the data buffer to begin reading.
Return Value

Returns true if the operation was successful, false otherwise.*/
virtual bool readBytes(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset = 0) const; 

/*clearBuffer


Clears the data buffer by filling it with zeroes. 

protected

virtual bool clearBuffer(); 
Return Value

Returns true if the operation was successful, false otherwise.*/
virtual bool clearBuffer(); 

public://func

/*serialize


Serializes the IONetworkData object. 

public

virtual bool serialize(
    OSSerialize *s) const; 
Parameters
s
An OSSerialize object.
Return Value

Returns true on success, false otherwise. 
Discussion 

If notification is enabled, then the notification handler is called just before the data buffer is serialized.*/
virtual bool serialize(
    OSSerialize *s) const; 

/*getNotificationParameter


Gets the parameter that will be passed to the access notification handler. 

public

virtual void * getNotificationParameter() const; 
Return Value

Returns the parameter that will be passed to the access notification handler.*/
virtual void * getNotificationParameter() const; 

/*getNotificationAction


Gets the C function that was registered to handle access notifications sent from this object. 

public

virtual Action getNotificationAction() const; 
Return Value

Returns a pointer to a C function, or 0 if notification is disabled.*/
virtual Action getNotificationAction() const; 

/*getNotificationTarget


Gets the first parameter that will be passed to the access notification handler. 

public

virtual void * getNotificationTarget() const; 
Return Value

Returns the first parameter that will be passed to the access notification handler.*/
virtual void * getNotificationTarget() const; 

/*getAccessTypes


Gets the types of data access supported by this object. 

public

virtual UInt32 getAccessTypes() const; 
Return Value

Returns a mask of supported access types.*/
virtual UInt32 getAccessTypes() const;

/*setNotificationTarget


Registers a C function to handle access notifications sent from this object. 

public

virtual void setNotificationTarget(
    void *target, 
    Action action, 
    void *param = 0); 
Parameters
target
The first parameter passed to the notification handler.
action
A pointer to a C function that will handle the notification. If 0, then notification is disabled.
param
An optional parameter passed to the notification handler.
Discussion 

A notification is sent by an IONetworkData object to the registered notification handler, when an access method is called to modify the contents of the data buffer.*/
virtual void setNotificationTarget(
    void *target, 
    Action action, 
    void *param = 0); 

/*setAccessTypes


Sets the types of access that are permitted on the data buffer. 

public

virtual void setAccessTypes(
    UInt32 types); 
Parameters
types
A mask of access types indicating the supported access types.*/
virtual void setAccessTypes(
    UInt32 types); 

/*getBufferType


Gets the type of data buffer managed by this object. 

public

virtual UInt32 getBufferType() const; 
Return Value

Returns a constant that describes the type of the data buffer.*/

virtual UInt32 getBufferType() const; 

/*withNoBuffer


Factory method that constructs and initializes an IONetworkData object without a data buffer. 

public

static IONetworkData * withNoBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes, 
    void *target, 
    Action action, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferSize
The size of the phantom data buffer.
accessTypes
The initial supported access types.
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns an IONetworkData object on success, or 0 otherwise. 
Discussion 

The notification handler must intervene when the IONetworkData is accessed.*/
static IONetworkData * withNoBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes, 
    void *target, 
    Action action, 
    void *param = 0); 

/*init


Initializes an IONetworkData object. 

public

virtual bool init(
    const char *name, 
    UInt32 bufferType, 
    UInt32 bufferSize, 
    void *externalBuffer = 0, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferType
The type of buffer associated with this object.
bufferSize
The size of the data buffer.
externalBuffer
Pointer to an external data buffer.
accessTypes
The initial supported access types. Can be later modified by calling setAccessTypes().
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns true if initialized successfully, false otherwise.*/
virtual bool init(
    const char *name, 
    UInt32 bufferType, 
    UInt32 bufferSize, 
    void *externalBuffer = 0, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0);

/*getSize


Gets the size of the data buffer. 

public

virtual UInt32 getSize() const; 
Return Value

Returns the size of the data buffer managed by this object in bytes.*/
virtual UInt32 getSize() const; 

/*read


An access method that reads from the data buffer. 

public

virtual IOReturn read(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset = 0); 
Parameters
dstBuffer
Pointer to the destination buffer.
dstBufferSize
Pointer to an integer containing the size of the destination buffer. And is overwritten by this method to the actual number of bytes copied to the destination buffer.
readOffset
An offset from the start of the source data buffer to begin reading.
Return Value

Returns kIOReturnSuccess on success, kIOReturnBadArgument if any of the arguments provided is invalid, kIOReturnNotReadable if read access is not permitted, or an error from the notification handler. 
Discussion 

This method handles an external request to read from the data buffer and copy it to the destination buffer provided by the accessor. If notification is enabled, then the notification handler is called before the data buffer is copied to the destination buffer. The notification handler may use this opportunity to intervene and to update the contents of the data buffer.*/
virtual IOReturn read(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset = 0); 

/*write


An access method that writes to the data buffer. 

public

virtual IOReturn write(
    void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset = 0); 
Parameters
srcBuffer
Pointer to the source buffer.
srcBufferSize
The number of bytes to write to the data buffer.
writeOffset
An offset from the start of the destination data buffer to begin writing.
Return Value

Returns kIOReturnSuccess on success, kIOReturnBadArgument if any of the arguments provided is invalid, kIOReturnNotWritable if write access is not permitted, or an error from the notification handler. 
Discussion 

This method handles an external request to write to the data buffer from a source buffer provided by the accessor. After checking that the data object supports write accesses, the data buffer is updated if it exists. Then the registered notification handler is called.*/
virtual IOReturn write(
    void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset = 0); 

/*reset


An access method that resets the data buffer. 

public

virtual IOReturn reset(); 
Return Value

Returns kIOReturnSuccess on success, kIOReturnNotWritable if reset access is not permitted, or an error from the notification handler. 
Discussion 

This method handles an external request to reset the data buffer. If notification is enabled, then the notification handler is called after the data buffer has been cleared.*/
virtual IOReturn reset(); 

/*getKey


Gets a unique OSSymbol key associated with this object. 

public

virtual const OSSymbol * getKey() const; 
Return Value

Returns an OSSymbol key that was generated from the name assigned to this object. 
Discussion 

During initialization, IONetworkData will create an OSSymbol key based on its assigned name.*/
virtual const OSSymbol * getKey() const; 

/*withExternalBuffer


Factory method that constructs and initializes an IONetworkData object with an external data buffer. 

public

static IONetworkData * withExternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    void *externalBuffer, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferSize
The size of the external data buffer.
externalBuffer
Pointer to the external data buffer.
accessTypes
The initial supported access types.
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns an IONetworkData object on success, or 0 otherwise.*/
static IONetworkData * withExternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    void *externalBuffer, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 

/*withInternalBuffer


Factory method that constructs and initializes an IONetworkData object with an internal data buffer. 

public

static IONetworkData * withInternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferSize
The number of bytes to allocate for the internal data buffer.
accessTypes
The initial supported access types.
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns an IONetworkData object on success, or 0 otherwise.*/
static IONetworkData * withInternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 

/*getBuffer


Gets a pointer to the data buffer. 

public

virtual const void * getBuffer() const; 
Return Value

Returns a pointer to the data buffer. Returns 0 if the buffer type is kIONetworkDataBufferTypeNone.*/
virtual const void * getBuffer() const; 

};

#endif //__cplusplus

//#endif // KERNEL 

#endif // _IONETWORKDATA_H 
