
#ifndef _IONETWORKUSERCLIENT_H
#define _IONETWORKUSERCLIENT_H

//#ifdef KERNEL

#include <IOKit/IOUserClient.h>

#ifdef __cplusplus
class IONetworkInterface;
#endif //__cplusplus

#include <HYS/IOKit/network/IONetworkUserClient.h>

#ifdef __cplusplus
class IONetworkUserClient : public IOUserClient,public IONetworkUserClient_HYS
{
    OSDeclareDefaultStructors( IONetworkUserClient )

protected:

/*free


Free the IONetworkUserClient object. 

protected

virtual void free(); */
virtual void free(); 

/*getNetworkDataHandle


Return an opaque handle to a provider's IONetworkData object. 

protected

virtual IOReturn getNetworkDataHandle(
    char *name, 
    OSSymbol ** handle, 
    IOByteCount nameSize, 
    IOByteCount *handleSizeP); 
Parameters
name
A C string with the name of the IONetworkData object.
handle
If an IONetworkData object with the given name is found, then its associated OSSymbol object is written to this address.
nameSize
The size of the name string, including the final terminating null character.
handleSizeP
The size of the buffer allocated by the caller to store the handle. This should be 4 bytes.
Return Value

kIOReturnSuccess on success, kIOReturnBadArgument if an argument is invalid, or kIOReturnNoMemory if unable to allocate memory. 
Discussion 

Called to obtain an unique handle that maps to an IONetworkData object. This handle can be later passed to other methods defined in this class to refer to the same object.*/
virtual IOReturn getNetworkDataHandle(
    char *name, 
    OSSymbol ** handle, 
    IOByteCount nameSize, 
    IOByteCount *handleSizeP); 

/*getNetworkDataCapacity


Get the capacity of an IONetworkData object, described by the size of its data buffer. 

protected

virtual IOReturn getNetworkDataCapacity(
    OSSymbol *key, 
    UInt32 *capacity); 
Parameters
key
The OSSymbol key of an IONetworkData object.
capacity
A pointer to the capacity value returned by this method.
Return Value

kIOReturnSuccess on success, kIOReturnBadArgument if an argument is invalid.*/

virtual IOReturn getNetworkDataCapacity(
    OSSymbol *key, 
    UInt32 *capacity); 

/*readNetworkData


Read the data buffer in an IONetworkData object and copy this data to a destination buffer provided by the caller. 

protected

virtual IOReturn readNetworkData(
    OSSymbol *key, 
    void *dstBuffer, 
    IOByteCount *dstBufferSize); 
Parameters
key
The OSSymbol key associated with an IONetworkData object.
dstBuffer
The destination buffer provided by the caller.
dstBufferSize
Pointer to an integer that the caller must initialize to hold the size of the destination buffer. This method will overwrite it with the actual number of bytes written.
Return Value

kIOReturnSuccess on success, kIOReturnBadArgument if an argument is invalid, or an error from IONetworkData::read().*/
virtual IOReturn readNetworkData(
    OSSymbol *key, 
    void *dstBuffer, 
    IOByteCount *dstBufferSize); 

/*writeNetworkData


Write to the data buffer in an IONetworkData object with data from a source buffer provided by the caller. 

protected

virtual IOReturn writeNetworkData(
    OSSymbol *key, 
    void *srcBuffer, 
    IOByteCount srcBufferSize); 
Parameters
key
The OSSymbol key associated with an IONetworkData object.
srcBuffer
The source buffer provided by the caller.
srcBufferSize
The size of the source buffer.
Return Value

kIOReturnSuccess on success, kIOReturnBadArgument if an argument is invalid, or an error from IONetworkData::write().*/
virtual IOReturn writeNetworkData(
    OSSymbol *key, 
    void *srcBuffer, 
    IOByteCount srcBufferSize); 

/*resetNetworkData


Fill the data buffer in an IONetworkData object with zeroes. 

protected

virtual IOReturn resetNetworkData(
    OSSymbol *key); 
Parameters
key
An OSSymbol key associated with an IONetworkData object.
Return Value

kIOReturnSuccess on success, kIOReturnBadArgument if an argument is invalid, or an error from IONetworkData::reset().*/
virtual IOReturn resetNetworkData(
    OSSymbol *key); 

/*setProperties


Handle a request to set properties from non-kernel clients. This call is propagated to our provider. 

protected

virtual IOReturn setProperties(
    OSObject *properties); 
Parameters
properties
An OSObject subclass that describes one or more properties.
Return Value

The return value from the invocation of this method in our provider is returned.*/
virtual IOReturn setProperties(
    OSObject *properties); 

/*getService


Get the IOService which is the provider of this user client. 

protected

virtual IOService * getService(); 
Return Value

Returns the IONetworkInterface that created the user client.*/
virtual IOService * getService(); 

public:

/*getExternalMethodForIndex


Look up a method entry from the method array. 

public

virtual IOExternalMethod * getExternalMethodForIndex(
    UInt32 index); 
Parameters
index
The method index.
Return Value

A pointer to an IOExternalMethod structure containing the method definition for the given index. 
Discussion 

Called by IOUserClient to fetch the method entry, described by an IOExternalMethod structure, that correspond to the index provided.*/
virtual IOExternalMethod * getExternalMethodForIndex(
    UInt32 index); 

/*clientDied


Handle client death. 

public

virtual IOReturn clientDied(); 
Return Value

kIOReturnSuccess. 
Discussion 

Close and detach from our owner (provider).*/
virtual IOReturn clientDied(); 

/*clientClose


Handle a client close. 

public

virtual IOReturn clientClose(); 
Return Value

kIOReturnSuccess. 
Discussion 

Close and detach from our owner (provider).*/
virtual IOReturn clientClose(); 

/*start


Start the IONetworkUserClient. 

public

virtual bool start(
    IOService *provider); 
Return Value

true on success, false otherwise. 
Discussion 

Open the provider, must be an IONetworkInterface object, and initialize the IOExternalMethod array.*/
virtual bool start(
    IOService *provider); 

/*withTask


Factory method that performs allocation and initialization of an IONetworkUserClient object. 

public

static IONetworkUserClient * withTask(
    task_t owningTask); 
Parameters
owningTask
See IOUserClient.
Return Value

An IONetworkUserClient on success, 0 otherwise.*/
static IONetworkUserClient * withTask(
    task_t owningTask);

};
#endif //__cplusplus

//#endif /* KERNEL */

#endif /* !_IONETWORKUSERCLIENT_H */
