
#ifndef _IOOUTPUTQUEUE_H
#define _IOOUTPUTQUEUE_H


#include <IOKit/network/IONetworkInterface.h>

struct mbuf;
class  IONetworkData;

/*OutputCommands


A command requested by the target. 

enum { 
    kIOOutputCommandMask = 0xff00, 
    kIOOutputCommandNone = 0x0000, 
    kIOOutputCommandStall = 0x0100 
};  
Constants
kIOOutputCommandMask
Define the command field in the return code.
kIOOutputCommandNone
No command.
kIOOutputCommandStall
A command to stall the queue.*/
enum { 
    kIOOutputCommandMask = 0xff00, 
    kIOOutputCommandNone = 0x0000, 
    kIOOutputCommandStall = 0x0100 
};  

/*OutputPacketStatus


The status of the packet sent to the target. 

enum { 
    kIOOutputStatusMask = 0x00ff, 
    kIOOutputStatusAccepted = 0x0000, 
    kIOOutputStatusDropped = 0x0001, 
    kIOOutputStatusRetry = 0x0002 
};  
Constants
kIOOutputStatusMask
Define the status field in the return code.
kIOOutputStatusAccept
Packet was accepted by the target.
kIOOutputStatusDropped
Packet accepted, but was also dropped.
kIOOutputStatusRetry
Target ran out of resources, and is unable to accept the packet. The ownership of the packet reverts back to the queue.*/
enum { 
    kIOOutputStatusMask = 0x00ff, 
    kIOOutputStatusAccepted = 0x0000, 
    kIOOutputStatusDropped = 0x0001, 
    kIOOutputStatusRetry = 0x0002 
};  

/*OutputHandlerReturnCodes


Common return codes returned by the target's output handler. 

enum { 
    kIOReturnOutputSuccess = (
        kIOOutputStatusAccepted | kIOOutputCommandNone), 
    kIOReturnOutputDropped = (
        kIOOutputStatusDropped | kIOOutputCommandNone), 
    kIOReturnOutputStall = (
        kIOOutputStatusRetry | kIOOutputCommandStall) 
};  
Constants
kIOReturnOutputSuccess
Packet was accepted.
kIOReturnOutputDropped
Packet was dropped.
kIOReturnOutputStall
Stall the queue and retry the same packet when the queue is restarted.*/

enum { 
    kIOReturnOutputSuccess = (
        kIOOutputStatusAccepted | kIOOutputCommandNone), 
    kIOReturnOutputDropped = (
        kIOOutputStatusDropped | kIOOutputCommandNone), 
    kIOReturnOutputStall = (
        kIOOutputStatusRetry | kIOOutputCommandStall) 
};  

#include <HYS/IOKit/network/IOOutputQueue.h>

class IOOutputQueue : public OSObject,public IOOutputQueue_HYS
{
    OSDeclareAbstractStructors( IOOutputQueue )

private:
protected:

/*init


Initializes an IOOutputQueue object. 

protected

virtual bool init(); 
Return Value

Returns true if initialized successfully, false otherwise.*/
virtual bool init(); 

/*free


Frees the IOOutputQueue object. 

protected

virtual void free(); 
Discussion 

Release allocated resources, then call super::free().*/
virtual void free(); 

/*cancelServiceThread


Cancels any pending service thread callout. 

protected

virtual bool cancelServiceThread(); 
Return Value

Returns true if a previously scheduled thread callout was canceled, false otherwise.*/
virtual bool cancelServiceThread(); 

/*scheduleServiceThread


Schedules a service thread callout. 

protected

virtual bool scheduleServiceThread(
    void *param); 
Parameters
param
A parameter to pass to the serviceThread() method.
Return Value

Returns true if a thread callout was scheduled, false otherwise. 
Discussion 

This method can be called by service() to schedule a thread that will call serviceThread() when it starts running.*/
virtual bool scheduleServiceThread(
    void *param); 

/*serviceThread


Method called by the scheduled service thread when it starts to run. 

protected

virtual void serviceThread(
    void *param); 
Parameters
param
A parameter that was given to scheduleServiceThread() when the service thread was scheduled.
Discussion 

Must be implemented by a subclass that calls scheduleServiceThread(). The default implementation does nothing.*/
virtual void serviceThread(
    void *param); 

public:
IOOutputQueue_runServiceThread

/*enqueue


Adds a packet, or a chain of packets, to the queue. 

public

virtual UInt32 enqueue(
    mbuf_t m,
    void *param) = 0; 
Parameters
m
A single packet, or a chain of packets.
param
A parameter provided by the caller.
Return Value

Returns a return code. 
Discussion 

This method is called by a client to add a packet, or a chain of packets, to the queue. A packet is described by an mbuf chain, while a chain of packets is constructed by linking multiple mbuf chains via the m_nextpkt field.*/
virtual UInt32 enqueue(
    mbuf_t m,
    void *param) = 0; 

/*getStatisticsData


Returns an IONetworkData object containing statistics counters updated by the queue. 

public

virtual IONetworkData * getStatisticsData() const; 
Return Value

Returns an IONetworkData object. This implementation will always return 0.*/

virtual IONetworkData * getStatisticsData() const; 

/*getOutputHandler


Returns the address of a function that is designated to handle incoming packets sent to the queue object. 

public

virtual IOOutputAction getOutputHandler() const; 
Return Value*/
virtual IOOutputAction getOutputHandler() const; 

/*service


Services the queue. 

public

virtual bool service(
    IOOptionBits options = 0) = 0; 
Parameters
options
Options for the service request.
Return Value

Returns a return value to indicate the service result. 
Discussion 

Manage the queue after it has been started.*/
virtual bool service(
    IOOptionBits options = 0) = 0; 

/*start


Starts up the queue. 

public

virtual bool start() = 0; 
Return Value

Returns true if the queue was started successfully, false otherwise. 
Discussion 

This method is called by the target to start the queue. This will allow packets to be removed from the queue, then delivered to the target.*/
virtual bool start() = 0; 

/*stop


Stops the queue. 

public

virtual bool stop() = 0; 
Return Value

Returns the previous running state of the queue, true if the queue was running, false if the queue was already stopped. 
Discussion 

Stop the queue and prevent it from sending packets to its target.*/
virtual bool stop() = 0; 

/*setCapacity


Changes the number of packets that the queue can hold before it begins to drop excess packets. 

public

virtual bool setCapacity(
    UInt32 capacity) = 0; 
Parameters
capacity
The new desired capacity.
Return Value

Returns true if the new capacity was accepted, false otherwise.*/
virtual bool setCapacity(
    UInt32 capacity) = 0; 

/*flush


Drops and frees all packets currently held by the queue. 

public

virtual UInt32 flush() = 0; 
Return Value

Returns the number of packets that were dropped and freed.*/

virtual UInt32 flush() = 0; 

};

#endif 
