
#ifndef _IOPACKETQUEUE_H
#define _IOPACKETQUEUE_H


#include <libkern/c++/OSObject.h>
#include <IOKit/IOLocks.h>
//extern "C" {
#include <sys/kpi_mbuf.h>
//}

struct mbuf;
struct IOMbufQueue;

#undef enqueue
#undef dequeue


#include <HYS/IOKit/network/IOPacketQueue.h>

class IOPacketQueue : public OSObject,public IOPacketQueue_HYS
{   
    OSDeclareDefaultStructors( IOPacketQueue )

protected://data
 
/*IOPacketQueueDefaultCapacity


Describes the default capacity of the queue object. 

protected

static const UInt32 IOPacketQueueDefaultCapacity = 100; 
Discussion 

The capacity is only observed by the enqueue() method. Therefore, it is possible for the size of the queue to exceed its capacity when other methods, such as prepend(), are used to add packets to the queue.*/
static const UInt32 IOPacketQueueDefaultCapacity = 100; 

protected://func

/*free


Frees the IOPacketQueue object. 

protected

virtual void free(); 
Discussion 

All packets held by the queue are released back to the free pool, resource are deallocated, then super::free() is called.*/
virtual void free();

public://func

/*lockFlush


Frees all packets currently held in a synchronized queue and releases them back to the free mbuf pool. 

public

virtual UInt32 lockFlush(); 
Return Value

Returns the number of packets freed. 
Discussion 

The size of the queue is cleared to zero. A spinlock is used to synchronize access to the queue.*/
virtual UInt32 lockFlush(); 

/*lockDequeueAll


Removes all packets from a synchronized queue and returns the head of the packet chain. 

public

virtual mbuf_t lockDequeueAll(); 
Return Value

Returns the head of a packet chain linking all packets that were held in the queue, or NULL if the queue was empty. 
Discussion 

The size of the queue is cleared to zero. A spinlock is used to synchronize access to the queue.*/
virtual mbuf_t lockDequeueAll(); 

/*lockDequeue


Removes a single packet from the head of a synchronized queue. 

public

virtual mbuf_t lockDequeue(); 
Return Value

Returns a packet removed from the head of the queue, or NULL if the queue was empty. 
Discussion 

A spinlock is used to synchronize access to the queue.*/

virtual mbuf_t lockDequeue(); 

/*lockEnqueueWithDrop


Adds a chain of packets to the tail of a synchronized queue. 

public

virtual UInt32 lockEnqueueWithDrop(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns the number of packets dropped and freed by the queue. 
Discussion 

Packets are dropped if the size of the queue has reached its capacity. A spinlock is used to synchronize access to the queue.*/
virtual UInt32 lockEnqueueWithDrop(
    mbuf_t m); 

/*lockEnqueue


Adds a chain of packets to the tail of a synchronized queue. 

public

virtual bool lockEnqueue(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns true on success, or false to indicate over-capacity and refusal to accept the packet chain provided. 
Discussion 

Packets are not added if the size of the queue has reached its capacity. A spinlock is used to synchronize access to the queue.*/
virtual bool lockEnqueue(
    mbuf_t m); 

/*lockPrepend


Adds a chain of packets to the head of a synchronized queue. 

public

virtual void lockPrepend(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the head of the queue.
Return Value

Always returns true. 
Discussion 

A spinlock is used to synchronize access to the queue.*/
virtual void lockPrepend(
    mbuf_t m); 

/*enqueueWithDrop


Adds a chain of packets to the tail of the queue. 

public

virtual UInt32 enqueueWithDrop(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns the number of packets dropped and freed by the queue. 
Discussion 

Packets are dropped if the size of the queue has reached its capacity.*/
virtual UInt32 enqueueWithDrop(
    mbuf_t m); 

/*setCapacity


Changes the capacity of the queue. 

public

virtual bool setCapacity(
    UInt32 capacity); 
Parameters
capacity
The new capacity.
Return Value

Returns true if the new capacity was accepted, false otherwise.*/
virtual bool setCapacity(
    UInt32 capacity); 

/*peek


Examines the packet at the head of the queue without removing it from the queue. 

public

virtual const mbuf_t peek() const; 
Return Value

Returns the packet at the head of the queue. 
Discussion 

A following call to peek() or dequeue() will return the same packet. The caller must never modify the mbuf packet returned*/
virtual const mbuf_t peek() const; 

/*getCapacity


Gets the current capacity of the queue. 

public

virtual UInt32 getCapacity() const; 
Return Value

Returns the current queue capacity.*/
virtual UInt32 getCapacity() const; 

/*dequeueAll


Removes all packets from the queue and returns the head of the packet chain. 

public

virtual mbuf_t dequeueAll(); 
Return Value

Returns the head of a packet chain linking all packets that were held in the queue, or NULL if the queue was empty. 
Discussion 

The size of the queue is cleared to zero.*/
virtual mbuf_t dequeueAll(); 

/*dequeue


Removes a single packet from the head of the queue. 

public

virtual mbuf_t dequeue(); 
Return Value

Returns a packet removed from the head of the queue, or NULL if the queue was empty.*/
virtual mbuf_t dequeue(); 

/*prepend(IOPacketQueue *)


Removes all packets from the specified queue, and adds them to the head of this queue. 

public

virtual void prepend(
    IOPacketQueue *queue); 
Parameters
queue
The source IOPacketQueue object containing the packets to be transferred.*/
virtual void prepend(
    IOPacketQueue *queue); 

/*prepend(mbuf_t)


Adds a chain of packets to the head of the queue. 

public

virtual void prepend(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the head of the queue.*/
virtual void prepend(
    mbuf_t m); 

/*initWithCapacity


Initializes an IOPacketQueue object. 

public

virtual bool initWithCapacity(
    UInt32 capacity = IOPacketQueueDefaultCapacity); 
Parameters
capacity
The initial capacity of the queue. Can be later changed by calling the setCapacity() method.
Return Value

Returns true if initialized successfully, false otherwise. 
Discussion 

This method initializes an IOPacketQueue object with the given capacity.*/
virtual bool initWithCapacity(
    UInt32 capacity = IOPacketQueueDefaultCapacity); 

/*withCapacity


Factory method that constructs and initializes an IOPacketQueue object. 

public

static IOPacketQueue * withCapacity(
    UInt32 capacity = IOPacketQueueDefaultCapacity); 
Parameters
capacity
The initial capacity of the queue object. Can be later changed by calling the setCapacity() method.
Return Value

Returns an IOPacketQueue instance on success, or 0 otherwise.*/
static IOPacketQueue * withCapacity(
    UInt32 capacity = IOPacketQueueDefaultCapacity); 

/*getSize


Gets the size of the queue. 

public

virtual UInt32 getSize() const; 
Return Value

Returns the number of packets currently held by the queue.*/
virtual UInt32 getSize() const; 

/*flush


Frees all packets currently held in the queue and releases them back to the free mbuf pool. 

public

virtual UInt32 flush(); 
Return Value

Returns the number of packets freed. 
Discussion 

The size of the queue is cleared to zero.*/
virtual UInt32 flush();

/*enqueue(IOPacketQueue *)


Removes all packets from the specified queue, and adds them to the tail of this queue. 

public

virtual bool enqueue(
    IOPacketQueue *queue); 
Parameters
queue
The source IOPacketQueue object containing the packets to be transferred.
Return Value

Always returns true.*/
virtual bool enqueue(
    IOPacketQueue *queue); 

/*enqueue(mbuf_t)


Adds a chain of packets to the tail of the queue. 

public

virtual bool enqueue(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns true on success, or false to indicate over-capacity and refusal to accept the packet chain provided. 
Discussion 

Packets are not added if the size of the queue has reached its capacity.*/
virtual bool enqueue(
    mbuf_t m); 

};

#endif //_IOPACKETQUEUE_H
