
#ifndef _IOKIT_IOPCIDEVICE_H
#define _IOKIT_IOPCIDEVICE_H

#include <IOKit/IOService.h>



class IOPCIBridge;
class IOPCI2PCIBridge;
class IOPCIMessagedInterruptController;

#include <HYS/IOKit/pci/IOPCIDevice.h>

class IOPCIDevice : public IOService,public IOPCIDevice_HYS
{
    OSDeclareDefaultStructors(IOPCIDevice)

    friend class IOPCIBridge;
    friend class IOPCI2PCIBridge;
    friend class IOPCIMessagedInterruptController;

protected:

/*reserved


protected

struct IOPCIDeviceExpansionData * reserved; 
Discussion 

Reserved for future use. (Internal use only)*/
struct IOPCIDeviceExpansionData * reserved;

public:

IOPCIDevice_attach
IOPCIDevice_detach
IOPCIDevice_init
IOPCIDevice_init_IORegistryEntry
IOPCIDevice_free
IOPCIDevice_setPowerState
IOPCIDevice_matchPropertyTable
IOPCIDevice_compareName
IOPCIDevice_getResources
IOPCIDevice_configRead32
IOPCIDevice_configWrite32
IOPCIDevice_configRead16
IOPCIDevice_configWrite16
IOPCIDevice_configRead8
IOPCIDevice_configWrite8
IOPCIDevice_setProperties
IOPCIDevice_saveDeviceState
IOPCIDevice_restoreDeviceState
IOPCIDevice_matchLocation

/*setConfigBits


Sets masked bits in a configuration space register. 

public

virtual UInt32 setConfigBits(
    UInt8 offset,
    UInt32 mask,
    UInt32 value ); 
Parameters
offset
An 8-bit offset into configuration space, of which bits 0-1 are ignored.
mask
An 32-bit mask indicating which bits in the value parameter are valid.
data
An 32-bit value to be written in host byte order (big endian on PPC).
Return Value

The value of the register masked with the mask before the write. 
Discussion 

This method sets masked bits in a configuration space register on the device by reading and writing the register. It returns the value of the masked bits before the write.*/

virtual UInt32 setConfigBits(
    UInt8 offset,
    UInt32 mask,
    UInt32 value );

/*extendedConfigWrite8


Writes an 8-bit value to the PCI device's configuration space. 

public

void extendedConfigWrite8(
    IOByteCount offset,
    UInt8 data ); 
Parameters
offset
A byte offset into configuration space.
data
An 8-bit value to be written.
Discussion 

This method writes an 8-bit value to a configuration space register on the device.*/
void extendedConfigWrite8(
    IOByteCount offset,
    UInt8 data ); 

/*extendedConfigRead8


Reads an 8-bit value from the PCI device's configuration space. 

public

UInt8 extendedConfigRead8(
    IOByteCount offset ); 
Parameters
offset
A byte offset into configuration space.
Return Value

An 8-bit value. 
Discussion 

This method reads an 8-bit configuration space register on the device and returns its value.*/
UInt8 extendedConfigRead8(
    IOByteCount offset ); 

/*extendedConfigWrite16


Writes a 16-bit value to the PCI device's configuration space. 

public

void extendedConfigWrite16(
    IOByteCount offset,
    UInt16 data ); 
Parameters
offset
A byte offset into configuration space, of which bit 0 is ignored.
data
An 16-bit value to be written in host byte order (big endian on PPC).
Discussion 

This method writes a 16-bit value to a configuration space register on the device.*/
void extendedConfigWrite16(
    IOByteCount offset,
    UInt16 data ); 

/*extendedConfigRead16


Reads a 16-bit value from the PCI device's configuration space. 

public

UInt16 extendedConfigRead16(
    IOByteCount offset ); 
Parameters
offset
A byte offset into configuration space, of which bit 0 is ignored.
Return Value

An 16-bit value in host byte order (big endian on PPC). 
Discussion 

This method reads a 16-bit configuration space register on the device and returns its value.*/
UInt16 extendedConfigRead16(
    IOByteCount offset ); 

/*extendedConfigWrite32


Writes a 32-bit value to the PCI device's configuration space. 

public

void extendedConfigWrite32(
    IOByteCount offset,
    UInt32 data ); 
Parameters
offset
A byte offset into configuration space, of which bits 0-1 are ignored.
data
An 32-bit value to be written in host byte order (big endian on PPC).
Discussion 

This method writes a 32-bit value to a configuration space register on the device.*/
void extendedConfigWrite32(
    IOByteCount offset,
    UInt32 data ); 

/*extendedConfigRead32


Reads a 32-bit value from the PCI device's configuration space. 

public

UInt32 extendedConfigRead32(
    IOByteCount offset ); 
Parameters
offset
A byte offset into configuration space, of which bits 0-1 are ignored.
Return Value

An 32-bit value in host byte order (big endian on PPC). 
Discussion 

This method reads a 32-bit configuration space register on the device and returns its value.*/

UInt32 extendedConfigRead32(
    IOByteCount offset ); 

/*ioDeviceMemory


Accessor to the I/O space aperture for the bus. 

public

virtual IODeviceMemory * ioDeviceMemory(
    void ); 
Return Value

A pointer to an IODeviceMemory object for the I/O aperture. The IODeviceMemory object is retained by the provider, so is valid while attached, or while any mappings to it exist. It should not be released by the caller. 
Discussion 

This method will return a reference to the IODeviceMemory for the I/O aperture of the bus the device is on.*/
virtual IODeviceMemory * ioDeviceMemory(
    void ); 

/*getDeviceMemoryWithRegister


Returns an instance of IODeviceMemory representing one of the device's memory mapped ranges. 

public

virtual IODeviceMemory * getDeviceMemoryWithRegister(
    UInt8 reg ); 
Parameters
reg
The 8-bit configuration space register that is the base address register for the desired range.
Return Value

A pointer to an instance of IODeviceMemory, or zero no such range was found. The IODeviceMemory is retained by the provider, so is valid while attached, or while any mappings to it exist. It should not be released by the caller. 
Discussion 

This method will return a pointer to an instance of IODeviceMemory for the physical memory range that was assigned to the configuration space base address register passed in. It is analogous to IOService::getDeviceMemoryWithIndex.*/
virtual IODeviceMemory * getDeviceMemoryWithRegister(
    UInt8 reg ); 

/*extendedFindPCICapability


Searches configuration space for a PCI capability register. 

public

virtual UInt32 extendedFindPCICapability(
    UInt32 capabilityID,
    IOByteCount *offset = 0 ); 
Parameters
capabilityID
A PCI capability ID. PCI Express devices may support extended capabilities in config space starting at offset 0x100. To search this space, the ID passed should be the negated value of the PCI-SIG assigned ID for the extended capability.
offset
An optional in/out parameter to return the offset into config space where the capability was found, and to set the start point of the next search. Initialize the offset to zero before the first call to extendedFindPCICapability and subsequent calls will find all capabilty blocks that may exist on the device with the same ID.
Return Value

The 32-bit value of the capability register if one was found, zero otherwise. 
Discussion 

This method searches the device's config space for a PCI capability register matching the passed capability ID, if the device supports PCI capabilities.*/
virtual UInt32 extendedFindPCICapability(
    UInt32 capabilityID,
    IOByteCount *offset = 0 ); 

/*configWrite8


Writes a 8-bit value to the PCI device's configuration space. 

public

virtual void configWrite8(
    UInt8 offset,
    UInt8 data ); 
Parameters
offset
An 8-bit offset into configuration space.
data
An 8-bit value to be written.
Discussion 

This method writes a 8-bit value to a configuration space register on the device.*/
virtual void configWrite8(
    UInt8 offset,
    UInt8 data ); 

/*configRead8


Reads a 8-bit value from the PCI device's configuration space. 

public

virtual UInt8 configRead8(
    UInt8 offset ); 
Parameters
offset
An 8-bit offset into configuration space.
Return Value

An 8-bit value. 
Discussion 

This method reads a 8-bit configuration space register on the device and returns its value.*/
virtual UInt8 configRead8(
    UInt8 offset ); 

/*findPCICapability


Searches configuration space for a PCI capability register. 

public

virtual UInt32 findPCICapability(
    UInt8 capabilityID,
    UInt8 *offset = 0 ); 
Parameters
capabilityID
An 8-bit PCI capability ID.
offset
An optional pointer to return the offset into config space where the capability was found.
Return Value

The 32-bit value of the capability register if one was found, zero otherwise. 
Discussion 

This method searches the device's config space for a PCI capability register matching the passed capability ID, if the device supports PCI capabilities. To search for PCI Express extended capabilities or for multiple capablities with the same ID, use the extendedFindPCICapability method.*/
virtual UInt32 findPCICapability(
    UInt8 capabilityID,
    UInt8 *offset = 0 ); 

/*getDeviceNumber 


Returns the PCI device's device number. 

public

virtual UInt8 getDeviceNumber(
    void ); 
Return Value

The 5-bit value of device's device number. 
Discussion 

This method is an accessor to return the PCI device's device number.*/
virtual UInt8 getDeviceNumber(
    void ); 

/*getFunctionNumber 


Returns the PCI device's function number. 

public

virtual UInt8 getFunctionNumber(
    void ); 
Return Value

The 3-bit value of device's function number. 
Discussion 

This method is an accessor to return the PCI device's function number.*/
virtual UInt8 getFunctionNumber(
    void ); 

/*setIOEnable 


Sets the device's I/O space response. 

public

virtual bool setIOEnable(
    bool enable,
    bool exclusive = false ); 
Parameters
enable 
True or false to enable or disable the I/O space response.
exclusive 
If true, only one setIOEnable with the exclusive flag set will be allowed at a time on the bus, this should be only for temporary access.
Return Value

True if the I/O space response was previously enabled, false otherwise. 
Discussion 

This method sets the I/O space response bit in the device's command config space register to the passed value, and returns the previous state of the enable. The exclusive option allows only one exclusive device on the bus to be enabled concurrently, this should be only for temporary access.*/
virtual bool setIOEnable(
    bool enable,
    bool exclusive = false ); 

/*getBusNumber 


Returns the PCI device's assigned bus number. 

public

virtual UInt8 getBusNumber(
    void ); 
Return Value

The 8-bit value of device's PCI bus number. 
Discussion 

This method is an accessor to return the PCI device's assigned bus number.*/

virtual UInt8 getBusNumber(
    void ); 

/*setMemoryEnable 


Sets the device's memory space response. 

public

virtual bool setMemoryEnable(
    bool enable ); 
Parameters
enable 
True or false to enable or disable the memory space response.
Return Value

True if the memory space response was previously enabled, false otherwise. 
Discussion 

This method sets the memory space response bit in the device's command config space register to the passed value, and returns the previous state of the enable.*/
virtual bool setMemoryEnable(
    bool enable ); 

/*setBusMasterEnable 


Sets the device's bus master enable. 

public

virtual bool setBusMasterEnable(
    bool enable ); 
Parameters
enable 
True or false to enable or disable bus mastering.
Return Value

True if bus mastering was previously enabled, false otherwise. 
Discussion 

This method sets the bus master enable bit in the device's command config space register to the passed value, and returns the previous state of the enable.*/
virtual bool setBusMasterEnable(
    bool enable ); 

/*configRead32 


Reads a 32-bit value from the PCI device's configuration space. 

public

virtual UInt32 configRead32(
    UInt8 offset ); 
Parameters
offset 
An 8-bit offset into configuration space, of which bits 0-1 are ignored.
Return Value

An 32-bit value in host byte order (big endian on PPC). 
Discussion 

This method reads a 32-bit configuration space register on the device and returns its value.*/
virtual UInt32 configRead32(
    UInt8 offset );

/*configWrite32 


Writes a 32-bit value to the PCI device's configuration space. 

public

virtual void configWrite32(
    UInt8 offset,
    UInt32 data ); 
Parameters
offset 
An 8-bit offset into configuration space, of which bits 0-1 are ignored.
data 
An 32-bit value to be written in host byte order (big endian on PPC).
Discussion 

This method writes a 32-bit value to a configuration space register on the device.*/

virtual void configWrite32(
    UInt8 offset,
    UInt32 data ); 

/*mapDeviceMemoryWithRegister 


Maps a physical range of the device. 

public

virtual IOMemoryMap * mapDeviceMemoryWithRegister(
    UInt8 reg, 
    IOOptionBits options = 0 ); 
Parameters
reg 
The 8-bit configuration space register that is the base address register for the desired range.
options 
Options to be passed to the IOMemoryDescriptor::map() method.
Return Value

An instance of IOMemoryMap, or zero if the index is beyond the count available. The mapping should be released only when access to it is no longer required. 
Discussion 

This method will create a mapping for the IODeviceMemory for the physical memory range that was assigned to the configuration space base address register passed in, with IODeviceMemory::map(options). The mapping is represented by the returned instance of IOMemoryMap, which should not be released until the mapping is no longer required. This method is analogous to IOService::mapDeviceMemoryWithIndex.*/

virtual IOMemoryMap * mapDeviceMemoryWithRegister(
    UInt8 reg, 
    IOOptionBits options = 0 ); 

/*ioWrite8 


Writes an 8-bit value to an I/O space aperture. 

public

virtual void ioWrite8(
    UInt16 offset,
    UInt8 value, 
    IOMemoryMap *map = 0 ); 
Parameters
offset 
An offset into a bus or device's I/O space aperture.
value 
The value to be written in host byte order (big endian on PPC).
map 
If the offset is relative to the beginning of a device's aperture, an IOMemoryMap object for that object should be passed in. Otherwise, passing zero will write the value relative to the beginning of the bus' I/O space.
Discussion 

This method will write an 8-bit value to an offset in an I/O space aperture. If a map object is passed in, the value is written relative to it, otherwise the value is written relative to the I/O space aperture for the bus. This function encapsulates the differences between architectures in generating I/O space operations. An eieio instruction is included on PPC*/
virtual void ioWrite8(
    UInt16 offset,
    UInt8 value, 
    IOMemoryMap *map = 0 ); 

/*ioRead8 


Reads an 8-bit value from an I/O space aperture. 

public

virtual UInt8 ioRead8(
    UInt16 offset,
    IOMemoryMap *map = 0 ); 
Parameters
offset 
An offset into a bus or device's I/O space aperture.
map 
If the offset is relative to the beginning of a device's aperture, an IOMemoryMap object for that object should be passed in. Otherwise, passing zero will write the value relative to the beginning of the bus' I/O space.
Return Value

The value read. 
Discussion 

This method will read an 8-bit value from an offset in an I/O space aperture. If a map object is passed in, the value is read relative to it, otherwise the value is read relative to the I/O space aperture for the bus. This function encapsulates the differences between architectures in generating I/O space operations. An eieio instruction is included on PPC*/

virtual UInt8 ioRead8(
    UInt16 offset,
    IOMemoryMap *map = 0 ); 

/*configRead16


Reads a 16-bit value from the PCI device's configuration space. 

public

virtual UInt16 configRead16(
    UInt8 offset ); 
Parameters
offset
An 8-bit offset into configuration space, of which bit 0 is ignored.
Return Value

An 16-bit value in host byte order (big endian on PPC). 
Discussion 

This method reads a 16-bit configuration space register on the device and returns its value.*/

virtual UInt16 configRead16(
    UInt8 offset ); 

/*configWrite16


Writes a 16-bit value to the PCI device's configuration space. 

public

virtual void configWrite16(
    UInt8 offset,
    UInt16 data ); 
Parameters
offset
An 8-bit offset into configuration space, of which bit 0 is ignored.
data
An 16-bit value to be written in host byte order (big endian on PPC).
Discussion 

This method writes a 16-bit value to a configuration space register on the device.*/
virtual void configWrite16(
    UInt8 offset,
    UInt16 data );

/*hasPCIPowerManagement


Determines whether or not the device supports PCI Bus Power Management. 

public

virtual bool hasPCIPowerManagement(
    IOOptionBits state = 0); 
Parameters
state
(optional) Check for support of a specific state (e.g. kPCIPMCPMESupportFromD3Cold). If state is not supplied or is 0, then check for a property in the I/O Registry which tells which state the hardware expects the device to go to during sleep.
Return Value

true if the specified state is supported 
Discussion 

This method will look at the device's capabilties registers and determine whether or not the device supports the PCI BUS Power Management Specification.*/
virtual bool hasPCIPowerManagement(
    IOOptionBits state = 0); 

/*enablePCIPowerManagement


Enables PCI power management for sleep state. 

public

virtual IOReturn enablePCIPowerManagement(
    IOOptionBits state = 0xffffffff); 
Parameters
state
(optional) Enables PCI Power Management by placing the function in the given state (e.g. kPCIPMCSPowerStateD3). If state is not specified or is 0xffffffff, then the IOPCIDevice determines the desired state. If state is kPCIPMCSPowerStateD0 (0) then PCI Power Management is disabled.
Return Value

kIOReturnSuccess if there were no errors 
Discussion 

This method will enable PCI Bus Powermanagement when going to sleep mode.*/
virtual IOReturn enablePCIPowerManagement(
    IOOptionBits state = 0xffffffff); 

/*ioRead16


Reads a 16-bit value from an I/O space aperture. 

public

virtual UInt16 ioRead16(
    UInt16 offset,
    IOMemoryMap *map = 0 ); 
Parameters
offset
An offset into a bus or device's I/O space aperture.
map
If the offset is relative to the beginning of a device's aperture, an IOMemoryMap object for that object should be passed in. Otherwise, passing zero will write the value relative to the beginning of the bus' I/O space.
Return Value

The value read in host byte order (big endian on PPC). 
Discussion 

This method will read a 16-bit value from a 2 byte aligned offset in an I/O space aperture. If a map object is passed in, the value is read relative to it, otherwise the value is read relative to the I/O space aperture for the bus. This function encapsulates the differences between architectures in generating I/O space operations. An eieio instruction is included on PPC.*/
virtual UInt16 ioRead16(
    UInt16 offset,
    IOMemoryMap *map = 0 ); 

/*ioRead32


Reads a 32-bit value from an I/O space aperture. 

public

virtual UInt32 ioRead32(
    UInt16 offset,
    IOMemoryMap *map = 0 ); 
Parameters
offset
An offset into a bus or device's I/O space aperture.
map
If the offset is relative to the beginning of a device's aperture, an IOMemoryMap object for that object should be passed in. Otherwise, passing zero will write the value relative to the beginning of the bus' I/O space.
Return Value

The value read in host byte order (big endian on PPC). 
Discussion 

This method will read a 32-bit value from a 4 byte aligned offset in an I/O space aperture. If a map object is passed in, the value is read relative to it, otherwise the value is read relative to the I/O space aperture for the bus. This function encapsulates the differences between architectures in generating I/O space operations. An eieio instruction is included on PPC.*/
virtual UInt32 ioRead32(
    UInt16 offset,
    IOMemoryMap *map = 0 ); 

/*ioWrite16


Writes a 16-bit value to an I/O space aperture. 

public

virtual void ioWrite16(
    UInt16 offset,
    UInt16 value, 
    IOMemoryMap *map = 0 ); 
Parameters
offset
An offset into a bus or device's I/O space aperture.
value
The value to be written in host byte order (big endian on PPC).
map
If the offset is relative to the beginning of a device's aperture, an IOMemoryMap object for that object should be passed in. Otherwise, passing zero will write the value relative to the beginning of the bus' I/O space.
Discussion 

This method will write a 16-bit value to a 2 byte aligned offset in an I/O space aperture. If a map object is passed in, the value is written relative to it, otherwise the value is written relative to the I/O space aperture for the bus. This function encapsulates the differences between architectures in generating I/O space operations. An eieio instruction is included on PPC. */
virtual void ioWrite16(
    UInt16 offset,
    UInt16 value, 
    IOMemoryMap *map = 0 ); 

/*ioWrite32


Writes a 32-bit value to an I/O space aperture. 

public

virtual void ioWrite32(
    UInt16 offset,
    UInt32 value, 
    IOMemoryMap *map = 0 ); 
Parameters
offset
An offset into a bus or device's I/O space aperture.
value
The value to be written in host byte order (big endian on PPC).
map
If the offset is relative to the beginning of a device's aperture, an IOMemoryMap object for that object should be passed in. Otherwise, passing zero will write the value relative to the beginning of the bus' I/O space.
Discussion 

This method will write a 32-bit value to a 4 byte aligned offset in an I/O space aperture. If a map object is passed in, the value is written relative to it, otherwise the value is written relative to the I/O space aperture for the bus. This function encapsulates the differences between architectures in generating I/O space operations. An eieio instruction is included on PPC.*/

virtual void ioWrite32(
    UInt16 offset,
    UInt32 value, 
    IOMemoryMap *map = 0 ); 

};

#endif //_IOKIT_IOPCIDEVICE_H

