
#ifndef _IOPSKEYS_H_
#define _IOPSKEYS_H_

#include <HYS/IOKit/ps/IOPSKeys.h>

/*kIOPSUPSManagementClaimed


Claims UPS management for a third-party driver.

#define kIOPSUPSManagementClaimed "/IOKit/UPSPowerManagementClaimed" 
Discussion 

kIOPSUPSManagementClaimed Obsolete. Do not use.*/
#define kIOPSUPSManagementClaimed "/IOKit/UPSPowerManagementClaimed" 

/*kIOPSPowerSourceIDKey


A key of type CFNumber (kCFNumberIntType) uniquely identifying a UPS attached to the system.

See Also:
kIOPSPowerSourceID
#define kIOPSPowerSourceIDKey "Power Source ID" */
#define kIOPSPowerSourceIDKey "Power Source ID" 

/*kIOPSIsPresentKey


CFDictionary key for the current power source's presence. 

#define kIOPSIsPresentKey "Is Present" 
Discussion 

For example, a PowerBook with the capacity for two batteries but with only one present would show two power source dictionaries, but kIOPSIsPresentKey would have the value kCFBooleanFalse in one of them. Th key is of type CFBoolean and its value is kCFBooleanTrue or kCFBooleanFalse.*/
#define kIOPSIsPresentKey "Is Present" 

/*kIOPSDynamicStorePath


This is only used for internal bookkeeping, and should be ignored. 

#define kIOPSDynamicStorePath "/IOKit/PowerSources" */
#define kIOPSDynamicStorePath "/IOKit/PowerSources" 

/*kIOPSUSBTransportType


Value for key kIOPSTransportTypeKey. 

#define kIOPSUSBTransportType "USB" 
Discussion 

Indicates the power source is a UPS attached over a USB connection.*/
#define kIOPSUSBTransportType "USB"

/*kIOPSInternalType


Value for key kIOPSTransportTypeKey. 

#define kIOPSInternalType "Internal" 
Discussion 

Indicates the power source is an internal battery.*/
#define kIOPSInternalType "Internal"

/*kIOPSNetworkTransportType


Value for key kIOPSTransportTypeKey. 

#define kIOPSNetworkTransportType "Ethernet" 
Discussion 

Indicates the power source is a UPS attached over a network connection (and it may be managing several computers).*/
#define kIOPSNetworkTransportType "Ethernet"

/*kIOPSTransportTypeKey


CFDictionary key for the current power source's transport type.

#define kIOPSTransportTypeKey "Transport Type" 
Discussion 

The key is of type CFStringRef. Valid transport types are kIOPSSerialTransportType, kIOPSUSBTransportType, kIOPSNetworkTransportType, or kIOPSInternalType*/
#define kIOPSTransportTypeKey "Transport Type"

/*kIOPSNameKey


CFDictionary key of type CFStringRef for the current power source's name.

#define kIOPSNameKey "Name" */
#define kIOPSNameKey "Name"

/*kIOPSCommandDelayedRemovePowerKey


Command to give a UPS when it should remove power from its AC plugs in a specified amount of time.

#define kIOPSCommandDelayedRemovePowerKey "Delayed Remove Power" 
Discussion 

The matching argument should be a CFNumber of kCFNumberIntType specifying when the UPS should remove power from its AC power ports.*/
#define kIOPSCommandDelayedRemovePowerKey "Delayed Remove Power"

/*kIOPSVoltageKey


CFDictionary key for the current power source's electrical voltage.

#define kIOPSVoltageKey "Voltage" 
Discussion 

The key is of type CFNumber (signed integer) and its units are mV.*/
#define kIOPSVoltageKey "Voltage"

/*kIOPSBatteryPowerValue


Value for key kIOPSPowerSourceStateKey. 

#define kIOPSBatteryPowerValue "Battery Power" 
Discussion 

Indicates the power source is currently using the internal battery.*/
#define kIOPSBatteryPowerValue "Battery Power"

/*kIOPSPowerSourceStateKey


CFDictionary key for the current source of power.

#define kIOPSPowerSourceStateKey "Power Source State" 
Discussion 

The key is of type CFString and its value is kIOPSACPowerValue, kIOPSBatteryPowerValue, or kIOPSOffLineValue.*/
#define kIOPSPowerSourceStateKey "Power Source State"

/*kIOPSCurrentKey


CFDictionary key for the current power source's electrical current.

#define kIOPSCurrentKey "Current" 
Discussion 

The key is of type CFNumber (signed integer) and its units are mA.*/
#define kIOPSCurrentKey "Current"

/*kIOPSIsChargingKey


CFDictionary key for the current power source's charging state.

#define kIOPSIsChargingKey "Is Charging" 
Discussion 

The key is of type CFBoolean and its value is kCFBooleanTrue or kCFBooleanFalse.*/
#define kIOPSIsChargingKey "Is Charging"

/*kIOPSACPowerValue


Value for key kIOPSPowerSourceStateKey. 

#define kIOPSACPowerValue "AC Power" 
Discussion 

Indicates the power source is connected to external or AC power and is not draining the internal battery.*/
#define kIOPSACPowerValue "AC Power"

/*kIOPSTimeToFullChargeKey


CFDictionary key for the current power source's time remaining until fully charged.

#define kIOPSTimeToFullChargeKey "Time to Full Charge" 
Discussion 

Only valid if the value of kIOPSIsChargingKey is kCFBooleanTrue. Type CFNumber (signed integer), units are minutes. A value of -1 indicates "Still Calculating the Time", otherwise estimated minutes until fully charged.*/
#define kIOPSTimeToFullChargeKey "Time to Full Charge"

/*kIOPSTimeToEmptyKey


CFDictionary key for the current power source's time remaining until empty.

#define kIOPSTimeToEmptyKey "Time to Empty" 
Discussion 

Only valid if the power source is running off its own power. That's when the kIOPSPowerSourceStateKey has value kIOPSBatteryPowerValue, and the value of kIOPSIsChargingKey is kCFBooleanFalse. Type CFNumber (signed integer), units are minutes. A value of -1 indicates "Still Calculating the Time", otherwise estimated minutes left on the battery.*/
#define kIOPSTimeToEmptyKey "Time to Empty"

/*kIOPSCurrentCapacityKey


CFDictionary key for the current power source's capacity.

#define kIOPSCurrentCapacityKey "Current Capacity" 
Discussion 

The key is of type CFNumber (signed integer) and the units are relative to "Max Capacity".*/
#define kIOPSCurrentCapacityKey "Current Capacity"

/*kIOPSMaxCapacityKey


CFDictionary key for the current power source's maximum capacity.

#define kIOPSMaxCapacityKey "Max Capacity" 
Discussion 

The key is of type CFNumber (signed integer) and its units are %.*/
#define kIOPSMaxCapacityKey "Max Capacity" 

#endif//_IOPSKEYS_H_
