#ifndef _IOKIT_IOPM_H
#define _IOKIT_IOPM_H

#include <IOKit/IOTypes.h>
#include <IOKit/IOMessage.h>
#include <IOKit/IOReturn.h>

//#ifdef __ppc__
#include <IOKit/pwr_mgt/IOPMDeprecated.h>
//#endif

#include <HYS/IOKit/pwr_mgt/IOPM.h>

/*IOPMPowerFlags 


Bits are used in defining capabilityFlags, inputPowerRequirements, and outputPowerCharacter in the IOPMPowerState structure. 

See Also:
IOPMPowerFlags
typedef unsigned long IOPMPowerFlags;  
Discussion 

These bits may be bitwise-OR'd together in the IOPMPowerState capabilityFlags field, the outputPowerCharacter field, and/or the inputPowerRequirement field. 

The comments clearly mark whether each flag should be used in the capabilityFlags field, outputPowerCharacter field, and inputPowerRequirement field, or all three. 

The value of capabilityFlags, inputPowerRequirement or outputPowerCharacter may be 0. Most drivers implement their 'OFF' state, used when asleep, by defininf each of the 3 fields as 0. 

The bits listed below are only the most common bits used to define a device's power states. Your device's IO family may require that your device specify other input or output power flags to interact properly. Consult family-specific documentation to determine if your IOPower plane parents or children require other power flags; they probably don't.&/*/
typedef unsigned long IOPMPowerFlags;  

/*IOPMPowerFlags


Bits are used in defining capabilityFlags, inputPowerRequirements, and outputPowerCharacter in the IOPMPowerState structure. 

See Also:
IOPMPowerFlags
enum { 
    kIOPMPowerOn = 0x00000002, 
    kIOPMDeviceUsable = 0x00008000, 
    kIOPMLowPower = 0x00010000, 
    kIOPMPreventIdleSleep = 0x00000040, 
    kIOPMSleepCapability = 0x00000004, 
    kIOPMRestartCapability = 0x00000080, 
    kIOPMSleep = 0x00000001, 
    kIOPMRestart = 0x00000080 
};  
Constants
kIOPMPowerOn
Indicates the device is on, requires power, and provides power. Useful as a: Capability, InputPowerRequirement, OutputPowerCharacter 

kIOPMDeviceUsable
Indicates the device is usable in this state. Useful only as a Capability 

kIOPMLowPower
Indicates device is in a low power state. May be bitwis-OR'd together with kIOPMDeviceUsable flag, to indicate the device is still usable. 

A device with a capability of kIOPMLowPower may: Require either 0 or kIOPMPowerOn from its power parent Offer either kIOPMLowPower, kIOPMPowerOn, or 0 (no power at all) to its power plane children. 

Useful only as a Capability, although USB drivers should consult USB family documentation for other valid circumstances to use the kIOPMLowPower bit. 

kIOPMPreventIdleSleep
In the capability field of a power state, disallows idle system sleep while the device is in that state. 

For example, displays and disks set this capability for their ON power state; since the system may not idle sleep while the display (and thus keyboard or mouse) or the disk is active. 

Useful only as a Capability. 

kIOPMSleepCapability
Used only by certain IOKit Families (USB). Not defined or used by generic Power Management. Read your family documentation to see if you should define a powerstate using these capabilities. 

kIOPMRestartCapability
Used only by certain IOKit Families (USB). Not defined or used by generic Power Management. Read your family documentation to see if you should define a powerstate using these capabilities. 

kIOPMSleep
Used only by certain IOKit Families (USB). Not defined or used by generic Power Management. Read your family documentation to see if you should define a powerstate using these capabilities. 

kIOPMRestart
Used only by certain IOKit Families (USB). Not defined or used by generic Power Management. Read your family documentation to see if you should define a powerstate using these capabilities.
Discussion 

These bits may be bitwise-OR'd together in the IOPMPowerState capabilityFlags field, the outputPowerCharacter field, and/or the inputPowerRequirement field. 

The comments clearly mark whether each flag should be used in the capabilityFlags field, outputPowerCharacter field, and inputPowerRequirement field, or all three. 

The value of capabilityFlags, inputPowerRequirement or outputPowerCharacter may be 0. Most drivers implement their 'OFF' state, used when asleep, by defininf each of the 3 fields as 0. 

The bits listed below are only the most common bits used to define a device's power states. Your device's IO family may require that your device specify other input or output power flags to interact properly. Consult family-specific documentation to determine if your IOPower plane parents or children require other power flags; they probably don't.*/
enum { 
    kIOPMPowerOn = 0x00000002, 
    kIOPMDeviceUsable = 0x00008000, 
    kIOPMLowPower = 0x00010000, 
    kIOPMPreventIdleSleep = 0x00000040, 
    kIOPMSleepCapability = 0x00000004, 
    kIOPMRestartCapability = 0x00000080, 
    kIOPMSleep = 0x00000001, 
    kIOPMRestart = 0x00000080 
}; 


#define  HYS_IOKIT_PWR_MGT_IOPM_H_END
#include <HYS/IOKit/pwr_mgt/IOPM.h>

#endif //_IOKIT_IOPM_H

