
#ifndef _IOKIT_IOFIREWIRESBP2LIB_H_
#define _IOKIT_IOFIREWIRESBP2LIB_H_

#include <IOKit/firewire/IOFireWireFamilyCommon.h>
#include <IOKit/IOMessage.h>

#include <HYS/IOKit/sbp2/IOFireWireSBP2Lib.h>

// 
/*FWSBP2LoginResponse


typedef struct { 
    UInt16 length; 
    UInt16 loginID; 
    UInt32 commandBlockAgentAddressHi; 
    UInt32 commandBlockAgentAddressLo; 
    UInt16 reserved; 
    UInt16 reconnectHold; 
} FWSBP2LoginResponse;  
Fields
length
Length of login response.
loginID
Unique ID representing this login.
commandBlockAgentAddressHi
High 32 bits of command block agent address.
commandBlockAgentAddressLo
Low 32 bits of command block agent address.
reserved
Reserved.
reconnectHold
Reconnect timeout encoded as 2^reconnectHold seconds.*/
typedef struct { 
    UInt16 length; 
    UInt16 loginID; 
    UInt32 commandBlockAgentAddressHi; 
    UInt32 commandBlockAgentAddressLo; 
    UInt16 reserved; 
    UInt16 reconnectHold; 
} FWSBP2LoginResponse;  

/*FWSBP2StatusBlock


typedef struct { 
    UInt8 details; 
    UInt8 sbpStatus; 
    UInt16 orbOffsetHi; 
    UInt32 orbOffsetLo; 
    UInt32 status[6]; 
} FWSBP2StatusBlock;  
Fields
details
Src, Resp, D, Len fields of status block format
sbpStatus
SBP2 specific status
orbOffsetHi
High 32 bits of address of orb status is for.
orbOffsetLo
Low 32 bits of address of orb status is for.
status
[6] Up to 48 bytes of additional data. Length is determined by len field.*/
typedef struct { 
    UInt8 details; 
    UInt8 sbpStatus; 
    UInt16 orbOffsetHi; 
    UInt32 orbOffsetLo; 
    UInt32 status[6]; 
} FWSBP2StatusBlock;  

/*FWSBP2LoginCompleteParams


typedef struct { 
    void *refCon; // refCon from login object 
    UInt32 generation; // generation this login was attempted in 
    IOReturn status; // status of login attempt 
    FWSBP2LoginResponse *loginResponse; // pointer to loginResponse buffer 
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer 
} FWSBP2LoginCompleteParams;  
Fields
refCon
refCon set on login object.
generation
FireWire generation value.
status
Status of login attempt.
loginResponse
Pointer to login response struct.
statusBlock
Pointer to status block buffer.
statusBlockLength
Length of entire status block.*/
typedef struct { 
    void *refCon; // refCon from login object 
    UInt32 generation; // generation this login was attempted in 
    IOReturn status; // status of login attempt 
    FWSBP2LoginResponse *loginResponse; // pointer to loginResponse buffer 
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer 
} FWSBP2LoginCompleteParams;  

/*IOFWSBP2LoginCallback


typedef void ( *IOFWSBP2LoginCallback)(
    void *refCon,
    FWSBP2LoginCompleteParams *params );  
Parameters
refCon
Reference constant supplied when the notification was registered.
params
Structure containing additional information about the status of the login.*/
typedef void ( *IOFWSBP2LoginCallback)(
    void *refCon,
    FWSBP2LoginCompleteParams *params );  

/*FWSBP2LogoutCompleteParams


typedef struct { 
    void *refCon; // refCon from login object 
    UInt32 generation; // generation this login was attempted in 
    IOReturn status; // status of login attempt 
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer 
} FWSBP2LogoutCompleteParams;  
Fields
refCon
refCon set on login object.
generation
FireWire generation value.
status
Status of login attempt.
statusBlock
Pointer to status block buffer.
statusBlockLength
Length of entire status block.*/
typedef struct { 
    void *refCon; // refCon from login object 
    UInt32 generation; // generation this login was attempted in 
    IOReturn status; // status of login attempt 
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer 
} FWSBP2LogoutCompleteParams;

/*IOFWSBP2LogoutCallback


typedef void ( *IOFWSBP2LogoutCallback)(
    void *refCon,
    FWSBP2LogoutCompleteParams *params );  
Parameters
refCon
Reference constant supplied when the notification was registered.
params
Structure containing additional information about the status of the logout.*/
typedef void ( *IOFWSBP2LogoutCallback)(
    void *refCon,
    FWSBP2LogoutCompleteParams *params );  

/*FWSBP2NotifyParams


typedef struct { 
    void *refCon; // refCon from ORB object 
    UInt32 notificationEvent; 
    const void *message; 
    UInt32 length; 
    UInt32 generation; 
} FWSBP2NotifyParams;  
Fields
refCon
refCon set on Login object for unsolicited status or refCon set ORB for normal status.
notificationEvent
Type of event we are being notified of.
message
buffer containing message.
length
length of message field.
generation
FireWire generation value.*/
typedef struct { 
    void *refCon; // refCon from ORB object 
    UInt32 notificationEvent; 
    const void *message; 
    UInt32 length; 
    UInt32 generation; 
} FWSBP2NotifyParams;  

/*FWSBP2NotifyCallback


typedef void ( *IOFWSBP2NotifyCallback)(
    void *refCon,
    FWSBP2NotifyParams *params);  
Parameters
refCon
Reference constant supplied when the notification was registered.
params
FWSBP2NotifyParams containing notification information.*/
typedef void ( *IOFWSBP2NotifyCallback)(
    void *refCon,
    FWSBP2NotifyParams *params);  

/*IOFWSBP2StatusCallback


typedef void ( *IOFWSBP2StatusCallback)(
    void *refCon,
    IOReturn status);  
Parameters
refCon
Reference constant supplied when the notification was registered.
status
Indicates success or failure of operation.*/
typedef void ( *IOFWSBP2StatusCallback)(
    void *refCon,
    IOReturn status);  

/*IOFWSBP2FetchAgentWriteCallback


typedef void ( *IOFWSBP2FetchAgentWriteCallback)(
    void *refCon,
    IOReturn status,
    void *orbRefCon );  
Parameters
refCon
Reference constant supplied when the notification was registered.
status
Indicates success or failure of operation.
orbRefCon
refCon from last orb in chain.*/
typedef void ( *IOFWSBP2FetchAgentWriteCallback)(
    void *refCon,
    IOReturn status,
    void *orbRefCon );  

/*IOFWSBP2ORBAppendCallback


typedef void ( *IOFWSBP2ORBAppendCallback)(
    void *refCon,
    IOReturn status,
    void *orb );  
Parameters
refCon
Reference constant supplied when the notification was registered.
status
Indicates success or failure of operation.
orb
refCon set on management orb.*/
typedef void ( *IOFWSBP2ORBAppendCallback)(
    void *refCon,
    IOReturn status,
    void *orb );  

/*IOFWSBP2ORBCompleteCallback


typedef void ( *IOFWSBP2ORBCompleteCallback)(
    void *refCon,
    IOReturn status,
    void *orb );  
Parameters
refCon
Reference constant supplied when the notification was registered.
status
Indicates success or failure of operation.
orb
refCon set on management orb.*/
typedef void ( *IOFWSBP2ORBCompleteCallback)(
    void *refCon,
    IOReturn status,
    void *orb );  

/*FWSBP2ReconnectParams


typedef struct { 
    void *refCon; // refCon from lun object 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of reconnect attempt  
    FWSBP2StatusBlock *reconnectStatusBlock; // pointer to statusBlock buffer 
    UInt32 reconnectStatusBlockLength; // size of statusBlock buffer 
} FWSBP2ReconnectParams;  
Fields
refCon
refCon set on LUN object.
generation
FireWire generation value.
status
Status of reconnect attempt.
reconnectStatusBlock
Pointer to status block buffer.
reconnectStatusBlockLength
Length of entire status block.*/
typedef struct { 
    void *refCon; // refCon from lun object 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of reconnect attempt  
    FWSBP2StatusBlock *reconnectStatusBlock; // pointer to statusBlock buffer 
    UInt32 reconnectStatusBlockLength; // size of statusBlock buffer 
} FWSBP2ReconnectParams;  

//////////////////////////////////

//struct

struct IOFireWireSBP2LibORBInterface {

	IUNKNOWN_C_GUTS;

	UInt16	version;						
    UInt16	revision;

/*setRefCon


Sets the ORB refCon. 

void ( *setRefCon)(
    void *self,
    void *refCon );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
refCon
a user defined value.
Discussion 

Sets a user defined value on the ORB that can be retrieved later with the method getRefCon.*/
void ( *setRefCon)(
    void *self,
    void *refCon );  

/*getRefCon


Returns the refCon set with setRefCon. 

void * ( *getRefCon)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
Return Value

Returns the previously stored user defined value. 
Discussion 

Returns the user defined value previously stored in the ORB with setRefCon*/
void * ( *getRefCon)(
    void *self );  

/*setCommandFlags


Sets configuration flags for the ORB. 

void ( *setCommandFlags)(
    void *self,
    UInt32 flags );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
flags
The flags to be set.
Discussion 

Sets the configuration flags for the ORB. These can be any of the following: 

kFWSBP2CommandCompleteNotify - Set the notify bit as specified in SBP2 standard. Set to receive completion/timeout notification on this ORB. You almost always want to set this.

kFWSBP2CommandTransferDataFromTarget - Transfer direction as specified in SBP2 standard. Set if data is to be written by the device into the host's memory.

kFWSBP2CommandImmediate - Immediate Append. ORB address will be written to fetch agent and not chained. It is only legal to have one immediate ORB in progress at a time.

kFWSBP2CommandNormalORB - ORB format 0 - Format specified by SBP2 standard. Set this for most ORBs.

kFWSBP2CommandReservedORB - ORB format 1 - Format reserved by SBP2 standard for future standardization.

kFWSBP2CommandVendorORB - ORB format 2 - Format specified by SBP2 standard for vendor dependent ORBs.

kFWSBP2CommandDummyORB - ORB format 3 - Format specified by SBP2 standard for dummy ORBs.

kFWSBP2CommandCheckGeneration - If set upon submitORB, the ORB will only be appended if generation set with setCommandGeneration() matches the current generation. Pretty much all SBP2 drivers need sophisticated logic to track login state, so this is generally not used. 

kFWSBP2CommandFixedSize - Do not allocate more memory for page table if needed. If there is not enough space in the currently allocated page table, the setCommandBuffers call will fail. This is important to set if your device is the backing store, as we don't want to cause memory allocations on the paging path. 

kFWSBP2CommandVirtualORBs - Normally ORBs are backed by physical address spaces. Setting this flag makes this ORB backed by a pseudo address space. This can make ORBs easier to see in a bus trace. Virtual ORBs will have an address in the form of ffcX.XXXX.0000.0000. Pseudo address space backed ORBs are slower, so you won't want to set for deployment builds.*/
void ( *setCommandFlags)(
    void *self,
    UInt32 flags );  

/*setMaxORBPayloadSize


Sets max payload size for the ORB. 

void ( *setMaxORBPayloadSize)(
    void *self,
    UInt32 size );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
maxPayloadSize
The maximum payload size in bytes.
Discussion 

This sets the maximum payload size for this ORB only. This size is clipped by the global max payload size set in the login object.*/
void ( *setMaxORBPayloadSize)(
    void *self,
    UInt32 size );  

/*setCommandTimeout


Sets the timeout of the ORB. 

void ( *setCommandTimeout)(
    void *self,
    UInt32 timeout );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
timeout
The timeout duration in milliseconds.
Discussion 

This sets the timeout for the ORB in milliseconds. Note that ORBs without timeouts can be "lost." You will obviously not recieve timeout notification for timeouts of zero. But perhaps less obviously you will not recieve orb reset notification, which is really a sort of accelerated timeout notification for bus reset situations.*/
void ( *setCommandTimeout)(
    void *self,
    UInt32 timeout );  

/*setCommandGeneration


Sets the command generation. 

void ( *setCommandGeneration)(
    void *self,
    UInt32 generation );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
gen
The bus generation for command execution.
Discussion 

This sets the bus generation this ORB should be appended in. It is only meaningful when combined with the kFWSBP2CommandCheckGeneration flags above.*/
void ( *setCommandGeneration)(
    void *self,
    UInt32 generation );  

/*setCommandBuffersAsRanges


Creates a page table from a list of ranges. 

IOReturn ( *setCommandBuffersAsRanges)(
    void *self,
    FWSBP2VirtualRange *ranges,
    UInt32 withCount, 
    UInt32 withDirection,
    UInt32 offset, 
    UInt32 length );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
ranges
An array of ranges representing the data to be transfered.
withCount
The number of ranges in the ranges array.
withDirection
An IODirection indicating the direction of data transfer.
offset
Offset in bytes into data to begin writing table at.
length
Number of bytes of data to map from offset.
Return Value

Returns KIOReturnSuccess if the page table was written successfully. 
Discussion 

Creates a page table with the given parameters. Any addresses mapped by this method must remain valid until setCommandBuffers is called again or releaseCommandBuffers is called. The SBP2 services do not release references to the command buffers just because the command has completed.*/

IOReturn ( *setCommandBuffersAsRanges)(
    void *self,
    FWSBP2VirtualRange *ranges,
    UInt32 withCount, 
    UInt32 withDirection,
    UInt32 offset, 
    UInt32 length );  

/*releaseCommandBuffers


Releases SBP2's reference to the command buffers. 

IOReturn ( *releaseCommandBuffers)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
Return Value

Returns KIOReturnSuccess if the page table was cleared successfully. 
Discussion 

When you create a page table with one of the variants of setCommandBuffers. SBP2 holds on to a reference to the buffers until this method is called. This means that if a command completed and you released the buffers without calling this method you could leave FW in an inconsistent state.*/
IOReturn ( *releaseCommandBuffers)(
    void *self );  

/*setCommandBlock


Sets the command block portion of the ORB. 

IOReturn ( *setCommandBlock)(
    void *self,
    void *buffer,
    UInt32 length );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
buffer
Pointer to buffer to copy command block from.
length
Number of bytes of data to copy.
Return Value

Returns KIOReturnSuccess if the command block was updated successfully. 
Discussion 

Copys the data provided in the buffer to the command block portion of the ORB.*/
IOReturn ( *setCommandBlock)(
    void *self,
    void *buffer,
    UInt32 length );  

/*LSIWorkaroundSetCommandBuffersAsRanges


Creates a page table with the LSI workaround from a list of ranges. 

IOReturn ( *LSIWorkaroundSetCommandBuffersAsRanges)(
    void *self,
    FWSBP2VirtualRange *ranges,
    UInt32 withCount, 
    UInt32 withDirection,
    UInt32 offset, 
    UInt32 length );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
ranges
An array of ranges representing the data to be transfered.
withCount
The number of ranges in the ranges array.
withDirection
An IODirection indicating the direction of data transfer.
offset
Offset in bytes into data to begin writing table at.
length
Number of bytes of data to map from offset.
Return Value

Returns KIOReturnSuccess if the page table was written successfully. 
Discussion 

Creates an LSI workaround page table with the given parameters. Any addresses mapped by this method routine must remain valid until setCommandBuffers is called again or releaseCommandBuffers is called. The SBP2 services do not release references to the command buffers just because the command has completed.*/
IOReturn ( *LSIWorkaroundSetCommandBuffersAsRanges)(
    void *self,
    FWSBP2VirtualRange *ranges,
    UInt32 withCount, 
    UInt32 withDirection,
    UInt32 offset, 
    UInt32 length );  

/*LSIWorkaroundSyncBuffersForOutput


Synchronize the buffers for output. 

IOReturn ( *LSIWorkaroundSyncBuffersForOutput)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
Return Value

Returns kIOReturnSuccess if sync was successful. 
Discussion 

Since double buffering may be invovled in the workaround. The driver needs to indicate when these buffers should be syncronized with the original descriptor. For data that will be output LSIWorkaroundSyncBuffersForOutput should be called before submiting the ORB.*/
IOReturn ( *LSIWorkaroundSyncBuffersForOutput)(
    void *self );  

/*LSIWorkaroundSyncBuffersForInput


Synchronize the buffers for input. 

IOReturn ( *LSIWorkaroundSyncBuffersForInput)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibORBInterface.
Return Value

Returns kIOReturnSuccess if sync was successful. 
Discussion 

Since double buffering may be invovled in the workaround. The driver needs to indicate when these buffers should be syncronized with the original descriptor. For data that will be input LSIWorkaroundSyncBuffersForInput should be called after receiving completion status for the ORB.*/
IOReturn ( *LSIWorkaroundSyncBuffersForInput)(
    void *self ); 

};
typedef IOFireWireSBP2LibORBInterface IOFireWireSBP2LibORBInterface;

struct IOFireWireSBP2LibLoginInterface {

	IUNKNOWN_C_GUTS;//c
	UInt16	version;	//c					
    	UInt16	revision;//c


/*submitLogin


Attempts to login to the LUN. 

IOReturn ( *submitLogin)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns kIOReturnSuccess login has successlly begun. 
Discussion 

This call begins the login process. The login object should be configured prior to this call. If kIOReturnSuccess is returned from this call then the loginCompletion routine will be called when the login completes (successfully or unsuccesfully).*/
IOReturn ( *submitLogin)(
    void *self );  


/*submitLogout


Attempts to logout of the LUN. 

IOReturn ( *submitLogout)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns kIOReturnSuccess if logout has successfully begun. 
Discussion 

This call begins the logout process. If kIOReturnSuccess is returned from this call then the logoutCompletion routine will be called when the logout completes (successfully or unsuccesfully).*/
IOReturn ( *submitLogout)(
    void *self );  

/*setLoginFlags


Sets login configuration flags. 

void ( *setLoginFlags)(
    void *self,
    UInt32 flags );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
loginFlags
the login configuration flags.
Discussion 

Configures the login behavior according to the provided flags. Currently two flags are defined for this API. kFWSBP2ExclusiveLogin sets the exclusive login bit in the login ORB. kFWSBP2DontSynchronizeMgmtAgent allows simultaneous logins or reconnects to LUNs with a common management agent (ie LUNs in the same unit directory).*/
void ( *setLoginFlags)(
    void *self,
    UInt32 flags );  

/*setLoginCallback


Sets the callback to be called when a login attempt is complete. 

void ( *setLoginCallback)(
    void *self,
    void *refCon,
    IOFWSBP2LoginCallback callback );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
refCon
refCon passed to callback.
callback
address of callback method of type FWSBP2LoginCallback.
Discussion 

The supplied callback is called when a login attempt has completed. "status" in the callback's params should be checked to determine the success or failure of the login attempt. The "refCon" field in the params will return the refcon set with setRefCon. If "statusBlock" is non-null then login status was written and it has been supplied here. If the login attempt was successful then the login response will be supplied in the "loginResponse" buffer. Note: all buffers supplied to callbacks are only valid for the duration of the callback. Also, you are not to modify the contents of any supplied buffer.*/
void ( *setLoginCallback)(
    void *self,
    void *refCon,
    IOFWSBP2LoginCallback callback );  

/*setLogoutCallback


Sets the callback to be called when a logout attempt is complete. 

void ( *setLogoutCallback)(
    void *self,
    void *refCon,
    IOFWSBP2LogoutCallback callback );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
refCon
refCon passed to callback.
callback
address of callback method of type FWSBP2LogoutCallback.
Discussion 

The supplied callback is called when a logout attempt has completed. "status" in the callback's params should be checked to determine the success or failure of the logout attempt. The "refCon" field in the params will return the refcon set with setRefCon. If "statusBlock" is non-null then logout status was written and it has been supplied here. Note: all buffers supplied to callbacks are only valid for the duration of the callback. Also, you are not to modify the contents of any supplied buffer.*/
void ( *setLogoutCallback)(
    void *self,
    void *refCon,
    IOFWSBP2LogoutCallback callback );  

/*setRefCon


Sets the login refCon. 

void ( *setRefCon)(
    void *self,
    void *refCon );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
refCon
a user defined value.
Discussion 

Sets a user defined value on the login that can be retrieved later with the method getRefCon.*/
void ( *setRefCon)(
    void *self,
    void *refCon ); 

/*getRefCon


Returns the refCon set with setRefCon. 

void * ( *getRefCon)(
    void *self);  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns the previously stored user defined value. 
Discussion 

Returns the user defined value previously stored in the login with setRefCon.*/
void * ( *getRefCon)(
    void *self);  

/*getMaxCommandBlockSize


Returns the maximum command block size. 

UInt32 ( *getMaxCommandBlockSize)(
    void *self);  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns a UInt32 containing the maximum command block size. 
Discussion 

The device publishes an upper limit on the size of command block that it can accept. That value can be accessed via this method.*/
UInt32 ( *getMaxCommandBlockSize)(
    void *self);  

/*getLoginID


Returns the current login ID. 

UInt32 ( *getLoginID)(
    void *self);  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns a UInt32 containing the current login ID. 
Discussion 

When we successfully login to a device. The device gives us a unique login id. This is used internally for reconnecting to the device after bus resets and for certain other management ORBs. Most drivers are probably not interested in this value.*/
UInt32 ( *getLoginID)(
    void *self); 

/*setMaxPayloadSize


Sets the maximum data transfer length for a normal command ORB. 

void ( *setMaxPayloadSize)(
    void *self,
    UInt32 size );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
reconnectTime
The desired maximum payload size in bytes.
Discussion 

Sets the maximum data transfer length for a normal command ORB. This value is the maximum for all ORBs sent to this LUN. This can be trimmed further on an ORB by ORB basis, by a similar call in the IOFireWireSBP2ORB itself.*/
void ( *setMaxPayloadSize)(
    void *self,
    UInt32 size );  

/*setReconnectTime


Sets the desired reconnect duration. 

void ( *setReconnectTime)(
    void *self,
    UInt32 time );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
reconnectTime
The desired reconnect timeout encoded as 2^reconnectTime seconds.
Discussion 

The target and initiator arbitrate the duration of the reconnect timeout. Here the initiator specifies its desired timeout time in 2^reconnectTime seconds. After a successful login the device returns the actual timeout value it wishes to use. This value may be less than the reconnect timeout that the intiator specified if this is all that the device can support.*/
void ( *setReconnectTime)(
    void *self,
    UInt32 time );  

/*createORB


Creates a new IOFireWireSBP2ORB for this login. 

IUnknownVTbl** ( *createORB)(
    void *self,
    REFIID iid );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
iid
UUID for the desired type of IOFireWireSBP2LibLoginInterface.
Return Value

Returns a pointer to the new ORB object. 
Discussion 

Create a new IOFireWireSBP2ORB for this login. It can be configured with it's accessors and executed with submitORB below.*/
IUnknownVTbl** ( *createORB)(
    void *self,
    REFIID iid );  

/*submitORB


Submits the given orb 

IOReturn ( *submitORB)(
    void *self,
    IOFireWireSBP2LibORBInterface ** orb );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
orb
The orb to be executed.
Return Value

Returns kIOReturnSuccess if the ORB has been started successfully. 
Discussion 

Starts execution of the given ORB. If the ORB is an immediate ORB it's addresss is written to the fetch agent. If it is a non immediate orb its address is appended to the last orb of the currently processing chain. The doorbell is not rung automatically it must be run manually with the ringDoorbell command described below.*/
IOReturn ( *submitORB)(
    void *self,
    IOFireWireSBP2LibORBInterface ** orb );  

/*setUnsolicitedStatusNotify


Sets the callback to be called on normal command status. 

void ( *setUnsolicitedStatusNotify)(
    void *self,
    void *refCon,
    IOFWSBP2NotifyCallback callback );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
refCon
refCon passed to callback.
callback
address of callback method of type FWSBP2NotifyCallback.
Discussion 

The supplied callback is called when unsolicited status is recieved. "notificationEvent" in the callback's params will indicate what happened. In this case it will be set to kFWSBP2UnsolicitedStatus. If "len" is non-zero then "message" contains the data written to the status block. Note: any buffers returned by callbacks are only valid for the duration of the login and should not have their contents modified. The "refCon" field in the callback's params will return the refcon set with setRefCon.*/
void ( *setUnsolicitedStatusNotify)(
    void *self,
    void *refCon,
    IOFWSBP2NotifyCallback callback );  

/*setStatusNotify


Sets the callback to be called on normal command status. 

void ( *setStatusNotify)(
    void *self,
    void *refCon,
    IOFWSBP2NotifyCallback callback );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
refCon
refCon passed to callback.
callback
Address of callback method of type FWSBP2NotifyCallback.
Discussion 

The supplied callback is called when normal command status is recieved, when a normal command times out, or when a normal command is aborted. "notificationEvent" in the callback's params will indicate what happened. It will be set to one of the following values: kFWSBP2NormalCommandReset, kFWSBP2NormalCommandStatus, or kFWSBP2NormalCommandTimeout. If the event type is kFWSBP2NormalCommandTimeout and "len" is non-zero then "message" contains the data written to the status block.*/
void ( *setStatusNotify)(
    void *self,
    void *refCon,
    IOFWSBP2NotifyCallback callback ); 

/*setFetchAgentResetCallback


Sets the callback to be called when a fetch agent reset completes. 

void ( *setFetchAgentResetCallback)(
    void *self,
    void *refCon,
    IOFWSBP2StatusCallback callback );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
refCon
refCon passed to callback.
callback
address of callback method of type FWSBP2FetchAgentWriteCallback.
Discussion 

The fetch agent state machine on the device can be reset by a write to a specific register. The SBP2 services offer a utility method to reset the fetch agent. You can register a callback routine here to be notified when this rest write completes.*/
void ( *setFetchAgentResetCallback)(
    void *self,
    void *refCon,
    IOFWSBP2StatusCallback callback );  

/*submitFetchAgentReset


Resets the LUN's fetch agent. 

IOReturn ( *submitFetchAgentReset)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns kIOReturnSuccess if the reset started successfully. 
Discussion 

The fetch agent state machine on the device can be reset by a write to a specific register. This reset can be intiated by a call to this method. Notification of the completion of this write can be had by registering a callback with the setFetchAgentResetCallback method.*/
IOReturn ( *submitFetchAgentReset)(
    void *self );  

/*setFetchAgentWriteCallback


Sets the callback to be called when the fetch agent write completes. 

void ( *setFetchAgentWriteCallback)(
    void *self,
    void *refCon,
    IOFWSBP2FetchAgentWriteCallback callback );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
refCon
refCon passed to callback.
callback
address of callback method of type FWSBP2FetchAgentWriteCallback.
Discussion 

When an immediate orb is executed with submitORB, it's address is written to a specific address on the device. This address is called the fetch agent. The device the reads that orb from the Mac's memory and executes it. With this call you can register to be called back when this write to the fetch agent completes. The SBP2 services guarantee that the fetch agent write will be complete before status is reported for an ORB, so for most drivers this notification is not required.*/
void ( *setFetchAgentWriteCallback)(
    void *self,
    void *refCon,
    IOFWSBP2FetchAgentWriteCallback callback );  

/*ringDoorbell


Rings the doorbell on the LUN. 

IOReturn ( *ringDoorbell)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns kIOReturnSuccess if the ring started successfully. 
Discussion 

Non-immediate appends to the ORB chain may require the fetch agent state machine to be notified of the new ORB's presence. This is accomplished by writing to the so called doorbell register. This method begins one of those writes.*/
IOReturn ( *ringDoorbell)(
    void *self );  

/*enableUnsolicitedStatus


Enables unsolicited status. 

IOReturn ( *enableUnsolicitedStatus)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
Return Value

Returns kIOReturnSuccess if the status enable write started successfully. 
Discussion 

After unsolicited is sent the device will not send any additional unsolicited status until a specific register is written. This serves as a sort of flow-control for unsolicited status. After unsolicited status is recieved and processed drivers will want to reenable the delivery of unsolicted status by a call to this method.*/
IOReturn ( *enableUnsolicitedStatus)(
    void *self ); 

/*setBusyTimeoutRegisterValue


Sets the value to be written to the BUSY_TIMEOUT register. 

IOReturn ( *setBusyTimeoutRegisterValue)(
    void *self,
    UInt32 timeout );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
timeout
desired value of the BUSY_TIMEOUT register.
Discussion 

1394-1995 defines a register known as the BUSY_TIMEOUT register. This register controls the busy retry behavior of your device. The initial value for this register is 0x00000000. Which means busied transactions will not be retried. Since most devices want their transactions retired on busy acks, the SBP2 service automatically updates the BUSY_TIMEOUT register with the value specified here whenever necessary. Most drivers should set this value to 0x0000000f.*/
IOReturn ( *setBusyTimeoutRegisterValue)(
    void *self,
    UInt32 timeout );  

/*setPassword


Sets the login password. 

IOReturn ( *setPassword)(
    void *self,
    void *buffer,
    UInt32 length );  
Parameters
self
Pointer to IOFireWireSBP2LibLoginInterface object.
buf
a pointer to the password buffer.
len
the length in bytes of the password buffer.
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

Sets the login password using a buffer and a length. An alternate version exists that accepts an IOMemoryDescriptor. If the password length is 8 or less the password is copied directly into the login orb. If the length is greater than 8 the buffer is referenced by address in the login ORB. In this case the buffer is not copied and should remain allocated for the duration of the login attempt.*/
IOReturn ( *setPassword)(
    void *self,
    void *buffer,
    UInt32 length );  
};
typedef struct IOFireWireSBP2LibLoginInterface IOFireWireSBP2LibLoginInterface;

struct IOFireWireSBP2LibMgmtORBInterface {
	IUNKNOWN_C_GUTS;
	UInt16	version;						
   	 UInt16	revision;


/*submitORB


Submits this ORB for execution. 

IOReturn ( *submitORB)(
    void *self );  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
Discussion 

Submits this ORB for execution*/
IOReturn ( *submitORB)(
    void *self ); 

/*setORBCompleteCallback


Sets the ORB completion routine. 

void ( *setORBCompleteCallback)(
    void *self,
    void *refCon, 
    IOFWSBP2ORBCompleteCallback callback );  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
refCon
refCon passed as first argument to completion routine
Discussion 

Sets the completion routine to be called when the ORB finishes execution. The refCon set with setRefCon will also be passed as the third argument to the completion handler.*/
void ( *setORBCompleteCallback)(
    void *self,
    void *refCon, 
    IOFWSBP2ORBCompleteCallback callback );  

/*setRefCon


Sets the login refCon. 

void ( *setRefCon)(
    void *self,
    void *refCon );  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
refCon
a user defined value.
Discussion 

Sets a user defined value on the login that can be retrieved later with the method getRefCon.*/
void ( *setRefCon)(
    void *self,
    void *refCon );  

/*getRefCon


Returns the current function of the management ORB. 

void * ( *getRefCon)(
    void *self);  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
Return Value

Returns the function of the management ORB. 
Discussion 

Returns the function of the management ORB. This is the same value that was set with setCommandFunction.*/
void * ( *getRefCon)(
    void *self);  

/*setCommandFunction


Sets the function of the management ORB. 

IOReturn ( *setCommandFunction)(
    void *self,
    UInt32 function );  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
function
a value indicating the desired management function.
Return Value

Returns kIOReturnSuccess if function was a legal function. 
Discussion 

Sets the the function of the management ORB. Legal values are kFWSBP2QueryLogins, kFWSBP2AbortTask, kFWSBP2AbortTaskSet, kFWSBP2LogicalUnitReset, and kFWSBP2TargetReset.*/
IOReturn ( *setCommandFunction)(
    void *self,
    UInt32 function );  

/*setManageeORB


Sets the command to be managed by the management ORB. 

IOReturn ( *setManageeORB)(
    void *self,
    void *command );  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
command
a reference to an IOFireWireSBP2Login or an IOFireWireSBP2ORB.
Return Value

Returns kIOReturnSuccess on a success. 
Discussion 

All management functions except kFWSBP2QueryLogins require a reference to an ORB of some sort. kFWSBP2AbortTask requires a reference to the ORB to be aborted. This method allows you to set the Normal Command ORB to be managed.*/
IOReturn ( *setManageeORB)(
    void *self,
    void *command );  

/*setManageeLogin


Sets the command to be managed by the management ORB. 

IOReturn ( *setManageeLogin)(
    void *self,
    void *command );  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
command
a reference to an IOFireWireSBP2Login or an IOFireWireSBP2ORB.
Return Value

Returns kIOReturnSuccess on a success. 
Discussion 

All management functions except kFWSBP2QueryLogins require a reference to an ORB of some sort. kFWSBP2AbortTaskSet, kFWSBP2LogicalUnitReset, and kFWSBP2TargetReset require a reference to the login ORB. This method allows you to set the login ORB to be managed.*/
IOReturn ( *setManageeLogin)(
    void *self,
    void *command ); 

/*setResponseBuffer


Sets the response buffer for the management ORB. 

IOReturn ( *setResponseBuffer)(
    void *self,
    void *buf,
    UInt32 len );  
Parameters
self
Pointer to a IOFireWireSBP2LibMgmtORBInterface.
buf
backing store for buffer
len
length of buffer.
Return Value

Returns kIOReturnSuccess on a success. 
Discussion 

Sets the response buffer for the management ORB. kFWSBP2QueryLogins returns a response to its query and needs to write it somewhere. This routine allows you to specify the location.*/
IOReturn ( *setResponseBuffer)(
    void *self,
    void *buf,
    UInt32 len ); 

};
typedef struct IOFireWireSBP2LibMgmtORBInterface IOFireWireSBP2LibMgmtORBInterface;

struct IOFireWireSBP2LibLUNInterface {

	IUNKNOWN_C_GUTS;

	UInt16	version;						
    UInt16	revision;


/*open


Exclusively opens a connection to the in-kernel device. 

IOReturn ( *open)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

Exclusively opens a connection to the in-kernel device. As long as the in-kernel device object is open, no other drivers will be able to open a connection to the device. When open the device on the bus may disappear, but the in-kernel object representing it will stay instantiated and can begin communicating with the device again if it ever reappears.*/
IOReturn ( *open)(
    void *self );  

/*openWithSessionRef


Opens a connection to a device that is already open. 

IOReturn ( *openWithSessionRef)(
    void *self,
    IOFireWireSessionRef sessionRef );  
Parameters
sessionRef
SessionRef returned from getSessionRef call.
self
Pointer to IOFireWireSBP2LibLUNInterface.
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

Sometimes it is desirable to open multiple user clients on a device. In the case of FireWire sometimes we wish to have both the FireWire User Client and the SBP2 User Client open at the same time. 

The technique to arbitrate this is as follows :

First open normally the device furthest from the root in the IORegistry.

Second, get its sessionRef with the getSessionRef call.

Third open the device further up the chain by calling this method and passing the sessionRef returned from the call in step 2.*/
IOReturn ( *openWithSessionRef)(
    void *self,
    IOFireWireSessionRef sessionRef );  

/*getSessionRef


Returns the session reference to an already open device. 

IOFireWireSessionRef ( *getSessionRef)(
    void *self);  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
Return Value

Returns a sessionRef on success. 
Discussion 

Sometimes it is desirable to open multiple user clients on a device. In the case of FireWire sometimes we wish to have both the FireWire User Client and the SBP2 User Client open at the same time. 

The technique to arbitrate this is as follows:

First open normally the device furthest from the root in the IORegistry.

Second, get its sessionRef with a call to this method.

Third open the device further up the chain by calling openWithSessionRef and passing the sessionRef returned from this call.*/
IOFireWireSessionRef ( *getSessionRef)(
    void *self); 

/*close


Opens a connection to a device that is not already open. 

void ( *close)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
Discussion 

Closes an exclusive access to the device. When a device is closed it may be unloaded by the kernel. If it is unloaded and then later reappears it will be represented by a different object. You won't be able to use this user client on the new object. The new object will have to be looked up in the IORegistry and a new user client will have to be opened on it.*/
void ( *close)(
    void *self );  

/*addCallbackDispatcherToRunLoop


Adds a dispatcher for kernel callbacks to the specified run loop. 

IOReturn ( *addCallbackDispatcherToRunLoop)(
    void *self,
    CFRunLoopRef cfRunLoopRef );  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
cfRunLoopRef
Reference to a run loop
Return Value

Returns kIOReturnSuccess on success. 
Discussion 

The user space portions of the SBP2 api communicate with the in-kernel services by messaging the kernel. Similarly, the kernel messages the user space services in response. These responses need to be picked up by a piece of code. This call adds that code to the specified run loop. Most drivers will call this method on the run loop that was created when your task was created. To avoid deadlock you must avoid sleeping (or spin waiting) the run loop to wait for SBP2 response. If you do this the dispatcher will never get to run and you will wait forever.*/
IOReturn ( *addCallbackDispatcherToRunLoop)(
    void *self,
    CFRunLoopRef cfRunLoopRef );  

/*removeCallbackDispatcherFromRunLoop


Removes a dispatcher for kernel callbacks from the specified run loop. 

void ( *removeCallbackDispatcherFromRunLoop)(
    void *self );  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
Discussion 

Undoes the work of addCallbackDispatcherToRunLoop.*/
void ( *removeCallbackDispatcherFromRunLoop)(
    void *self );  

/*setMessageCallback


Set callback for user space message routine. 

void ( *setMessageCallback)(
    void *self,
    void *refCon,
    IOFWSBP2MessageCallback callback);  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
refCon
RefCon to be returned as first argument of completion routine
callback
Address of completion routine.
Discussion 

In FireWire & SBP2 bus status messages are delivered via IOKit's message routine. This routine is emulated in user space for SBP2 & FireWire messages via this callback. You should register here for bus reset, and reconnect messages.*/
void ( *setMessageCallback)(
    void *self,
    void *refCon,
    IOFWSBP2MessageCallback callback);  

/*setRefCon


Sets the ORB refCon. 

void ( *setRefCon)(
    void *self,
    void *refCon );  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
refCon
a user defined value.
Discussion 

Sets a user defined value on the ORB that can be retrieved later with the method getRefCon.*/
void ( *setRefCon)(
    void *self,
    void *refCon );  

/*getRefCon


Returns the refCon set with setRefCon. 

void * ( *getRefCon)(
    void *self);  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
Return Value

Returns the previously stored user defined value. 
Discussion 

Returns the user defined value previously stored in the ORB with setRefCon.*/
void * ( *getRefCon)(
    void *self);  

/*createLogin


Creates a new IOFireWireSBP2LibLoginInterface object. 

IUnknownVTbl** ( *createLogin)(
    void *self,
    REFIID iid );  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
iid
UUID for desired type of IOFireWireSBP2LibLoginInterface.
Return Value

Returns a pointer to a new IOFireWireSBP2LibLoginInterface. 
Discussion 

Creates a new IOFireWireSBP2LibLoginInterface object for the LUN. Login objects supply most of the SBP2 APIs related to login maintenance and Normal Command ORB execution.*/
IUnknownVTbl** ( *createLogin)(
    void *self,
    REFIID iid );  

/*createMgmtORB


Creates a new IOFireWireSBP2LibMgmntORBInterface object. 

IUnknownVTbl** ( *createMgmtORB)(
    void *self,
    REFIID iid );  
Parameters
self
Pointer to IOFireWireSBP2LibLUNInterface.
iid
UUID for desired type of IOFireWireSBP2LibMgmtORBInterface.
Return Value

Returns a pointer to a new IOFireWireSBP2Login. 
Discussion 

Creates a new IOFireWireSBP2LibMgmtORBInterface object. Management objects let you execute commands like QueryLogins, LogicalUnitReset, and AbortTask. These commands are configured after they are created here. When they are done executing (after a call to submit) the supplied completion routine will be called with the supplied refcon. Usually this refCon is the "this" pointer of completion method's object.*/
IUnknownVTbl** ( *createMgmtORB)(
    void *self,
    REFIID iid );  

};
typedef struct IOFireWireSBP2LibLUNInterface IOFireWireSBP2LibLUNInterface;

#endif //_IOKIT_IOFIREWIRESBP2LIB_H_

