
#ifndef _IOKIT_IOFIREWIRESBP2LOGIN_H
#define _IOKIT_IOFIREWIRESBP2LOGIN_H

#include <IOKit/IOCommandGate.h>

#include <IOKit/firewire/IOFireWireUnit.h>

#include <IOKit/sbp2/IOFireWireSBP2ORB.h>
#include <IOKit/sbp2/IOFireWireSBP2Target.h>

class IOFireWireSBP2LUN;
class IOFireWireSBP2Login;


/*FWSBP2StatusBlock


typedef struct { 
    UInt8 details; 
    UInt8 sbpStatus; 
    UInt16 orbOffsetHi; 
    UInt32 orbOffsetLo; 
    UInt32 status[6]; 
} FWSBP2StatusBlock;  
Fields
details
Src, Resp, D, Len fields of status block format
sbpStatus
SBP2 specific status
orbOffsetHi
High 32 bits of address of orb status is for.
orbOffsetLo
Low 32 bits of address of orb status is for.
status
[6] Up to 48 bytes of additional data. Length is determined by len field.*/
typedef struct { 
    UInt8 details; 
    UInt8 sbpStatus; 
    UInt16 orbOffsetHi; 
    UInt32 orbOffsetLo; 
    UInt32 status[6]; 
} FWSBP2StatusBlock; 

/*FWSBP2LoginResponse


See Also:
FWSBP2LoginResponsePtr
typedef struct { 
    UInt16 length; 
    UInt16 loginID; 
    UInt32 commandBlockAgentAddressHi; 
    UInt32 commandBlockAgentAddressLo; 
    UInt16 reserved; 
    UInt16 reconnectHold; 
} FWSBP2LoginResponse, *FWSBP2LoginResponsePtr;  
Fields
length
Length of login response.
loginID
Unique id representing this login.
commandBlockAgentAddressHi
High 32 bits of command block agent address.
commandBlockAgentAddressLo
Low 32 bits of command block agent address.
reserved
Reserved.
reconnectHold
Reconnect timeout encoded as 2^reconnectHold seconds.*/
typedef struct { 
    UInt16 length; 
    UInt16 loginID; 
    UInt32 commandBlockAgentAddressHi; 
    UInt32 commandBlockAgentAddressLo; 
    UInt16 reserved; 
    UInt16 reconnectHold; 
} FWSBP2LoginResponse, *FWSBP2LoginResponsePtr;  

/*FWSBP2LoginCompleteParamsPtr


See Also:
FWSBP2LoginCompleteParams
typedef struct { 
    IOFireWireSBP2Login *login; // login object this param is sent from 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of login attempt  
    FWSBP2LoginResponsePtr loginResponse; // pointer to loginResponse buffer 
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer  
} FWSBP2LoginCompleteParams, *FWSBP2LoginCompleteParamsPtr;  
Fields
login
Pointer to IOFireWireSBP2Login object.
generation
FireWire generation value.
status
Status of login attempt.
loginResponse
Pointer to login response struct.
statusBlock
Pointer to status block buffer.
statusBlockLength
Length of entire status block.*/
typedef struct { 
    IOFireWireSBP2Login *login; // login object this param is sent from 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of login attempt  
    FWSBP2LoginResponsePtr loginResponse; // pointer to loginResponse buffer 
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer  
} FWSBP2LoginCompleteParams, *FWSBP2LoginCompleteParamsPtr;  

/*FWSBP2LogoutCompleteParams


See Also:
FWSBP2LogoutCompleteParamsPtr
typedef struct { 
    IOFireWireSBP2Login *login; // login object this param is sent from 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of login attempt  
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer  
} FWSBP2LogoutCompleteParams, *FWSBP2LogoutCompleteParamsPtr;  
Fields
login
Pointer to IOFireWireSBP2Login object.
generation
FireWire generation value.
status
Status of login attempt.
statusBlock
Pointer to status block buffer.
statusBlockLength
Length of entire status block.*/
typedef struct { 
    IOFireWireSBP2Login *login; // login object this param is sent from 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of login attempt  
    FWSBP2StatusBlock *statusBlock; // pointer to statusBlock buffer 
    UInt32 statusBlockLength; // size of statusBlock buffer  
} FWSBP2LogoutCompleteParams, *FWSBP2LogoutCompleteParamsPtr;  

/*FWSBP2LogoutCompleteParams


See Also:
FWSBP2ReconnectParamsPtr
typedef struct { 
    IOFireWireSBP2Login *login; // login object this param is sent from 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of reconnect attempt  
    void *reconnectStatusBlock; // pointer to statusBlock buffer 
    UInt32 reconnectStatusBlockLength; // size of statusBlock buffer 
} FWSBP2ReconnectParams, *FWSBP2ReconnectParamsPtr;  
Fields
login
Pointer to IOFireWireSBP2Login object.
generation
FireWire generation value.
status
Status of login attempt.
reconnectStatusBlock
Pointer to status block buffer.
reconnectStatusBlockLength
Length of entire status block.*/
typedef struct { 
    IOFireWireSBP2Login *login; // login object this param is sent from 
    UInt32 generation; // generation this login was attempted in  
    IOReturn status; // status of reconnect attempt  
    void *reconnectStatusBlock; // pointer to statusBlock buffer 
    UInt32 reconnectStatusBlockLength; // size of statusBlock buffer 
} FWSBP2ReconnectParams, *FWSBP2ReconnectParamsPtr;  

/*FWSBP2NotifyParams


See Also:
FWSBP2NotifyParamsPtr
typedef struct { 
    void *commandObject; 
    UInt32 notificationEvent; 
    const void *message; 
    UInt32 length; 
    UInt32 generation; 
} FWSBP2NotifyParams, *FWSBP2NotifyParamsPtr;  
Fields
notificationEvent
Type of event we are being notified of.
message
buffer containing message.
length
length of message field.
generation
FireWire generation value.*/
typedef struct { 
    void *commandObject; 
    UInt32 notificationEvent; 
    const void *message; 
    UInt32 length; 
    UInt32 generation; 
} FWSBP2NotifyParams, *FWSBP2NotifyParamsPtr;  

/*FWSBP2LoginCallback


typedef void ( *FWSBP2LoginCallback)(
    void *refCon,
    FWSBP2LoginCompleteParamsPtr params);  
Fields
refCon
Reference constant supplied when the notification was registered.
params
Structure containing additional information about the status of the login.*/
typedef void ( *FWSBP2LoginCallback)(
    void *refCon,
    FWSBP2LoginCompleteParamsPtr params);  

/*FWSBP2LogoutCallback


typedef void ( *FWSBP2LogoutCallback)(
    void *refCon,
    FWSBP2LogoutCompleteParamsPtr params);  
Fields
refCon
Reference constant supplied when the notification was registered.
params
Structure containing additional information about the status of the logout.*/
typedef void ( *FWSBP2LogoutCallback)(
    void *refCon,
    FWSBP2LogoutCompleteParamsPtr params);  

/*FWSBP2NotifyCallback


typedef void ( *FWSBP2NotifyCallback)(
    void *refCon,
    FWSBP2NotifyParamsPtr params);  
Fields
refCon
Reference constant supplied when the notification was registered.
params
FWSBP2NotifyParams containing notification information.*/
typedef void ( *FWSBP2NotifyCallback)(
    void *refCon,
    FWSBP2NotifyParamsPtr params);  

/*FWSBP2FetchAgentWriteCallback


typedef void ( *FWSBP2FetchAgentWriteCallback)(
    void *refCon,
    IOReturn status,
    IOFireWireSBP2ORB *orb);  
Fields
refCon
Reference constant supplied when the notification was registered.
status
Indicates success or failure of operation.
orb
Indicates current last orb in chain.*/
typedef void ( *FWSBP2FetchAgentWriteCallback)(
    void *refCon,
    IOReturn status,
    IOFireWireSBP2ORB *orb);  

/*FWSBP2StatusCallback


typedef void ( *FWSBP2StatusCallback)(
    void *refCon,
    IOReturn status);  
Fields
refCon
Reference constant supplied when the notification was registered.
status
Indicates success or failure of operation.*/
typedef void ( *FWSBP2StatusCallback)(
    void *refCon,
    IOReturn status);  

#include <HYS/IOKit/sbp2/IOFireWireSBP2Login.h>
//func
//class

class IOFireWireSBP2Login : public OSObject,public IOFireWireSBP2Login_HYS
{
    OSDeclareDefaultStructors( IOFireWireSBP2Login )

	friend class IOFireWireSBP2ORB;
	friend class IOFireWireSBP2LUN;
	
protected:
private:
public:

IOFireWireSBP2Login_setBusyTimeoutComplete
IOFireWireSBP2Login_unsolicitedStatusEnableComplete
IOFireWireSBP2Login_staticExecuteUnsolicitedStatusEnable
IOFireWireSBP2Login_doorbellComplete
IOFireWireSBP2Login_executeDoorbell
IOFireWireSBP2Login_staticExecuteDoorbell
IOFireWireSBP2Login_fetchAgentResetComplete
IOFireWireSBP2Login_executeFetchAgentReset
IOFireWireSBP2Login_staticExecuteFetchAgentReset
IOFireWireSBP2Login_isFetchAgentWriteInProgress
IOFireWireSBP2Login_fetchAgentRetryTimer
IOFireWireSBP2Login_startFetchAgentRetryTimer
IOFireWireSBP2Login_appendORB
IOFireWireSBP2Login_appendORBImmediate
IOFireWireSBP2Login_startORBTimer
IOFireWireSBP2Login_executeORB
IOFireWireSBP2Login_staticExecuteORB
IOFireWireSBP2Login_isConnected
IOFireWireSBP2Login_staticExecuteRemoveORB
IOFireWireSBP2Login_executeAddORB
IOFireWireSBP2Login_executeRemoveORB
IOFireWireSBP2Login_enableUnsolicitedStatus
IOFireWireSBP2Login_ringDoorbell
IOFireWireSBP2Login_staticExecuteAddORB
IOFireWireSBP2Login_submitFetchAgentReset
IOFireWireSBP2Login_addORB
IOFireWireSBP2Login_setBusyTimeoutRegisterValue
IOFireWireSBP2Login_createORB
IOFireWireSBP2Login_submitORB
IOFireWireSBP2Login_clearAllTasksInSet
IOFireWireSBP2Login_logoutTimeout
IOFireWireSBP2Login_logoutWriteComplete
IOFireWireSBP2Login_staticExecuteLogout
IOFireWireSBP2Login_reconnectRetryTimeout
IOFireWireSBP2Login_sendReconnectNotificationWithStatusBlock
IOFireWireSBP2Login_reconnectStatusBlockWrite
IOFireWireSBP2Login_reconnectTimeout
IOFireWireSBP2Login_startReconnectRetryTimer
IOFireWireSBP2Login_reconnectWriteComplete
IOFireWireSBP2Login_sendReconnectNotification
IOFireWireSBP2Login_doReconnect
IOFireWireSBP2Login_terminateNotify
IOFireWireSBP2Login_restartReconnect
IOFireWireSBP2Login_executeLogout
IOFireWireSBP2Login_executeSetBusyTimeout
IOFireWireSBP2Login_resumeNotify
IOFireWireSBP2Login_startReconnectTimer
IOFireWireSBP2Login_suspendedNotify
IOFireWireSBP2Login_completeLogout
IOFireWireSBP2Login_isORBAppended
IOFireWireSBP2Login_cancelORBTimer
IOFireWireSBP2Login_statusBlockWrite
IOFireWireSBP2Login_executeUnsolicitedStatusEnable
IOFireWireSBP2Login_loginRetryTimeout
IOFireWireSBP2Login_loginTimeout
IOFireWireSBP2Login_completeLogin
IOFireWireSBP2Login_setFetchAgentResetCompletion
IOFireWireSBP2Login_submitLogout
IOFireWireSBP2Login_sendTimeoutNotification
IOFireWireSBP2Login_removeORB
IOFireWireSBP2Login_processLoginWrite
IOFireWireSBP2Login_loginWriteComplete
IOFireWireSBP2Login_isPhysicalAccessEnabled
IOFireWireSBP2Login_setAddressLoForLoginORBAndResponse
IOFireWireSBP2Login_startLoginRetryTimer
IOFireWireSBP2Login_executeLogin
IOFireWireSBP2Login_initialExecuteLogin
IOFireWireSBP2Login_staticExecuteLogin
IOFireWireSBP2Login_clearLoginGeneration
IOFireWireSBP2Login_submitLogin
IOFireWireSBP2Login_setPassword_void
IOFireWireSBP2Login_setPassword
IOFireWireSBP2Login_setLoginRetryCountAndDelayTime
IOFireWireSBP2Login_getMaxPayloadSize
IOFireWireSBP2Login_setMaxPayloadSize
IOFireWireSBP2Login_getUnsolicitedStatusNotifyProc
IOFireWireSBP2Login_setUnsolicitedStatusNotifyProc
IOFireWireSBP2Login_setStatusNotifyProc
IOFireWireSBP2Login_getReconnectTime
IOFireWireSBP2Login_setReconnectTime
IOFireWireSBP2Login_setLogoutCompletion
IOFireWireSBP2Login_setLoginCompletion
IOFireWireSBP2Login_getLoginFlags
IOFireWireSBP2Login_setLoginFlags
IOFireWireSBP2Login_getRefCon
IOFireWireSBP2Login_setRefCon
IOFireWireSBP2Login_getMaxCommandBlockSize
IOFireWireSBP2Login_getStatusNotifyProc
IOFireWireSBP2Login_getFireWireLUN
IOFireWireSBP2Login_setLoginGeneration
IOFireWireSBP2Login_getLoginID
IOFireWireSBP2Login_getFireWireUnit
IOFireWireSBP2Login_stopFetchAgentRetryTimer
IOFireWireSBP2Login_stopReconnectRetryTimer
IOFireWireSBP2Login_stopLoginRetryTimer
IOFireWireSBP2Login_free
IOFireWireSBP2Login_setBusyTimeoutCompleteStatic
IOFireWireSBP2Login_doorbellCompleteStatic
IOFireWireSBP2Login_fetchAgentResetCompleteStatic
IOFireWireSBP2Login_fetchAgentRetryTimerStatic
IOFireWireSBP2Login_logoutTimeoutStatic
IOFireWireSBP2Login_logoutWriteCompleteStatic
IOFireWireSBP2Login_reconnectTimeoutStatic
IOFireWireSBP2Login_reconnectWriteCompleteStatic
IOFireWireSBP2Login_reconnectRetryTimeoutStatic
IOFireWireSBP2Login_loginRetryTimeoutStatic
IOFireWireSBP2Login_loginTimeoutStatic
IOFireWireSBP2Login_loginWriteCompleteStatic
IOFireWireSBP2Login_isORBTimerSet
IOFireWireSBP2Login_unsolicitedStatusEnableCompleteStatic
IOFireWireSBP2Login_release
IOFireWireSBP2Login_removeLogin
IOFireWireSBP2Login_reconnectStatusBlockWriteStatic
IOFireWireSBP2Login_setORBIsAppended
IOFireWireSBP2Login_abortLogin
IOFireWireSBP2Login_statusBlockWriteStatic
IOFireWireSBP2Login_allocateResources
IOFireWireSBP2Login_getUnitInformation
IOFireWireSBP2Login_setFetchAgentWriteCompletion
IOFireWireSBP2Login_fetchAgentWriteCompleteStatic
IOFireWireSBP2Login_fetchAgentWriteComplete_IOReturn
IOFireWireSBP2Login_setNextORBAddress
IOFireWireSBP2Login_initORBWithLogin
IOFireWireSBP2Login_getARDMMax
IOFireWireSBP2Login_fetchAgentWriteComplete
IOFireWireSBP2Login_getTarget
IOFireWireSBP2Login_prepareORBForExecution
IOFireWireSBP2Login_initWithLUN

 };

#endif//_IOKIT_IOFIREWIRESBP2LOGIN_H

