
#ifndef _IOFILTERSCHEME_H
#define _IOFILTERSCHEME_H


//#ifdef KERNEL
#ifdef __cplusplus

#include <IOKit/storage/IOMedia.h>
#include <IOKit/storage/IOStorage.h>

#include <HYS/IOKit/storage/IOFilterScheme.h>
class IOFilterScheme : public IOStorage,public IOFilterScheme_HYS
{
    OSDeclareDefaultStructors(IOFilterScheme);

protected:

/*handleOpen


protected

virtual bool handleOpen(
    IOService *client, 
    IOOptionBits options, 
    void *access); 
Parameters
client
Client requesting the open.
options
Options for the open. Set to zero.
access
Access level for the open. Set to kIOStorageAccessReader or kIOStorageAccessReaderWriter.
Return Value

Returns true if the open was successful, false otherwise. 
Discussion 

The handleOpen method grants or denies permission to access this object to an interested client. The argument is an IOStorageAccess value that specifies the level of access desired -- reader or reader-writer.
This method can be invoked to upgrade or downgrade the access level for an existing client as well. The previous access level will prevail for upgrades that fail, of course. A downgrade should never fail. If the new access level should be the same as the old for a given client, this method will do nothing and return success. In all cases, one, singular close-per-client is expected for all opens-per-client received.
This implementation replaces the IOService definition of handleOpen().*/
virtual bool handleOpen(
    IOService *client, 
    IOOptionBits options, 
    void *access); 

/*handleIsOpen


protected

virtual bool handleIsOpen(
    const IOService *client) const; 
Parameters
client
Client to check the open state of. Set to zero to check the open state of all clients.
Return Value

Returns true if the client was (or clients were) open, false otherwise. 
Discussion 

The handleIsOpen method determines whether the specified client, or any client if none is specified, presently has an open on this object.
This implementation replaces the IOService definition of handleIsOpen().*/

virtual bool handleIsOpen(
    const IOService *client) const; 

/*handleClose


protected

virtual void handleClose(
    IOService *client,
    IOOptionBits options); 
Parameters
client
Client requesting the close.
options
Options for the close. Set to zero.
Discussion 

The handleClose method closes the client's access to this object.
This implementation replaces the IOService definition of handleClose().*/
virtual void handleClose(
    IOService *client,
    IOOptionBits options); 

public:

using IOStorage::read;
using IOStorage::write;

IOFilterScheme_getProvider

/*write


public

virtual void write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 
Parameters
client
Client requesting the write.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
attributes
Attributes of the data transfer. See IOStorageAttributes. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
completion
Completion routine to call once the data transfer is complete. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
Discussion 

Write data into the storage object at the specified byte offset from the specified buffer, asynchronously. When the write completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the write.
For simple filter schemes, the default behavior is to simply pass the write through to the provider media. More complex filter schemes such as RAID will need to do extra processing here.*/
virtual void write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 

/*read


public

virtual void read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 
Parameters
client
Client requesting the read.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
attributes
Attributes of the data transfer. See IOStorageAttributes. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
completion
Completion routine to call once the data transfer is complete. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
Discussion 

Read data from the storage object at the specified byte offset into the specified buffer, asynchronously. When the read completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the read.
For simple filter schemes, the default behavior is to simply pass the read through to the provider media. More complex filter schemes such as RAID will need to do extra processing here.*/
virtual void read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 

/*synchronizeCache


public

virtual IOReturn synchronizeCache(
    IOService *client); 
Parameters
client
Client requesting the cache synchronization.
Return Value

Returns the status of the cache synchronization. 
Discussion 

Flush the cached data in the storage object, if any, synchronously.*/

virtual IOReturn synchronizeCache(
    IOService *client); 

};

#endif /* __cplusplus */
//#endif /* KERNEL */
#endif /* !_IOFILTERSCHEME_H */
