#ifndef IOMEDIA_H
#define IOMEDIA_H

#include <IOKit/IOTypes.h>

//////////////////

/*kIOMediaContentMaskKey


A property of IOMedia clients.

#define kIOMediaContentMaskKey "Content Mask" 
Discussion 

The kIOMediaContentMaskKey property has an OSString value and must exist in all IOMedia clients that drive new content (that is, produce new media objects). When the client matches against the provider media, the value of the client's kIOMediaContentMaskKey property is used to replace the provider's kIOMediaContentKey property.*/
#define kIOMediaContentMaskKey "Content Mask" 

/*kIOMediaOpenKey


A property of IOMedia objects.

#define kIOMediaOpenKey "Open" 
Discussion 

The kIOMediaOpenKey property has an OSBoolean value and describes whether a client presently has an open on this media.*/
#define kIOMediaOpenKey "Open" 

/*kIOMediaIconKey


A property of any object in the media stack.

#define kIOMediaIconKey "IOMediaIcon" 
Discussion 

kIOMediaIconKey is a property of any object in the media stack that wishes to override the default icon shown for the media objects in the stack. It is usually defined in a provider object below the media object. It has an OSDictionary value, with properties identical to the kIOIconKey definition, that is, kCFBundleIdentifierKey and kIOBundleResourceFileKey.*/
#define kIOMediaIconKey "IOMediaIcon" 

/*kIOMediaRemovableKey


A property of IOMedia objects.

#define kIOMediaRemovableKey "Removable" 
Discussion 

The kIOMediaRemovableKey property has an OSBoolean value and describes whether the media is removable from the drive mechanism.*/
#define kIOMediaRemovableKey "Removable" 

/*kIOMediaLeafKey


A property of IOMedia objects.

#define kIOMediaLeafKey "Leaf" 
Discussion 

The kIOMediaLeafKey property has an OSBoolean value and describes whether the media is a leaf, that is, it is the deepest media object in this branch of the I/O Registry.*/
#define kIOMediaLeafKey "Leaf" 

/*kIOMediaWritableKey


A property of IOMedia objects.

#define kIOMediaWritableKey "Writable" 
Discussion 

The kIOMediaWritableKey property has an OSBoolean value and describes whether the media is writable.*/
#define kIOMediaWritableKey "Writable" 

/*kIOMediaContentKey


A property of IOMedia objects.

#define kIOMediaContentKey "Content" 
Discussion 

The kIOMediaContentKey property has an OSString value and contains a description of the media's contents. The description is the same as the hint at the time of the object's creation, but it is possible that the description has been overridden by a client (which has probed the media and identified the content correctly) of the media object. It is more accurate than the hint for this reason. The string is formed in the likeness of Apple's "Apple_HFS" strings or in the likeness of a UUID.*/
#define kIOMediaContentKey "Content" 

/*kIOMediaPreferredBlockSizeKey


A property of IOMedia objects.

#define kIOMediaPreferredBlockSizeKey "Preferred Block Size" 
Discussion 

The kIOMediaPreferredBlockSizeKey property has an OSNumber value and describes the media's natural block size in bytes. This information is useful to clients that want to optimize access to the media.*/
#define kIOMediaPreferredBlockSizeKey "Preferred Block Size" 

/*kIOMediaSizeKey


A property of IOMedia objects.

#define kIOMediaSizeKey "Size" 
Discussion 

The kIOMediaSizeKey property has an OSNumber value and describes the total length of the media in bytes.*/
#define kIOMediaSizeKey "Size" 

/*kIOMediaUUIDKey


A property of IOMedia objects.

#define kIOMediaUUIDKey "UUID" 
Discussion 

The kIOMediaUUIDKey property has an OSString value and contains a persistent Universal Unique Identifier for the media if such an identifier is available.*/
#define kIOMediaUUIDKey "UUID"

/*IOMediaAttributeMask


enum { 
    kIOMediaAttributeEjectableMask = 0x00000001, 
    kIOMediaAttributeRemovableMask = 0x00000002, 
    kIOMediaAttributeReservedMask = 0xFFFFFFFC 
};  
Constants
kIOMediaAttributeEjectableMask
Indicates whether the media is ejectable from the drive mechanism under software control. Implies kIOMediaAttributeRemovableMask.
kIOMediaAttributeRemovableMask
Indicates whether the media is removable from the drive mechanism.
Discussion 

The IOMediaAttributeMask bit mask describes various attributes of the media object, such as its ejectability and its removability.*/

enum { 
    kIOMediaAttributeEjectableMask = 0x00000001, 
    kIOMediaAttributeRemovableMask = 0x00000002, 
    kIOMediaAttributeReservedMask = 0xFFFFFFFC 
};  

/*kIOMediaEjectableKey


A property of IOMedia objects.
#define kIOMediaEjectableKey "Ejectable" 
Discussion 

The kIOMediaEjectableKey property has an OSBoolean value and describes whether the media is ejectable from the drive mechanism under software control. Implies IOMediaRemovable is also true.*/
#define kIOMediaEjectableKey "Ejectable" 

/*kIOMediaClass


The name of the IOMedia class. 
#define kIOMediaClass "IOMedia" */
#define kIOMediaClass "IOMedia"

/*kIOMediaWholeKey


A property of IOMedia objects.
#define kIOMediaWholeKey "Whole" 
Discussion 

The kIOMediaWholeKey property has an OSBoolean value and describes whether the media is whole, that is, it represents the whole disk (the physical disk, or a virtual replica thereof).*/
#define kIOMediaWholeKey "Whole" 

/*kIOMediaContentHintKey


A property of IOMedia objects.

#define kIOMediaContentHintKey "Content Hint" 
Discussion 

The kIOMediaContentHintKey property has an OSString value and contains a hint of the media's contents. The hint is set at the time of the object's creation, should the creator have a clue as to what it may contain. The hint string does not change for the lifetime of the object and is formed in the likeness of Apple's "Apple_HFS" strings or in the likeness of a UUID.*/
#define kIOMediaContentHintKey "Content Hint" 
///////////////////////////


#include <IOKit/storage/IOStorage.h>


#include <HYS/IOKit/storage/IOMedia.h>

#ifdef __cplusplus

class IOMedia : public IOStorage,public IOMedia_HYS
{
   OSDeclareDefaultStructors(IOMedia)

protected:

/*handleOpen


protected

virtual bool handleOpen(
    IOService *client, 
    IOOptionBits options, 
    void *access); 
Parameters
client
Client requesting the open.
options
Options for the open. Set to zero.
access
Access level for the open. Set to kIOStorageAccessReader or kIOStorageAccessReaderWriter.
Return Value

Returns true if the open was successful, false otherwise. 
Discussion 

The handleOpen method grants or denies permission to access this object to an interested client. The argument is an IOStorageAccess value that specifies the level of access desired -- reader or reader-writer.
This method can be invoked to upgrade or downgrade the access level for an existing client as well. The previous access level will prevail for upgrades that fail, of course. A downgrade should never fail. If the new access level should be the same as the old for a given client, this method will do nothing and return success. In all cases, one, singular close-per-client is expected for all opens-per-client received.
This implementation replaces the IOService definition of handleOpen().*/
virtual bool handleOpen(
    IOService *client, 
    IOOptionBits options, 
    void *access); 

/*handleIsOpen


protected

virtual bool handleIsOpen(
    const IOService *client) const; 
Parameters
client
Client to check the open state of. Set to zero to check the open state of all clients.
Return Value

Returns true if the client was (or clients were) open, false otherwise. 
Discussion 

The handleIsOpen method determines whether the specified client, or any client if none is specified, presently has an open on this object.
This implementation replaces the IOService definition of handleIsOpen().*/
virtual bool handleIsOpen(
    const IOService *client) const; 

/*handleClose


protected

virtual void handleClose(
    IOService *client,
    IOOptionBits options); 
Parameters
client
Client requesting the close.
options
Options for the close. Set to zero.
Discussion 

The handleClose method closes the client's access to this object.
This implementation replaces the IOService definition of handleClose().*/
virtual void handleClose(
    IOService *client,
    IOOptionBits options); 

public:

using IOStorage::read;
using IOStorage::write;

IOMedia_init
IOMedia_getProvider
IOMedia_matchPropertyTable
IOMedia_free
IOMedia_attachToChild
IOMedia_detachFromChild

/*getContent


public

virtual const char * getContent() const; 
Return Value

Description of media's contents. 
Discussion 

Ask the media object for a description of its contents. The description is the same as the hint at the time of the object's creation, but it is possible that the description has been overridden by a client (which has probed the media and identified the content correctly) of the media object. It is more accurate than the hint for this reason. The string is formed in the likeness of Apple's "Apple_HFS" strings or in the likeness of a UUID.
The content description can be overridden by any client that matches onto this media object with a match category of kIOStorageCategory. The media object checks for a kIOMediaContentMaskKey property in the client, and if it finds one, it copies it into kIOMediaContentKey property.*/
virtual const char * getContent() const; 

/*getContentHint


public

virtual const char * getContentHint() const; 
Return Value

Hint of media's contents. 
Discussion 

Ask the media object for a hint of its contents. The hint is set at the time of the object's creation, should the creator have a clue as to what it may contain. The hint string does not change for the lifetime of the object and is also formed in the likeness of Apple's "Apple_HFS" strings or in the likeness of a UUID.*/
virtual const char * getContentHint() const; 

/*getBase


public

virtual UInt64 getBase() const; 
Discussion 

Ask the media object for its byte offset relative to its provider media object below it in the storage hierarchy. Media offset, in bytes.*/

virtual UInt64 getBase() const; 

/*isWhole


public

virtual bool isWhole() const; 
Return Value

Returns true if the media represents the whole disk, false otherwise. 
Discussion 

Ask the media object whether it represents the whole disk.*/
virtual bool isWhole() const; 

/*getAttributes


public

virtual IOMediaAttributeMask getAttributes() const; 
Return Value

Media attributes, such as ejectability and removability. See IOMediaAttributeMask. 
Discussion 

Ask the media object for its attributes.*/
virtual IOMediaAttributeMask getAttributes() const; 


/*isFormatted


public

virtual bool isFormatted() const; 
Return Value

Returns true if the media is formatted, false otherwise. 
Discussion 

Ask the media object whether it is formatted.*/

virtual bool isFormatted() const; 

/*getSize

public

virtual UInt64 getSize() const; 
Return Value

Media size, in bytes. 
Discussion 

Ask the media object for its total length in bytes.*/
virtual UInt64 getSize() const; 

/*isEjectable

public

virtual bool isEjectable() const; 
Return Value

Returns true if the media is ejectable, false otherwise. 
Discussion 

Ask the media object whether it is ejectable.*/
virtual bool isEjectable() const; 

/*isWritable

public

virtual bool isWritable() const; 
Return Value

Returns true if the media is writable, false otherwise. 
Discussion 

Ask the media object whether it is writable.*/
virtual bool isWritable() const; 

/*write

public

virtual void write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageCompletion completion); 
Parameters
client
Client requesting the write.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
completion
Completion routine to call once the data transfer is complete.
Discussion 

Write data into the storage object at the specified byte offset from the specified buffer, asynchronously. When the write completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the write.*/

    virtual void write(IOService *           client,
                       UInt64                byteStart,
                       IOMemoryDescriptor *  buffer,
                       IOStorageAttributes * attributes,
                       IOStorageCompletion * completion);

/*read

public

virtual void read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageCompletion completion); 
Parameters
client
Client requesting the read.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
completion
Completion routine to call once the data transfer is complete.
Discussion 

Read data from the storage object at the specified byte offset into the specified buffer, asynchronously. When the read completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the read.*/ 
    virtual void read(IOService *           client,
                      UInt64                byteStart,
                      IOMemoryDescriptor *  buffer,
                      IOStorageAttributes * attributes,
                      IOStorageCompletion * completion);

/*synchronizeCache

public

virtual IOReturn synchronizeCache(
    IOService *client); 
Parameters
client
Client requesting the cache synchronization.
Return Value

Returns the status of the cache synchronization. 
Discussion 

Flush the cached data in the storage object, if any, synchronously.*/
virtual IOReturn synchronizeCache(
    IOService *client); 

/*getPreferredBlockSize

public

virtual UInt64 getPreferredBlockSize() const; 
Return Value

Natural block size, in bytes. 
Discussion 

Ask the media object for its natural block size. This information is useful to clients that want to optimize access to the media.*/
virtual UInt64 getPreferredBlockSize() const; 

/*init

public

virtual bool init(
    UInt64 base, 
    UInt64 size, 
    UInt64 preferredBlockSize, 
    IOMediaAttributeMask attributes, 
    bool isWhole, 
    bool isWritable, 
    const char *contentHint = 0, 
    OSDictionary *properties = 0); 
Parameters
base
Media offset, in bytes.
size
Media size, in bytes.
preferredBlockSize
Natural block size, in bytes.
attributes
Media attributes, such as ejectability and removability. See IOMediaAttributeMask.
isWhole
Indicates whether the media represents the whole disk.
isWritable
Indicates whether the media is writable.
contentHint
Hint of media's contents (optional). See getContentHint().
properties
Substitute property table for this object (optional).
Return Value

Returns true on success, false otherwise. 
Discussion 

Initialize this object's minimal state.*/

    virtual bool init(UInt64               base,
                      UInt64               size,
                      UInt64               preferredBlockSize,
                      IOMediaAttributeMask attributes,
                      bool                 isWhole,
                      bool                 isWritable,
                      const char *         contentHint = 0,
                      OSDictionary *       properties  = 0);

};

#endif//__cplusplus
#endif//IOMEDIA_H

