
#ifndef _IOPARTITIONSCHEME_H
#define _IOPARTITIONSCHEME_H

//#ifdef KERNEL


#include <IOKit/storage/IOMedia.h>
#include <IOKit/storage/IOStorage.h>
///////////////////////////

/*


A property of IOMedia objects. 

#define kIOMediaPartitionIDKey "Partition ID" 
Discussion 

The kIOMediaPartitionIDKey property has an OSNumber value and is placed into an IOMedia instance created via the partition scheme. It is an ID that differentiates one partition from the other (within a given scheme). It is typically an index into the on-disk partition table.*/
#define kIOMediaPartitionIDKey "Partition ID" 

/*kIOMediaPartitionIDKey


A property of IOMedia objects.

#define kIOMediaPartitionIDKey "Partition ID" 
Discussion 

The kIOMediaPartitionIDKey property has an OSNumber value and is placed into an IOMedia instance created via the partition scheme. It is an ID that differentiates one partition from the other (within a given scheme). It is typically an index into the on-disk partition table.*/
#define kIOMediaPartitionIDKey "Partition ID"

/*kIOMediaLiveKey


A property of IOMedia objects.

#define kIOMediaLiveKey "Live" 
Discussion 

The kIOMediaLiveKey property has an OSBoolean value and is placed into an IOMedia instance created via the partition scheme. It describes whether the partition is live, that is, it is up-to-date with respect to the on-disk partition table.*/
#define kIOMediaLiveKey "Live" 

///////////////////////
#include <HYS/IOKit/storage/IOPartitionScheme.h>
#ifdef __cplusplus

class IOPartitionScheme : public IOStorage,public IOPartitionScheme_HYS
{
    OSDeclareDefaultStructors(IOPartitionScheme);

protected:

/*handleClose


protected

virtual void handleClose(
    IOService *client,
    IOOptionBits options); 
Parameters
client
Client requesting the close.
options
Options for the close. Set to zero.
Discussion 

The handleClose method closes the client's access to this object.
This implementation replaces the IOService definition of handleClose().*/
virtual void handleClose(
    IOService *client,
    IOOptionBits options); 

/*handleIsOpen


protected

virtual bool handleIsOpen(
    const IOService *client) const; 
Parameters
client
Client to check the open state of. Set to zero to check the open state of all clients.
Return Value

Returns true if the client was (or clients were) open, false otherwise. 
Discussion 

The handleIsOpen method determines whether the specified client, or any client if none is specified, presently has an open on this object.
This implementation replaces the IOService definition of handleIsOpen().*/

virtual bool handleIsOpen(
    const IOService *client) const;

/*handleOpen


protected

virtual bool handleOpen(
    IOService *client, 
    IOOptionBits options, 
    void *access); 
Parameters
client
Client requesting the open.
options
Options for the open. Set to zero.
access
Access level for the open. Set to kIOStorageAccessReader or kIOStorageAccessReaderWriter.
Return Value

Returns true if the open was successful, false otherwise. 
Discussion 

The handleOpen method grants or denies permission to access this object to an interested client. The argument is an IOStorageAccess value that specifies the level of access desired -- reader or reader-writer.
This method can be invoked to upgrade or downgrade the access level for an existing client as well. The previous access level will prevail for upgrades that fail, of course. A downgrade should never fail. If the new access level should be the same as the old for a given client, this method will do nothing and return success. In all cases, one, singular close-per-client is expected for all opens-per-client received.
This implementation replaces the IOService definition of handleOpen().*/
virtual bool handleOpen(
    IOService *client, 
    IOOptionBits options, 
    void *access); 

public:

using IOStorage::read;
using IOStorage::write;

IOPartitionScheme_getProvider
IOPartitionScheme_init
IOPartitionScheme_free
IOPartitionScheme_attachMediaObjectToDeviceTree
IOPartitionScheme_detachMediaObjectFromDeviceTree
IOPartitionScheme_juxtaposeMediaObjects

/*synchronizeCache


public

virtual IOReturn synchronizeCache(
    IOService *client); 
Parameters
client
Client requesting the cache synchronization.
Return Value

Returns the status of the cache synchronization. 
Discussion 

Flush the cached data in the storage object, if any, synchronously.*/
virtual IOReturn synchronizeCache(
    IOService *client); 

/*read


public

virtual void read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageCompletion completion); 
Parameters
client
Client requesting the read.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
completion
Completion routine to call once the data transfer is complete.
Discussion 

Read data from the storage object at the specified byte offset into the specified buffer, asynchronously. When the read completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the read.
For simple partition schemes, the default behavior is to simply pass the read through to the provider media. More complex partition schemes such as RAID will need to do extra processing here.*/
virtual void read(IOService *           client,
                      UInt64                byteStart,
                      IOMemoryDescriptor *  buffer,
                      IOStorageAttributes * attributes,
                      IOStorageCompletion * completion);

/*write


public

virtual void write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageCompletion completion); 
Parameters
client
Client requesting the write.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
completion
Completion routine to call once the data transfer is complete.
Discussion 

Write data into the storage object at the specified byte offset from the specified buffer, asynchronously. When the write completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the write.
For simple partition schemes, the default behavior is to simply pass the write through to the provider media. More complex partition schemes such as RAID will need to do extra processing here.*/
    virtual void write(IOService *           client,
                       UInt64                byteStart,
                       IOMemoryDescriptor *  buffer,
                       IOStorageAttributes * attributes,
                       IOStorageCompletion * completion);


};

#endif /* __cplusplus */
//#endif /* KERNEL */
#endif /* !_IOPARTITIONSCHEME_H */
