#ifndef _IOSTORAGE_H
#define _IOSTORAGE_H

#ifdef _APPLERAID_H
	class AppleLVMMemoryDescriptor;//AppleRAID
#endif

#include <IOKit/IOTypes.h>
//////////////

/*kIOStorageFeatureForceUnitAccess


Describes the presence of the Force Unit Access feature.

#define kIOStorageFeatureForceUnitAccess "Force Unit Access" 
Discussion 

This property describes the ability of the storage stack to force a request to access the media. It is one of the feature entries listed under the top- level kIOStorageFeaturesKey property table. It has an OSBoolean value.*/
#define kIOStorageFeatureForceUnitAccess "Force Unit Access" 

/*kIOStorageFeaturesKey


A property of any object in the storage stack.

#define kIOStorageFeaturesKey "IOStorageFeatures" 
Discussion 

kIOStorageFeaturesKey is a property of any object in the storage stack that wishes to express support of additional features, such as Force Unit Access. It is typically defined in the device object below the block storage driver object. It has an OSDictionary value, where each entry describes one given feature.*/
#define kIOStorageFeaturesKey "IOStorageFeatures" 

/*kIOStorageCategory


kIOStorageCategory is a value for IOService's kIOMatchCategoryKey property.

#define kIOStorageCategory "IOStorage" /(as IOMatchCategory) 
Discussion 

The kIOStorageCategory value is the standard value for the IOService property kIOMatchCategoryKey ("IOMatchCategory") for all storage drivers. All storage objects that expect to drive new content (that is, produce new media objects) are expected to compete within the kIOStorageCategory namespace.
See the IOService documentation for more information on match categories.*/

#define kIOStorageCategory "IOStorage" /* (as IOMatchCategory) */

///////////
#include <HYS/IOKit/storage/IOStorage.h>


//#ifdef __cplusplus

#include <IOKit/assert.h>
#include <IOKit/IOMemoryDescriptor.h>
#include <IOKit/IOService.h>

/*IOStorageAccess


enum { 
    kIOStorageAccessNone = 0x00, 
    kIOStorageAccessReader = 0x01, 
    kIOStorageAccessReaderWriter = 0x03, 
    kIOStorageAccessSharedLock = 0x04, 
    kIOStorageAccessExclusiveLock = 0x08 
};  
Constants
kIOStorageAccessNone
No access is requested; should not be passed to open().
kIOStorageAccessReader
Read-only access is requested.
kIOStorageAccessReaderWriter
Read and write access is requested.
kIOStorageAccessSharedLock
Shared access is requested.
kIOStorageAccessExclusiveLock
Exclusive access is requested.
Discussion 

The IOStorageAccess enumeration describes the possible access levels for open requests.*/
enum { 
    kIOStorageAccessNone = 0x00, 
    kIOStorageAccessReader = 0x01, 
    kIOStorageAccessReaderWriter = 0x03, 
    kIOStorageAccessSharedLock = 0x04, 
    kIOStorageAccessExclusiveLock = 0x08 
}; 

/*IOStorageCompletionAction

typedef void (*IOStorageCompletionAction)(
    void *target, 
    void *parameter, 
    IOReturn status, 
    UInt64 actualByteCount);  
Parameters
target
Opaque client-supplied pointer (or an instance pointer for a C++ callback).
parameter
Opaque client-supplied pointer.
status
Status of the data transfer.
actualByteCount
Actual number of bytes transferred in the data transfer.
Discussion 

The IOStorageCompletionAction declaration describes the C (or C++) completion routine that is called once an asynchronous storage operation completes.*/
typedef void (*IOStorageCompletionAction)(
    void *target, 
    void *parameter, 
    IOReturn status, 
    UInt64 actualByteCount);  


/*StorageCompletion

struct IOStorageCompletion { 
    void *target; 
    IOStorageCompletionAction action; 
    void *parameter; 
};  
Fields
target
Opaque client-supplied pointer (or an instance pointer for a C++ callback).
action
Completion routine to call on completion of the data transfer.
parameter
Opaque client-supplied pointer.
Discussion 

The IOStorageCompletion structure describes the C (or C++) completion routine that is called once an asynchronous storage operation completes. The values passed for the target and parameter fields will be passed to the routine when it is called*/
struct IOStorageCompletion { 
    void *target; 
    IOStorageCompletionAction action; 
    void *parameter; 
};  

/*IOStorageOptions


enum { 
    kIOStorageOptionNone = 0x00000000, 
    kIOStorageOptionForceUnitAccess = 0x00000001, 
    kIOStorageOptionReserved = 0xFFFFFFFE 
};  
Constants
kIOStorageOptionForceUnitAccess
Force the request to access the media.
Discussion 

Options for read and write storage requests.*/
enum { 
    kIOStorageOptionNone = 0x00000000, 
    kIOStorageOptionForceUnitAccess = 0x00000001, 
    kIOStorageOptionReserved = 0xFFFFFFFE 
};  
typedef UInt32 IOStorageOptions;

/*IOStorageAttributes


struct IOStorageAttributes { 
    IOStorageOptions options; 
    UInt32 reserved[3]; 
};  
Fields
options
Options for the request. See IOStorageOptions.
reserved
Reserved for future use. Set to zero.
Discussion 

Attributes of read and write storage requests.*/
struct IOStorageAttributes { 
    IOStorageOptions options; 
    UInt32 reserved[3]; 
}; 

#ifdef __cplusplus
class IOStorage : public IOService,public IOStorage_HYS
{
OSDeclareAbstractStructors(IOStorage);

public:

IOStorage_complete
IOStorage_read
IOStorage_write
IOStorage_init

/*synchronizeCache


public

virtual IOReturn synchronizeCache(
    IOService *client) = 0; 
Parameters
client
Client requesting the cache synchronization.
Return Value

Returns the status of the cache synchronization. 
Discussion 

Flush the cached data in the storage object, if any, synchronously.*/
virtual IOReturn synchronizeCache(
    IOService *client) = 0;

/*complete


public

static void complete(
    IOStorageCompletion *completion, 
    IOReturn status, 
    UInt64 actualByteCount = 0); 
Parameters
completion
Completion information for the data transfer.
status
Status of the data transfer.
actualByteCount
Actual number of bytes transferred in the data transfer.
Discussion 

Invokes the specified completion action of the read/write request. If the completion action is unspecified, no action is taken. This method serves simply as a convenience to storage subclass developers.*/
static void complete(
    IOStorageCompletion *completion, 
    IOReturn status, 
    UInt64 actualByteCount = 0);

/*write(IOService *, UInt64, IOMemoryDescriptor *, IOStorageAttributes *, IOStorageCompletion *)


public

virtual void write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 
Parameters
client
Client requesting the write.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
attributes
Attributes of the data transfer. See IOStorageAttributes. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
completion
Completion routine to call once the data transfer is complete. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
Discussion 

Write data into the storage object at the specified byte offset from the specified buffer, asynchronously. When the write completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the write. */
virtual void write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 

/*write(IOService *, UInt64, IOMemoryDescriptor *, UInt64 *)


public

virtual IOReturn write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    UInt64 *actualByteCount = 0); 
Parameters
client
Client requesting the write.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
actualByteCount
Returns the actual number of bytes transferred in the data transfer.
Return Value

Returns the status of the data transfer. 
Discussion 

Write data into the storage object at the specified byte offset from the specified buffer, synchronously. When the write completes, this method will return to the caller. The actual byte count field is optional.*/
virtual IOReturn write(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    UInt64 *actualByteCount = 0); 

/*read(IOService *, UInt64, IOMemoryDescriptor *, UInt64 *)


public

virtual IOReturn read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    UInt64 *actualByteCount = 0); 
Parameters
client
Client requesting the read.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
actualByteCount
Returns the actual number of bytes transferred in the data transfer.
Return Value

Returns the status of the data transfer. 
Discussion 

Read data from the storage object at the specified byte offset into the specified buffer, synchronously. When the read completes, this method will return to the caller. The actual byte count field is optional.*/
virtual IOReturn read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    UInt64 *actualByteCount = 0); 

/*read(IOService *, UInt64, IOMemoryDescriptor *, IOStorageAttributes *, IOStorageCompletion *)


public

virtual void read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 
Parameters
client
Client requesting the read.
byteStart
Starting byte offset for the data transfer.
buffer
Buffer for the data transfer. The size of the buffer implies the size of the data transfer.
attributes
Attributes of the data transfer. See IOStorageAttributes. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
completion
Completion routine to call once the data transfer is complete. It is the responsibility of the callee to maintain the information for the duration of the data transfer, as necessary.
Discussion 

Read data from the storage object at the specified byte offset into the specified buffer, asynchronously. When the read completes, the caller will be notified via the specified completion action.
The buffer will be retained for the duration of the read.*/

virtual void read(
    IOService *client, 
    UInt64 byteStart, 
    IOMemoryDescriptor *buffer, 
    IOStorageAttributes *attributes, 
    IOStorageCompletion *completion); 

/*open

public

virtual bool open(
    IOService *client, 
    IOOptionBits options, 
    IOStorageAccess access); 
Parameters
client
Client requesting the open.
options
Options for the open. Set to zero.
access
Access level for the open. Set to kIOStorageAccessReader or kIOStorageAccessReaderWriter.
Return Value

Returns true if the open was successful, false otherwise. 
Discussion 

Ask the storage object for permission to access its contents; the method is equivalent to IOService::open(), but with the correct parameter types.
This method may also be invoked to upgrade or downgrade the access of an existing open (if it fails, the existing open prevails).*/
virtual bool open(
    IOService *client, 
    IOOptionBits options, 
    IOStorageAccess access);

};

#endif //__cplusplus

#endif//_IOSTORAGE_H
