
#ifndef _IOKIT_IO_STORAGE_PROTOCOL_CHARACTERISTICS_H_
#define _IOKIT_IO_STORAGE_PROTOCOL_CHARACTERISTICS_H_

#include <HYS/IOKit/storage/IOStorageProtocolCharacteristics.h>

/*kIOPropertyPhysicalInterconnectTypeATAPI


#define kIOPropertyPhysicalInterconnectTypeATAPI "ATAPI" 
Discussion 

This key defines the value of ATAPI for the key kIOPropertyPhysicalInterconnectTypeKey. If the device is connected to an ATA bus and follows the ATAPI command specification, this key should be set. 

Example: 

<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>ATAPI</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
	</dict>
</dict>
*/
#define kIOPropertyPhysicalInterconnectTypeATAPI "ATAPI" 

/*kIOPropertyPhysicalInterconnectTypeUSB


#define kIOPropertyPhysicalInterconnectTypeUSB "USB" 
Discussion 

This key defines the value of USB for the key kIOPropertyPhysicalInterconnectTypeKey. If the device is connected to a USB port, this key should be set. 

Example: 

<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>USB</string>
		<key>Physical Interconnect Location</key>
		<string>External</string>
	</dict>
</dict>
*/
#define kIOPropertyPhysicalInterconnectTypeUSB "USB" 

/*kIOPropertyPhysicalInterconnectTypeVirtual


#define kIOPropertyPhysicalInterconnectTypeVirtual "Virtual Interface" 
Discussion 

This key defines the value of Virtual Interface for the key kIOPropertyPhysicalInterconnectTypeVirtual. If the device is being made to look like a storage device, but is not such in actuality, such as a File or RAM, this key should be set. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>Virtual Interface</string>
		<key>Physical Interconnect Location</key>
		<string>File</string>
	</dict>
</dict>*/

#define kIOPropertyPhysicalInterconnectTypeVirtual "Virtual Interface" 

/*kIOPropertyInternalExternalKey


#define kIOPropertyInternalExternalKey "Internal/External" 
Discussion 

This key defines the value of Internal/External for the key kIOPropertyPhysicalInterconnectLocationKey. If the device is connected to a bus and it is indeterminate whether it is internal or external, this key should be set. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>Internal/External</string>
	</dict>
</dict>
*/
#define kIOPropertyInternalExternalKey "Internal/External" 

/*kIOPropertyPortStatusLinkFailedKey


#define kIOPropertyPortStatusLinkFailedKey "Link Failed" 
Discussion 

This key defines the value of Link Failed for the key kIOPropertyPortStatusKey. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port Status</key>
		<string>Link Failed</string>
	</dict>
</dict>
*/
#define kIOPropertyPortStatusLinkFailedKey "Link Failed" 

/*kIOPropertyPortStatusNoLinkEstablishedKey


#define kIOPropertyPortStatusNoLinkEstablishedKey "No Link Established" 
Discussion 

This key defines the value of No Link Established for the key kIOPropertyPortStatusKey. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port Status</key>
		<string>No Link Established</string>
	</dict>
</dict>
*/
#define kIOPropertyPortStatusNoLinkEstablishedKey "No Link Established" 

/*kIOPropertyPortStatusLinkEstablishedKey


#define kIOPropertyPortStatusLinkEstablishedKey "Link Established" 
Discussion 

This key defines the value of Link Established for the key kIOPropertyPortStatusKey. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port Status</key>
		<string>Link Established</string>
	</dict>
</dict>
*/
#define kIOPropertyPortStatusLinkEstablishedKey "Link Established" 

/*kIOPropertyPortStatusKey


#define kIOPropertyPortStatusKey "Port Status" 
Discussion 

This key is associated with the current port status of the physical link. The port status is either "Link Established", "No Link Established", or "Link Failed". 

Note: This value can change when the port status changes. It is not a static value. 

Requirement: Optional for any interconnect. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port Status</key>
		<string>Link Established</string>
	</dict>
</dict>
*/
#define kIOPropertyPortStatusKey "Port Status" 

/*kIOPropertyFibreChannelALPAKey


#define kIOPropertyFibreChannelALPAKey "AL_PA" 
Discussion 

This key is the 8-bit Arbitrated Loop Physical Address (AL_PA) value as defined in the FC-AL-2 specification. 

Note: This value can change. It is not a static value. 

Requirement: Optional (only necessary for Fibre Channel Interface). 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>Fibre Channel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>External</string>
		<key>AL_PA</key>
		<data>04</data>
	</dict>
</dict>



Example2: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>AL_PA</key>
		<data>04</data>
	</dict>
</dict>
*/
#define kIOPropertyFibreChannelALPAKey "AL_PA" 

/*kIOPropertyPortTopologyKey


#define kIOPropertyPortTopologyKey "Port Topology" 
Discussion 

This key is associated with the current port topology. The port topology can be any valid topology for the interconnect. 

Note: This value can change. It is not a static value. 

Requirement: Optional for any interconnect. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port Topology</key>
		<string>Automatic (N_Port)</string>
	</dict>
</dict>
*/
#define kIOPropertyPortTopologyKey "Port Topology" 

/*kIOPropertyFibreChannelAddressIdentifierKey


#define kIOPropertyFibreChannelAddressIdentifierKey "Address Identifier" 
Discussion 

This key is the 24-bit Address Identifier (S_ID or D_ID) as defined in the FC-FS specification. It contains the address identifier of the source or destination Nx_Port. 

Note: This value can change. It is not a static value. 

Requirement: Optional (only necessary for Fibre Channel Interface). 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>Fibre Channel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>External</string>
		<key>Address Identifier</key>
		<data>001122</data>
	</dict>
</dict>



Example2: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Address Identifier</key>
		<data>001122</data>
	</dict>
</dict>
*/
#define kIOPropertyFibreChannelAddressIdentifierKey "Address Identifier" 

/*kIOPropertyFibreChannelNodeWorldWideNameKey


#define kIOPropertyFibreChannelNodeWorldWideNameKey "Node World Wide Name" 
Discussion 

This key is the unique 64-bit World Wide Name for the device server node located at this port, or for the initiating host port. 

Requirement: Mandatory for Fibre Channel Interface. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>Fibre Channel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>External</string>
		<key>Node World Wide Name</key>
		<data>0011223344556677</data>
	</dict>
</dict>



Example2: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Node World Wide Name</key>
		<data>0011223344556677</data>
	</dict>
</dict>
*/
#define kIOPropertyFibreChannelNodeWorldWideNameKey "Node World Wide Name" 

/*kIOPropertyFibreChannelPortWorldWideNameKey


#define kIOPropertyFibreChannelPortWorldWideNameKey "Port World Wide Name" 
Discussion 

This key is the unique 64-bit World Wide Name for the port. 

Requirement: Mandatory for Fibre Channel Interface. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>Fibre Channel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>External</string>
		<key>Port World Wide Name</key>
		<data>0011223344556677</data>
	</dict>
</dict>



Example2: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port World Wide Name</key>
		<data>0011223344556677</data>
	</dict>
</dict>*/
#define kIOPropertyFibreChannelPortWorldWideNameKey "Port World Wide Name" 

/*kIOPropertyFibreChannelCableDescriptionKey


#define kIOPropertyFibreChannelCableDescriptionKey "Fibre Channel Cabling Type" 
Discussion 

This key is associated with the cabling type used for this Fibre Channel port. Valid values include "Copper" and "Fiber Optic". 

Requirement: Optional for Fibre Channel Interface. Not defined for any other physical interconnect. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Fibre Channel Cabling Type</key>
		<string>Copper</string>
	</dict>
</dict>*/
#define kIOPropertyFibreChannelCableDescriptionKey "Fibre Channel Cabling Type" 

/*kIOPropertySCSIParallelSignalingTypeKey


#define kIOPropertySCSIParallelSignalingTypeKey "SCSI Parallel Signaling Type" 
Discussion 

This key is associated with the signaling type used for this SCSI Parallel bus. Valid values include "High Voltage Differential", "Low Voltage Differential", and "Single Ended". 

Requirement: Optional for SCSI Parallel Interface. Not defined for any other physical interconnect. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>SCSI Parallel Signaling Type</key>
		<string>High Voltage Differential</string>
	</dict>
</dict>
*/
#define kIOPropertySCSIParallelSignalingTypeKey "SCSI Parallel Signaling Type" 

/*kIOPropertyPortSpeedKey


#define kIOPropertyPortSpeedKey "Port Speed" 
Discussion 

This key is associated with the current port speed. The port speed can be any valid speed for the interconnect. 

Note: This value can change. It is not a static value. 

Requirement: Optional for any interconnect. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port Speed</key>
		<string>Automatic (1 Gigabit)</string>
	</dict>
</dict>
*/
#define kIOPropertyPortSpeedKey "Port Speed"

/*kIOPropertyPortDescriptionKey


#define kIOPropertyPortDescriptionKey "Port Description" 
Discussion 

This key is associated with an human readable port description. Examples include "Channel A", "Port 1", etc. 

Requirement: Optional for all interconnects. 

Example: 


<dict>
	<key>Controller Characteristics</key>
	<dict>
		<key>Port Description</key>
		<string>Channel A</string>
	</dict>
</dict>
*/
#define kIOPropertyPortDescriptionKey "Port Description" 

/*kIOPropertySCSIInitiatorIdentifierKey


#define kIOPropertySCSIInitiatorIdentifierKey "SCSI Initiator Identifier" 
Discussion 

An identifier that will uniquely identify this SCSI Initiator for the SCSI Domain. 

Requirement: Mandatory for SCSI Parallel Interface, SAS, and Fibre Channel Interface. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
		<key>SCSI Initiator Identifier</key>
		<integer>7</integer>
	</dict>
</dict>
*/
#define kIOPropertySCSIInitiatorIdentifierKey "SCSI Initiator Identifier" 

/*kIOPropertySCSILogicalUnitNumberKey


#define kIOPropertySCSILogicalUnitNumberKey "SCSI Logical Unit Number" 
Discussion 

This key is the SCSI Logical Unit Number for the device server controlled by the driver. 

Requirement: Mandatory for SCSI Parallel Interface and Fibre Channel Interface. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
		<key>SCSI Logical Unit Number</key>
		<integer>2</integer>
	</dict>
</dict>
*/
#define kIOPropertySCSILogicalUnitNumberKey "SCSI Logical Unit Number" 

/*kIOPropertySCSITargetIdentifierKey


#define kIOPropertySCSITargetIdentifierKey "SCSI Target Identifier" 
Discussion 

This is the SCSI Target Identifier for a given SCSI Target Device. 

Requirement: Mandatory for SCSI Parallel Interface and Fibre Channel Interface. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
		<key>SCSI Target Identifier</key>
		<integer>3</integer>
	</dict>
</dict>
*/
#define kIOPropertySCSITargetIdentifierKey "SCSI Target Identifier" 

/*kIOPropertySCSIDomainIdentifierKey


#define kIOPropertySCSIDomainIdentifierKey "SCSI Domain Identifier" 
Discussion 

An identifier that will uniquely identify this SCSI Domain for the Physical Interconnect type. This identifier is only guaranteed to be unique for any given Physical Interconnect and is not guaranteed to be the same across restarts or shutdowns. 

Requirement: Mandatory for SCSI Parallel Interface and Fibre Channel Interface. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
		<key>SCSI Domain Identifier</key>
		<integer>0</integer>
	</dict>
</dict>
*/
#define kIOPropertySCSIDomainIdentifierKey "SCSI Domain Identifier" 

/*kIOPropertyPhysicalInterconnectTypeKey


#define kIOPropertyPhysicalInterconnectTypeKey "Physical Interconnect" 
Discussion 

This key is used to define the Physical Interconnect to which a device is attached. 

Requirement: Mandatory. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
	</dict>
</dict>*/
#define kIOPropertyPhysicalInterconnectTypeKey "Physical Interconnect" 

/*kIOPropertyPhysicalInterconnectTypeSerialATA


#define kIOPropertyPhysicalInterconnectTypeSerialATA "SATA" 
Discussion 

This key defines the value of SATA for the key kIOPropertyPhysicalInterconnectTypeKey. If the device is connected to a SATA bus, this key should be set. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SATA</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
	</dict>
</dict>*/
#define kIOPropertyPhysicalInterconnectTypeSerialATA "SATA" 

/*kIOPropertyProtocolCharacteristicsKey


#define kIOPropertyProtocolCharacteristicsKey "Protocol Characteristics" 
Discussion 

This key is used to define Protocol Characteristics for a particular protocol and it has an associated dictionary which lists the protocol characteristics. 

Requirement: Mandatory 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>ATAPI</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
	</dict>
</dict>*/
#define kIOPropertyProtocolCharacteristicsKey "Protocol Characteristics" 

/*kIOPropertyInternalKey


#define kIOPropertyInternalKey "Internal" 
Discussion 

This key defines the value of Internal for the key kIOPropertyPhysicalInterconnectLocationKey. If the device is connected to an internal bus, this key should be set. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>ATA</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
	</dict>
</dict>
*/
#define kIOPropertyInternalKey "Internal" 

/*kIOPropertyExternalKey


#define kIOPropertyExternalKey "External" 
Discussion 

This key defines the value of External for the key kIOPropertyPhysicalInterconnectLocationKey. If the device is connected to an external bus, this key should be set. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>Fibre Channel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>External</string>
	</dict>
</dict>*/
#define kIOPropertyExternalKey "External" 

/*kIOPropertyPhysicalInterconnectLocationKey


#define kIOPropertyPhysicalInterconnectLocationKey "Physical Interconnect Location" 
Discussion 

This key is used to define the Physical Interconnect Location. 

Requirement: Mandatory. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
	</dict>
</dict>
*/
#define kIOPropertyPhysicalInterconnectLocationKey "Physical Interconnect Location" 

/*kIOPropertyPhysicalInterconnectTypeATA


#define kIOPropertyPhysicalInterconnectTypeATA "ATA" 
Discussion 

This key defines the value of ATA for the key kIOPropertyPhysicalInterconnectTypeKey. If the device is connected to an ATA bus, this key should be set. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>ATA</string>
		<key>Physical Interconnect Location</key>
		<string>Internal</string>
	</dict>
</dict>
*/
#define kIOPropertyPhysicalInterconnectTypeATA "ATA" 

/*kIOPropertyPhysicalInterconnectTypeSCSIParallel


#define kIOPropertyPhysicalInterconnectTypeSCSIParallel "SCSI Parallel Interface" 
Discussion 

This key defines the value of SCSI Parallel Interface for the key kIOPropertyPhysicalInterconnectTypeKey. If the device is connected to a SCSI Parallel port, this key should be set. 

Example: 


<dict>
	<key>Protocol Characteristics</key>
	<dict>
		<key>Physical Interconnect</key>
		<string>SCSI Parallel Interface</string>
		<key>Physical Interconnect Location</key>
		<string>External</string>
	</dict>
</dict>*/
#define kIOPropertyPhysicalInterconnectTypeSCSIParallel "SCSI Parallel Interface" 

#endif	//_IOKIT_IO_STORAGE_PROTOCOL_CHARACTERISTICS_H_

