#ifndef _IOKIT_IOUSBINTERFACE_H
#define _IOKIT_IOUSBINTERFACE_H

#include <IOKit/IOService.h>
#include <libkern/c++/OSData.h>

#include <IOKit/usb/USB.h>
#include <IOKit/usb/IOUSBNub.h>
#include <IOKit/usb/IOUSBDevice.h>

#include <HYS/IOKit/usb/IOUSBInterface.h>
class IOUSBInterface : public IOUSBNub,public IOUSBInterface_HYS
{
    friend class IOUSBInterfaceUserClient;
    
    OSDeclareDefaultStructors(IOUSBInterface)

protected:
public:

IOUSBInterface_start
IOUSBInterface_close
IOUSBInterface_init
IOUSBInterface_DeviceRequest
IOUSBInterface_withDescriptors
IOUSBInterface_handleOpen
IOUSBInterface_open
IOUSBInterface_SetProperties
IOUSBInterface_CallSuperClose
IOUSBInterface_CallSuperOpen
IOUSBInterface_CreatePipes
IOUSBInterface_matchPropertyTable
IOUSBInterface_handleClose
IOUSBInterface_message
IOUSBInterface_terminate
IOUSBInterface_stop
IOUSBInterface_ClosePipes
IOUSBInterface_finalize
IOUSBInterface_free
IOUSBInterface_hex2char

/*GetConfigValue


public

virtual UInt8 GetConfigValue(); 
Return Value

The device configuration value. 
Discussion 

returns the device configuration value for the interface*/
virtual UInt8 GetConfigValue(); 

/*GetPipeObj


public

virtual IOUSBPipe *GetPipeObj(
    UInt8 index); 
Parameters
index
value from zero to kUSBMaxPipes-1
Return Value

The IOUSBPipe object. Note that the client does not own a reference to this pipe, so the client should retain() the IOUSBPipe object if necessary. 
Discussion 

returns a handle to the pipe at the corresponding index*/
virtual IOUSBPipe *GetPipeObj(
    UInt8 index); 

/*GetEndpointProperties


Returns the properties of an endpoint, possibly in an alternate interface. 

public

virtual IOReturn GetEndpointProperties(
    UInt8 alternateSetting,
    UInt8 endpointNumber,
    UInt8 direction,
    UInt8 *transferType,
    UInt16 *maxPacketSize,
    UInt8 *interval); 
Parameters
alternateSetting
specifies the desired alternate setting
endpointNumber
specifies the endpoint number
direction
specifies the direction (kUSBIn, kUSBOut)
transferType
a pointer to hold the transfer type (kUSBControl, kUSBBulk, etc.) of the endpoint if found.
maxPacketSize
a pointer to hold the maxPacketSize in the endpoint descriptor.
interval
a pointer to hold the interval value in the endpoint descriptor.
Return Value

returns kIOReturnSuccess if the endpoint is found, and kIOUSBEndpointNotFound if it is not.*/

virtual IOReturn GetEndpointProperties(
    UInt8 alternateSetting,
    UInt8 endpointNumber,
    UInt8 direction,
    UInt8 *transferType,
    UInt16 *maxPacketSize,
    UInt8 *interval); 

/*GetInterfaceClass


public

virtual UInt8 GetInterfaceClass(); 
Return Value

the interface class 
Discussion 

returns the class code for this interface (assigned by the USB) a value of zero is reserved if the value is FFh, the interface class is vendor-specific all other values are reserved for assignment by the USB*/
virtual UInt8 GetInterfaceClass(); 

/*GetAlternateSetting


public

virtual UInt8 GetAlternateSetting(); 
Return Value

the alternate setting 
Discussion 

returns the alternate setting for this interface.*/
virtual UInt8 GetAlternateSetting(); 

/*FindNextAltInterface


public

virtual const IOUSBInterfaceDescriptor *FindNextAltInterface(
    const IOUSBInterfaceDescriptor *current, 
    IOUSBFindInterfaceRequest *request); 
Parameters
current
interface descriptor to start searching from, NULL to start at alternate interface 0.
request
specifies what properties an interface must have to match.
Return Value

Pointer to a matching interface descriptor, or NULL if none match. 
Discussion 

return alternate interface descriptor satisfying the requirements specified in request, or NULL if there aren't any. request is updated with the properties of the returned interface.*/
virtual const IOUSBInterfaceDescriptor *FindNextAltInterface(
    const IOUSBInterfaceDescriptor *current, 
    IOUSBFindInterfaceRequest *request); 

/*GetNumEndpoints


public

virtual UInt8 GetNumEndpoints(); 
Return Value

the number of endpoints 
Discussion 

returns the number of endpoints used by this interface (excluding device endpoint zero. If the value is zero, this interface only uses endpoint zero.*/
virtual UInt8 GetNumEndpoints(); 

/*GetInterfaceSubClass


public

virtual UInt8 GetInterfaceSubClass(); 
Return Value

the interface subclass 
Discussion 

returns the subclass code (assigned by the USB). These codes are qualified by the value returned by GetInterfaceClass*/
virtual UInt8 GetInterfaceSubClass(); 

/*FindNextAssociatedDescriptor


public

virtual const IOUSBDescriptorHeader * FindNextAssociatedDescriptor(
    const void *current,
    UInt8 type); 
Parameters
current
Descriptor to start searching from, NULL to start from beginning of list.
type
Descriptor type to search for, or kUSBAnyDesc to return any descriptor type.
Return Value

Pointer to the descriptor, or NULL if no matching descriptors found. 
Discussion 

Find the next descriptor of the requested type associated with the interface.*/
virtual const IOUSBDescriptorHeader * FindNextAssociatedDescriptor(
    const void *current,
    UInt8 type); 

/*FindNextPipe


public

virtual IOUSBPipe *FindNextPipe(
    IOUSBPipe *current,
    IOUSBFindEndpointRequest *request); 
Parameters
current
Pipe to start searching from, NULL to start from beginning of list.
request
Requirements for pipe to match, updated with the found pipe's properties.
Return Value

Pointer to the pipe, or NULL if no pipe matches the request. 
Discussion 

Find a pipe of the interface that matches the requirements, either starting from the beginning of the interface's pipe list or from a specified pipe.*/

virtual IOUSBPipe *FindNextPipe(
    IOUSBPipe *current,
    IOUSBFindEndpointRequest *request); 

/*SetAlternateInterface


public

virtual IOReturn SetAlternateInterface(
    IOService *forClient,
    UInt16 alternateSetting); 
Parameters
forClient
The client requesting the alternate setting. This client must have the interface open in order to perform the request.
alternateSetting
Alternate setting (from the alternate interface's interface descriptor).
Return Value

exclusive access error if the interface is not open. otherwise the result of the transaction 
Discussion 

Select the specified alternate interface.*/

virtual IOReturn SetAlternateInterface(
    IOService *forClient,
    UInt16 alternateSetting); 

/*DeviceRequest


Sends a control request to the default control pipe in the device (pipe zero) 

public

virtual IOReturn DeviceRequest(
    IOUSBDevRequest *request,
    IOUSBCompletion *completion = 0); 
Parameters
request
The parameter block to send to the device
completion
Function to call when request completes. If omitted then DeviceRequest() executes synchronously, blocking until the request is complete.*/

virtual IOReturn DeviceRequest(
    IOUSBDevRequest *request,
    IOUSBCompletion *completion = 0); 

/*GetInterfaceStringIndex


public

virtual UInt8 GetInterfaceStringIndex(); 
Return Value

the string index 
Discussion 

returns the index of the string descriptor describing the interface*/
virtual UInt8 GetInterfaceStringIndex(); 

/*GetInterfaceProtocol


public

virtual UInt8 GetInterfaceProtocol(); 
Return Value

the interface index 
Discussion 

returns the protocol code (assigned by the USB).*/
virtual UInt8 GetInterfaceProtocol(); 

/*GetInterfaceNumber


public

virtual UInt8 GetInterfaceNumber(); 
Return Value

the interface index 
Discussion 

returns the zero based value identifying the index in the array of concurrent interfaces supported by the current configuration*/
virtual UInt8 GetInterfaceNumber(); 

/*GetDevice


public

virtual IOUSBDevice *GetDevice(); 
Return Value

Pointer to the IOUSBDevice object which is the parent of this IOUSBInterface object. 
Discussion 

returns the device the interface is part of.*/

virtual IOUSBDevice *GetDevice(); 

};

#endif /* _IOKIT_IOUSBINTERFACE_H */
