#ifndef __ICAAPPLICATION__
#define __ICAAPPLICATION__

#include <IOKit/IOTypes.h>
#include <CoreServices/CoreServices.h>
#include <AvailabilityMacros.h>

#ifdef __cplusplus
extern "C" {
#endif

#include <HYS/ImageCapture/ICAApplication.h>

/*ICAObject types and subtypes

enum { 
    kICADevice = 'icdv', 
    kICADeviceCamera = 'cmra', 
    kICADeviceScanner = 'scan', 
    kICADeviceMFP = 'mfp ', 
    kICADevicePhone = 'phon', 
    kICADevicePDA = 'pda ', 
    kICADeviceOther = 'doth', 
    kICAList = 'objl', 
    kICADirectory = 'dire', 
    kICAFile = 'file', 
    kICAFileImage = 'imag', 
    kICAFileMovie = 'moov', 
    kICAFileAudio = 'audo', 
    kICAFileFirmware = 'firm', 
    kICAFileOther = 'othe' 
};  

Constants

    kICADevice
        Object is a device supported by Image Capture framework.
    kICADeviceCamera
        Object is a camera.
    kICADeviceScanner
        Object is a scanner.
    kICADeviceMFP
        Object is a multi-function peripheral.
    kICADevicePhone
        Object is a camera phone.
    kICADevicePDA
        Object is a personal digital assistant.
    kICADeviceOther
        Object is a device supported by Image Capture framework, but of unknown subtype.
    kICAList
        Object is a device list.
    kICADirectory
        Object is a directory.
    kICAFile
        Object is a file.
    kICAFileImage
        Object is an image file.
    kICAFileMovie
        Object is a movie file.
    kICAFileAudio
        Object is an audio file.
    kICAFileFirmware
        Object is a firmware file.
    kICAFileOther
        Object is a generic file.

Discussion

Definition of ICAObject types and subtypes*/
enum { 
    kICADevice = 'icdv', 
    kICADeviceCamera = 'cmra', 
    kICADeviceScanner = 'scan', 
    kICADeviceMFP = 'mfp ', 
    kICADevicePhone = 'phon', 
    kICADevicePDA = 'pda ', 
    kICADeviceOther = 'doth', 
    kICAList = 'objl', 
    kICADirectory = 'dire', 
    kICAFile = 'file', 
    kICAFileImage = 'imag', 
    kICAFileMovie = 'moov', 
    kICAFileAudio = 'audo', 
    kICAFileFirmware = 'firm', 
    kICAFileOther = 'othe' 
};  

/*ICAMessage

typedef struct ICAMessage { 
    OSType messageType; 
    UInt32 startByte; 
    void *dataPtr; 
    UInt32 dataSize; 
    OSType dataType; 
} ICAMessage;  

Fields

    messageType
        A message type. e.g., kICAMessageCameraCaptureNewImage. <--
    startByte
        Offset in dataPtr from where data access for read/write should occur. <--
    dataPtr
        A pointer to a data buffer. <--
    dataSize
        Size of data. <--
    dataType
        Type of data. <--

*/
typedef struct ICAMessage { 
    OSType messageType; 
    UInt32 startByte; 
    void *dataPtr; 
    UInt32 dataSize; 
    OSType dataType; 
} ICAMessage;  

/*ICAHeader

typedef struct ICAHeader { 
    ICAError err; 
    unsigned long refcon; 
} ICAHeader;  

Fields

    err
        Error returned by an API. -->
    refcon
        An arbitrary refcon value passed to the callback. <--

Discussion

This is the first field in all parameter blocks used by APIs defined in ICAApplication.h. Type of parameter passed to a callback function used by APIs defined in ICAApplication.h. The parameter for the completion proc should to be casted to an appropriate type such as ICAGetChildCountPB* for it to be useful.*/
typedef struct ICAHeader { 
    ICAError err; 
    unsigned long refcon; 
} ICAHeader;  

/*ICAObjectSendMessagePB

typedef struct ICAObjectSendMessagePB { 
    ICAHeader header; 
    ICAObject object; 
    ICAMessage message; 
    UInt32 result; 
} ICAObjectSendMessagePB;  

Fields

    header
        See description for ICAHeader. <-->
    object
        A target object for the message sent by ICAObjectSendMessage. <--
    message
        One of the messages define above. <--
    result
        A message specific result is returned here. -->

*/
typedef struct ICAObjectSendMessagePB { 
    ICAHeader header; 
    ICAObject object; 
    ICAMessage message; 
    UInt32 result; 
} ICAObjectSendMessagePB; 

/*ICAGetDeviceListPB

typedef struct ICAGetDeviceListPB { 
    ICAHeader header; 
    ICAObject object; 
} ICAGetDeviceListPB;  

Fields

    header
        See description for ICAHeader. <-->
    object
        The device list object, if ICAGetDeviceList returns successfully. -->

*/

typedef struct ICAGetDeviceListPB { 
    ICAHeader header; 
    ICAObject object; 
} ICAGetDeviceListPB;  

/*ICAGetChildCountPB

typedef struct ICAGetChildCountPB { 
    ICAHeader header; 
    ICAObject object; 
    UInt32 count; 
} ICAGetChildCountPB;  

Fields

    header
        See description for ICAHeader. <-->
    object
        An object whose number of children is being requested by calling ICAGetChildCount. <--
    count
        Number of children returned by ICAGetChildCount, if successful. Should check err field in header before using the value returned in count. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
typedef struct ICAGetChildCountPB { 
    ICAHeader header; 
    ICAObject object; 
    UInt32 count; 
} ICAGetChildCountPB;  

/*ICAObjectInfo

typedef struct ICAObjectInfo { 
    OSType objectType; 
    OSType objectSubtype; 
} ICAObjectInfo;  

Fields

    objectType
        An object type, e.g., kICAFile.
    objectSubtype
        An object subtype, e.g., kICAFileImage.

*/
typedef struct ICAObjectInfo { 
    OSType objectType; 
    OSType objectSubtype; 
} ICAObjectInfo;  

/*ICAGetNthChildPB

typedef struct ICAGetNthChildPB { 
    ICAHeader header; 
    ICAObject parentObject; 
    UInt32 index; 
    ICAObject childObject; 
    ICAObjectInfo childInfo; 
} ICAGetNthChildPB;  

Fields

    header
        See description for ICAHeader. <-->
    parentObject
        An object whose child is being accessed. <--
    index
        A zero based index in to the children of 'parentObject'. <--
    childObject
        Child object, if ICAGetNthChild returns successfully. -->
    childInfo
        Object information for 'childObject', if ICAGetNthChild returns successfully. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
typedef struct ICAGetNthChildPB { 
    ICAHeader header; 
    ICAObject parentObject; 
    UInt32 index; 
    ICAObject childObject; 
    ICAObjectInfo childInfo; 
} ICAGetNthChildPB;  

/*ICACopyObjectPropertyDictionaryPB

typedef struct ICACopyObjectPropertyDictionaryPB { 
    ICAHeader header; 
    ICAObject object; 
    CFDictionaryRef *theDict; 
} ICACopyObjectPropertyDictionaryPB;  

Fields

    header
        See description for ICAHeader. <->
    object
        An object whose properties are being requested. <--
    theDict
        A dictionary to hold the properties. This must be released by the caller. -->

*/

typedef struct ICACopyObjectPropertyDictionaryPB { 
    ICAHeader header; 
    ICAObject object; 
    CFDictionaryRef *theDict; 
} ICACopyObjectPropertyDictionaryPB;  

/*ICAGetObjectInfoPB

typedef struct ICAGetObjectInfoPB { 
    ICAHeader header; 
    ICAObject object; 
    ICAObjectInfo objectInfo; 
} ICAGetObjectInfoPB;  

Fields

    header
        See description for ICAHeader. <-->
    object
        An object whose information is being requested by calling ICAGetObjectInfo. <--
    objectInfo
        Object information for 'object', if ICAGetObjectInfo returns successfully. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */

typedef struct ICAGetObjectInfoPB { 
    ICAHeader header; 
    ICAObject object; 
    ICAObjectInfo objectInfo; 
} ICAGetObjectInfoPB;  

/*ICAPropertyInfo

typedef struct ICAPropertyInfo { 
    OSType propertyType; 
    OSType dataType; 
    UInt32 dataSize; 
    UInt32 dataFlags; 
} ICAPropertyInfo;  

Fields

    propertyType
        A property type.
    dataType
        A property subtype.
    dataSize
        TBD
    dataFlags
        TBD

*/
typedef struct ICAPropertyInfo { 
    OSType propertyType; 
    OSType dataType; 
    UInt32 dataSize; 
    UInt32 dataFlags; 
} ICAPropertyInfo;  

/*ICAGetPropertyInfoPB

typedef struct ICAGetPropertyInfoPB { 
    ICAHeader header; 
    ICAProperty property; 
    ICAPropertyInfo propertyInfo; 
} ICAGetPropertyInfoPB;  

Fields

    header
        See description for ICAHeader. <-->
    property
        Property whose information is being fetched. <--
    propertyInfo
        Property information for 'property', if ICAGetPropertyInfo returns successfully. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
	typedef struct ICAGetPropertyInfoPB { 
    ICAHeader header; 
    ICAProperty property; 
    ICAPropertyInfo propertyInfo; 
} ICAGetPropertyInfoPB;  

/*ICAGetPropertyDataPB

typedef struct ICAGetPropertyDataPB { 
    ICAHeader header; 
    ICAProperty property; 
    UInt32 startByte; 
    UInt32 requestedSize; 
    void *dataPtr; 
    UInt32 actualSize; 
    OSType dataType; 
} ICAGetPropertyDataPB;  

Fields

    header
        See description for ICAHeader. <-->
    property
        Property whose data is being fetched. <--
    startByte
        Offset into 'dataPtr' from where the fetched data should be written. <--
    requestedSize
        Requested size of data in bytes. <--
    dataPtr
        A buffer to receive the data. <--
    actualSize
        Actual size of data written to dataPtr. -->
    dataType
        Type of data fetched. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
	typedef struct ICAGetPropertyDataPB { 
    ICAHeader header; 
    ICAProperty property; 
    UInt32 startByte; 
    UInt32 requestedSize; 
    void *dataPtr; 
    UInt32 actualSize; 
    OSType dataType; 
} ICAGetPropertyDataPB;  

/*ICAGetPropertyByTypePB

typedef struct ICAGetPropertyByTypePB { 
    ICAHeader header; 
    ICAObject object; 
    OSType propertyType; 
    ICAProperty property; 
    ICAPropertyInfo propertyInfo; 
} ICAGetPropertyByTypePB;  

Fields

    header
        See description for ICAHeader. <-->
    object
        An object whose property is being fetched. <--
    propertyType
        The type of property being fetched. <--
    property
        Property, if ICAGetPropertyByType returns successfully. -->
    propertyInfo
        Property information for 'property', if ICAGetPropertyByType returns successfully. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
	typedef struct ICAGetPropertyByTypePB { 
    ICAHeader header; 
    ICAObject object; 
    OSType propertyType; 
    ICAProperty property; 
    ICAPropertyInfo propertyInfo; 
} ICAGetPropertyByTypePB;  

/*ICAProperty types

enum { 
    kICAProperty = 'prop', 
    kICAPropertyImageWidth = '0100', 
    kICAPropertyImageHeight = '0101', 
    kICAPropertyImageBitDepth = '0102', 
    kICAPropertyImageDPI = '011A', 
    kICAPropertyImageExposureTime = '829A', 
    kICAPropertyImageFNumber = '829D', 
    kICAPropertyImageDateOriginal = '9003', 
    kICAPropertyImageDateDigitized = '9004', 
    kICAPropertyImageShutterSpeed = '9201', 
    kICAPropertyImageAperture = '9202', 
    kICAPropertyImageFlash = '9209', 
    kICAPropertyColorSpace = 'A001', 
    kICAPropertyImageFilename = 'ifil', 
    kICAPropertyImageSize = 'isiz', 
    kICAPropertyImageData = 'idat', 
    kICAPropertyImageThumbnail = 'thum', 
    kICAPropertyColorSyncProfile = 'prof' 
};  

Constants

    kICAProperty
        Generic property type; for images, refer to 'Digital Still Camera Image File Format Standard' Exif Version 2.1 section 2.6.4. and 2.6.5.
    kICAPropertyImageWidth
        Image width.
    kICAPropertyImageHeight
        Image height.
    kICAPropertyImageBitDepth
        Image bit-depth.
    kICAPropertyImageDPI
        Image DPI.
    kICAPropertyImageExposureTime
        Image exposure time.
    kICAPropertyImageFNumber
        Image f-Number.
    kICAPropertyImageDateOriginal
        Original date & time of an object; value associated with this property is a null-terminated string conforming to format "YYYY:MM:DD hh:mm:ss".
    kICAPropertyImageDateDigitized
        Digitized date & time of an object; value associated with this property is a null-terminated string conforming to format "YYYY:MM:DD hh:mm:ss".
    kICAPropertyImageShutterSpeed
        Shutter speed used to capture an image.
    kICAPropertyImageAperture
        Aperture used to capture an image.
    kICAPropertyImageFlash
        Indicates whether flash was used to capture an image.
    kICAPropertyColorSpace
        Color space used to represent an image.
    kICAPropertyImageFilename
        Filename of an image.
    kICAPropertyImageSize
        Size of an image in bytes.
    kICAPropertyImageData
        Data of an image.
    kICAPropertyImageThumbnail
        Thumbnail of an image.
    kICAPropertyColorSyncProfile
        ColorSync profile associated with an image.

Discussion

Definition of ICAProperties*/
enum { 
    kICAProperty = 'prop', 
    kICAPropertyImageWidth = '0100', 
    kICAPropertyImageHeight = '0101', 
    kICAPropertyImageBitDepth = '0102', 
    kICAPropertyImageDPI = '011A', 
    kICAPropertyImageExposureTime = '829A', 
    kICAPropertyImageFNumber = '829D', 
    kICAPropertyImageDateOriginal = '9003', 
    kICAPropertyImageDateDigitized = '9004', 
    kICAPropertyImageShutterSpeed = '9201', 
    kICAPropertyImageAperture = '9202', 
    kICAPropertyImageFlash = '9209', 
    kICAPropertyColorSpace = 'A001', 
    kICAPropertyImageFilename = 'ifil', 
    kICAPropertyImageSize = 'isiz', 
    kICAPropertyImageData = 'idat', 
    kICAPropertyImageThumbnail = 'thum', 
    kICAPropertyColorSyncProfile = 'prof' 
};  

/*ICADownloadFilePB

typedef struct ICADownloadFilePB { 
    ICAHeader header; 
    ICAObject object; 
    FSRef *dirFSRef; 
    UInt32 flags; 
    OSType fileType; 
    OSType fileCreator; 
    Fixed rotationAngle; 
    FSRef *fileFSRef; 
} ICADownloadFilePB;  

Fields

    header
        See description for ICAHeader. <->
    object
        The file object. <--
    dirFSRef
        FSRef of destination directiory. <--
    flags
        Any combination of flag values defined above. <--
    fileType
        Four-char code indicating the type of file. <--
    fileCreator
        Four-char code indicating with the creator of the file. <--
    rotationAngle
        Rotation angle in steps of 90 degress. <--
    fileFSRef
        A pointer to FSRef struct to hold the FSRef of downloaded file. Set this to NULL if the FSRef of downloaded file is not of interest. -->

*/
typedef struct ICADownloadFilePB { 
    ICAHeader header; 
    ICAObject object; 
    FSRef *dirFSRef; 
    UInt32 flags; 
    OSType fileType; 
    OSType fileCreator; 
    Fixed rotationAngle; 
    FSRef *fileFSRef; 
} ICADownloadFilePB;  

/*ICAGetPropertyCountPB

typedef struct ICAGetPropertyCountPB { 
    ICAHeader header; 
    ICAObject object; 
    UInt32 count; 
} ICAGetPropertyCountPB;  

Fields

    header
        See description for ICAHeader. <-->
    object
        An object whose number of properties is being requested by calling ICAGetPropertyCount. <--
    count
        Number of properties returned by ICAGetPropertyCount, if successful. Should check err field in header before using the value returned in count. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. 

*/
typedef struct ICAGetPropertyCountPB { 
    ICAHeader header; 
    ICAObject object; 
    UInt32 count; 
} ICAGetPropertyCountPB;  

/*ICAGetNthPropertyPB

typedef struct ICAGetNthPropertyPB { 
    ICAHeader header; 
    ICAObject object; 
    UInt32 index; 
    ICAProperty property; 
    ICAPropertyInfo propertyInfo; 
} ICAGetNthPropertyPB;  

Fields

    header
        See description for ICAHeader. <-->
    object
        An object whose property is being fetched. <--
    index
        A zero based index in to the properties of 'object'. <--
    property
        Property, if ICAGetNthProperty returns successfully. -->
    propertyInfo
        Property information for 'property', if ICAGetNthProperty returns successfully. -->

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
typedef struct ICAGetNthPropertyPB { 
    ICAHeader header; 
    ICAObject object; 
    UInt32 index; 
    ICAProperty property; 
    ICAPropertyInfo propertyInfo; 
} ICAGetNthPropertyPB;  

//function

/*ICAObjectSendMessage

Use this API to send a message to a device object.

extern ICAError ICAObjectSendMessage( 
    ICAObjectSendMessagePB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAObjectSendMessagePB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAObjectSendMessage function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to send a message to a device object. All devices do not respond to all the messages defined above.

Availability
    Introduced in Mac OS X v10.0. */

	extern ICAError ICAObjectSendMessage( 
    ICAObjectSendMessagePB *pb, 
    ICACompletion completion );  

/*ICAGetDeviceList

Fetches the object at the top of the object heirarchy.

extern ICAError ICAGetDeviceList( 
    ICAGetDeviceListPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetDeviceListPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetDeviceList function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Image Capture framework presents cameras and scanners, their contents and their capabilities as a heirarchy of objects and their properties. The device list object is at the top of the heirarchy of objects. The ICAGetDeviceList function fetches this object in the object field of parameter pb. Children of the device list object can be accessed by passing the device list object to functions ICAGetChildCount() and ICAGetNthChild().



        Example:
        
        ICAObject GetDeviceList()
        {
            ICAGetDeviceListPB getDeviceListPB  = {};
            ICAObject          deviceList       = 0;
            OSErr              err;
            
            err = ICAGetDeviceList( &getDeviceListPB, nil );
            
            if ( noErr == err )
            {
                deviceList = getDeviceListPB.object;
            }
            
            return deviceList;
        }



Availability
    Introduced in Mac OS X v10.0. */
extern ICAError ICAGetDeviceList( 
    ICAGetDeviceListPB *pb, 
    ICACompletion completion );  
	
/*ICAGetChildCount

Fetches the number of children of an object. This API is deprecated in 10.5.

extern ICAError ICAGetChildCount( 
    ICAGetChildCountPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetChildCountPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetChildCount function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Image Capture framework presents cameras and scanners, their contents and their capabilities as a heirarchy of objects and their properties. The ICAGetChildCount function fetches the number of children of the object specified in the object field of paramter pb.



        Example:
        
        UInt32 GetNumberOfDevices ()
        {
            ICAGetChildCountPB getChildCountPB;
            OSErr              err;
            
            memset(&getChildCountPB, 0, sizeof(ICAGetChildCountPB));
            getChildCountPB.object = GetDeviceList();
            err = ICAGetChildCount(&getChildCountPB, nil);
            
            return getChildCountPB.count;
        }



Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
extern ICAError ICAGetChildCount( 
    ICAGetChildCountPB *pb, 
    ICACompletion completion );  
	
/*ICAGetNthChild

Fetches the child of a given object at a given index. This API is deprecated in 10.5.

extern ICAError ICAGetNthChild( 
    ICAGetNthChildPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetNthChildPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetNthChild function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Image Capture framework presents cameras and scanners, their contents and their capabilities as a heirarchy of objects and their properties. The ICAGetNthChild function fetches the child object of an object specifed in the parentObject field of the parameter pb at the index specified in the index field of the parameter pb. The index is zero-based. The function also returns the ICAObjectInfo for the child object in the childInfo field of the parameter pb.



        Example:
        
        ICAObject GetFirstDevice () {
            ICAGetNthChildPB getNthChildPB;
            ICAObject        firstDevice = NULL;
            OSErr            err;
            UInt32           count;
            
            count = GetNumberOfDevices();
            if (count > 0)
            {
                memset(&getNthChildPB, 0, sizeof(ICAGetNthChildPB));
                getNthChildPB.parentObject = Get_Device_List();
                getNthChildPB.index = 0;
                err = ICAGetNthChild (&getNthChildPB, nil);
                if (noErr == err)
                {
                    firstDevice = getNthChildPB.childObject;
                }
            }
            return firstDevice;
        }



Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
	extern ICAError ICAGetNthChild( 
    ICAGetNthChildPB *pb, 
    ICACompletion completion );  
	
/*ICACopyObjectPropertyDictionary

Use this API to get a CFDictionaryRef containing all the properties for an object specified in the object field of the ICACopyObjectPropertyDictionaryPB struct.

extern ICAError ICACopyObjectPropertyDictionary( 
    ICACopyObjectPropertyDictionaryPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICACopyObjectPropertyDictionaryPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICACopyObjectPropertyDictionary function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

This API is the preferred way to get to any ICAObject related property data.



        Example:
        
        void  CopyObjectPropertyDictionary()
        {
            OSErr                             err;
            ICACopyObjectPropertyDictionaryPB pb = {};

            pb.object = <#ICAObject object#>;
            err = ICACopyObjectPropertyDictionary( &pb, NULL );

            if ( noErr != err)
            {
                // handle error
            }
            else
            {
                // Make sure to release the returned dictionary
                // pb.theDict   // CFDictionaryRef *
            }
        }
        



Availability
    Introduced in Mac OS X v10.1. */
	extern ICAError ICACopyObjectPropertyDictionary( 
    ICACopyObjectPropertyDictionaryPB *pb, 
    ICACompletion completion );  
	
/*ICAGetObjectInfo

Use this API to get information about an object. This API is deprecated in 10.5.

extern ICAError ICAGetObjectInfo( 
    ICAGetObjectInfoPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetObjectInfoPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetObjectInfo function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get information about an object. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
extern ICAError ICAGetObjectInfo( 
    ICAGetObjectInfoPB *pb, 
    ICACompletion completion );

/*ICAGetPropertyData

Use this API to get data associated with a property. This API is deprecated in 10.5. Use one of the ICACopy* APIs instead.

extern ICAError ICAGetPropertyData( 
    ICAGetPropertyDataPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetPropertyDataPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetPropertyData function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get data associated with a property. This API is deprecated in 10.5. Use one of the ICACopy* APIs instead.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
extern ICAError ICAGetPropertyData( 
    ICAGetPropertyDataPB *pb, 
    ICACompletion completion );  
	
/*ICAGetPropertyByType

Use this API to get an object's property by type and its information. This API is deprecated in 10.5.

extern ICAError ICAGetPropertyByType( 
    ICAGetPropertyByTypePB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetPropertyByTypePB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetPropertyByType function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get an object's property by type and its information. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
	extern ICAError ICAGetPropertyByType( 
    ICAGetPropertyByTypePB *pb, 
    ICACompletion completion );  
	
/*ICADownloadFile

Use this API to download a file to disk.

extern ICAError ICADownloadFile( 
    ICADownloadFilePB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICADownloadFilePB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICADownloadFile function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

This API is a convenient way to download a file to disk. To receive the image data in memory use ICACopyObjectData. Using ICAGetPropertyData is not recommend for this purpose since ICAGetPropertyData is Deprecated in 10.5.



        Example:
        
        void DownloadFile()
        {
            OSErr             err;
            ICADownloadFilePB pb = {};

            pb.flags         = <#UInt32 flags#>;
            pb.rotationAngle = <#Fixed rotationAngle#>;
            pb.object        = <#ICAObject object#>;
            pb.fileCreator   = <#OSType fileCreator#>;
            pb.dirFSRef      = <#FSRef * dirFSRef#>;
            pb.fileType      = <#OSType fileType#>;
            
            err = ICADownloadFile( &pb, NULL );

            if ( noErr != err )
            {
                // handle error
            }
            else
            {
                // pb.fileFSRef   // FSRef *
            }
        }



Availability
    Introduced in Mac OS X v10.1. */
	extern ICAError ICADownloadFile( 
    ICADownloadFilePB *pb, 
    ICACompletion completion );  
	
/*ICAGetPropertyCount

Use this API to get the number of properties an object has. This API is deprecated in 10.5.

extern ICAError ICAGetPropertyCount( 
    ICAGetPropertyCountPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetPropertyCountPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetPropertyCount function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get the number of properties an object has. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
extern ICAError ICAGetPropertyCount( 
    ICAGetPropertyCountPB *pb, 
    ICACompletion completion );  

/*ICAGetNthProperty

Use this API to get an object's specific property and its information. This API is deprecated in 10.5.

extern ICAError ICAGetNthProperty( 
    ICAGetNthPropertyPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetNthPropertyPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetNthProperty function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get an object's specific property and its information. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
extern ICAError ICAGetNthProperty( 
    ICAGetNthPropertyPB *pb, 
    ICACompletion completion );  
	
#ifdef __cplusplus
}
#endif


#endif //__ICAAPPLICATION__
