#import <Foundation/Foundation.h>
#import <QuickTime/QuickTime.h>
#import <QTKit/QTKitDefines.h>
#import <QTKit/QTTime.h>
#import <QTKit/QTTimeRange.h>

@class QTMovie;
@class QTMedia;
@class NSImage;


/*Constants

The following constants specify the track attributes that you can get and set using the trackAttributes and setTrackAttributes methods. To get or set a single attribute, use attributeForKey or setAttribute.
Constant	
Description

QTTrackBoundsAttribute	
The bounding rectangle of a QTTrack object; the value for this key is of type NSValue, interpreted as an NSRect.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackCreationTimeAttribute	
The creation time of a QTTrack object; the value for this key is of type NSDate.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackDimensionsAttribute	
The dimensions of a QTTrack object; the value for this key is of type NSValue, interpreted as an NSSize.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackDisplayNameAttribute	
The display name of a QTTrack object; the value for this key is of type NSString.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackEnabledAttribute	
The track enabled state of a QTTrack object; the value for this key is of type NSNumber, interpreted as a BOOL.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackFormatSummaryAttribute	
An NSString that is a localized, human-readable string that summarizes a track’s format; for example, “16-bit Integer (Big Endian), Stereo (L R), 48.000 kHz”. This attribute is gettable but not settable.

Mac OS X v10.5 and later.

Declared in QTTrack.h
QTTrackHasApertureModeDimensionsAttribute	
The value to determine whether aperture mode dimensions have been set on a track, even if they are all identical to the classic dimensions (as is the case for content with square pixels and no edge-processing region).

Available in Mac OS X v10.5 and later.

Declared in QTTrack.h
QTTrackIDAttribute	
The track ID of a QTTrack object; the value for this key is of type NSNumber, interpreted as a long.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackLayerAttribute	
The track layer of a QTTrack object; the value for this key is of type NSNumber, interpreted as a short.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackMediaTypeAttribute	
The media type of a QTTrack object; the value for this key is of type NSString.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackModificationTimeAttribute	
The modification time of a QTTrack object; the value for this key is of type NSDate.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackRangeAttribute	
The range of time this track occupies; the value for this key is of type NSValue, interpreted as a QTTimeRange.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackTimeScaleAttribute	
The track time scale; the value for this key is of type NSNumber, interpreted as a long.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackUsageInMovieAttribute	
The movie usage setting; the value for this key is of type NSNumber, interpreted as a BOOL.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackUsageInPosterAttribute	
The poster usage setting; the value for this key is of type NSNumber, interpreted as a BOOL.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackUsageInPreviewAttribute	
The preview usage setting; the value for this key is of type NSNumber, interpreted as a BOOL.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h
QTTrackVolumeAttribute	
The volume of a QTTrack object; the value for this key is of type NSNumber, interpreted as a float.

Available in Mac OS X v10.3 and later.

Declared in QTTrack.h*/

extern NSString * QTTrackBoundsAttribute;	
extern NSString  * QTTrackCreationTimeAttribute;	
extern NSString *QTTrackDimensionsAttribute	;
extern NSString *QTTrackDisplayNameAttribute	;
extern NSString  *QTTrackEnabledAttribute	;
extern NSString  *QTTrackFormatSummaryAttribute	;
extern NSString * QTTrackHasApertureModeDimensionsAttribute	;
extern NSString * QTTrackIDAttribute	;
extern NSString  * QTTrackLayerAttribute	;
extern NSString * QTTrackMediaTypeAttribute	;
extern NSString  *QTTrackModificationTimeAttribute	;
extern NSString * QTTrackRangeAttribute	;
extern NSString * QTTrackTimeScaleAttribute	;
extern NSString * QTTrackUsageInMovieAttribute	;
extern NSString * QTTrackUsageInPosterAttribute	;
extern NSString * QTTrackUsageInPreviewAttribute	;
extern NSString * QTTrackVolumeAttribute	;

@interface QTTrack : NSObject
/*quickTimeTrack

-(Track)quickTimeTrack
Discussion

Returns the QuickTime track associated with a QTTrack object.
Availability
Available in Mac OS X v10.3 and later.*/
-(Track)quickTimeTrack;

/*setEnabled:

- (void)setEnabled:(BOOL)enabled
Discussion

Sets the enabled state of a QTTrack to enabled.
Availability
Available in Mac OS X v10.3 and later.*/
- (void)setEnabled:(BOOL)enabled;

/*media

- (QTMedia *)media
Discussion

Returns the media associated with a QTTrack object.
Availability
Available in Mac OS X v10.3 and later.*/
- (QTMedia *)media;

/*attributeForKey:
-(id)attributeForKey:(NSString *)attributeKey

Discussion
Returns the current value of the track attribute attributeKey. A list of supported track attributes and their acceptable values can be found in the Constants section.

Availability
Available in Mac OS X v10.3 and later.
Declared In
QTTrack.h*/
-(id)attributeForKey:(NSString *)attributeKey;

/*isEnabled
- (BOOL)isEnabled

Discussion
Returns YES if the QTTrack object is currently enabled, NO otherwise.

Availability
Available in Mac OS X v10.3 and later.
Declared In
QTTrack.h*/
- (BOOL)isEnabled;

/*volume
-(float)volume

Discussion
Returns the volume of a QTTrack object. The valid range is 0.0 to 1.0.

Availability
Available in Mac OS X v10.3 and later.
Declared In
QTTrack.h*/
-(float)volume;

/*setVolume:
-(void)setVolume:(float)volume

Discussion
Sets the volume of a QTTrack to volume. The valid range is 0.0 to 1.0.

Availability
Available in Mac OS X v10.3 and later.
Declared In
QTTrack.h*/
-(void)setVolume:(float)volume;

@end


@interface QTTrack (QTTrackVisualSupport)

@end
