#import <AppKit/AppKit.h>
#import <QuartzComposer/QCRenderer.h>

@interface QCView : NSView
/*loadCompositionFromFile:

Loads a Quartz Composer composition into a QCView object.

- (BOOL) loadCompositionFromFile:(NSString*)path
Parameters
path

A string that specifies the location of a Quartz Composer composition.
Return Value

If unsuccessful, returns NO; any composition that’s already loaded in the view remains loaded.
Availability
Available in Mac OS X v10.4 and later.*/
- (BOOL) loadCompositionFromFile:(NSString*)path;

/*setValue:forInputKey:

Sets the value for an input port of the composition in the view.

- (BOOL) setValue:(id)value forInputKey:(NSString*)key
Parameters
value

The value for the input port. The data type of this value must match the type of the port. For the data types that are associated with a port type see QCPortAttributeTypeKey in QCRenderer Class Reference.
key

The key associated with the input port whose value you want to set. This method throws an exception if key is invalid.
Return Value

Returns NO if it cannot set the value.
Availability
Available in Mac OS X v10.4 and later.
See Also
– valueForInputKey:*/
- (BOOL) setValue:(id)value forInputKey:(NSString*)key;

/*setAutostartsRendering:

Sets whether the view starts rendering automatically when the view is put on screen. 

- (void) setAutostartsRendering:(BOOL)flag
Parameters
flag

Pass YES to enable autostart mode.
Availability
Available in Mac OS X v10.4 and later.
See Also
– autostartsRendering*/
- (void) setAutostartsRendering:(BOOL)flag;

/*startRendering

Starts rendering a composition in the view. 

- (BOOL) startRendering
Return Value

Returns NO if the composition fails to start, YES otherwise.
Availability
Available in Mac OS X v10.4 and later.
See Also
– stopRendering*/
- (BOOL) startRendering;

@end

@interface QCView (IBExtensions)

@end
