
#ifndef SECBASE_H
#define SECBASE_H

#include <CoreFoundation/CFBase.h>

#if defined(__cplusplus)
extern "C" {
#endif

/*Result Codes

The most common result codes returned by Keychain Services are listed in the table below. The assigned error space for Keychain Services is discontinuous: –25240 through –25279 and –25290 through –25329. Keychain Item Services may also return noErr (0) or paramErr (–50), or CSSM result codes (see Common Security: CDSA and CSSM, version 2 (with corrigenda) from The Open Group (http://www.opengroup.org/security/cdsa.htm)).
Result Code	Value	Description
errSecNotAvailable	–25291	
No trust results are available.

Available in Mac OS X v10.2 and later.
errSecReadOnly	–25292	
Read only error.

Available in Mac OS X v10.2 and later.
errSecAuthFailed	–25293	
Authorization/Authentication failed.

Available in Mac OS X v10.2 and later.
errSecNoSuchKeychain	–25294	
The keychain does not exist.

Available in Mac OS X v10.2 and later.
errSecInvalidKeychain	–25295	
The keychain is not valid.

Available in Mac OS X v10.2 and later.
errSecDuplicateKeychain	–25296	
A keychain with the same name already exists.

Available in Mac OS X v10.2 and later.
errSecDuplicateCallback	–25297	
More than one callback of the same name exists.

Available in Mac OS X v10.2 and later.
errSecInvalidCallback	–25298	
The callback is not valid.

Available in Mac OS X v10.2 and later.
errSecDuplicateItem	–25299	
The item already exists.

Available in Mac OS X v10.2 and later.
errSecItemNotFound	–25300	
The item cannot be found.

Available in Mac OS X v10.2 and later.
errSecBufferTooSmall	–25301	
The buffer is too small.

Available in Mac OS X v10.2 and later.
errSecDataTooLarge	–25302	
The data is too large for the particular data type.

Available in Mac OS X v10.2 and later.
errSecNoSuchAttr	–25303	
The attribute does not exist.

Available in Mac OS X v10.2 and later.
errSecInvalidItemRef	–25304	
The item reference is invalid.

Available in Mac OS X v10.2 and later.
errSecInvalidSearchRef	–25305	
The search reference is invalid.

Available in Mac OS X v10.2 and later.
errSecNoSuchClass	–25306	
The keychain item class does not exist.

Available in Mac OS X v10.2 and later.
errSecNoDefaultKeychain	–25307	
A default keychain does not exist.

Available in Mac OS X v10.2 and later.
errSecInteractionNotAllowed	–25308	
Interaction with the Security Server is not allowed.

Available in Mac OS X v10.2 and later.
errSecReadOnlyAttr	–25309	
The attribute is read only.

Available in Mac OS X v10.2 and later.
errSecWrongSecVersion	–25310	
The version is incorrect.

Available in Mac OS X v10.2 and later.
errSecKeySizeNotAllowed	–25311	
The key size is not allowed.

Available in Mac OS X v10.2 and later.
errSecNoStorageModule	–25312	
There is no storage module available.

Available in Mac OS X v10.2 and later.
errSecNoCertificateModule	–25313	
There is no certificate module available.

Available in Mac OS X v10.2 and later.
errSecNoPolicyModule	–25314	
There is no policy module available.

Available in Mac OS X v10.2 and later.
errSecInteractionRequired	–25315	
User interaction is required.

Available in Mac OS X v10.2 and later.
errSecDataNotAvailable	–25316	
The data is not available.

Available in Mac OS X v10.2 and later.
errSecDataNotModifiable	–25317	
The data is not modifiable.

Available in Mac OS X v10.2 and later.
errSecCreateChainFailed	–25318	
The attempt to create a certificate chain failed.

Available in Mac OS X v10.2 and later.
errSecInvalidPrefsDomain	–25319	
The preference domain specified is invalid. This error is available in Mac OS X v10.3 and later.

Available in Mac OS X v10.3 and later.
errSecACLNotSimple	–25240	
The access control list is not in standard simple form.

Available in Mac OS X v10.2 and later.
errSecPolicyNotFound	–25241	
The policy specified cannot be found.

Available in Mac OS X v10.2 and later.
errSecInvalidTrustSetting	–25242	
The trust setting is invalid.

Available in Mac OS X v10.2 and later.
errSecNoAccessForItem	–25243	
The specified item has no access control.

Available in Mac OS X v10.2 and later.
errSecInvalidOwnerEdit	–25244	
An invalid attempt to change the owner of an item.

Available in Mac OS X v10.2 and later.
errSecTrustNotAvailable	–25245	
No trust results are available.

Available in Mac OS X v10.3 and later.
errSecUnsupportedFormat	–25256	
The specified import or export format is not supported.

Available in Mac OS X v10.4 and later.
errSecUnknownFormat	–25257	
The item you are trying to import has an unknown format.

Available in Mac OS X v10.4 and later.
errSecKeyIsSensitive	–25258	
The key must be wrapped to be exported.

Available in Mac OS X v10.4 and later.
errSecMultiplePrivKeys	–25259	
An attempt was made to import multiple private keys.

Available in Mac OS X v10.4 and later.
errSecPassphraseRequired	–25260	
A password is required for import or export.

Available in Mac OS X v10.4 and later.*/

enum {
	errSecInteractionNotAllowed  = -25308,
    	errSecInvalidSearchRef       = -25305,
    	errSecInvalidItemRef         = -25304,
 	errSecWrongSecVersion        = -25310,
 	errSecNoSuchAttr             = -25303,
    	errSecKeySizeNotAllowed      = -25311,
	errSecDataTooLarge           = -25302,
 	errSecNoStorageModule        = -25312,
    	errSecBufferTooSmall         = -25301,
	errSecNoDefaultKeychain      = -25307,
    	errSecNoSuchClass            = -25306,
    	errSecNoPolicyModule         = -25314,	
	errSecNoCertificateModule    = -25313,
    	errSecDuplicateKeychain      = -25296,
 	errSecInvalidCallback        = -25298,
    	errSecReadOnlyAttr           = -25309,
    	errSecInvalidKeychain        = -25295,
 	errSecCreateChainFailed      = -25318,	
    	errSecItemNotFound           = -25300,
    	errSecDuplicateItem          = -25299,
	errSecNoAccessForItem        = -25243,
    	errSecNotAvailable           = -25291,
    	errSecReadOnly               = -25292,
  	errSecAuthFailed             = -25293,
	errSecInvalidOwnerEdit       = -25244,
 	errSecNoSuchKeychain         = -25294,
	errSecInvalidTrustSetting    = -25242,
	errSecACLNotSimple           = -25240,
    	errSecDuplicateCallback      = -25297,	
  	errSecDataNotAvailable       = -25316,	
    	errSecDataNotModifiable      = -25317,
	errSecPolicyNotFound         = -25241,
	errSecInteractionRequired    = -25315,
};

/*SecKeychainRef

Contains information about a keychain.

typedef struct OpaqueSecKeychainRef *SecKeychainRef;
Availability
Available in Mac OS X v10.0 and later.*/
typedef struct OpaqueSecKeychainRef *SecKeychainRef;

/*SecKeychainAttrType

Represents a keychain attribute type.

typedef OSType SecKeychainAttrType;
Availability
Available in Mac OS X v10.0 and later.*/
typedef OSType SecKeychainAttrType;

/*SecKeychainItemRef

Contains information about a keychain item.

typedef struct OpaqueSecKeychainItemRef *SecKeychainItemRef;
Discussion

A SecKeychainItemRef object for a certificate that is stored in a keychain can be safely cast to a SecCertificateRef for use with the Certificate, Key, and Trust API.
Availability
Available in Mac OS X v10.0 and later.*/
typedef struct OpaqueSecKeychainItemRef *SecKeychainItemRef;

/*SecKeychainAttribute

Contains keychain attributes. 

struct SecKeychainAttribute
   {
   SecKeychainAttrType tag;
   UInt32 length;
   void *data;
};
typedef struct SecKeychainAttribute SecKeychainAttribute;
typedef SecKeychainAttribute *SecKeychainAttributePtr;
Fields
tag

A 4-byte attribute tag. See “Keychain Item Attribute Constants” for valid attribute types.
length

The length of the buffer pointed to by data.
data

A pointer to the attribute data.
Availability
Available in Mac OS X v10.0 and later.*/
struct SecKeychainAttribute
   {
   SecKeychainAttrType tag;
   UInt32 length;
   void *data;
};
typedef struct SecKeychainAttribute SecKeychainAttribute;
typedef SecKeychainAttribute *SecKeychainAttributePtr;


/*SecKeychainAttributeList

Represents a list of keychain attributes.

struct SecKeychainAttributeList
   {
   UInt32 count;
   SecKeychainAttribute *attr;
};
typedef struct SecKeychainAttributeList SecKeychainAttributeList;
Fields
count

An unsigned 32-bit integer that represents the number of keychain attributes in the array.
attr

A pointer to the first keychain attribute in the array.
Availability
Available in Mac OS X v10.0 and later.*/
struct SecKeychainAttributeList
   {
   UInt32 count;
   SecKeychainAttribute *attr;
};
typedef struct SecKeychainAttributeList SecKeychainAttributeList;

/*SecCertificateRef

Contains information about a certificate.

typedef struct OpaqueSecCertificateRef *SecCertificateRef;
Discussion

A SecCertificateRef object for a certificate that is stored in a keychain can be safely cast to a SecKeychainItemRef for manipulation as a keychain item. On the other hand, if the SecCertificateRef is not stored in a keychain, casting the object to a SecKeychainItemRef and passing it to Keychain Services functions will return errors.
Availability
Available in Mac OS X v10.2 and later.*/
typedef struct OpaqueSecCertificateRef *SecCertificateRef;

/*SecIdentityRef

Contains information about an identity.

typedef struct OpaqueSecIdentityRef *SecIdentityRef;
Availability
Available in Mac OS X v10.2 and later.*/
typedef struct OpaqueSecIdentityRef *SecIdentityRef;

/*SecKeychainSearchRef

Contains information about a keychain search.

typedef struct OpaqueSecKeychainSearchRef *SecKeychainSearchRef;
Availability
Available in Mac OS X v10.0 and later.
Declared In
SecBase.h*/
typedef struct OpaqueSecKeychainSearchRef *SecKeychainSearchRef;

/*SecAccessRef

Identifies a keychain or keychain item’s access information.

typedef struct OpaqueSecAccessRef *SecAccessRef;
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecBase.h(\*/
typedef struct OpaqueSecAccessRef *SecAccessRef;

/*SecPolicyRef

Contains information about a policy.

typedef struct OpaqueSecPolicyRef *SecPolicyRef;

Availability
Available in Mac OS X v10.2 and later.
Declared In
SecBase.h*/
typedef struct OpaqueSecPolicyRef *SecPolicyRef;

/*SecKeyRef

Abstract Core Foundation-type object representing an asymmetric key.

typedef struct __SecKey *SecKeyRef;
Discussion

A SecKeyRef object for a key that is stored in a keychain can be safely cast to a SecKeychainItemRef for manipulation as a keychain item. On the other hand, if the SecKeyRef is not stored in a keychain, casting the object to a SecKeychainItemRef and passing it to Keychain Services functions returns errors.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecBase.h*/
typedef struct __SecKey *SecKeyRef;

/*SecKeychainAttributeInfo

Represents an attribute.

struct SecKeychainAttributeInfo
   {
   UInt32 count;
   UInt32 *tag;
   UInt32 *format;
};
typedef struct SecKeychainAttributeInfo SecKeychainAttributeInfo;

Fields
count

The number of tag-format pairs in the respective arrays.
tag

A pointer to the first attribute tag in the array.
format

A pointer to the first attribute format in the array.
Discussion

Each tag and format item form a pair.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecBase.h*/
struct SecKeychainAttributeInfo
   {
   UInt32 count;
   UInt32 *tag;
   UInt32 *format;
};
typedef struct SecKeychainAttributeInfo SecKeychainAttributeInfo;

/*SecTrustedApplicationRef

Contains information about a trusted application.

typedef struct OpaqueSecTrustedApplicationRef *SecTrustedApplicationRef;

Availability
Available in Mac OS X v10.2 and later.
Declared In
SecBase.h*/
typedef struct OpaqueSecTrustedApplicationRef *SecTrustedApplicationRef;

/*SecACLRef

Represents information about an access control list entry.

typedef struct OpaqueSecTrustRef *SecACLRef;

Availability
Available in Mac OS X v10.2 and later.
Declared In
SecBase.h*/
typedef struct OpaqueSecTrustRef *SecACLRef;

#if defined(__cplusplus)
}
#endif

#endif //SECBASE_H
