 
 
#ifndef SECIMPORTEXPORT_H
#define SECIMPORTEXPORT_H

#include <Security/cssmtype.h>
#include <Security/SecAccess.h>
#include <Security/SecKeychain.h>
#include <CoreFoundation/CoreFoundation.h>
#include <stdint.h>

#ifdef	__cplusplus
extern "C" {
#endif

/*Import/Export Parameters Version

Defines the version of an import/export parameters structure.

#defineSEC_KEY_IMPORT_EXPORT_PARAMS_VERSION

Constants
SEC_KEY_IMPORT_EXPORT_PARAMS_VERSION

Defines the version number for a SecImportExportParameters structure used as input to the functions SecKeychainItemExport and SecKeychainItemImport.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
*/
#define SEC_KEY_IMPORT_EXPORT_PARAMS_VERSION 0

/*Keychain Item Import/Export Flags

Defines values for import and export flags.

enum
{
   kSecItemPemArmour           = 0x00000001,
};
typedef uint32_t SecItemImportExportFlags;

Constants
kSecItemPemArmour

The exported data should have PEM armour.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
Discussion

This enumeration lists values used by the flags parameter of the functions SecKeychainItemExport and SecKeychainItemImport.

PEM armour refers to a way of expressing binary data as an ASCII string so that it can be transferred over text-only channels such as email. (PEM stands for an Internet standard, Privacy Enhanced Mail.)*/

enum
{
   kSecItemPemArmour           = 0x00000001,
};

/*Keychain Item Import/Export Formats

Specifies the format of an item after export from or before import to the keychain.

enum
{
   kSecFormatUnknown = 0,
   
   // Asymmetric Key Formats 
   kSecFormatOpenSSL,
   kSecFormatSSH,      //not supported
   kSecFormatBSAFE,
   
   // Symmetric Key Formats 
   kSecFormatRawKey,
   
   //Formats for wrapped symmetric and private keys 
   kSecFormatWrappedPKCS8,
   kSecFormatWrappedOpenSSL,
   kSecFormatWrappedSSH,   //not supported
   kSecFormatWrappedLSH,   //not supported
   
   // Formats for certificates 
   kSecFormatX509Cert,
   
   // Aggregate Types 
   kSecFormatPEMSequence,
   kSecFormatPKCS7,
   kSecFormatPKCS12,
   kSecFormatNetscapeCertSequence
};
typedef uint32_t SecExternalFormat;

Constants
kSecFormatUnknown

When importing, indicates the format is unknown. When exporting, use the default format for the item. For asymmetric keys, the default is kSecFormatOpenSSL. For symmetric keys, the default is kSecFormatRawKey. For certificates, the default is kSecFormatX509Cert. For multiple items, the default is kSecFormatPEMSequence.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatOpenSSL

Format for asymmetric (public/private) keys. OpenSSL is an open source toolkit for Secure Sockets Layer (SSL) and Transport Layer Security (TLS). Also known as X.509 for public keys.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatSSH

Not supported.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatBSAFE

Format for asymmetric keys. BSAFE is a standard from RSA Security for encryption, digital signatures, and privacy.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatRawKey

Format for symmetric keys. Raw, unformatted key bits. This is the default for symmetric keys.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatWrappedPKCS8

Format for wrapped symmetric and private keys. PKCS8 is the Private-Key Information Syntax Standard from RSA Security.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatWrappedOpenSSL

Format for wrapped symmetric and private keys. OpenSSL is an open-source toolkit for Secure Sockets Layer (SSL) and Transport Layer Security (TLS). 

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatWrappedSSH

Not supported.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatWrappedLSH

Not supported.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatX509Cert

Format for certificates. DER (distinguished encoding rules) encoded. X.509 is a standard for digital certificates from the International Telecommunication Union (ITU). This is the default for certificates.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatPEMSequence

Sequence of certificates and keys with PEM armour. PEM armour refers to a way of expressing binary data as an ASCII string so that it can be transferred over text-only channels such as email. This is the default format for multiple items.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatPKCS7

Sequence of certificates, no PEM armour. PKCS7 is the Cryptographic Message Syntax Standard from RSA Security, Inc.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatPKCS12

Set of certificates and private keys. PKCS12 is the Personal Information Exchange Syntax from RSA Security, Inc.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecFormatNetscapeCertSequence

Set of certificates in the Netscape Certificate Sequence format.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.*/
enum
{
   kSecFormatUnknown = 0,
   
   /* Asymmetric Key Formats */
   kSecFormatOpenSSL,
   kSecFormatSSH,      //not supported
   kSecFormatBSAFE,
   
   /* Symmetric Key Formats */
   kSecFormatRawKey,
   
   /* Formats for wrapped symmetric and private keys */
   kSecFormatWrappedPKCS8,
   kSecFormatWrappedOpenSSL,
   kSecFormatWrappedSSH,   //not supported
   kSecFormatWrappedLSH,   //not supported
   
   /* Formats for certificates */
   kSecFormatX509Cert,
   
   /* Aggregate Types */
   kSecFormatPEMSequence,
   kSecFormatPKCS7,
   kSecFormatPKCS12,
   kSecFormatNetscapeCertSequence,
	kSecFormatSSHv2,
};
typedef uint32_t SecExternalFormat;

/*Keychain Item Import/Export Parameter Flags

Defines values for the flags field of the import/export parameters.

enum
{
   kSecKeyImportOnlyOne        = 0x00000001,
   kSecKeySecurePassphrase     = 0x00000002,
   kSecKeyNoAccessControl      = 0x00000004
};
typedef uint32_t SecKeyImportExportFlags;

Constants
kSecKeyImportOnlyOne

Prevents the importing of more than one private key by the SecKeychainItemImport function. If the importKeychain parameter is NULL, this bit is ignored. Otherwise, if this bit is set and there is more than one key in the incoming external representation, no items are imported to the specified keychain and the error errSecMultipleKeys is returned.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecKeySecurePassphrase

When set, the password for import or export is obtained by user prompt. (A password is sometimes referred to as a passphrase to emphasize the fact that a longer string that includes non-letter characters, such as numbers, punctuation, and spaces, is more secure than a simple word.) Otherwise, you must provide the password in the passphrase field of the SecKeyImportExportParameters structure. A user-supplied password is preferred, because it avoids having the cleartext password appear in the application’s address space at any time.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecKeyNoAccessControl

When set, imported private keys have no access object attached to them. In the absence of both this bit and the accessRef field in SecKeyImportExportParameters, imported private keys are given default access controls.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
Discussion

These flags are used as input to the import/export parameters structure (SecKeyImportExportParameters, which in turn is used as input to the functions SecKeychainItemExport and SecKeychainItemImport.*/
enum
{
   kSecKeyImportOnlyOne        = 0x00000001,
   kSecKeySecurePassphrase     = 0x00000002,
   kSecKeyNoAccessControl      = 0x00000004
};
typedef uint32_t SecKeyImportExportFlags;

/*SecKeyImportExportParameters

Contains input parameters for import and export functions.

typedef struct
{
// for import and export 
uint32_t                version;
SecKeyImportExportFlags flags;
CFTypeRef               passphrase;
CFStringRef             alertTitle;
CFStringRef             alertPrompt;

//for import only 
SecAccessRef            accessRef;
CSSM_KEYUSE             keyUsage;
CSSM_KEYATTR_FLAGS      keyAttributes;
} SecKeyImportExportParameters;
Fields
version

The version of this structure; the current value is SEC_KEY_IMPORT_EXPORT_PARAMS_VERSION.
flags

A set of flag bits, defined in “Keychain Item Import/Export Formats.”
passphrase

A password, used for kSecFormatPKCS12 and kSecFormatWrapped formats only. (A password is sometimes referred to as a passphrase to emphasize the fact that a longer string that includes non-letter characters, such as numbers, punctuation, and spaces, is more secure than a simple word.) Legal types are CFStringRef and CFDataRef. PKCS12 requires passwords to be in Unicode format; passing in a CFStringRef as the password is the safest way to ensure that this requirement is met (and that the result is compatible with other implementations). If a CFDataRef object is supplied as the password for a PKCS12 export operation, the data is assumed to be in UTF8 form and is converted as appropriate.

When importing or exporting keys (SecKeyRef objects) in one of the wrapped formats (kSecFormatWrappedOpenSSL, kSecFormatWrappedSSH, or kSecFormatWrappedPKCS8) or in PKCS12 format, you must either explicitly specify the passphrase field or set the kSecKeySecurePassphrase bit in the Flags field (to prompt the user for the password).
alertTitle

Title of secure password alert panel. When importing or exporting a key, if you set the kSecKeySecurePassphrase flag bit, you can optionally use this field to specify a string for the password panel’s title bar. 
alertPrompt

Prompt in secure password alert panel. When importing or exporting a key, if you set the kSecKeySecurePassphrase flag bit, you can optionally use this field to specify a string for the prompt that appears in the password panel.
accessRef

Specifies the initial access controls of imported private keys. If more than one private key is being imported, all private keys get the same initial access controls. If this field is NULL when private keys are being imported, then the access object for the keychain item for an imported private key depends on the kSecKeyNoAccessControl bit in the flags parameter. If this bit is 0 (or keyParams is NULL), the default access control is used. If this bit is 1, no access object is attached to the keychain item for imported private keys.
keyUsage

A word of bits constituting the low-level use flags for imported keys as defined in cssmtype.h. If this field is 0 or keyParams is NULL, the default value is CSSM_KEYUSE_ANY. 
keyAttributes

A word of bits constituting the low-level attribute flags for imported keys. The default value is CSSM_KEYATTR_SENSITIVE | CSSM_KEYATTR_EXTRACTABLE; the CSSM_KEYATTR_PERMANENT bit is also added to the default if a non-NULL value is specified for the importKeychain parameter. 

The following are valid values for these flags: CSSM_KEYATTR_PERMANENT, CSSM_KEYATTR_SENSITIVE, and CSSM_KEYATTR_EXTRACTABLE. 

If the CSSM_KEYATTR_PERMANENT bit is set, the importKeychain parameter is not valid, and if any keys are found in the external representation, then the error errSecInvalidKeychain is returned.

The CSSM_KEYATTR_SENSITIVE bit indicates that the key can only be extracted in wrapped form.

Important: If you do not set the CSSM_KEYATTR_EXTRACTABLE bit, you cannot extract the imported key from the keychain in any form, including in wrapped form.

The CSSM_KEYATTR_FLAGS enumeration is defined in cssmtype.h. Note that the CSSM_KEYATTR_RETURN_xxx bits are always forced to CSSM_KEYATTR_RETURN_REF regardless of how they are specified in the keyAttributes field.
Discussion

This structure is passed in the keyParams parameter as input to the functions SecKeychainItemExport and SecKeychainItemImport.

PKCS12 is an abbreviation for Public-Key Cryptography Standard # 12. This standard, by RSA Security, provides a format for external representation of keys and certificates and is described in PKCS 12 v1.0: Personal Information Exchange Syntax.
Availability
Available in Mac OS X v10.4 and later.
Declared In
SecImportExport.h*/
typedef struct
{
/* for import and export */
uint32_t                version;
SecKeyImportExportFlags flags;
CFTypeRef               passphrase;
CFStringRef             alertTitle;
CFStringRef             alertPrompt;

/* for import only */
SecAccessRef            accessRef;
CSSM_KEYUSE             keyUsage;
CSSM_KEYATTR_FLAGS      keyAttributes;
} SecKeyImportExportParameters;


/*Keychain Item Type When Importing

Specifies the type of keychain item being imported.

enum {
   kSecItemTypeUnknown,            //caller doesn't know what  this is 
   kSecItemTypePrivateKey,
   kSecItemTypePublicKey,
   kSecItemTypeSessionKey,
   kSecItemTypeCertificate,
   kSecItemTypeAggregate
};
typedef uint32_t SecExternalItemType;

Constants
kSecItemTypePrivateKey

Indicates a private key.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecItemTypePublicKey

Indicates a public key.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecItemTypeSessionKey

Indicates a session key.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecItemTypeCertificate

Indicates a certificate.

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.
kSecItemTypeAggregate

Indicates a set of certificates or certificates and private keys, such as PKCS7, PKCS12, or kSecFormatPEMSequence formats (see “Keychain Item Import/Export Formats”).

Available in Mac OS X v10.4 and later.

Declared in SecImportExport.h.*/
enum {
   kSecItemTypeUnknown,            /* caller doesn't know what  this is */
   kSecItemTypePrivateKey,
   kSecItemTypePublicKey,
   kSecItemTypeSessionKey,
   kSecItemTypeCertificate,
   kSecItemTypeAggregate
};
typedef uint32_t SecExternalItemType;

#ifdef	__cplusplus
}
#endif

#endif//SECIMPORTEXPORT_H
