
#ifndef SECKEY_H
#define SECKEY_H

#include <Security/SecBase.h>
#include <Security/cssmtype.h>


#if defined(__cplusplus)
extern "C" {
#endif

/*Keychain Item Attribute Constants For Keys

Specifies the attributes for a key item in a keychain.

enum
{
   kSecKeyKeyClass         =0,
   kSecKeyPrintName        =1,
   kSecKeyAlias            =2,
   kSecKeyPermanent        =3,
   kSecKeyPrivate          =4,
   kSecKeyModifiable       =5,
   kSecKeyLabel            =6,
   kSecKeyApplicationTag   =7,
   kSecKeyKeyCreator       =8,
   kSecKeyKeyType          =9,
   kSecKeyKeySizeInBits    =10,
   kSecKeyEffectiveKeySize =11,
   kSecKeyStartDate        =12,
   kSecKeyEndDate          =13,
   kSecKeySensitive        =14,
   kSecKeyAlwaysSensitive  =15,
   kSecKeyExtractable      =16,
   kSecKeyNeverExtractable =17,
   kSecKeyEncrypt          =18,
   kSecKeyDecrypt          =19,
   kSecKeyDerive           =20,
   kSecKeySign             =21,
   kSecKeyVerify           =22,
   kSecKeySignRecover      =23,
   kSecKeyVerifyRecover    =24,
   kSecKeyWrap             =25,
   kSecKeyUnwrap           =26
};

Constants
kSecKeyKeyClass

Type uint32 (CSSM_KEYCLASS); value is one of CSSM_KEYCLASS_PUBLIC_KEY, CSSM_KEYCLASS_PRIVATE_KEY or CSSM_KEYCLASS_SESSION_KEY.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyPrintName

Type blob; human readable name of the key. Same as kSecLabelItemAttr for normal keychain items.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyAlias

Type blob; currently unused.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyPermanent

Type uint32; value is nonzero. This key is permanent (stored in some keychain) and is always 1.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyPrivate

Type uint32; value is nonzero. This key is protected by a user login, a password, or both.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyModifiable

Type uint32; value is nonzero. Attributes of this key can be modified.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyLabel

Type blob; for private and public keys this contains the hash of the public key. This is used to associate certificates and keys. Its value matches the value of the kSecPublicKeyHashItemAttr attribute of a certificate and it's used to construct an identity from a certificate and a key. For symmetric keys this is whatever the creator of the key passed in when they generated the key.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyApplicationTag

Type blob; currently unused.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyKeyCreator

Type data. The data points to a CSSM_GUID structure representing the module ID of the CSP owning this key.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyKeyType

Type uint32; value is a CSSM algorithm (CSSM_ALGORITHMS) representing the algorithm associated with this key.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyKeySizeInBits

Type uint32; value is the number of bits in this key.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyEffectiveKeySize

Type uint32; value is the effective number of bits in this key. For example, a DES key has a key size in bits (kSecKeyKeySizeInBits) of 64 but a value for kSecKeyEffectiveKeySize of 56.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyStartDate

Type CSSM_DATE. Earliest date at which this key may be used. If the value is all zeros or not present, no restriction applies.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyEndDate

Type CSSM_DATE. Latest date at which this key may be used. If the value is all zeros or not present, no restriction applies.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeySensitive

Type uint32; value is nonzero. This key cannot be wrapped with CSSM_ALGID_NONE.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyAlwaysSensitive

Type uint32; value is nonzero. This key has always been marked sensitive.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyExtractable

Type uint32; value is nonzero. This key can be wrapped.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyNeverExtractable

Type uint32; value is nonzero. This key was never marked extractable.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyEncrypt

Type uint32; value is nonzero. This key can be used in an encrypt operation.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyDecrypt

Type uint32; value is nonzero. This key can be used in a decrypt operation.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyDerive

Type uint32; value is nonzero. This key can be used in a key derivation operation.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeySign

Type uint32, value is nonzero. This key can be used in a sign operation.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyVerify

Type uint32, value is nonzero. This key can be used in a verify operation.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeySignRecover

Type uint32.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyVerifyRecover

Type uint32. This key can unwrap other keys.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyWrap

Type uint32; value is nonzero. This key can wrap other keys.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
kSecKeyUnwrap

Type uint32; value is nonzero. This key can unwrap other keys.

Available in Mac OS X v10.4 and later.

Declared in SecKey.h.
Discussion

For attributes for items other than keys, see “Keychain Item Attribute Constants.”*/
enum
{
   kSecKeyKeyClass         =0,
   kSecKeyPrintName        =1,
   kSecKeyAlias            =2,
   kSecKeyPermanent        =3,
   kSecKeyPrivate          =4,
   kSecKeyModifiable       =5,
   kSecKeyLabel            =6,
   kSecKeyApplicationTag   =7,
   kSecKeyKeyCreator       =8,
   kSecKeyKeyType          =9,
   kSecKeyKeySizeInBits    =10,
   kSecKeyEffectiveKeySize =11,
   kSecKeyStartDate        =12,
   kSecKeyEndDate          =13,
   kSecKeySensitive        =14,
   kSecKeyAlwaysSensitive  =15,
   kSecKeyExtractable      =16,
   kSecKeyNeverExtractable =17,
   kSecKeyEncrypt          =18,
   kSecKeyDecrypt          =19,
   kSecKeyDerive           =20,
   kSecKeySign             =21,
   kSecKeyVerify           =22,
   kSecKeySignRecover      =23,
   kSecKeyVerifyRecover    =24,
   kSecKeyWrap             =25,
   kSecKeyUnwrap           =26
};

#if defined(__cplusplus)
}
#endif

#endif//SECKEY_H
