#ifndef  SECKEYCHAINSEARCH_H
#define SECKEYCHAINSEARCH_H

#include <Security/SecKeychainItem.h>


#if defined(__cplusplus)
extern "C" {
#endif

/*SecKeychainSearchCopyNext

Finds the next keychain item matching the given search criteria.

OSStatus SecKeychainSearchCopyNext (
   SecKeychainSearchRef searchRef,
   SecKeychainItemRef *itemRef
);
Parameters
searchRef

A reference to the current search criteria. The search object is created in the SecKeychainSearchCreateFromAttributes function and must be released by calling the CFRelease function when you are done with it.
itemRef

On return, a pointer to a keychain item object of the next matching keychain item, if any. You must release this object by calling the CFRelease function.
Return Value

A result code. When there are no more items that match, errSecItemNotFound is returned. See “Keychain Services Result Codes.”
Discussion

Each item stored in the keychain contains data (such as a certificate), which is indexed by the item’s attributes. Use the SecKeychainSearchCreateFromAttributes function to specify attributes to search for. If the SecKeychainSearchCopyNext function finds a match, you can use the SecKeychainItemCopyAttributesAndData function to retrieve the item’s data.

A SecKeychainItemRef object for a certificate that is stored in a keychain can be safely cast to a SecCertificateRef for use with the Certificate, Key, and Trust API.

To find and obtain data from a password keychain item, use the SecKeychainFindInternetPassword or SecKeychainFindGenericPassword function.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecKeychainSearch.h*/
OSStatus SecKeychainSearchCopyNext (
   SecKeychainSearchRef searchRef,
   SecKeychainItemRef *itemRef
);

/*SecKeychainSearchCreateFromAttributes

Creates a search object matching a list of zero or more attributes.

OSStatus SecKeychainSearchCreateFromAttributes (
   CFTypeRef keychainOrArray,
   SecItemClass itemClass,
   const SecKeychainAttributeList *attrList,
   SecKeychainSearchRef *searchRef
);

Parameters
keychainOrArray

A reference to an array of keychains to search, a single keychain, or NULL to search the user’s current keychain search list. Use the function SecKeychainCopySearchList to retrieve the user’s default search list.
itemClass

The keychain item class. See “Keychain Item Class Constants” for valid constants.
attrList

A pointer to a list of zero or more keychain attribute records to match. Pass NULL to match any keychain attribute.
searchRef

On return, a pointer to the current search object. You are responsible for calling the CFRelease function to release this object when finished with it.
Return Value

A result code. See “Keychain Services Result Codes.”
Discussion

Each item stored in the keychain contains data (such as a certificate), which is indexed by the item’s attributes. You look up an item in a keychain by its attributes. If you find a match, you can then retrieve the item’s data. Use the search object created by this function as input to the SecKeychainSearchCopyNext function to find a a keychain item and the SecKeychainItemCopyAttributesAndData function to retrieve the item’s data. 

To find and obtain data from a password keychain item, use the SecKeychainFindInternetPassword or SecKeychainFindGenericPassword function.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecKeychainSearch.h*/
OSStatus SecKeychainSearchCreateFromAttributes (
   CFTypeRef keychainOrArray,
   SecItemClass itemClass,
   const SecKeychainAttributeList *attrList,
   SecKeychainSearchRef *searchRef
);

#if defined(__cplusplus)
}
#endif

#endif //SECKEYCHAINSEARCH_H
