
#ifndef SECTRUSTEDAPPLICATION_H
#define SECTRUSTEDAPPLICATION_H

#include <Security/SecBase.h>
#include <CoreFoundation/CoreFoundation.h>


#if defined(__cplusplus)
extern "C" {
#endif

/*SecTrustedApplicationCreateFromPath

Creates a trusted application object based on the application specified by path.

OSStatus SecTrustedApplicationCreateFromPath (
   const char *path,
   SecTrustedApplicationRef *app
);

Parameters
path

The path to the application or tool to trust. For application bundles, use the path to the bundle directory. Pass NULL to refer to the application or tool making this call.
app

On return, points to the newly created trusted application object. Call the CFRelease function to release this object when you are finished with it.
Return Value

A result code. See “Keychain Services Result Codes.”
Discussion

This function creates a trusted application object, which both identifies an application and provides data that can be used to ensure that the application has not been altered since the object was created. The application object is used as input to the SecAccessCreate function, which creates an access object. The access object, in turn, is used as input to the SecKeychainItemSetAccess function to specify the set of applications that are trusted to access a specific keychain item. 
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecTrustedApplication.h*/
OSStatus SecTrustedApplicationCreateFromPath (
   const char *path,
   SecTrustedApplicationRef *app
);

#if defined(__cplusplus)
}
#endif

#endif //SECTRUSTEDAPPLICATION_H
