#ifndef CSSMTYPE_H
#define CSSMTYPE_H

#include <Security/cssmconfig.h>

#include <HYS/Security/cssmtype.h>

#ifdef __cplusplus
extern "C" {
#endif

/*Authorization Tag Type Constants

Defines constants that specify which operations an access control list entry applies to.

typedef sint32 CSSM_ACL_AUTHORIZATION_TAG;
enum {
   CSSM_ACL_AUTHORIZATION_TAG_VENDOR_DEFINED_START =
   0x00010000,
   CSSM_ACL_AUTHORIZATION_ANY =        CSSM_WORDID__STAR_,
   CSSM_ACL_AUTHORIZATION_LOGIN =      CSSM_WORDID_LOGIN,
   CSSM_ACL_AUTHORIZATION_GENKEY =     CSSM_WORDID_GENKEY,
   CSSM_ACL_AUTHORIZATION_DELETE =     CSSM_WORDID_DELETE,
   CSSM_ACL_AUTHORIZATION_EXPORT_WRAPPED =
   CSSM_WORDID_EXPORT_WRAPPED,
   CSSM_ACL_AUTHORIZATION_EXPORT_CLEAR =CSSM_WORDID_EXPORT_CLEAR,
   CSSM_ACL_AUTHORIZATION_IMPORT_WRAPPED =
   CSSM_WORDID_IMPORT_WRAPPED,
   CSSM_ACL_AUTHORIZATION_IMPORT_CLEAR =CSSM_WORDID_IMPORT_CLEAR,
   CSSM_ACL_AUTHORIZATION_SIGN =       CSSM_WORDID_SIGN,
   CSSM_ACL_AUTHORIZATION_ENCRYPT =    CSSM_WORDID_ENCRYPT,
   CSSM_ACL_AUTHORIZATION_DECRYPT =    CSSM_WORDID_DECRYPT,
   CSSM_ACL_AUTHORIZATION_MAC =        CSSM_WORDID_MAC,
   CSSM_ACL_AUTHORIZATION_DERIVE =     CSSM_WORDID_DERIVE
};
// Apple-defined ACL authorization tags 
enum {
   CSSM_ACL_AUTHORIZATION_CHANGE_ACL =
   CSSM_ACL_AUTHORIZATION_TAG_VENDOR_DEFINED_START,
   CSSM_ACL_AUTHORIZATION_CHANGE_OWNER
};

Constants
CSSM_ACL_AUTHORIZATION_TAG_VENDOR_DEFINED_START

All vendor specific constants must be in the number range starting at this value.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_ANY

No restrictions. This ACL entry applies to all operations available to the caller.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_LOGIN

Use for a CSP (smart card) login.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_GENKEY

Generate a key.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_DELETE

Delete this item.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_EXPORT_WRAPPED

Export a wrapped (that is, encrypted) key. This tag is checked on the key being exported; in addition, the CSSM_ACL_AUTHORIZATION_ENCRYPT tag is checked for any key used in the wrapping operation.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_EXPORT_CLEAR

Export an unencrypted key.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_IMPORT_WRAPPED

Import an encrypted key. This tag is checked on the key being imported; in addition, the CSSM_ACL_AUTHORIZATION_DECRYPT tag is checked for any key used in the unwrapping operation.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_IMPORT_CLEAR

Import an unencrypted key.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_SIGN

Digitally sign data.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_ENCRYPT

Encrypt data.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_DECRYPT

Decrypt data.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_MAC

Create or verify a message authentication code. 

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_DERIVE

Derive a new key from another key.

Available in Mac OS X v10.0 and later.

Declared in cssmtype.h.
CSSM_ACL_AUTHORIZATION_CHANGE_ACL

Change an access control list entry. 

Available in Mac OS X v10.0 and later.

Declared in cssmapple.h.
CSSM_ACL_AUTHORIZATION_CHANGE_OWNER

For internal system use only. Use the CSSM_ACL_AUTHORIZATION_CHANGE_ACL tag for changes to owner ACL entries.

Available in Mac OS X v10.0 and later.

Declared in cssmapple.h.*/

typedef sint32 CSSM_ACL_AUTHORIZATION_TAG;
enum {
   CSSM_ACL_AUTHORIZATION_TAG_VENDOR_DEFINED_START =
   0x00010000,
   CSSM_ACL_AUTHORIZATION_ANY =        CSSM_WORDID__STAR_,
   CSSM_ACL_AUTHORIZATION_LOGIN =      CSSM_WORDID_LOGIN,
   CSSM_ACL_AUTHORIZATION_GENKEY =     CSSM_WORDID_GENKEY,
   CSSM_ACL_AUTHORIZATION_DELETE =     CSSM_WORDID_DELETE,
   CSSM_ACL_AUTHORIZATION_EXPORT_WRAPPED =
   CSSM_WORDID_EXPORT_WRAPPED,
   CSSM_ACL_AUTHORIZATION_EXPORT_CLEAR =CSSM_WORDID_EXPORT_CLEAR,
   CSSM_ACL_AUTHORIZATION_IMPORT_WRAPPED =
   CSSM_WORDID_IMPORT_WRAPPED,
   CSSM_ACL_AUTHORIZATION_IMPORT_CLEAR =CSSM_WORDID_IMPORT_CLEAR,
   CSSM_ACL_AUTHORIZATION_SIGN =       CSSM_WORDID_SIGN,
   CSSM_ACL_AUTHORIZATION_ENCRYPT =    CSSM_WORDID_ENCRYPT,
   CSSM_ACL_AUTHORIZATION_DECRYPT =    CSSM_WORDID_DECRYPT,
   CSSM_ACL_AUTHORIZATION_MAC =        CSSM_WORDID_MAC,
   CSSM_ACL_AUTHORIZATION_DERIVE =     CSSM_WORDID_DERIVE
};
/* Apple-defined ACL authorization tags */
enum {
   CSSM_ACL_AUTHORIZATION_CHANGE_ACL =
   CSSM_ACL_AUTHORIZATION_TAG_VENDOR_DEFINED_START,
   CSSM_ACL_AUTHORIZATION_CHANGE_OWNER
};

/*Keychain Item Class Constants

Specifies a keychain item’s class code.

typedef FourCharCode SecItemClass;
enum
{
   / SecKeychainItem.h *
   kSecInternetPasswordItemClass   = 'inet',
   kSecGenericPasswordItemClass    = 'genp',
   kSecAppleSharePasswordItemClass = 'ashp',
   kSecCertificateItemClass        =
   CSSM_DL_DB_RECORD_X509_CERTIFICATE,
};
enum
{
   / Record Types defined in The Open Group Application Name Space  *
   / cssmtype.h *
   CSSM_DL_DB_RECORD_PUBLIC_KEY =
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 5,
   CSSM_DL_DB_RECORD_PRIVATE_KEY =
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 6,
   CSSM_DL_DB_RECORD_SYMMETRIC_KEY =
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 7,
   CSSM_DL_DB_RECORD_ALL_KEYS =
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 8
};
Constants
kSecInternetPasswordItemClass

Indicates that the item is an Internet password.

Available in Mac OS X v10.2 and later.
kSecGenericPasswordItemClass

Indicates that the item is a generic password.

Available in Mac OS X v10.2 and later.
kSecAppleSharePasswordItemClass

Indicates that the item is an AppleShare password.

Available in Mac OS X v10.2 and later.
kSecCertificateItemClass

Indicates that the item is an X509 certificate.

Available in Mac OS X v10.2 and later.
CSSM_DL_DB_RECORD_PUBLIC_KEY

Indicates that the item is a public key of a public-private pair.

Available in Mac OS X v10.0 and later.
CSSM_DL_DB_RECORD_PRIVATE_KEY

Indicates that the item is a private key of a public-private pair.

Available in Mac OS X v10.0 and later.
CSSM_DL_DB_RECORD_SYMMETRIC_KEY

Indicates that the item is a private key used for symmetric-key encryption.

Available in Mac OS X v10.0 and later.
CSSM_DL_DB_RECORD_ALL_KEYS

The item can be any type of key; used for searches only.

Available in Mac OS X v10.0 and later.
Discussion

These enumerations define constants your application can use to specify the type of the keychain item you wish to create, dispose, add, delete, update, copy, or locate. You can also use these constants with the tag constant SecItemAttr.
Declared In
SecKeychainItem.h, cssmtype.h.*/

enum
{
   /* Record Types defined in The Open Group Application Name Space  */
   /* cssmtype.h */
   CSSM_DL_DB_RECORD_PUBLIC_KEY =\
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 5,
   CSSM_DL_DB_RECORD_PRIVATE_KEY =\
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 6,
   CSSM_DL_DB_RECORD_SYMMETRIC_KEY =\
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 7,
   CSSM_DL_DB_RECORD_ALL_KEYS =\
   CSSM_DB_RECORDTYPE_OPEN_GROUP_START  + 8
};



#ifdef __cplusplus
}
#endif

#endif//CSSMTYPE_H
