#import <SyncServices/ISyncCommon.h>

@class ISyncClient;
/*ISyncChange—Change Types

typedef int ISyncChangeType;
enum __ISyncChangeType {
   ISyncChangeTypeAdd=1,
   ISyncChangeTypeModify,
   ISyncChangeTypeDelete
};
Discussion

These types are described in “ISyncChange”.*/
typedef int ISyncChangeType;
enum __ISyncChangeType {
   ISyncChangeTypeAdd=1,
   ISyncChangeTypeModify,
   ISyncChangeTypeDelete
};

/*The following constants are used as keys for individual property changes encapsulated in an ISyncChange object. When pushing changes, use these keys to set key-value pairs for dictionaries you add to the changes argument passed to either the changeWithType:recordIdentifier:changes: class method or the initWithChangeType:recordIdentifier:changes: instance method. When pulling changes, you also use these keys to get the attributes of each change. Use the object enumerator returned by the changes method to iterate through the changes array.
Constant	
Description
ISyncChangePropertyActionKey	
Specifies whether or not the property is being set or deleted. The value for this key should be either ISyncChangePropertySet or ISyncChangePropertyClear described below.

Available in Mac OS X v10.4 and later.
ISyncChangePropertyNameKey	
Key for the name of the property.

Available in Mac OS X v10.4 and later.
ISyncChangePropertyValueKey	
Key for the new value of the property. Not used if the action is ISyncChangePropertyClear. However, the absence of this key does not imply the property is being deleted. This key-value pair may be omitted if the value is unspecified. You can also set the value to nil. If the property is a relationship, then the value is an array of record identifiers belonging to the destination objects. If the relationship is to-one, this array contains a single record identifier.

Available in Mac OS X v10.4 and later.*/
extern  NSString * const ISyncChangePropertyNameKey;
extern  NSString * const ISyncChangePropertyValueKey;

@interface ISyncChange : NSObject
/*recordIdentifier

Returns the unique record identifier for the record that changed.

- (NSString *)recordIdentifier
Discussion

Returns the unique identifier for the record returned by record, or the record identifier you specified when creating the receiver. Use the changes method to get the changes that were made to this record. 
Availability
Available in Mac OS X v10.4 and later.*/
- (NSString *)recordIdentifier;

/*record

Returns a dictionary representation of the record that changed. 

- (NSDictionary *)record
Discussion

The dictionary contains a key-value pair for each property unless the value of a property is unspecified. Only changes created by the sync engine have an associated record. Returns nil if the client created the receiver to push changes, or this is a delete change.

When pulling changes, this method returns a copy of the record as it appears in the truth database. Only those properties supported by the client are included in this record. Use the changes method to get the changes made to this record, and use the recordIdentifier method to get the record’s unique identifier.
Availability
Available in Mac OS X v10.4 and later.*/
- (NSDictionary *)record;

/*type

Returns the type of change the receiver represents.

- (ISyncChangeType)type
Discussion

Returns whether or not this change was an add, delete or modify. See “Constants” for a description of the possible return values.
Availability
Available in Mac OS X v10.4 and later.
See Also
changes*/
- (ISyncChangeType)type;


/*changes

Returns an array of changes made to the record.

- (NSArray *)changes
Discussion

Returns an array of the changes made to the record returned by record with the identifier returned by recordIdentifier. The changes array encapsulates multiple property changes to a single record. The returned array contains dictionaries with keys specifying the type of change to a property and its new value. See “Constants” for a description of the keys used in these dictionaries. See ISyncChangePropertyValueKey for a description of the value of relationship properties. Returns nil if the change type is ISyncChangeTypeDelete.
Availability
Available in Mac OS X v10.4 and later.
See Also
type*/
- (NSArray *)changes;

@end
