#ifndef  SCPREFERENCES_H
#define SCPREFERENCES_H

#include <AvailabilityMacros.h>
#include <sys/cdefs.h>
#include <CoreFoundation/CoreFoundation.h>
#include <SystemConfiguration/SCDynamicStore.h>

/*SCPreferencesRef

typedef const struct __SCPreferences * SCPreferencesRef;  
Discussion 

This is the handle to an open preferences session for accessing system configuration preferences.*/
typedef const struct __SCPreferences * SCPreferencesRef;  

/*SCPreferencesNotification


enum { 
    kSCPreferencesNotificationCommit = 1<<0, 
    kSCPreferencesNotificationApply = 1<<1 
};  
Constants
kSCPreferencesNotificationCommit
Indicates when new preferences have been saved.
kSCPreferencesNotificationApply
Key Indicates when a request has been made to apply the currently saved preferences to the active system configuration.
Discussion 

Used with the SCPreferencesCallBack callback to describe the type of notification. 

Availability
Introduced in Mac OS X v10.4.*/
enum { 
    kSCPreferencesNotificationCommit = 1<<0, 
    kSCPreferencesNotificationApply = 1<<1 
};  
typedef	uint32_t	SCPreferencesNotification;

/*SCPreferencesCallBack


typedef void ( *SCPreferencesCallBack) ( 
    SCPreferencesRef prefs, 
    SCPreferencesNotification notificationType, 
    void *info );  
Parameters
prefs
The preferences session.
notificationType
The type of notification, such as changes committed, changes applied, etc.
info
A C pointer to a user-specified block of data.
Discussion 

Type of the callback function used when the preferences have been updated and/or applied. 

Availability
Introduced in Mac OS X v10.4.*/
typedef void ( *SCPreferencesCallBack) ( 
    SCPreferencesRef prefs, 
    SCPreferencesNotification notificationType, 
    void *info );  

/*SCPreferencesContext


typedef struct { 
    CFIndex version; 
    void *info; 
    const void *(*retain)(
        const void *info); 
    void (*release)(
        const void *info); 
    CFStringRef (*copyDescription)(
        const void *info); 
} SCPreferencesContext;  
Fields
version
The version number of the structure type being passed in as a parameter to the SCPreferencesSetCallback function. This structure is version 0.
info
A C pointer to a user-specified block of data.
retain
The callback used to add a retain for the info field. If this parameter is not a pointer to a function of the correct prototype, the behavior is undefined. The value may be NULL.
release
The calllback used to remove a retain previously added for the info field. If this parameter is not a pointer to a function of the correct prototype, the behavior is undefined. The value may be NULL.
copyDescription
The callback used to provide a description of the info field.
Discussion 

Structure containing user-specified data and callbacks for SCPreferences.

Availability
Introduced in Mac OS X v10.4.*/
typedef struct { 
    CFIndex version; 
    void *info; 
    const void *(*retain)(
        const void *info); 
    void (*release)(
        const void *info); 
    CFStringRef (*copyDescription)(
        const void *info); 
} SCPreferencesContext;

//function


/*SCPreferencesGetValue

CFPropertyListRef SCPreferencesGetValue ( 
    SCPreferencesRef prefs, 
    CFStringRef key );  
Parameters
prefs
The preferences session.
key
The preference key to be returned.
Return Value

Returns the value associated with the specified preference key; NULL if no value was located. 
Discussion 

Returns the data associated with a preference key. 

This function retrieves data associated with the specified key. 

Note: To avoid inadvertantly reading stale data, first call the SCPreferencesLock function.*/
CFPropertyListRef SCPreferencesGetValue ( 
    SCPreferencesRef prefs, 
    CFStringRef key );  

/*SCPreferencesCreate

SCPreferencesRef SCPreferencesCreate ( 
    CFAllocatorRef allocator, 
    CFStringRef name, 
    CFStringRef prefsID );  
Parameters
allocator
The CFAllocator that should be used to allocate memory for this preferences session. This parameter may be NULL in which case the current default CFAllocator is used. If this reference is not a valid CFAllocator, the behavior is undefined.
name
A string that describes the name of the calling process.
prefsID
A string that identifies the name of the group of preferences to be accessed or updated.
Return Value

Returns a reference to the new SCPreferences. You must release the returned value. 
Discussion 

Initiates access to the per-system set of configuration preferences.*/
SCPreferencesRef SCPreferencesCreate ( 
    CFAllocatorRef allocator, 
    CFStringRef name, 
    CFStringRef prefsID );  

/*SCPreferencesLock

Boolean SCPreferencesLock ( 
    SCPreferencesRef prefs, 
    Boolean wait );  
Parameters
prefs
The preferences session.
wait
A boolean flag indicating whether the calling process should block waiting for another process to complete its update operation and release its lock.
Return Value

Returns TRUE if the lock was obtained; FALSE if an error occurred. 
Discussion 

Locks access to the configuration preferences. 

This function obtains exclusive access to the configuration preferences. Clients attempting to obtain exclusive access to the preferences will either receive a kSCStatusPrefsBusy error or block waiting for the lock to be released.*/
Boolean SCPreferencesLock ( 
    SCPreferencesRef prefs, 
    Boolean wait ); 

/*SCPreferencesCommitChanges

Boolean SCPreferencesCommitChanges ( 
    SCPreferencesRef prefs );  
Parameters
prefs
The preferences session.
Return Value

Returns TRUE if the lock was obtained; FALSE if an error occurred. 
Discussion 

Commits changes made to the configuration preferences to persistent storage. 

This function commits any changes to permanent storage. Implicit calls to the SCPreferencesLock and SCPreferencesUnlock functions will be made if exclusive access has not already been established. 

Note: This routine commits changes to persistent storage. Call the SCPreferencesApplyChanges function to apply the changes to the running system*/
Boolean SCPreferencesCommitChanges ( 
    SCPreferencesRef prefs );  

/*SCPreferencesSetValue

Boolean SCPreferencesSetValue ( 
    SCPreferencesRef prefs, 
    CFStringRef key, 
    CFPropertyListRef value );  
Parameters
prefs
The preferences session.
key
The preference key to be updated.
value
The CFPropertyListRef object containing the data to be associated with the specified preference key.
Return Value

Returns TRUE if the value was set; FALSE if an error occurred. 
Discussion 

Updates the data associated with a preference key. 

This function adds or replaces the value associated with the specified key. To commit these changes to permanent storage a call must be made to the SCPreferencesCommitChanges function.*/
Boolean SCPreferencesSetValue ( 
    SCPreferencesRef prefs, 
    CFStringRef key, 
    CFPropertyListRef value );  

/*SCPreferencesUnlock

Boolean SCPreferencesUnlock ( 
    SCPreferencesRef prefs );  
Parameters
prefs
The preferences session.
Return Value

Returns TRUE if the lock was obtained; FALSE if an error occurred. 
Discussion 

Releases exclusive access to the configuration preferences. 

This function releases the exclusive access lock to the preferences. Other clients will be now be able to establish exclusive access to the preferences.*/

Boolean SCPreferencesUnlock ( 
    SCPreferencesRef prefs );  

/*SCPreferencesApplyChanges

Boolean SCPreferencesApplyChanges ( 
    SCPreferencesRef prefs );  
Parameters
prefs
The preferences session.
Return Value

Returns TRUE if the lock was obtained; FALSE if an error occurred. 
Discussion 

Requests that the currently stored configuration preferences be applied to the active configuration.*/
Boolean SCPreferencesApplyChanges ( 
    SCPreferencesRef prefs );  

/*SCPreferencesCopyKeyList

CFArrayRef SCPreferencesCopyKeyList ( 
    SCPreferencesRef prefs );  
Parameters
prefs
The preferences session.
Return Value

Returns the list of keys. You must release the returned value. 
Discussion 

Returns an array of currently defined preference keys.*/
CFArrayRef SCPreferencesCopyKeyList ( 
    SCPreferencesRef prefs );  

#endif
