#ifndef __TRAPS__
#define __TRAPS__


#include <ConditionalMacros.h>

#include <HYS/Traps.h>

#ifdef __cplusplus
extern "C" {
#endif


/* Constants

//Gestalt selectors//
#define gestaltOSTable        'ostt'   //base of Operating System dispatch //
                                       // table//
#define gestaltToolboxTable   'tbtt'   //base of Toolbox dispatch table//
#define gestaltExtToolboxTable'xttt'   //0, unless Toolbox dispatch table //
                                       // is disjoint, in which case base //
                                       // of upper half//
//values of TrapType//
enum {OSTrap, ToolTrap};
//system errors triggered by Trap Manager//
enum {
   dsCoreErr         = 12,             //unimplemented trap error//
   dsBadPatchHeader  = 83              //attempt to install come-from patch//
};
 */
//values of TrapType//
enum {OSTrap, ToolTrap};

/* Data Types

typedef unsigned char TrapType;
 */
typedef unsigned char TrapType;

/*Routines
Accessing Addresses From the Trap Dispatch Tables

pascal long NGetTrapAddress
				(short trapNum, TrapType tTyp);
pascal long GetOSTrapAddress
				(short trapNum);
//GetToolboxTrapAddress is also spelled as GetToolTrapAddress
pascal long GetToolboxTrapAddress
				(short trapNum);

Installing Patch Addresses Into the Trap Dispatch Tables

pascal void NSetTrapAddress
			(long trapAddr, short trapNum,
			 TrapType tTyp);
pascal void SetOSTrapAddress
			(long trapAddr, short trapNum);
//SetToolboxTrapAddress is also spelled as SetToolTrapAddress
pascal void SetToolboxTrapAddress
			(long trapAddr, short trapNum);
pascal void SetToolTrapAddress
			(long trapAddr, short trapNum);

Detecting Unimplemented System Software Routines

pascal void Unimplemented(void);

Manipulating One Trap Dispatch Table (Obsolete Routines)

pascal long GetTrapAddress	(short trapNum);
pascal void SetTrapAddress	(long trapAddr, short trapNum); */


/* NGetTrapAddress
You can use the NGetTrapAddress function to retrieve the address of either an Operating System routine or a Toolbox routine.

FUNCTION NGetTrapAddress (trapNum: Integer; tTyp: TrapType)
                           :LongInt;

trapNum
    A-line instruction or a trap number. If you specify an A-line instruction, the function extracts the trap number for you. 
tTyp
    The trap type. If you supply the tTyp parameter with the constant OSTrap, the NGetTrapAddress function retrieves the address from the Operating System trap dispatch table. If you supply tTyp parameter with the constant ToolTrap, the NGetTrapAddress function retrieves the address from the Toolbox trap dispatch table. 

DESCRIPTION
The NGetTrapAddress function returns the address of the system software routine specified by the tTyp and trapNum parameters. If tTyp is OSTrap, the NGetTrapAddress function retrieves the address from the Operating System trap dispatch table. If tTyp is ToolTrap, the NGetTrapAddress function retrieves the address from the Toolbox trap dispatch table. If the desired system software routine is not supported on the installed system software, NGetTrapAddress returns the address of the Unimplemented procedure. The trapNum parameter should contain a trap number in bits 0-7 if tTyp is OSTrap, and in bits 0-9 if tTyp is ToolTrap.

The trapNum parameter may have any word value; its irrelevant high-order bits are masked according to the value of the tTyp parameter.

Note
    If the system software routine has a come-from patch, the NGetTrapAddress function returns the address of the routine immediately following the come-from patch. 

ASSEMBLY-LANGUAGE INFORMATION
The registers on entry and exit for the _GetTrapAddress macro are
Registers on entry
D0	An A-line trap word
Registers on exit
A0	Address of next routine in the daisy chain (a system software routine or a patch)

When calling the _GetTrapAddress macro, you set bit 9 of the A-line instruction to indicate a "new" system; that is, any version since the Macintosh Plus or Macintosh 512K. You use bit 10 to indicate whether the trap in question is a Toolbox routine (by setting bit 10 to 1) or an Operating System routine (by setting bit 10 to 0). Macintosh development environments provide the modifier words newTool and newOS to be used as arguments in the _GetTrapAddress macro.

To obtain the address of a Toolbox trap whose number is in register D0, you use the macro

_GetTrapAddress newTool

This is equivalent to calling NGetTrapAddress (trapNum, newTool). The trapNum parameter is the A-line trap word placed in register D0 for the assembly-language call. Similarly, to obtain the address of an Operating System routine whose A-line trap word is in register D0, you use the macro

_GetTrapAddress newOS

This is equivalent to calling NGetTrapAddress(trapNum, newOS).

SEE ALSO
For information about the Unimplemented procedure, see page 8-29. For information about the NSetTrapAddress function, see page 8-30. */

pascal long NGetTrapAddress
				(short trapNum, TrapType tTyp);
				
#ifdef __cplusplus
}
#endif

#endif //__TRAPS__



