#import <Cocoa/Cocoa.h>


@class NSError;
@class NSURLResponse;
@class NSURLRequest;
@class WebView;
@class WebFrame;
@class WebPolicyPrivate;

@protocol WebPolicyDecisionListener <NSObject>

/*ignore

Tells the listener to ignore this resource.

- (void)ignore
Discussion

You might invoke this method to handle the request yourself. For example, you might open a new window, open a window behind the current window, open a URL in an external application, or show a file URL location in the Finder.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.*/
- (void)ignore;

/*use

Tells the listener to use the resource.

- (void)use
Discussion

If there are pending policy decisions, then the next policy delegate method has the opportunity to decide what to do with this resource. This will be either the next navigation policy delegate (if there is a redirect), or the content policy delegate. If there are no pending policy decisions, the resource will be displayed if possible. If there is no document view available to display the resource, then the webView:unableToImplementPolicyWithError:frame: message will be sent to the WebView policy delegate with an appropriate error. Invoking this method will create any new windows needed to handle this resource.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
+ registerViewClass:representationClass:forMIMEType:*/
- (void)use;

@end

@interface NSObject (WebPolicyDelegate)
@end
