#import <Cocoa/Cocoa.h>
@class DOMCSSStyleDeclaration;
@class DOMDocument;
@class DOMElement;
@class DOMNode;
@class DOMRange;

@class WebArchive;
@class WebBackForwardList;
@class WebDataSource;
@class WebFrame;
@class WebFrameView;
@class WebHistoryItem;
@class WebPreferences;
@class WebScriptObject;
@class WebViewPrivate;


/*WebViewProgressEstimateChangedNotification

Posted by a WebView object when the estimated progress value of a load changes. This notification may be posted zero or more times after a WebViewProgressStartedNotification notification is posted. The notification object is the WebView for which the progress value has changed. This notification does not contain a userInfo dictionary.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– estimatedProgress*/
extern NSString *WebViewProgressEstimateChangedNotification;

/*WebViewProgressFinishedNotification

Posted by a WebView object when the load has finished. The notification object is the WebView that finished loading. This notification does not contain a userInfo dictionary.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– estimatedProgress*/
extern NSString *WebViewProgressFinishedNotification;

/*WebViewProgressStartedNotification

Posted by a WebView object when a load begins, including a load that is initiated in a subframe. The notification object is the WebView that began loading. This notification does not contain a userInfo dictionary.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– estimatedProgress*/

extern NSString *WebViewProgressStartedNotification;

@interface WebView : NSView
/*setUIDelegate:

Sets the receiver's user interface delegate.

- (void)setUIDelegate:(id)anObject
Discussion

This method sets the receiver’s user interface delegate to anObject, which conforms to the WebUIDelegate informal protocol.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– UIDelegate*/
- (void)setUIDelegate:(id)anObject;

/*setResourceLoadDelegate:

Sets the receiver's resource load delegate.

- (void)setResourceLoadDelegate:(id)delegate
Discussion

This method sets the receiver’s resource load delegate to anObject, which conforms to the WebResourceLoadDelegate informal protocol.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– resourceLoadDelegate*/
- (void)setResourceLoadDelegate:(id)delegate;

/*mainFrame

Returns the main frame, the root of the WebFrame hierarchy for this page. 

- (WebFrame *)mainFrame
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.*/
- (WebFrame *)mainFrame;

/*windowScriptObject

Returns the receiver’s window object from the scripting environment. 

- (WebScriptObject *)windowScriptObject
Availability
Available in Mac OS X v10.3.9 and later.
See Also
– objectForWebScript (WebPlugIn) (WebFrameLoadDelegate)
– webView:windowScriptObjectAvailable:*/
- (WebScriptObject *)windowScriptObject;

/*stringByEvaluatingJavaScriptFromString:

Returns the result of running a script.

- (NSString *)stringByEvaluatingJavaScriptFromString:(NSString *)script
Discussion

Returns the result of running a JavaScript specified by script, or nil if the script failed.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.*/
- (NSString *)stringByEvaluatingJavaScriptFromString:(NSString *)script;

/*stopLoading:

This is an action method that stops the loading of any web frame content managed by the receiver.

- (IBAction)stopLoading:(id)sender
Discussion

Stops any content in the process of being loaded by the main frame or any of its children frames. Does nothing if no content is being loaded.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.*/
- (IBAction)stopLoading:(id)sender;

/*setFrameLoadDelegate:

Sets the receiver's frame load delegate.

- (void)setFrameLoadDelegate:(id)anObject
Discussion

Sets the receiver’s frame load delegate to anObject, which should conform to the WebFrameLoadDelegate informal protocol.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– frameLoadDelegate*/
- (void)setFrameLoadDelegate:(id)anObject;


/*setPolicyDelegate:

Sets the receiver's policy delegate.

- (void)setPolicyDelegate:(id)delegate
Discussion

This method sets the receiver’s policy delegate to anObject, which conforms to the WebPolicyDelegate informal protocol.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– policyDelegate*/
- (void)setPolicyDelegate:(id)delegate;

/*preferences

Returns the receiver’s preferences.

- (WebPreferences *)preferences
Discussion

If the receiver’s preferences were not set by previously invoking setPreferences:, returns the standard preferences.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– setPreferences:
+ standardPreferences*/
- (WebPreferences *)preferences;

/*setCustomUserAgent:

Sets the receiver’s custom user-agent string. 

- (void)setCustomUserAgent:(NSString *)userAgentString
Discussion

The user-agent string is used by web sites to identify the client browser. The custom user-agent string will be used for all URLs. If userAgentString is nil, then the receiver will construct a user-agent string for each URL that will produce the best rendering results. 
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– setApplicationNameForUserAgent:
– applicationNameForUserAgent
– customUserAgent*/
- (void)setCustomUserAgent:(NSString *)userAgentString;

/*setMaintainsBackForwardList:

Sets whether or not to use a back-forward list. 

- (void)setMaintainsBackForwardList:(BOOL)flag
Discussion

The back-forward list maintains a page cache, so applications that do not use the goForward or goBack methods should disable it. If flag is NO the back-forward list is cleared and the page cache is released.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– backForwardList*/
- (void)setMaintainsBackForwardList:(BOOL)flag;

/*reload:

Reloads the current page.

- (IBAction)reload:(id)sender
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
– setResourceLoadDelegate:*/
- (IBAction)reload:(id)sender;

/*estimatedProgress

Returns an estimate, as a percentage, of the amount of content that is currently loaded.

- (double)estimatedProgress
Discussion

This value returned will range from 0 to 1.0 and, once a load completes, will remain at 1.0 until a new load starts, at which point it will be reset to 0. The value is an estimate based on the total number of bytes expected to be received for a document, including all it's possible subresources. For more accurate load progress information it is recommended that you implement WebView delegates conforming to the WebFrameLoadDelegate and WebResourceLoadDelegate informal protocols.
Availability
Available in Mac OS X v10.2 with Safari 1.0 and later.
Available in Mac OS X v10.2.7 and later.
See Also
WebViewProgressEstimateChangedNotification
WebViewProgressFinishedNotification
WebViewProgressStartedNotification*/

- (double)estimatedProgress;

@end

//work


@interface WebView (WebIBActions) <NSUserInterfaceValidations>
@end

@interface WebView (WebViewCSS)
@end

@interface WebView (WebViewEditing)
@end

@interface WebView (WebViewUndoableEditing)
@end

@interface WebView (WebViewEditingActions)
@end
