#ifndef OC_DIRENT_H
#define OC_DIRENT_H

#include <_types.h>
#include <sys/dirent.h>
#include <sys/cdefs.h>
/////////////////////
#ifdef __linux__
#define d_off d_namlen //linux

#ifdef	_INO64_T
#define ino64_t linux_ino64_t
#endif

#ifdef DT_UNKNOWN
#ifdef __USE_BSD//linux
#undef DT_UNKNOWN
#endif
#endif

#ifdef DT_DIR
#ifdef __USE_BSD//linux
#undef DT_DIR
#endif
#endif

#endif//__linux__
////////////////////
#include "/usr/include/dirent.h"
////////////////////////////////////
#ifdef __linux__

#undef d_off

#ifdef ino64_t
#undef ino64_t 
#endif

#endif//__linux__
///////////////////////////


//////////////////////////////////////////////

/*DIRECTORY(3)             BSD Library Functions Manual             DIRECTORY(3)

NAME
     closedir, dirfd, opendir, readdir, readdir_r, rewinddir, seekdir, telldir -- directory operations

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <dirent.h>

     int
     closedir(DIR *dirp);

     int
     dirfd(DIR *dirp);

     DIR *
     opendir(const char *dirname);

     struct dirent *
     readdir(DIR *dirp);

     int
     readdir_r(DIR *restrict dirp, struct dirent *restrict entry, struct dirent **restrict result);

     void
     rewinddir(DIR *dirp);

     void
     seekdir(DIR *dirp, long loc);

     long
     telldir(DIR *dirp);

DESCRIPTION
     The opendir() function opens the directory named by dirname, associates a directory stream with it, and
     returns a pointer to be used to identify the directory stream in subsequent operations.  The pointer
     NULL is returned if dirname cannot be accessed or if it cannot malloc(3) enough memory to hold the
     whole thing.

     The readdir() function returns a pointer to the next directory entry.  It returns NULL upon reaching
     the end of the directory or detecting an invalid seekdir() operation.

     readdir_r() provides the same functionality as readdir(), but the caller must provide a directory entry
     buffer to store the results in.  If the read succeeds, result is pointed at the entry; upon reaching
     the end of the directory, result is set to NULL.  readdir_r() returns 0 on success or an error number
     to indicate failure.

     The telldir() function returns the current location associated with the named directory stream.  Values
     returned by telldir() are good only for the lifetime of the DIR pointer (e.g., dirp) from which they
     are derived.  If the directory is closed and then reopened, prior values returned by telldir() will no
     longer be valid.

     The seekdir() function sets the position of the next readdir() operation on the directory stream.  The
     new position reverts to the one associated with the directory stream when the telldir() operation was
     performed.

     The rewinddir() function resets the position of the named directory stream to the beginning of the
     directory.

     The closedir() function closes the named directory stream and frees the structure associated with the
     dirp pointer, returning 0 on success.  On failure, -1 is returned and the global variable errno is set
     to indicate the error.

     The dirfd() function returns the integer file descriptor associated with the named directory stream,
     see open(2).

     Sample code which searches a directory for entry ``name'' is:

           len = strlen(name);
           dirp = opendir(".");
           while ((dp = readdir(dirp)) != NULL)
                   if (dp->d_namlen == len && !strcmp(dp->d_name, name)) {
                           (void)closedir(dirp);
                           return FOUND;
                   }
           (void)closedir(dirp);
           return NOT_FOUND;

LEGACY SYNOPSIS
     #include <sys/types.h>
     #include <dirent.h>

     <sys/types.h> is necessary for these functions.

SEE ALSO
     close(2), lseek(2), open(2), read(2), compat(5), dir(5)

HISTORY
     The closedir(), dirfd(), opendir(), readdir(), rewinddir(), seekdir(), and telldir() functions appeared
     in 4.2BSD.

BSD                              June 4, 1993                              BSD*/
     int  readdir_r(DIR * dirp, struct dirent * entry, struct dirent ** result);

#endif//OC_DIRENT_H
