#ifndef _OS_OSARRAY_H
#define _OS_OSARRAY_H

#include <libkern/c++/OSCollection.h>

#ifdef __cplusplus
class OSSerialize;
#endif //__cplusplus

#include <HYS/libkern/c++/OSArray.h>

#ifdef __cplusplus
class OSArray : public OSCollection,public OSArray_HYS
{
    OSDeclareDefaultStructors(OSArray)

protected:
public:

/*setCapacityIncrement


Sets the growth size of the array. 

public

virtual unsigned int setCapacityIncrement(
    unsigned increment); 
Return Value

Returns the new growth size.*/
virtual unsigned int setCapacityIncrement(
    unsigned increment); 

/*merge


Appends the contents of an array onto the receiving array. 

public

virtual bool merge(
    const OSArray *otherArray); 
Parameters
otherArray
The array whose contents will be appended to the receiving array.
Return Value

Returns true when merging was successful, false otherwise.*/
virtual bool merge(
    const OSArray *otherArray); 

/*getNextIndexOfObject


Searches the array for the next instance of a specific object, at or beyond the supplied index. 

public

virtual unsigned int getNextIndexOfObject(
    const OSMetaClassBase *anObject, 
    unsigned int index) const; 
Return Value

Returns the next index of the object in the array or -1 if none is found.*/
virtual unsigned int getNextIndexOfObject(
    const OSMetaClassBase *anObject, 
    unsigned int index) const; 

/*setObject(unsigned int, const OSMetaClassBase *)


Inserts an object into the array at a particular index. 

public

virtual bool setObject(
    unsigned int index,
    const OSMetaClassBase *anObject); 
Parameters
index
The index into the array to insert the object.
anObject
The object to add to the OSArray instance. The object will be retained automatically.
Return Value

Returns true if the addition of 'anObject' was successful, false if not.*/
virtual bool setObject(
    unsigned int index,
    const OSMetaClassBase *anObject); 

/*free


Deallocates and releases all resources used by the OSArray instance. 

public

virtual void free(); 
Discussion 

This function should not be called directly, use release() instead.*/
virtual void free(); 

/*getLastObject


Returns a reference to the last object in the array. 

public

virtual OSObject *getLastObject() const; 
Return Value

Returns a reference to the last object in the array or 0 if the array is empty. 
Discussion 

Note that the caller should not release the returned object.*/
virtual OSObject *getLastObject() const; 

/*withArray


Creates and initializes an instance of OSArray of a given capacity and populates it with the contents of the supplied OSArray object. 

public

static OSArray *withArray(
    const OSArray *array, 
    unsigned int capacity = 0); 
Parameters
array
An instance of OSArray from which the new instance will aquire its contents.
capacity
The capacity of the new OSArray. If 0, the capacity will be set to the number of elements in the array, else the capacity must be greater than or equal to the number of elements in the array.
Return Value

Returns a reference to a new instance of OSArray or 0 if an error occurred.*/
static OSArray *withArray(
    const OSArray *array, 
    unsigned int capacity = 0); 

/*serialize


Archives the receiver. 

public

virtual bool serialize(
    OSSerialize *s) const; 
Parameters
s
The OSSerialize object.
Return Value

Returns true if serialization was successful, false if not.*/
virtual bool serialize(
    OSSerialize *s) const; 

/*removeObject


Removes an object from the array. 

public

virtual void removeObject(
    unsigned int index); 
Parameters
index
The index of the object to be removed.
Discussion 

This function removes an object from the array which is located at a given index. Once removed the contents of the array will shift to fill in the vacated spot. The removed object is automatically released.*/

virtual void removeObject(
    unsigned int index); 

/*flushCollection


Removes and releases all items within the array (a member function). 

public

virtual void flushCollection(); */
virtual void flushCollection(); 

/*withCapacity


Creates and initializes a new instance of OSArray with a given capacity. 

public

static OSArray *withCapacity(
    unsigned int capacity); 
Parameters
capacity
The initial capacity (number of references) of the OSArray instance.
Return Value

Returns a reference to an instance of OSArray or 0 if an error occurred.*/
static OSArray *withCapacity(
    unsigned int capacity); 

/*replaceObject


Replaces an object in an array at a given index. 

public

virtual void replaceObject(
    unsigned int index,
    const OSMetaClassBase *anObject); 
Parameters
index
The index into the array at which the new object will be placed.
anObject
The object to be placed into the array.
Discussion 

Note that the original object will be released and the new object will be retained.*/
virtual void replaceObject(
    unsigned int index,
    const OSMetaClassBase *anObject); 

/*setObject(const OSMetaClassBase *)


Appends an object onto the end of the array. 

public

virtual bool setObject(
    const OSMetaClassBase *anObject); 
Parameters
anObject
The object to add to the OSArray instance. The object will be retained automatically.
Return Value

Returns true if the addition of 'anObject' was successful, false if not; failure usually results from failing to allocate the necessary memory.*/
virtual bool setObject(
    const OSMetaClassBase *anObject); 

/*withObjects


Creates and initializes a new instance of OSArray and populates it with a list of objects provided. 

public

static OSArray *withObjects(
    const OSObject *objects[], 
    unsigned int count, 
    unsigned int capacity = 0); 
Parameters
objects
A static array of references to OSMetaClassBase-derived objects.
count
The number of objects provided.
capacity
The initial storage size of the OSArray instance. If 0, the capacity will be set to the size of count, else the capacity must be greater than or equal to count.
Return Value

Returns a reference to a new instance of OSArray or 0 if an error occurred.*/
static OSArray *withObjects(
    const OSObject *objects[], 
    unsigned int count, 
    unsigned int capacity = 0); 


/*getCount


Returns the number of references contained within the OSArray object. 

public

virtual unsigned int getCount() const; 
Return Value

Returns the number of items within the OSArray object.*/
virtual unsigned int getCount() const; 

/*getObject


Returns a reference to an object located within the array at a given index. 

public

virtual OSObject *getObject(
    unsigned int index) const; 
Parameters
index
The index into the array from which the reference to an object is taken.
Return Value

Returns a reference to an object or 0 if the index is beyond the bounds of the array. 
Discussion 

Note that the caller should not release the returned object.*/

virtual OSObject *getObject(
    unsigned int index) const; 

};
#endif //__cplusplus

#endif //_OS_OSARRAY_H
