#ifndef OS_OSDICTIONARY_H
#define OS_OSDICTIONARY_H

#include <libkern/c++/OSCollection.h>

#ifdef __cplusplus
class OSArray;
class OSSymbol;
class OSString;
#endif//__cplusplus

#include <HYS/libkern/c++/OSDictionary.h>

#ifdef __cplusplus
class OSDictionary : public OSCollection,public OSDictionary_HYS
{
  OSDeclareDefaultStructors(OSDictionary)

public:

/*getCapacity


Returns the storage capacity of the dictionary. 

public

virtual unsigned int getCapacity() const; 
Return Value

Returns the storage capacity of the dictionary.*/
virtual unsigned int getCapacity() const; 

/*setCapacityIncrement


Sets the growth size of the dictionary. 

public

virtual unsigned int setCapacityIncrement(
    unsigned increment); 
Parameters
increment
The new growth size.
Return Value

Returns the new capacity increment.*/
virtual unsigned int setCapacityIncrement(
    unsigned increment); 

/*merge


Merges the contents of a dictionary into the receiver. 

public

virtual bool merge(
    const OSDictionary *aDictionary); 
Parameters
aDictionary
The dictionary whose contents are to be merged with the receiver.
Return Value

Returns true if the merge is successful, false otherwise. 
Discussion 

If there are keys in 'aDictionary' that match keys in the receiving dictionary, then the objects in the receiver are replaced by those from 'aDictionary'; the replaced objects are released.*/
virtual bool merge(
    const OSDictionary *aDictionary); 

/*free


Deallocates and releases all resources used by the OSDictionary instance. 

public

virtual void free(); 
Discussion 

This function should not be called directly, use release() instead.*/
virtual void free(); 

/*flushCollection


Removes and releases all objects within the dictionary. 

public

virtual void flushCollection(); */
virtual void flushCollection(); 

/*initWithCapacity


Initializes an instance of OSDictionary. 

public

virtual bool initWithCapacity(
    unsigned int capacity); 
Parameters
capacity
The initial storage capacity of the dictionary object.
Return Value

Returns true if initialization succeeded or false on failure.*/
virtual bool initWithCapacity(
    unsigned int capacity); 

/*removeObject(const OSString *)


Removes an object from the dictionary. 

public

virtual void removeObject(
    const OSString *aKey); 
Parameters
aKey
A unique OSString identifying the object to be removed from the dictionary.
Discussion 

Note that the removed object is automatically released. */
virtual void removeObject(
    const OSString *aKey); 

/*removeObject(const OSSymbol *)


Removes an object from the dictionary. 

public

virtual void removeObject(
    const OSSymbol *aKey); 
Parameters
aKey
A unique OSSymbol identifying the object to be removed from the dictionary.
Discussion 

Note that the removed object is automatically released.*/
virtual void removeObject(
    const OSSymbol *aKey); 

/*serialize


Archives the receiver. 

public

virtual bool serialize(
    OSSerialize *s) const; 
Parameters
s
The OSSerialize object.
Return Value

Returns true if serialization was successful, false if not.*/
virtual bool serialize(
    OSSerialize *s) const; 

/*getCount


Returns the current number of objects within the dictionary. 

public

virtual unsigned int getCount() const; 
Return Value

Returns the number of objects contained within the dictionary.*/
virtual unsigned int getCount() const; 

/*getObject(const OSString *)


Finds an object in the dictionary identified by the given key. 

public

virtual OSObject *getObject(
    const OSString *aKey) const; 
Parameters
aKey
The unique OSString key identifying the object to be returned to caller.
Return Value

Returns a reference to the object corresponding to the given key, or 0 if the key does not exist in the dictionary.*/
virtual OSObject *getObject(
    const OSString *aKey) const; 

/*withObjects(const OSObject *, const OSString *, unsigned int, unsigned int)


Creates and initializes an instance of OSDictionary and populates it with the objects provided. 

public

static OSDictionary *withObjects(
    const OSObject *objects[], 
    const OSString *keys[], 
    unsigned int count, 
    unsigned int capacity = 0); 
Parameters
objects
A static array of OSMetaClassBase-derived objects.
keys
A static array of OSString keys.
count
The number of items to be placed into the dictionary.
capacity
The initial storage capacity of the dictionary object. If 0, the capacity will be set to the size of 'count', else this value must be greater or equal to 'count'.
Return Value

Returns an instance of OSDictionary or 0 on failure. */
static OSDictionary *withObjects(
    const OSObject *objects[], 
    const OSString *keys[], 
    unsigned int count, 
    unsigned int capacity = 0); 

/*withObjects(const OSObject *, const OSSymbol *, unsigned int, unsigned int)


Creates and initializes an instance of OSDictionary and populates it with the objects provided. 

public

static OSDictionary *withObjects(
    const OSObject *objects[], 
    const OSSymbol *keys[], 
    unsigned int count, 
    unsigned int capacity = 0); 
Parameters
objects
A static array of OSMetaClassBase-derived objects.
keys
A static array of OSSymbol keys.
count
The number of items to be placed into the dictionary.
capacity
The initial storage capacity of the dictionary object. If 0, the capacity will be set to the size of 'count', else this value must be greater or equal to 'count'.
Return Value

Returns an instance of OSDictionary or 0 on failure.*/
static OSDictionary *withObjects(
    const OSObject *objects[], 
    const OSSymbol *keys[], 
    unsigned int count, 
    unsigned int capacity = 0); 

/*withDictionary


Creates and initializes an instance of OSDictionary and populates it with objects from another dictionary. 

public

static OSDictionary *withDictionary(
    const OSDictionary *dict, 
    unsigned int capacity = 0); 
Parameters
dict
A dictionary whose contents will be placed in the new instance.
capacity
The initial storage capacity of the dictionary object. If 0, the capacity will be set to the number of elements in the dictionary object, else the capacity must be greater than or equal to the number of elements in the dictionary.
Return Value

Returns an instance of OSDictionary or 0 on failure.*/
static OSDictionary *withDictionary(
    const OSDictionary *dict, 
    unsigned int capacity = 0); 

/*setObject(const OSString *, const OSMetaClassBase *)


Places an object into the dictionary and identifies it by a unique key. 

public

virtual bool setObject(
    const OSString *aKey,
    const OSMetaClassBase *anObject); 
Parameters
aKey
A unique OSString identifying the object placed within the collection.
anObject
The object to be stored in the dictionary. It is automatically retained.
Return Value

Returns true if the addition of an object was successful, false otherwise.*/
virtual bool setObject(
    const OSString *aKey,
    const OSMetaClassBase *anObject); 

/*getObject(const OSSymbol *)


Finds an object in the dictionary identified by the given key. 

public

virtual OSObject *getObject(
    const OSSymbol *aKey) const; 
Parameters
aKey
The unique OSSymbol key identifying the object to be returned to caller.
Return Value

Returns a reference to the object corresponding to the given key, or 0 if the key does not exist in the dictionary.*/
virtual OSObject *getObject(
    const OSSymbol *aKey) const; 


/*removeObject


Removes an object from the dictionary. 

public

virtual void removeObject(
    const char *aKey); 
Parameters
aKey
A unique string identifying the object to be removed from the dictionary.
Discussion 

Note that the removed object is automatically released*/
virtual void removeObject(
    const char *aKey); 

/*getObject


Finds an object in the dictionary identified by the given key. 
public

virtual OSObject *getObject(
    const char *aKey) const; 
Parameters
aKey
The unique string identifying the object to be returned to caller.
Return Value

Returns a reference to the object corresponding to the given key, or 0 if the key does not exist in the dictionary.*/
virtual OSObject *getObject(
    const char *aKey) const; 

/*withCapacity


Creates and initializes an instance of OSDictionary. 

public

static OSDictionary *withCapacity(
    unsigned int capacity); 
Parameters
capacity
The initial storage capacity of the dictionary object.
Return Value

Returns an instance of OSDictionary or 0 on failure.*/

static OSDictionary *withCapacity(
    unsigned int capacity); 

/*setObject


Places an object into the dictionary and identifies it by a unique key. 

public

virtual bool setObject(
    const char *aKey,
    const OSMetaClassBase *anObject); 
Parameters
aKey
A unique string identifying the object placed within the dictionary.
anObject
The object to be stored in the dictionary. It is automatically retained.
Return Value

Returns true if the addition of an object was successful, false otherwise.*/

virtual bool setObject(
    const char *aKey,
    const OSMetaClassBase *anObject); 

};
#endif //__cplusplus

#endif//OS_OSDICTIONARY_H
