#ifndef OS_OSNUMBER_H
#define OS_OSNUMBER_H

#include <libkern/c++/OSObject.h>
#ifdef __cplusplus
class OSNumber : public OSObject
{
    OSDeclareDefaultStructors(OSNumber)

public:

/*addValue


Adds an integer value to the internal numeric value of the OSNumber object. 

public

virtual void addValue(
    signed long long value); 
Parameters
value
The value to be added.*/
virtual void addValue(
    signed long long value); 

/*unsigned8BitValue


Returns its internal value as an 8-bit value. 

public

virtual unsigned char unsigned8BitValue() const; 
Return Value

Returns the internal value as an 8-bit value.*/

virtual unsigned char unsigned8BitValue() const; 

/*setValue


Replaces the current internal numeric value of the OSNumber object by the value given. 

public

virtual void setValue(
    unsigned long long value); 
Parameters
value
The new value for the OSNumber object.*/
virtual void setValue(
    unsigned long long value); 

/*unsigned64BitValue


Returns its internal value as a 64-bit value. 

public

virtual unsigned long long unsigned64BitValue() const; 
Return Value

Returns the internal value as a 64-bit value.*/
virtual unsigned long long unsigned64BitValue() const; 

/*unsigned16BitValue


Returns its internal value as a 16-bit value. 

public

virtual unsigned short unsigned16BitValue() const; 
Return Value

Returns the internal value as a 16-bit value.*/
virtual unsigned short unsigned16BitValue() const; 

/*unsigned32BitValue


Returns its internal value as a 32-bit value. 
public

virtual unsigned int unsigned32BitValue() const; 
Return Value

Returns the internal value as a 32-bit value.*/
virtual unsigned int unsigned32BitValue() const; 

/*withNumber(const char *, unsigned int)


Creates and initializes an instance of OSNumber with a given value represented as a simple C string. 

public

static OSNumber *withNumber(
    const char *value,
    unsigned int numberOfBits); 
Parameters
value
A C string representing a numeric value.
numberOfBits
The number of bits required to represent the value.
Return Value

Returns an instance of OSNumber or 0 if an error occurred. 
Discussion 

This function does not work on IOKit versions prior to 8.0 (prior to Mac OS X v10.4). For IOKit versions 8.0 and later, it works but is limited to parsing unsigned 32-bit quantities The format of the C string may be decimal, hexadecimal ("0x" prefix), binary ("0b" prefix), or octal ("0" prefix).*/
static OSNumber *withNumber(
    const char *value,
    unsigned int numberOfBits); 

/*withNumber(unsigned long long, unsigned int)


Creates and initializes an instance of OSNumber with a given value. 

public

static OSNumber *withNumber(
    unsigned long long value, 
    unsigned int numberOfBits); 
Parameters
value
The numeric integer value.
numberOfBits
The number of bits required to represent the value.
Return Value

Returns an instance of OSNumber or 0 if an error occurred.*/
static OSNumber *withNumber(
    unsigned long long value, 
    unsigned int numberOfBits);

};
#endif //__cplusplus

#endif//OS_OSNUMBER_H
