#ifndef  OS_OSOBJECT_H
#define OS_OSOBJECT_H


#include <libkern/c++/OSMetaClass.h>

#ifdef __cplusplus
class OSSymbol;
class OSString;
#endif //__cplusplus

#include <HYS/libkern/c++/OSObject.h>

#ifdef __cplusplus
class OSObject : public OSMetaClassBase,public OSObject_HYS
{

    OSDeclareAbstractStructors(OSObject)
private:
protected:

/*release(int)


Implements the untagged release(when) mechanism. 

protected

virtual void release(
    int when) const; 
Parameters
when
Pass through to taggedRelease.*/
virtual void release(
    int when) const; 

/*free


The last reference is gone so clean up your resources. 

protected

virtual void free(); 
Discussion 

Release all resources held by the object, then call your parent's free(). 

Caution:
You cannot assume that you have completed initialization before your free is called, so be very careful in your implementation.
The implementation is OSObject::free() { delete this; } so do not call super::free() until just before you return.
Free is not allowed to fail; all resources must be released on completion.*/
virtual void free(); 

/*init


Mac OS X kernel's primary mechanism for constructing objects. 

protected

virtual bool init(); 
Return Value

OSObject::init always returns true, but subclasses will return false on init failure. 
Discussion 

Your responsibility as a subclass author is to override the init method of your parent. In general, most of our implementations call super::init() before doing local initialization, if the parent fails then return false immediately. If you have a failure during your local initialization, then return false.*/
virtual bool init(); 

public:

/*serialize


Archives the receiver. 

public

virtual bool serialize(
    OSSerialize *s) const; 
Parameters
s
The OSSerialize object.
Return Value

Returns true if serialization was successful, false if not.*/
virtual bool serialize(
    OSSerialize *s) const; 

/*release


Releases a reference to this object. 
public

virtual void release() const; 
Discussion 

Removes a reference that is NULL tagged. See taggedRelease.*/
virtual void release() const; 


/*retain


Retains a reference to this object. 
public

virtual void retain() const; 
Discussion 

Takes a reference that is NULL tagged. See taggedRetain.*/
virtual void retain() const; 

/*getRetainCount


Gets the number of times this object has been retained. 

public

virtual int getRetainCount() const; 
Return Value

Returns the current retain count.*/
virtual int getRetainCount() const; 

};
#endif //__cplusplus

#endif//OS_OSOBJECT_H
