#ifndef _OS_OSORDEREDSET_H
#define _OS_OSORDEREDSET_H

#include <libkern/c++/OSCollection.h>
#include <libkern/OSTypes.h>

#ifdef __cplusplus
class OSOffset;
class OSOrderedSet : public OSCollection
{
    OSDeclareDefaultStructors(OSOrderedSet)

public://datatype
/*OSOrderFunction


The sorting function used by the collection to order objects. 

public

typedef SInt32 ( *OSOrderFunction)(
    const OSMetaClassBase *obj1, 
    const OSMetaClassBase *obj2, 
    void *ref ); 
Parameters
obj1
An object from the collection.
obj2
An object to be compared to obj1.
ref
The ordering context used by the sorting function as a hint for sorting.
Return Value

Returns a comparison result of the object, a negative value if obj1 > obj2, 0 if obj1 == obj2, and a positive value if obj1 < obj2.*/
typedef SInt32 ( *OSOrderFunction)(
    const OSMetaClassBase *obj1, 
    const OSMetaClassBase *obj2, 
    void *ref ); 

public://func

/*getLastObject


Returns the last object in the set. 

public

virtual OSObject *getLastObject() const; 
Return Value

Returns the object ordered last in the set or 0 if none exist.*/
virtual OSObject *getLastObject() const; 

/*containsObject


Queries the set for the presence of the specified object. 

public

virtual bool containsObject(
    const OSMetaClassBase *anObject) const; 
Parameters
anObject
The object to be located.
Return Value

Returns true if the object is present in the set, false otherwise.*/
virtual bool containsObject(
    const OSMetaClassBase *anObject) const; 

/*getObject


Returns a reference to an object at the specified index. 

public

virtual OSObject *getObject(
    unsigned int index) const; 
Parameters
index
The index into the set.
Return Value

Returns a reference to the object at the given index, 0 if none exist at that location.*/

virtual OSObject *getObject(
    unsigned int index) const; 

/*removeObject


Removes and releases an object in the set. 

public

virtual void removeObject(
    const OSMetaClassBase *anObject); 
Parameters
anObject
The object to remove from the set.*/
virtual void removeObject(
    const OSMetaClassBase *anObject); 

/*flushCollection


Removes and releases all items in the set. 

public

virtual void flushCollection(); */
virtual void flushCollection(); 

/*setObject(const OSMetaClassBase *)


Places an OSMetaClassBase-derived object into the set. 

public

virtual bool setObject(
    const OSMetaClassBase *anObject); 
Parameters
anObject
The object to be placed into the collection.
Return Value

Returns true if the object was successfully added to the collection, false otherwise. 
Discussion 

Note that the object will be automatically sorted in the set. */
virtual bool setObject(
    const OSMetaClassBase *anObject); 

/*setObject(unsigned int, const OSMetaClassBase *)


Places the specified object into the set at the specified index. 

public

virtual bool setObject(
    unsigned int index,
    const OSMetaClassBase *anObject); 
Parameters
index
The index in the set to place the object.
anObject
The object to be placed into the set.
Return Value

Returns true if the object was successfully placed into the collection, false otherwise.*/
virtual bool setObject(
    unsigned int index,
    const OSMetaClassBase *anObject); 

/*getCount


Returns the number of objects within the collection. 

public

virtual unsigned int getCount() const; 
Return Value

Returns the number of items in the set.*/
virtual unsigned int getCount() const; 

/*withCapacity


Creates and initializes an instance of OSOrderedSet. 

public

static OSOrderedSet *withCapacity(
    unsigned int capacity, 
    OSOrderFunction orderFunc = 0, 
    void *orderingRef = 0); 
Parameters
capacity
The initial storage size in number of objects of the set.
orderFunc
A C-style function that implements the sorting algorithm for the set.
orderingRef
An ordering context used as a hint for ordering objects within the set.
Return Value

Returns an instance of OSOrderedSet, or 0 if a failure occurred.*/

static OSOrderedSet *withCapacity(
    unsigned int capacity, 
    OSOrderFunction orderFunc = 0, 
    void *orderingRef = 0); 


protected:
};
#endif//__cplusplus

#endif /* ! _OS_OSORDEREDSET_H */
