#ifndef _OS_OSSET_H
#define _OS_OSSET_H

#include <libkern/c++/OSCollection.h>

#ifdef __cplusplus
class OSArray;
class OSSet : public OSCollection
{
    OSDeclareDefaultStructors(OSSet)

private:

protected:
public:

/*getCapacity


Returns the storage capacity of the set. 

public

virtual unsigned int getCapacity() const; 
Return Value

Returns the storage size of the set.*/

virtual unsigned int getCapacity() const; 

/*free


Releases all resources created or used by the OSSet instance. 

public

virtual void free(); 
Discussion 

This function should not be called directly, use release() instead.*/

virtual void free(); 

/*flushCollection


Removes and releases all objects within the set. 

public

virtual void flushCollection(); */
virtual void flushCollection(); 

/*getAnyObject


Returns an arbitrary object from the set. 

public

virtual OSObject *getAnyObject() const; 
Return Value

Returns an object if one exists within the set.*/
virtual OSObject *getAnyObject() const; 

/*withSet


Creates an instance of OSSet and populates it with the objects from the specified OSSet object. 

public

static OSSet *withSet(
    const OSSet *set, 
    unsigned int capacity = 0); 
Parameters
set
An OSSet object containing OSMetaClassBase-derived objects which are used to initially populate the new OSSet object.
capacity
The initial storage size of the set. This value must be equal to or larger than the number of objects provided by the OSSet object passed as the first parameter.
Return Value

Returns an instance of OSSet or 0 on failure.*/
static OSSet *withSet(
    const OSSet *set, 
    unsigned int capacity = 0); 

/*containsObject


Queries the set for the presence of the specified object. 

public

virtual bool containsObject(
    const OSMetaClassBase *anObject) const; 
Parameters
anObject
The OSMetaClassBase-derived object to be queried for in the set.
Return Value

Returns true if the object is present within the set, false otherwise.*/
virtual bool containsObject(
    const OSMetaClassBase *anObject) const; 

/*withObjects


Creates and initializes an instance of OSSet and populates it with the objects provided. 

public

static OSSet *withObjects(
    const OSObject *objects[], 
    unsigned int count, 
    unsigned int capacity = 0); 
Parameters
objects
A static array of OSMetaClassBase-derived objects which are used to populate the set.
count
The number of objects passed to the set.
capacity
The initial storage size of the set. The capacity is the total number of objects that can be stored in the set. This value must be equal to or larger than the count parameter.
Return Value

Returns an instance of OSSet or 0 on failure.*/
static OSSet *withObjects(
    const OSObject *objects[], 
    unsigned int count, 
    unsigned int capacity = 0);

/*withCapacity


Creates and initializes an instance of OSSet with the specified capacity. 

public

static OSSet *withCapacity(
    unsigned int capacity); 
Parameters
capacity
The initial capacity of the set. The capacity is the total number of objects that can be stored in the set.
Return Value

Returns an instance of OSSet or 0 on failure.*/
static OSSet *withCapacity(
    unsigned int capacity); 

/*setObject


Places objects into the set. 

public

virtual bool setObject(
    const OSMetaClassBase *anObject); 
Parameters
anObject
The OSMetaClassBase-derived object to be placed into the set.
Return Value

Returns true if the object was successfully placed into the set, false otherwise. 
Discussion 

Note that the object added to the set is automatically retained.*/

virtual bool setObject(
    const OSMetaClassBase *anObject); 

/*removeObject


Removes objects from the set. 

public

virtual void removeObject(
    const OSMetaClassBase *anObject); 
Parameters
anObject
The OSMetaClassBase-derived object to be removed from the set.
Discussion 

Note that the object removed from the set is automatically released.*/
virtual void removeObject(
    const OSMetaClassBase *anObject); 

/*getCount


Returns the number of objects currently in the set. 

public

virtual unsigned int getCount() const; 
Return Value

Returns the number of objects in the set.*/

virtual unsigned int getCount() const; 

};
#endif //__cplusplus

#endif //_OS_OSSET_H
