#ifndef OS_OSSTRING_H
#define OS_OSSTRING_H

#include <libkern/c++/OSObject.h>

#ifdef __cplusplus
class OSData;

class OSString : public OSObject{
OSDeclareDefaultStructors(OSString)

public:

/*withCStringNoCopy


Creates and initializes an instance of OSString but does not copy the original C string into container. 

public

static OSString *withCStringNoCopy(
    const char *cString); 
Parameters
cString
A simple C string.
Return Value

Returns an instance of OSString or 0 on error.*/
static OSString *withCStringNoCopy(
    const char *cString); 

/*withString


Creates and initializes an instance of OSString from another OSString. 

public

static OSString *withString(
    const OSString *aString); 
Parameters
aString
An OSString object.
Return Value

Returns an instance of OSString or 0 on error.*/
static OSString *withString(
    const OSString *aString); 

/*isEqualTo(const OSData *)


Tests the equality of an unknown OSData object and the OSString instance. 

public

virtual bool isEqualTo(
    const OSData *obj) const; 
Parameters
obj
An OSData object.
Return Value

Returns true if the two objects are equivalent, false otherwise. */
virtual bool isEqualTo(
    const OSData *obj) const; 

/*isEqualTo(const OSMetaClassBase *)


Tests the equality of an unknown OSObject-derived object and the OSString instance. 

public

virtual bool isEqualTo(
    const OSMetaClassBase *obj) const; 
Parameters
obj
An OSObject-derived object.
Return Value

Returns true if the two objects are equivalent, false otherwise.*/

virtual bool isEqualTo(
    const OSMetaClassBase *obj) const; 

/*initWithCString


Initializes an instance of OSString with a simple C string. 

public

virtual bool initWithCString(
    const char *cString); 
Parameters
cString
A simple C string.
Return Value

Returns true on success, false otherwise.*/

virtual bool initWithCString(
    const char *cString);

/*withCString


Creates and initializes an instance of OSString. 

public

static OSString *withCString(
    const char *cString); 
Parameters
cString
A simple C string.
Return Value

Returns an instance of OSString or 0 on error.*/
static OSString *withCString(
    const char *cString); 

/*isEqualTo(const OSString *)


Tests the equality of two OSString objects. 

public

virtual bool isEqualTo(
    const OSString *aString) const; 
Parameters
aString
An OSString object.
Return Value

Returns true if the two strings are equal, false otherwise.*/
virtual bool isEqualTo(
    const OSString *aString) const; 

/*isEqualTo(const char *)


Tests the equality of the specified C string and the internal string array of the receiving OSString object. 

public

virtual bool isEqualTo(
    const char *aCString) const; 
Parameters
aCString 
A simple C string.
Return Value

Returns true if the two strings are equal, false otherwise.*/
virtual bool isEqualTo(
    const char *aCString) const; 

/*getCStringNoCopy


Returns a pointer to the internal C string array. 

public

virtual const char *getCStringNoCopy() const; 
Return Value

Returns a pointer to the internal C string array.*/
virtual const char *getCStringNoCopy() const; 

/*getLength


Returns the length of the string. 

public

virtual unsigned int getLength() const; 
Return Value

Returns the length of the string.*/
virtual unsigned int getLength() const; 

};
#endif //__cplusplus


#endif//OS_OSSTRING_H
