
#ifndef _MACH_O_GETSECT_H_
#define _MACH_O_GETSECT_H_

#include <stdint.h>
#include <mach-o/loader.h>

/*getsectbynamefromheader

Returns the data structure representing a section of a specified 32-bit Mach-O file.

const struct section* getsectbynamefromheader(
   const struct mach_header* mhp,
   const char* segname,
   const char* sectname);
Parameters
mhp

A pointer to a mach_header data structure. Pass the mach_header of the file containing the section data you wish to retrieve.
segname

A pointer to a C string. Pass the name of the segment in which the section resides.
sectname

A pointer to a C string. Pass the name of the section.
Return Value

A pointer to a section data structure.*/
const struct section* getsectbynamefromheader(
   const struct mach_header* mhp,
   const char* segname,
   const char* sectname);

/*GETSECTBYNAME(3)                                              GETSECTBYNAME(3)



NAME
       getsectbyname,  getsectdata - get the section information for the named
       section

SYNOPSIS
       #include <mach-o/getsect.h>

       const struct section *getsectbynamefromheader(
       const struct mach_header *mhp,
       const char *segname,
       const char *sectname)

       const struct section *getsectbyname(
       const char *segname,
       const char *sectname)

       char *getsectdatafromheader(
       const struct mach_header *mhp,
       const char *segname,
       const char *sectname,
       unsigned long *size)

       char *getsectdata(
       const char *segname,
       const char *sectname,
       unsigned long *size)

       char *getsectdatafromFramework(
       const char *FrameworkName,
       const char *segname,
       const char *sectname,
       unsigned long *size)

DESCRIPTION
       Getsectbynamefromheader returns the section  structure  for  the  named
       section  in the named segment if it exists in the specified Mach header
       otherwise it returns NULL.  If the specified Mach header comes  from  a
       dynamic library as returned by _dyld_get_image_header(3) the addr field
       in     the     section     structure     will     have     to      have
       _dyld_get_image_vmaddr_slide(3) added to it to make it a valid pointer.

       Getsectbyname is the same as  getsectbynamefromheader  with  its  first
       argument being the link editor defined symbol _mh_execute_header.

       Getsectdatafromheader  returns  the  address  to the data for the named
       section in the named segment if it exists in the specified Mach header.
       Also  it  returns  the  size of the section data indirectly through the
       pointer size.  Otherwise it returns NULL for the pointer and  zero  for
       the size.  If the specified Mach header comes from a dynamic library as
       returned by _dyld_get_image_header(3) the address to the data  returned
       will  have  to have _dyld_get_image_vmaddr_slide(3) added to it to make
       it a valid pointer.

       Getsectdata is the same as getsectdatafromheader with its  first  argu-ment argument
       ment being the link editor defined symbol _mh_execute_header.

       getsectdatafromFramework is used to get the named section data from the
       named Framework.  For example, the framework name ``Appkit''  would  be
       used for /System/Library/Frameworks/Appkit.framework/Versions/C/Appkit.
       If that Framework isn't being used by the program then it returns  NULL
       for the pointer and zero for the size.

SEE ALSO
       dyld(3), getsegbyname(3)



Apple Computer, Inc.            April 10, 1998                GETSECTBYNAME(3)*/

  char *getsectdata(
       const char *segname,
       const char *sectname,
       unsigned long *size);

/*GETSEGBYNAME(3)                                                GETSEGBYNAME(3)



NAME
       getsegbyname - get the segment command for the named segment

SYNOPSIS
       #include <mach-o/getsect.h>

       const struct segment_command *getsegbyname(const char *segname);

DESCRIPTION
       This  routine  returns the segment_command structure for the named seg-ment segment
       ment if it exists in the  Mach-O  (Mach  object)  executable  getsegby-name(3) getsegbyname(3)
       name(3)  is  linked  into.  Otherwise getsegbyname(3) returns NULL.  It
       uses the link editor defined symbol _mh_execute_header and  just  looks
       through the load commands.  Since these are mapped into the __TEXT seg-ment segment
       ment they are read-only and thus const by default.

SEE ALSO
       end(3), getsectbyname(3)



Apple Computer, Inc.            April 10, 1998                 GETSEGBYNAME(3)*/
       const struct segment_command *getsegbyname(const char *segname);

#endif 
