#ifndef MACH_O_LOADER_H
#define MACH_O_LOADER_H

#include <stdint.h>
#include <mach/machine.h>
#include <mach/vm_prot.h>
#include <mach/machine/thread_status.h>
#include <architecture/byte_order.h>
#include <HYS/mach-o/loader.h>

typedef uint32_t uint_32;//add

/*mach_header_64

Defines the general attributes of a file targeted for a 64-bit architecture. Declared in /usr/include/mach-o/loader.h.

struct mach_header_64
   {
   uint32_t magic;
   cpu_type_t cputype;
   cpu_subtype_t cpusubtype;
   uint32_t filetype;
   uint32_t ncmds;
   uint32_t sizeofcmds;
   uint32_t flags;
   uint32_t reserved;
};
Fields
magic

An integer containing a value identifying this file as a 64-bit Mach-O file. Use the constant MH_MAGIC_64 if the file is intended for use on a CPU with the same endianness as the computer on which the compiler is running. The constant MH_CIGAM_64 can be used when the byte ordering scheme of the target machine is the reverse of the host CPU.
cputype

An integer indicating the architecture you intend to use the file on. The only appropriate value for this structure is:
CPU_TYPE_POWERPC64 to target 64-bit PowerPC–based Macintosh computers.
cpusubtype

An integer specifying the exact model of the CPU. To run on all PowerPC processors supported by the Mac OS X kernel, this should be set to CPU_SUBTYPE_POWERPC_ALL.
filetype

An integer indicating the usage and alignment of the file. Valid values for this field include:
The MH_OBJECT file type is the format used for intermediate object files. It is a very compact format containing all its sections in one segment. The compiler and assembler usually create one MH_OBJECT file for each source code file. By convention, the file name extension for this format is .o.
The MH_EXECUTE file type is the format used by standard executable programs.
The MH_BUNDLE file type is the type typically used by code that you load at runtime (typically called bundles or plug-ins). By convention, the file name extension for this format is .bundle.
The MH_DYLIB file type is for dynamic shared libraries. It contains some additional tables to support multiple modules. By convention, the file name extension for this format is .dylib, except for the main shared library of a framework, which does not usually have a file name extension.
The MH_PRELOAD file type is an executable format used for special-purpose programs that are not loaded by the Mac OS X kernel, such as programs burned into programmable ROM chips. Do not confuse this file type with the MH_PREBOUND flag, which is a flag that the static linker sets in the header structure to mark a prebound image.
The MH_CORE file type is used to store core files, which are traditionally created when a program crashes. Core files store the entire address space of a process at the time it crashed. You can later run gdb on the core file to figure out why the crash occurred.
The MH_DYLINKER file type is the type of a dynamic linker shared library. This is the type of the dyld file.
The MH_DSYM file type designates files that store symbol information for a corresponding binary file.
ncmds

An integer indicating the number of load commands following the header structure.
sizeofcmds

An integer indicating the number of bytes occupied by the load commands following the header structure.
flags

An integer containing a set of bit flags that indicate the state of certain optional features of the Mach-O file format. These are the masks you can use to manipulate this field:
MH_NOUNDEFS—The object file contained no undefined references when it was built.
MH_INCRLINK—The object file is the output of an incremental link against a base file and cannot be linked again.
MH_DYLDLINK—The file is input for the dynamic linker and cannot be statically linked again.
MH_TWOLEVEL—The image is using two-level namespace bindings.
MH_BINDATLOAD—The dynamic linker should bind the undefined references when the file is loaded.
MH_PREBOUND—The file’s undefined references are prebound.
MH_PREBINDABLE—This file is not prebound but can have its prebinding redone. Used only when MH_PREBEOUND is not set.
MH_NOFIXPREBINDING—The dynamic linker doesn’t notify the prebinding agent about this executable.
MH_ALLMODSBOUND—Indicates that this binary binds to all two-level namespace modules of its dependent libraries. Used only when MH_PREBINDABLE and MH_TWOLEVEL are set.
MH_CANONICAL—This file has been canonicalized by unprebinding—clearing prebinding information from the file. See the redo_prebinding man page for details.
MH_SPLIT_SEGS—The file has its read-only and read-write segments split.
MH_FORCE_FLAT—The executable is forcing all images to use flat namespace bindings.
MH_SUBSECTIONS_VIA_SYMBOLS—The sections of the object file can be divided into individual blocks. These blocks are dead-stripped if they are not used by other code. See “Linking” in Xcode 2 User Guide for details.
MH_NOMULTIDEFS—This umbrella guarantees there are no multiple definitions of symbols in its subimages. As a result, the two-level namespace hints can always be used.
reserved

Reserved for future use.
Special Considerations

See comment in mach_header*/

struct mach_header_64
   {
   uint32_t magic;
   cpu_type_t cputype;
   cpu_subtype_t cpusubtype;
   uint32_t filetype;
   uint32_t ncmds;
   uint32_t sizeofcmds;
   uint32_t flags;
   uint32_t reserved;
};

/*mach_header

Specifies the general attributes of a file. Appears at the beginning of object files targeted to 32-bit architectures. Declared in /usr/include/mach-o/loader.h. See also mach_header_64.

struct mach_header
   {
   uint32_t magic;
   cpu_type_t cputype;
   cpu_subtype_t cpusubtype;
   uint32_t filetype;
   uint32_t ncmds;
   uint32_t sizeofcmds;
   uint32_t flags;
};
Fields
magic

An integer containing a value identifying this file as a 32-bit Mach-O file. Use the constant MH_MAGIC if the file is intended for use on a CPU with the same endianness as the computer on which the compiler is running. The constant MH_CIGAM can be used when the byte ordering scheme of the target machine is the reverse of the host CPU.
cputype

An integer indicating the architecture you intend to use the file on. Appropriate values include:
CPU_TYPE_POWERPC to target PowerPC-based Macintosh computers
CPU_TYPE_I386 to target the Intel-based Macintosh computers
cpusubtype

An integer specifying the exact model of the CPU. To run on all PowerPC or x86 processors supported by the Mac OS X kernel, this should be set to CPU_SUBTYPE_POWERPC_ALL or CPU_SUBTYPE_I386_ALL.
filetype

An integer indicating the usage and alignment of the file. Valid values for this field include:
The MH_OBJECT file type is the format used for intermediate object files. It is a very compact format containing all its sections in one segment. The compiler and assembler usually create one MH_OBJECT file for each source code file. By convention, the file name extension for this format is .o.
The MH_EXECUTE file type is the format used by standard executable programs.
The MH_BUNDLE file type is the type typically used by code that you load at runtime (typically called bundles or plug-ins). By convention, the file name extension for this format is .bundle.
The MH_DYLIB file type is for dynamic shared libraries. It contains some additional tables to support multiple modules. By convention, the file name extension for this format is .dylib, except for the main shared library of a framework, which does not usually have a file name extension.
The MH_PRELOAD file type is an executable format used for special-purpose programs that are not loaded by the Mac OS X kernel, such as programs burned into programmable ROM chips. Do not confuse this file type with the MH_PREBOUND flag, which is a flag that the static linker sets in the header structure to mark a prebound image.
The MH_CORE file type is used to store core files, which are traditionally created when a program crashes. Core files store the entire address space of a process at the time it crashed. You can later run gdb on the core file to figure out why the crash occurred.
The MH_DYLINKER file type is the type of a dynamic linker shared library. This is the type of the dyld file.
The MH_DSYM file type designates files that store symbol information for a corresponding binary file.
ncmds

An integer indicating the number of load commands following the header structure.
sizeofcmds

An integer indicating the number of bytes occupied by the load commands following the header structure.
flags

An integer containing a set of bit flags that indicate the state of certain optional features of the Mach-O file format. These are the masks you can use to manipulate this field:
MH_NOUNDEFS—The object file contained no undefined references when it was built.
MH_INCRLINK—The object file is the output of an incremental link against a base file and cannot be linked again.
MH_DYLDLINK—The file is input for the dynamic linker and cannot be statically linked again.
MH_TWOLEVEL—The image is using two-level namespace bindings.
MH_BINDATLOAD—The dynamic linker should bind the undefined references when the file is loaded.
MH_PREBOUND—The file’s undefined references are prebound.
MH_PREBINDABLE—This file is not prebound but can have its prebinding redone. Used only when MH_PREBEOUND is not set.
MH_NOFIXPREBINDING—The dynamic linker doesn’t notify the prebinding agent about this executable.
MH_ALLMODSBOUND—Indicates that this binary binds to all two-level namespace modules of its dependent libraries. Used only when MH_PREBINDABLE and MH_TWOLEVEL are set.
MH_CANONICAL—This file has been canonicalized by unprebinding—clearing prebinding information from the file. See the redo_prebinding man page for details.
MH_SPLIT_SEGS—The file has its read-only and read-write segments split.
MH_FORCE_FLAT—The executable is forcing all images to use flat namespace bindings.
MH_SUBSECTIONS_VIA_SYMBOLS—The sections of the object file can be divided into individual blocks. These blocks are dead-stripped if they are not used by other code. See “Linking” in Xcode User Guide for details.
MH_NOMULTIDEFS—This umbrella guarantees there are no multiple definitions of symbols in its subimages. As a result, the two-level namespace hints can always be used.
Special Considerations

For all file types, except MH_OBJECT, segments must be aligned on page boundaries for the given CPU architecture: 4096 bytes for PowerPC and x86 processors. This allows the kernel to page virtual memory directly from the segment into the address space of the process. The header and load commands must be aligned as part of the data of the first segment stored on disk (which would be the __TEXT segment, in the file types described in filetype).*/

struct mach_header
   {
   uint32_t magic;
   cpu_type_t cputype;
   cpu_subtype_t cpusubtype;
   uint32_t filetype;
   uint32_t ncmds;
   uint32_t sizeofcmds;
   uint32_t flags;
};

/*lc_str

Defines a variable-length string. Declared in /usr/include/mach-o/loader.h.

union lc_str
   {
      uint32_t offset;
      #ifndef __LP64__
      char *ptr;
      #endif
};

Fields
offset

A long integer. A byte offset from the start of the load command that contains this string to the start of the string data.
ptr

A pointer to an array of bytes. At runtime, this pointer contains the virtual memory address of the string data. The ptr field is not used in Mach-O files.
Discussion

Load commands store variable-length data such as library names using the lc_str data structure. Unless otherwise specified, the data consists of a C string.

The data pointed to is stored just after the load command, and the size is added to the size of the load command. The string should be null terminated; any extra bytes to round up the size should be null. You can also determine the size of the string by subtracting the size of the load command data structure from the cmdsize field of the load command data structure.*/
union lc_str
   {
      uint32_t offset;
      #ifndef __LP64__
      char *ptr;
      #endif
};

/*dylib

Defines the data used by the dynamic linker to match a shared library against the files that have linked to it. Used exclusively in the dylib_command data structure. Declared in /usr/include/mach-o/loader.h.

struct dylib
   {
   union lc_str  name;
      uint_32 timestamp;
      uint_32 current_version;
      uint_32 compatibility_version;
   };
Fields
name

A data structure of type lc_str. Specifies the name of the shared library.
timestamp

The date and time when the shared library was built.
current_version

The current version of the shared library.
compatibility_version

The compatibility version of the shared library*/
struct dylib
   {
   union lc_str  name;
      uint_32 timestamp;
      uint_32 current_version;
      uint_32 compatibility_version;
   };

/*dylib_command

Defines the attributes of the LC_LOAD_DYLIB and LC_ID_DYLIB load commands. Declared in /usr/include/mach-o/loader.h.

struct dylib_command
   {
   uint_32 cmd;
   uint_32 cmdsize;
   struct dylib dylib;
   };

Fields
cmd

Common to all load command structures. For this structure, set to either LC_LOAD_DYLIB, LC_LOAD_WEAK_DYLIB, or LC_ID_DYLIB.
cmdsize

Common to all load command structures. For this structure, set to sizeof(dylib_command) plus the size of the data pointed to by the name field of the dylib field.
dylib

A data structure of type dylib. Specifies the attributes of the shared library.
Discussion

For each shared library that a file links against, the static linker creates an LC_LOAD_DYLIB command and sets its dylib field to the value of the dylib field of the LC_ID_DYLD load command of the target library. All the LC_LOAD_DYLIB commands together form a list that is ordered according to location in the file, earliest LC_LOAD_DYLIB command first. For two-level namespace files, undefined symbol entries in the symbol table refer to their parent shared libraries by index into this list. The index is called a library ordinal, and it is stored in the n_desc field of the nlist data structure.

At runtime, the dynamic linker uses the name in the dyld field of the LC_LOAD_DYLIB command to locate the shared library. If it finds the library, the dynamic linker compares the version information of the LC_LOAD_DYLIB load command against the library’s version. For the dynamic linker to successfully link the shared library, the compatibility version of the shared library must be less than or equal to the compatibility version in the LC_LOAD_DYLIB command.

The dynamic linker uses the timestamp to determine whether it can use the prebinding information. The current version is returned by the function NSVersionOfRunTimeLibrary to allow you to determine the version of the library your program is using.*/
struct dylib_command
   {
   uint_32 cmd;
   uint_32 cmdsize;
   struct dylib dylib;
   };

/*segment_command_64

Specifies the range of bytes in a 64-bit Mach-O file that make up a segment. Those bytes are mapped by the loader into the address space of a program. If the 64-bit segment has sections, they are defined by section_64 structures. Declared in /usr/include/mach-o/loader.h.

struct segment_command_64
   {
   uint32_t cmd;
   uint32_t cmdsize;
   char segname[16];
   uint64_t vmaddr;
   uint64_t vmsize;
   uint64_t fileoff;
   uint64_t filesize;
   vm_prot_t maxprot;
   vm_prot_t initprot;
   uint32_t nsects;
   uint32_t flags;
};
Fields
cmd

See description in segment_command. Set to LC_SEGMENT_64 for this structure.
cmdsize

Common to all load command structures. For this structure, set this field to sizeof(segment_command_64) plus the size of all the section data structures that follow (sizeof(segment_command_64 + (sizeof(section_64) * segment->nsect))).
segname

A C string specifying the name of the segment. The value of this field can be any sequence of ASCII characters, although segment names defined by Apple begin with two underscores and consist of capital letters (as in __TEXT and __DATA). This field is fixed at 16 bytes in length.
vmaddr

Indicates the starting virtual memory address of this segment.
vmsize

Indicates the number of bytes of virtual memory occupied by this segment. See also the description of filesize, below.
fileoff

Indicates the offset in this file of the data to be mapped at vmaddr.
filesize

Indicates the number of bytes occupied by this segment on disk. For segments that require more memory at runtime than they do at build time, vmsize can be larger than filesize. For example, the __PAGEZERO segment generated by the linker for MH_EXECUTABLE files has a vmsize of 0x1000 but a filesize of 0. Because __PAGEZERO contains no data, there is no need for it to occupy any space until runtime. Also, the static linker often allocates uninitialized data at the end of the __DATA segment; in this case, the vmsize is larger than the filesize. The loader guarantees that any memory of this sort is initialized with zeros.
maxprot

Specifies the maximum permitted virtual memory protections of this segment.
initprot

Specifies the initial virtual memory protections of this segment.
nsects

Indicates the number of section data structures following this load command.
flags

Defines a set of flags that affect the loading of this segment:
SG_HIGHVM—The file contents for this segment are for the high part of the virtual memory space; the low part is zero filled (for stacks in core files).
SG_NORELOC—This segment has nothing that was relocated in it and nothing relocated to it. It may be safely replaced without relocation.*/
struct segment_command_64
   {
   uint32_t cmd;
   uint32_t cmdsize;
   char segname[16];
   uint64_t vmaddr;
   uint64_t vmsize;
   uint64_t fileoff;
   uint64_t filesize;
   vm_prot_t maxprot;
   vm_prot_t initprot;
   uint32_t nsects;
   uint32_t flags;
};

/*section_64

Defines the elements used by a 64-bit section. Directly following a segment_command_64 data structure is an array of section_64 data structures, with the exact count determined by the nsects field of the segment_command_64 structure. Declared in /usr/include/mach-o/loader.h.

struct section_64
   {
   char sectname[16];
   char segname[16];
   uint64_t addr;
   uint64_t size;
   uint32_t offset;
   uint32_t align;
   uint32_t reloff;
   uint32_t nreloc;
   uint32_t flags;
   uint32_t reserved1;
   uint32_t reserved2;
};

Fields
sectname

A string specifying the name of this section. The value of this field can be any sequence of ASCII characters, although section names defined by Apple begin with two underscores and consist of lowercase letters (as in __text and __data). This field is fixed at 16 bytes in length.
segname

A string specifying the name of the segment that should eventually contain this section. For compactness, intermediate object files—files of type MH_OBJECT—contain only one segment, in which all sections are placed. The static linker places each section in the named segment when building the final product (any file that is not of type MH_OBJECT).
addr

An integer specifying the virtual memory address of this section.
size

An integer specifying the size in bytes of the virtual memory occupied by this section.
offset

An integer specifying the offset to this section in the file.
align

An integer specifying the section’s byte alignment. Specify this as a power of two; for example, a section with 8-byte alignment would have an align value of 3 (2 to the 3rd power equals 8).
reloff

An integer specifying the file offset of the first relocation entry for this section.
nreloc

An integer specifying the number of relocation entries located at reloff for this section.
flags

An integer divided into two parts. The least significant 8 bits contain the section type, while the most significant 24 bits contain a set of flags that specify other attributes of the section. These types and flags are primarily used by the static linker and file analysis tools, such as otool, to determine how to modify or display the section. These are the possible types:
S_REGULAR—This section has no particular type. The standard tools create a __TEXT,__text section of this type.
S_ZEROFILL—Zero-fill-on-demand section—when this section is first read from or written to, each page within is automatically filled with bytes containing zero.
S_CSTRING_LITERALS—This section contains only constant C strings. The standard tools create a __TEXT,__cstring section of this type.
S_4BYTE_LITERALS—This section contains only constant values that are 4 bytes long. The standard tools create a __TEXT,__literal4 section of this type.
S_8BYTE_LITERALS—This section contains only constant values that are 8 bytes long. The standard tools create a __TEXT,__literal8 section of this type.
S_LITERAL_POINTERS—This section contains only pointers to constant values.
S_NON_LAZY_SYMBOL_POINTERS—This section contains only non-lazy pointers to symbols. The standard tools create a section of the __DATA,__nl_symbol_ptrs section of this type.
S_LAZY_SYMBOL_POINTERS—This section contains only lazy pointers to symbols. The standard tools create a __DATA,__la_symbol_ptrs section of this type.
S_SYMBOL_STUBS——This section contains symbol stubs. The standard tools create __TEXT,__symbol_stub and __TEXT,__picsymbol_stub sections of this type. See “Dynamic Code Generation” in Mach-O Programming Topics for more information.
S_MOD_INIT_FUNC_POINTERS—This section contains pointers to module initialization functions. The standard tools create __DATA,__mod_init_func sections of this type.
S_MOD_TERM_FUNC_POINTERS—This section contains pointers to module termination functions. The standard tools create __DATA,__mod_term_func sections of this type.
S_COALESCED—This section contains symbols that are coalesced by the static linker and possibly the dynamic linker. More than one file may contain coalesced definitions of the same symbol without causing multiple-defined-symbol errors.
S_GB_ZEROFILL—This is a zero-filled on-demand section. It can be larger than 4 GB. This section must be placed in a segment containing only zero-filled sections. If you place a zero-filled section in a segment with non–zero-filled sections, you may cause those sections to be unreachable with a 31-bit offset. That outcome stems from the fact that the size of a zero-filled section can be larger than 4 GB (in a 32-bit address space). As a result of this, the static linker would be unable to build the output file. See segment_command_64 for more information.

The following are the possible attributes of a section:
S_ATTR_PURE_INSTRUCTIONS—This section contains only executable machine instructions. The standard tools set this flag for the sections __TEXT,__text, __TEXT,__symbol_stub, and __TEXT,__picsymbol_stub.
S_ATTR_SOME_INSTRUCTIONS—This section contains executable machine instructions.
S_ATTR_NO_TOC—This section contains coalesced symbols that must not be placed in the table of contents (SYMDEF member) of a static archive library.
S_ATTR_EXT_RELOC—This section contains references that must be relocated. These references refer to data that exists in other files (undefined symbols). To support external relocation, the maximum virtual memory protections of the segment that contains this section must allow both reading and writing.
S_ATTR_LOC_RELOC—This section contains references that must be relocated. These references refer to data within this file.
S_ATTR_STRIP_STATIC_SYMS—The static symbols in this section can be stripped if the MH_DYLDLINK flag of the image’s mach_header header structure is set.
S_ATTR_NO_DEAD_STRIP—This section must not be dead-stripped. See “Linking” in Xcode User Guide for details.
S_ATTR_LIVE_SUPPORT—This section must not be dead-stripped if they reference code that is live, but the reference is undetectable.
reserved1

An integer reserved for use with certain section types. For symbol pointer sections and symbol stubs sections that refer to indirect symbol table entries, this is the index into the indirect table for this section’s entries. The number of entries is based on the section size divided by the size of the symbol pointer or stub. Otherwise, this field is set to 0.
reserved2

For sections of type S_SYMBOL_STUBS, an integer specifying the size (in bytes) of the symbol stub entries contained in the section. Otherwise, this field is reserved for future use and should be set to 0.
Discussion

Each section in a Mach-O file has both a type and a set of attribute flags. In intermediate object files, the type and attributes determine how the static linker copies the sections into the final product. Object file analysis tools (such as otool) use the type and attributes to determine how to read and display the sections. Some section types and attributes are used by the dynamic linker.

These are important static-linking variants of the symbol type and attributes:
Regular sections. In a regular section, only one definition of an external symbol may exist in intermediate object files. The static linker returns an error if it finds any duplicate external symbol definitions.
Coalesced sections. In the final product, the static linker retains only one instance of each symbol defined in coalesced sections. To support complex language features (such as C++ vtables and RTTI) the compiler may create a definition of a particular symbol in every intermediate object file. The static linker and the dynamic linker would then reduce the duplicate definitions to the single definition used by the program.
Coalesced sections with weak definitions Weak symbol definitions may appear only in coalesced sections. When the static linker finds duplicate definitions for a symbol, it discards any coalesced symbol definition that has the weak definition attribute set (see nlist). If there are no non-weak definitions, the first weak definition is used instead. This feature is designed to support C++ templates; it allows explicit template instantiations to override implicit ones. The C++ compiler places explicit definitions in a regular section, and it places implicit definitions in a coalesced section, marked as weak definitions. Intermediate object files (and thus static archive libraries) built with weak definitions can be used only with the static linker in Mac OS X v10.2 and later. Final products (applications and shared libraries) should not contain weak definitions if they are expected to be used on earlier versions of Mac OS X.*/
struct section_64
   {
   char sectname[16];
   char segname[16];
   uint64_t addr;
   uint64_t size;
   uint32_t offset;
   uint32_t align;
   uint32_t reloff;
   uint32_t nreloc;
   uint32_t flags;
   uint32_t reserved1;
   uint32_t reserved2;
  uint32_t	reserved3;
};

/*section

Defines the elements used by a 32-bit section. Directly following a segment_command data structure is an array of section data structures, with the exact count determined by the nsects field of the segment_command structure. Declared in /usr/include/mach-o/loader.h. See also section_64.

struct section
   {
   char sectname[16];
   char segname[16];
   uint32_t addr;
   uint32_t size;
   uint32_t offset;
   uint32_t align;
   uint32_t reloff;
   uint32_t nreloc;
   uint32_t flags;
   uint32_t reserved1;
   uint32_t reserved2;
};

Fields
sectname

A string specifying the name of this section. The value of this field can be any sequence of ASCII characters, although section names defined by Apple begin with two underscores and consist of lowercase letters (as in __text and __data). This field is fixed at 16 bytes in length.
segname

A string specifying the name of the segment that should eventually contain this section. For compactness, intermediate object files—files of type MH_OBJECT—contain only one segment, in which all sections are placed. The static linker places each section in the named segment when building the final product (any file that is not of type MH_OBJECT).
addr

An integer specifying the virtual memory address of this section.
size

An integer specifying the size in bytes of the virtual memory occupied by this section.
offset

An integer specifying the offset to this section in the file.
align

An integer specifying the section’s byte alignment. Specify this as a power of two; for example, a section with 8-byte alignment would have an align value of 3 (2 to the 3rd power equals 8).
reloff

An integer specifying the file offset of the first relocation entry for this section.
nreloc

An integer specifying the number of relocation entries located at reloff for this section.
flags

An integer divided into two parts. The least significant 8 bits contain the section type, while the most significant 24 bits contain a set of flags that specify other attributes of the section. These types and flags are primarily used by the static linker and file analysis tools, such as otool, to determine how to modify or display the section. These are the possible types:
S_REGULAR—This section has no particular type. The standard tools create a __TEXT,__text section of this type.
S_ZEROFILL—Zero-fill-on-demand section—when this section is first read from or written to, each page within is automatically filled with bytes containing zero.
S_CSTRING_LITERALS—This section contains only constant C strings. The standard tools create a __TEXT,__cstring section of this type.
S_4BYTE_LITERALS—This section contains only constant values that are 4 bytes long. The standard tools create a __TEXT,__literal4 section of this type.
S_8BYTE_LITERALS—This section contains only constant values that are 8 bytes long. The standard tools create a __TEXT,__literal8 section of this type.
S_LITERAL_POINTERS—This section contains only pointers to constant values.
S_NON_LAZY_SYMBOL_POINTERS—This section contains only non-lazy pointers to symbols. The standard tools create a section of the __DATA,__nl_symbol_ptrs section of this type.
S_LAZY_SYMBOL_POINTERS—This section contains only lazy pointers to symbols. The standard tools create a __DATA,__la_symbol_ptrs section of this type.
S_SYMBOL_STUBS——This section contains symbol stubs. The standard tools create __TEXT,__symbol_stub and __TEXT,__picsymbol_stub sections of this type. See “Dynamic Code Generation” in Mach-O Programming Topics for more information.
S_MOD_INIT_FUNC_POINTERS—This section contains pointers to module initialization functions. The standard tools create __DATA,__mod_init_func sections of this type.
S_MOD_TERM_FUNC_POINTERS—This section contains pointers to module termination functions. The standard tools create __DATA,__mod_term_func sections of this type.
S_COALESCED—This section contains symbols that are coalesced by the static linker and possibly the dynamic linker. More than one file may contain coalesced definitions of the same symbol without causing multiple-defined-symbol errors.
S_GB_ZEROFILL—This is a zero-filled on-demand section. It can be larger than 4 GB. This section must be placed in a segment containing only zero-filled sections. If you place a zero-filled section in a segment with non–zero-filled sections, you may cause those sections to be unreachable with a 31-bit offset. That outcome stems from the fact that the size of a zero-filled section can be larger than 4 GB (in a 32-bit address space). As a result of this, the static linker would be unable to build the output file. See segment_command for more information.

The following are the possible attributes of a section:
S_ATTR_PURE_INSTRUCTIONS—This section contains only executable machine instructions. The standard tools set this flag for the sections __TEXT,__text, __TEXT,__symbol_stub, and __TEXT,__picsymbol_stub.
S_ATTR_SOME_INSTRUCTIONS—This section contains executable machine instructions.
S_ATTR_NO_TOC—This section contains coalesced symbols that must not be placed in the table of contents (SYMDEF member) of a static archive library.
S_ATTR_EXT_RELOC—This section contains references that must be relocated. These references refer to data that exists in other files (undefined symbols). To support external relocation, the maximum virtual memory protections of the segment that contains this section must allow both reading and writing.
S_ATTR_LOC_RELOC—This section contains references that must be relocated. These references refer to data within this file.
S_ATTR_STRIP_STATIC_SYMS—The static symbols in this section can be stripped if the MH_DYLDLINK flag of the image’s mach_header header structure is set.
S_ATTR_NO_DEAD_STRIP—This section must not be dead-stripped. See “Linking” in Xcode User Guide for details.
S_ATTR_LIVE_SUPPORT—This section must not be dead-stripped if they reference code that is live, but the reference is undetectable.
reserved1

An integer reserved for use with certain section types. For symbol pointer sections and symbol stubs sections that refer to indirect symbol table entries, this is the index into the indirect table for this section’s entries. The number of entries is based on the section size divided by the size of the symbol pointer or stub. Otherwise, this field is set to 0.
reserved2

For sections of type S_SYMBOL_STUBS, an integer specifying the size (in bytes) of the symbol stub entries contained in the section. Otherwise, this field is reserved for future use and should be set to 0.
Discussion

Each section in a Mach-O file has both a type and a set of attribute flags. In intermediate object files, the type and attributes determine how the static linker copies the sections into the final product. Object file analysis tools (such as otool) use the type and attributes to determine how to read and display the sections. Some section types and attributes are used by the dynamic linker.

These are important static-linking variants of the symbol type and attributes:
Regular sections. In a regular section, only one definition of an external symbol may exist in intermediate object files. The static linker returns an error if it finds any duplicate external symbol definitions.
Coalesced sections. In the final product, the static linker retains only one instance of each symbol defined in coalesced sections. To support complex language features (such as C++ vtables and RTTI) the compiler may create a definition of a particular symbol in every intermediate object file. The static linker and the dynamic linker would then reduce the duplicate definitions to the single definition used by the program.
Coalesced sections with weak definitions Weak symbol definitions may appear only in coalesced sections. When the static linker finds duplicate definitions for a symbol, it discards any coalesced symbol definition that has the weak definition attribute set (see nlist). If there are no non-weak definitions, the first weak definition is used instead. This feature is designed to support C++ templates; it allows explicit template instantiations to override implicit ones. The C++ compiler places explicit definitions in a regular section, and it places implicit definitions in a coalesced section, marked as weak definitions. Intermediate object files (and thus static archive libraries) built with weak definitions can be used only with the static linker in Mac OS X v10.2 and later. Final products (applications and shared libraries) should not contain weak definitions if they are expected to be used on earlier versions of Mac OS X.*/
struct section
   {
   char sectname[16];
   char segname[16];
   uint32_t addr;
   uint32_t size;
   uint32_t offset;
   uint32_t align;
   uint32_t reloff;
   uint32_t nreloc;
   uint32_t flags;
   uint32_t reserved1;
   uint32_t reserved2;
};

/*segment_command

Specifies the range of bytes in a 32-bit Mach-O file that make up a segment. Those bytes are mapped by the loader into the address space of a program. Declared in /usr/include/mach-o/loader.h. See also segment_command_64.

struct segment_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
   char segname[16];
   uint32_t vmaddr;
   uint32_t vmsize;
   uint32_t fileoff;
   uint32_t filesize;
   vm_prot_t maxprot;
   vm_prot_t initprot;
   uint32_t nsects;
   uint32_t flags;
};

Fields
cmd

Common to all load command structures. Set to LC_SEGMENT for this structure.
cmdsize

Common to all load command structures. For this structure, set this field to sizeof(segment_command) plus the size of all the section data structures that follow (sizeof(segment_command + (sizeof(section) * segment->nsect))).
segname

A C string specifying the name of the segment. The value of this field can be any sequence of ASCII characters, although segment names defined by Apple begin with two underscores and consist of capital letters (as in __TEXT and __DATA). This field is fixed at 16 bytes in length.
vmaddr

Indicates the starting virtual memory address of this segment.
vmsize

Indicates the number of bytes of virtual memory occupied by this segment. See also the description of filesize, below.
fileoff

Indicates the offset in this file of the data to be mapped at vmaddr.
filesize

Indicates the number of bytes occupied by this segment on disk. For segments that require more memory at runtime than they do at build time, vmsize can be larger than filesize. For example, the __PAGEZERO segment generated by the linker for MH_EXECUTABLE files has a vmsize of 0x1000 but a filesize of 0. Because __PAGEZERO contains no data, there is no need for it to occupy any space until runtime. Also, the static linker often allocates uninitialized data at the end of the __DATA segment; in this case, the vmsize is larger than the filesize. The loader guarantees that any memory of this sort is initialized with zeros.
maxprot

Specifies the maximum permitted virtual memory protections of this segment.
initprot

Specifies the initial virtual memory protections of this segment.
nsects

Indicates the number of section data structures following this load command.
flags

Defines a set of flags that affect the loading of this segment:
SG_HIGHVM—The file contents for this segment are for the high part of the virtual memory space; the low part is zero filled (for stacks in core files).
SG_NORELOC—This segment has nothing that was relocated in it and nothing relocated to it. It may be safely replaced without relocation.
Special Considerations

Segments with sections of type S_GB_ZEROFILL are placed after all other segments. See section for additional information*/
struct segment_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
   char segname[16];
   uint32_t vmaddr;
   uint32_t vmsize;
   uint32_t fileoff;
   uint32_t filesize;
   vm_prot_t maxprot;
   vm_prot_t initprot;
   uint32_t nsects;
   uint32_t flags;
};

/*load_command

Contains fields that are common to all load commands.

struct load_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
};

Fields
cmd

An integer indicating the type of load command. Table 4 lists the valid load command types.
cmdsize

An integer specifying the total size in bytes of the load command data structure. Each load command structure contains a different set of data, depending on the load command type, so each might have a different size. In 32-bit architectures, the size must always be a multiple of 4; in 64-bit architectures, the size must always be a multiple of 8. If the load command data does not divide evenly by 4 or 8 (depending on whether the target architecture is 32-bit or 64-bit, respectively), add bytes containing zeros to the end until it does.
Discussion

Table 4 lists the valid load command types, with links to the full data structures for each type.
Table 4  Mach-O load commands
Commands	
Data structures	
Purpose

LC_UUID	
uuid_command	
Specifies the 128-bit UUID for an image or its corresponding dSYM file.

LC_SEGMENT	
segment_command	
Defines a segment of this file to be mapped into the address space of the process that loads this file. It also includes all the sections contained by the segment.

LC_SEGMENT_64	
segment_command_64	
Defines a 64-bit segment of this file to be mapped into the address space of the process that loads this file. It also includes all the sections contained by the segment.

LC_SYMTAB	
symtab_command	
Specifies the symbol table for this file. This information is used by both static and dynamic linkers when linking the file, and also by debuggers to map symbols to the original source code files from which the symbols were generated.

LC_DYSYMTAB	
dysymtab_command	
Specifies additional symbol table information used by the dynamic linker.

LC_THREAD LC_UNIXTHREAD	
thread_command	
For an executable file, the LC_UNIXTHREAD command defines the initial thread state of the main thread of the process. LC_THREAD is similar to LC_UNIXTHREAD but does not cause the kernel to allocate a stack.

LC_LOAD_DYLIB	
dylib_command	
Defines the name of a dynamic shared library that this file links against.

LC_ID_DYLIB	
dylib_command	
Specifies the install name of a dynamic shared library.

LC_PREBOUND_DYLIB	
prebound_dylib_command	
For a shared library that this executable is linked prebound against, specifies the modules in the shared library that are used.

LC_LOAD_DYLINKER	
dylinker_command	
Specifies the dynamic linker that the kernel executes to load this file.

LC_ID_DYLINKER	
dylinker_command	
Identifies this file as a dynamic linker.

LC_ROUTINES	
routines_command	
Contains the address of the shared library initialization routine (specified by the linker’s -init option).

LC_ROUTINES_64	
routines_command_64	
Contains the address of the shared library 64-bit initialization routine (specified by the linker’s -init option).

LC_TWOLEVEL_HINTS	
twolevel_hints_command	
Contains the two-level namespace lookup hint table.

LC_SUB_FRAMEWORK	
sub_framework_command	
Identifies this file as the implementation of a subframework of an umbrella framework. The name of the umbrella framework is stored in the string parameter.

LC_SUB_UMBRELLA	
sub_umbrella_command	
Specifies a file that is a subumbrella of this umbrella framework.

LC_SUB_LIBRARY	
sub_library_command	
Identifies this file as the implementation of a sublibrary of an umbrella framework. The name of the umbrella framework is stored in the string parameter. Note that Apple has not defined a supported location for sublibraries.

LC_SUB_CLIENT	
sub_client_command	
A subframework can explicitly allow another framework or bundle to link against it by including an LC_SUB_CLIENT load command containing the name of the framework or a client name for a bundle.

Declared In
/usr/include/mach-o/loader.h*/

struct load_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
};

/*thread_command

Defines the attributes of the LC_THREAD and LC_UNIXTHREAD load commands. The data of this command is specific to each architecture and appears in thread_status.h, located in the architecture’s directory in /usr/include/mach. Declared in /usr/include/mach-o/loader.h.

struct thread_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
   // uint32_t flavor;
   // uint32_t count; 
   // struct cpu_thread_state state;
};

Fields
cmd

Common to all load command structures. For this structure, set to LC_THREAD or LC_UNIXTHREAD.
cmdsize

Common to all load command structures. For this structure, set to sizeof(thread_command) plus the size of the flavor and count fields plus the size of the CPU-specific thread state data structure.
flavor

Integer specifying the particular flavor of the thread state data structure. See the thread_status.h file for your target architecture.
count

Size of the thread state data, in number of 32-bit integers. The thread state data structure must be fully padded to 32-bit alignment.*/
struct thread_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
   /* uint32_t flavor;*/
   /* uint32_t count; */
   /* struct cpu_thread_state state;*/
};

/*symtab_command

Defines the attributes of the LC_SYMTAB load command. Describes the size and location of the symbol table data structures. Declared in /usr/include/mach-o/loader.h.

struct symtab_command
   {
   uint_32 cmd;
   uint_32 cmdsize;
   uint_32 symoff;
   uint_32 nsyms;
   uint_32 stroff;
   uint_32 strsize;
};

Fields
cmd

Common to all load command structures. For this structure, set to LC_SYMTAB.
cmdsize

Common to all load command structures. For this structure, set to sizeof(symtab_command).
symoff

An integer containing the byte offset from the start of the file to the location of the symbol table entries. The symbol table is an array of nlist data structures.
nsyms

An integer indicating the number of entries in the symbol table.
stroff

An integer containing the byte offset from the start of the image to the location of the string table.
strsize

An integer indicating the size (in bytes) of the string table.
Discussion

LC_SYMTAB should exist in both statically linked and dynamically linked file types.*/
struct symtab_command
   {
   uint_32 cmd;
   uint_32 cmdsize;
   uint_32 symoff;
   uint_32 nsyms;
   uint_32 stroff;
   uint_32 strsize;
};

/*uuid_command

Specifies the 128-bit universally unique identifier (UUID) for an image or for its corresponding dSYM file.

struct uuid_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
   uint8_t uuid[16];
};
Fields
cmd

Set to LC_UUID for this structure.
cmdsize

Set to sizeof(uuid_command).
uuid

128-bit unique identifier.
Declared In
/usr/include/mach-o/loader.h*/
struct uuid_command
   {
   uint32_t cmd;
   uint32_t cmdsize;
   uint8_t uuid[16];
};

#define HYS_MACH_O_LOADER_H_END
#include <HYS/mach-o/loader.h>
#undef HYS_MACH_O_LOADER_H_END

#endif//MACH_O_LOADER_H
