#ifndef	MACH_MACH_PORT_H
#define	MACH_MACH_PORT_H


#include <string.h>
#include <mach/ndr.h>
#include <mach/boolean.h>
#include <mach/kern_return.h>
#include <mach/notify.h>
#include <mach/mach_types.h>
#include <mach/message.h>
#include <mach/mig_errors.h>
#include <mach/port.h>
#include <mach/std_types.h>
#include <mach/mig.h>
#include <mach/mach_types.h>
#include <mach_debug/mach_debug_types.h>
#include <sys/cdefs.h>

#include <HYS/mach/mach_port.h>

//func
/*
Function: kern_return_t mach_port_allocate (mach_port_t task, mach_port_right_t right, mach_port_t *name)
    The mach_port_allocate function creates a new right in the specified task. The new right's name is returned in name, which may be any name that wasn't in use.

    The right argument takes the following values:

    MACH_PORT_RIGHT_RECEIVE
        mach_port_allocate creates a port. The new port is not a member of any port set. It doesn't have any extant send or send-once rights. Its make-send count is zero, its sequence number is zero, its queue limit is MACH_PORT_QLIMIT_DEFAULT, and it has no queued messages. name denotes the receive right for the new port. task does not hold send rights for the new port, only the receive right. mach_port_insert_right and mach_port_extract_right can be used to convert the receive right into a combined send/receive right. 
    MACH_PORT_RIGHT_PORT_SET
        mach_port_allocate creates a port set. The new port set has no members. 
    MACH_PORT_RIGHT_DEAD_NAME
        mach_port_allocate creates a dead name. The new dead name has one user reference. 

    The function returns KERN_SUCCESS if the call succeeded, KERN_INVALID_TASK if task was invalid, KERN_INVALID_VALUE if right was invalid, KERN_NO_SPACE if there was no room in task's IPC name space for another right and KERN_RESOURCE_SHORTAGE if the kernel ran out of memory.

    The mach_port_allocate call is actually an RPC to task, normally a send right for a task port, but potentially any send right. In addition to the normal diagnostic return codes from the call's server (normally the kernel), the call may return mach_msg return codes. */
kern_return_t mach_port_allocate (mach_port_t task, mach_port_right_t right, mach_port_t *name);

#endif//MACH_MACH_PORT_H
