#ifndef __KPI_PROTOCOL__
#define __KPI_PROTOCOL__
#include <sys/kernel_types.h>
#include <net/kpi_interface.h>


//__BEGIN_DECLS

/*proto_plumb_handler

typedef errno_t (*proto_plumb_handler)(
    ifnet_t ifp,
    protocol_family_t protocol);  
Parameters
ifp
The interface the protocol should be attached to.
protocol_family
The protocol that should be attached to the interface.
Return Value

A non-zero value of the attach failed. 
Discussion 

proto_plumb_handler is called to attach a protocol to an interface. A typical protocol plumb function would fill out an ifnet_attach_proto_param and call ifnet_attach_protocol.*/
typedef errno_t (*proto_plumb_handler)(
    ifnet_t ifp,
    protocol_family_t protocol);  

/*proto_unplumb_handler

typedef void (*proto_unplumb_handler)(
    ifnet_t ifp,
    protocol_family_t protocol);  
Parameters
ifp
The interface the protocol should be detached from.
protocol_family
The protocol that should be detached from the interface.
Discussion 

proto_unplumb_handler is called to detach a protocol from an interface. A typical unplumb function would call ifnet_detach_protocol and perform any necessary cleanup.*/
typedef void (*proto_unplumb_handler)(
    ifnet_t ifp,
    protocol_family_t protocol);  

//functions

/*proto_register_plumber

errno_t proto_register_plumber(
    protocol_family_t proto_fam,
    ifnet_family_t if_fam, 
    proto_plumb_handler plumb,
    proto_unplumb_handler unplumb);  
Parameters
proto_fam
The protocol family these plumbing functions will handle.
if_fam
The interface family these plumbing functions will handle.
plumb
The function to call to attach the protocol to an interface.
unplumb
The function to call to detach the protocol to an interface, may be NULL in which case ifnet_detach_protocol will be used to detach the protocol.
Return Value

A non-zero value of the attach failed. 
Discussion 

Allows the caller to specify the functions called when a protocol is attached to an interface belonging to the specified family and when that protocol is detached.*/
errno_t proto_register_plumber(
    protocol_family_t proto_fam,
    ifnet_family_t if_fam, 
    proto_plumb_handler plumb,
    proto_unplumb_handler unplumb);  

/*proto_unregister_plumber

void proto_unregister_plumber(
    protocol_family_t proto_fam,
    ifnet_family_t if_fam);  
Parameters
proto_fam
The protocol family these plumbing functions handle.
if_fam
The interface family these plumbing functions handle.
Discussion 

Unregisters a previously registered plumbing function.*/
void proto_unregister_plumber(
    protocol_family_t proto_fam,
    ifnet_family_t if_fam);  

/*proto_input

errno_t proto_input(
    protocol_family_t protocol,
    mbuf_t packet);  
Parameters
protocol
The protocol of the packet.
packet
The first packet in a chain of packets to be input.
Return Value

A errno error on failure. Unless proto_input returns zero, the caller is responsible for freeing the mbuf. 
Discussion 

Inputs a packet on the specified protocol from the input path.*/
errno_t proto_input(
    protocol_family_t protocol,
    mbuf_t packet); 

//__END_DECLS

#endif//__KPI_PROTOCOL__
