#ifndef OC_NETDB_H
#define OC_NETDB_H

#include <stdint.h>
#include <_types.h>
#include <netinet/in.h>		

#ifndef __USE_POSIX
//	#define __USE_POSIX 1//struct gaicb
#endif

#ifdef __unused
	#undef __unused
	#define __unused_def
#endif

#include "/usr/include/netdb.h"

#ifdef __unused_def
	#define __unused
	#undef __unused_def
#endif


#include <HYS/netdb.h>

//getnameinfo
#ifdef __CYGWIN__

#include <sys/socket.h>
/* GETNAMEINFO(3)           BSD Library Functions Manual           GETNAMEINFO(3)

NAME
     getnameinfo -- socket address structure to hostname and service name

SYNOPSIS
     #include <sys/socket.h>
     #include <netdb.h>

     int
     getnameinfo(const struct sockaddr /restrict sa, socklen_t salen,
         char /restrict node, socklen_t nodelen, char /restrict service,
         socklen_t servicelen, int flags);

DESCRIPTION
     The getnameinfo() function is used to convert a sockaddr structure to a
     pair of host name and service strings.  It is a replacement for and pro-vides provides
     vides more flexibility than the gethostbyaddr(3) and getservbyport(3)
     functions and is the converse of the get1(3) function.

     The sockaddr structure sa should point to either a sockaddr_in or
     sockaddr_in6 structure (for IPv4 or IPv6 respectively) that is salen
     bytes long.

     The host and service names associated with sa are stored in node and
     service which have length parameters nodelen and servicelen.  The maximum
     value for nodelen is NI_MAXHOST and the maximum value for servicelen is
     NI_MAXSERV, as defined by <netdb.h>.  If a length parameter is zero, no
     string will be stored.  Otherwise, enough space must be provided to store
     the host name or service string plus a byte for the NUL terminator.

     The flags argument is formed by OR'ing the following values:

     NI_NOFQDN         A fully qualified domain name is not required for local
                       hosts.  The local part of the fully qualified domain
                       name is returned instead.

     NI_NUMERICHOST    Return the address in numeric form, as if calling
                       inet_ntop(3), instead of a host name.

     NI_NAMEREQD       A name is required.  If the host name cannot be found
                       in DNS and this flag is set, a non-zero error code is
                       returned.  If the host name is not found and the flag
                       is not set, the address is returned in numeric form.

     NI_NUMERICSERV    The service name is returned as a digit string repre-senting representing
                       senting the port number.

     NI_DGRAM          Specifies that the service being looked up is a data-gram datagram
                       gram service, and causes getservbyport(3) to be called
                       with a second argument of ``udp'' instead of its
                       default of ``tcp''.  This is required for the few ports
                       (512-514) that have different services for UDP and TCP.

     This implementation allows numeric IPv6 address notation with scope iden-tifier, identifier,
     tifier, as documented in chapter 11 of draft-ietf-ipv6-scoping-arch-02.txt. draft-ietf-ipv6-scopingarch-02.txt.
     arch-02.txt.  IPv6 link-local address will appear as a string like
     ``fe80::1%ne0''.  Refer to getaddrinfo(3) for more information.

RETURN VALUES
     getnameinfo() returns zero on success or one of the error codes listed in
     gai_strerror(3) if an error occurs.

EXAMPLES
     The following code tries to get a numeric host name, and service name,
     for a given socket address.  Observe that there is no hardcoded reference
     to a particular address family.

           struct sockaddr /sa;    // input //
           char hbuf[NI_MAXHOST], sbuf[NI_MAXSERV];

           if (getnameinfo(sa, sa->sa_len, hbuf, sizeof(hbuf), sbuf,
               sizeof(sbuf), NI_NUMERICHOST | NI_NUMERICSERV)) {
                   errx(1, "could not get numeric hostname");
                   //NOTREACHED//
           }
           printf("host=%s, serv=%s\n", hbuf, sbuf);

     The following version checks if the socket address has a reverse address
     mapping:

           struct sockaddr /sa;    // input //
           char hbuf[NI_MAXHOST];

           if (getnameinfo(sa, sa->sa_len, hbuf, sizeof(hbuf), NULL, 0,
               NI_NAMEREQD)) {
                   errx(1, "could not resolve hostname");
                   //NOTREACHED//
           }
           printf("host=%s\n", hbuf);

LEGACY SYNOPSIS
     #include <sys/types.h>
     #include <sys/socket.h>
     #include <netdb.h>

     The include file <sys/types.h> is necessary.

     int getnameinfo(const struct sockaddr /restrict sa, socklen_t salen,
     char /restrict node, size_t nodelen, char /service, size_t servicelen,
     int flags);

     The type of nodelen and servicelen has changed.

SEE ALSO
     gai_strerror(3), getaddrinfo(3), gethostbyaddr(3), getservbyport(3),
     inet_ntop(3), resolver(3), hosts(5), resolv.conf(5), services(5),
     hostname(7), named(8)

     R. Gilligan, S. Thomson, J. Bound, and W. Stevens, Basic Socket Interface
     Extensions for IPv6, RFC 2553, March 1999.

     S. Deering, B. Haberman, T. Jinmei, E. Nordmark, and B. Zill, IPv6 Scoped
     Address Architecture, internet draft, draft-ietf-ipv6-scoping-arch-02.txt, draft-ietf-ipv6-scopingarch-02.txt,
     arch-02.txt, work in progress material.

     Craig Metz, "Protocol Independence Using the Sockets API", Proceedings of
     the FREENIX track: 2000 USENIX annual technical conference, June 2000.

STANDARDS
     The getnameinfo() function is defined by the IEEE Std 1003.1g-2000
     (``POSIX.1'') draft specification and documented in RFC 2553, ``Basic
     Socket Interface Extensions for IPv6''.

CAVEATS
     getnameinfo() can return both numeric and FQDN forms of the address spec-ified specified
     ified in sa.  There is no return value that indicates whether the string
     returned in host is a result of binary to numeric-text translation (like
     inet_ntop(3)), or is the result of a DNS reverse lookup.  Because of
     this, malicious parties could set up a PTR record as follows:

           1.0.0.127.in-addr.arpa. IN PTR  10.1.1.1

     and trick the caller of getnameinfo() into believing that sa is 10.1.1.1
     when it is actually 127.0.0.1.

     To prevent such attacks, the use of NI_NAMEREQD is recommended when the
     result of getnameinfo() is used for access control purposes:

           struct sockaddr /sa;
           socklen_t salen;
           char addr[NI_MAXHOST];
           struct addrinfo hints, /res;
           int error;

           error = getnameinfo(sa, salen, addr, sizeof(addr),
               NULL, 0, NI_NAMEREQD);
           if (error == 0) {
                   memset(&hints, 0, sizeof(hints));
                   hints.ai_socktype = SOCK_DGRAM; //dummy//
                   hints.ai_flags = AI_NUMERICHOST;
                   if (getaddrinfo(addr, "0", &hints, &res) == 0) {
                           // malicious PTR record //
                           freeaddrinfo(res);
                           printf("bogus PTR record\n");
                           return -1;
                   }
                   // addr is FQDN as a result of PTR lookup //
           } else {
                   // addr is numeric string //
                   error = getnameinfo(sa, salen, addr, sizeof(addr),
                       NULL, 0, NI_NUMERICHOST);
           }

BSD                            December 20, 2004                           BSD
 */
 int getnameinfo(const struct sockaddr *restrict_sa, socklen_t salen,
         char *restrict_node, socklen_t nodelen, char *restrict_service,
         socklen_t servicelen, int flags);
#endif
	
/*GETIPNODEBYNAME(3)       BSD Library Functions Manual       GETIPNODEBYNAME(3)

NAME
     getipnodebyname, getipnodebyaddr, freehostent -- nodename-to-address and address-to-nodename transla-tion translation
     tion

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <sys/types.h>
     #include <sys/socket.h>
     #include <netdb.h>

     struct hostent *
     getipnodebyname(const char *name, int af, int flags, int *error_num);

     struct hostent *
     getipnodebyaddr(const void *src, size_t len, int af, int *error_num);

     void
     freehostent(struct hostent *ptr);

DESCRIPTION
     getipnodebyname() and getipnodebyaddr() functions are very similar to gethostbyname(3),
     gethostbyname2(3) and gethostbyaddr(3).  The functions cover all the functionalities provided by the
     older ones, and provide better interface to programmers.  The functions require additional arguments,
     af, and flags, for specifying address family and operation mode.  The additional arguments allow pro-grammer programmer
     grammer to get address for a nodename, for specific address family (such as AF_INET or AF_INET6).  The
     functions also require an additional pointer argument, error_num to return the appropriate error code,
     to support thread safe error code returns.

     The type and usage of the return value, struct hostent is described in gethostbyname(3).

     For getipnodebyname(), the name argument can be either a node name or a numeric address string (i.e., a
     dotted-decimal IPv4 address or an IPv6 hex address).  The af argument specifies the address family,
     either AF_INET or AF_INET6.  The flags argument specifies the types of addresses that are searched for,
     and the types of addresses that are returned.  We note that a special flags value of AI_DEFAULT
     (defined below) should handle most applications.  That is, porting simple applications to use IPv6
     replaces the call

        hptr = gethostbyname(name);

     with

        hptr = getipnodebyname(name, AF_INET6, AI_DEFAULT, &error_num);

     Applications desiring finer control over the types of addresses searched for and returned, can specify
     other combinations of the flags argument.

     A flags of 0 implies a strict interpretation of the af argument:

     oo   If flags is 0 and af is AF_INET, then the caller wants only IPv4 addresses.  A query is made for A
         records.  If successful, the IPv4 addresses are returned and the h_length member of the hostent
         structure will be 4, else the function returns a NULL pointer.

     oo   If flags is 0 and if af is AF_INET6, then the caller wants only IPv6 addresses.  A query is made
         for AAAA records.  If successful, the IPv6 addresses are returned and the h_length member of the
         hostent structure will be 16, else the function returns a NULL pointer.

     Other constants can be logically-ORed into the flags argument, to modify the behavior of the function.

     oo   If the AI_V4MAPPED flag is specified along with an af of AF_INET6, then the caller will accept
         IPv4-mapped IPv6 addresses.  That is, if no AAAA records are found then a query is made for A
         records and any found are returned as IPv4-mapped IPv6 addresses (h_length will be 16).  The
         AI_V4MAPPED flag is ignored unless af equals AF_INET6.

     oo   The AI_V4MAPPED_CFG flag is exact same as the AI_V4MAPPED flag only if the kernel supports
         IPv4-mapped IPv6 address.

     oo   If the AI_ALL flag is used in conjunction with the AI_V4MAPPED flag, and only used with the IPv6
         address family.  When AI_ALL is logically or'd with AI_V4MAPPED flag then the caller wants all
         addresses: IPv6 and IPv4-mapped IPv6.  A query is first made for AAAA records and if successful,
         the IPv6 addresses are returned.  Another query is then made for A records and any found are
         returned as IPv4-mapped IPv6 addresses.  h_length will be 16.  Only if both queries fail does the
         function return a NULL pointer.  This flag is ignored unless af equals AF_INET6.  If both AI_ALL
         and AI_V4MAPPED are specified, AI_ALL takes precedence.

     oo   The AI_ADDRCONFIG flag specifies that a query for AAAA records should occur only if the node has at
         least one IPv6 source address configured and a query for A records should occur only if the node
         has at least one IPv4 source address configured.

         For example, if the node has no IPv6 source addresses configured, and af equals AF_INET6, and the
         node name being looked up has both AAAA and A records, then: (a) if only AI_ADDRCONFIG is speci-fied, specified,
         fied, the function returns a NULL pointer; (b) if AI_ADDRCONFIG | AI_V4MAPPED is specified, the A
         records are returned as IPv4-mapped IPv6 addresses;

     The special flags value of AI_DEFAULT is defined as

        #define  AI_DEFAULT  (AI_V4MAPPED_CFG | AI_ADDRCONFIG)

     We noted that the getipnodebyname() function must allow the name argument to be either a node name or a
     literal address string (i.e., a dotted-decimal IPv4 address or an IPv6 hex address).  This saves appli-cations applications
     cations from having to call inet_pton(3) to handle literal address strings.  When the name argument is
     a literal address string, the flags argument is always ignored.

     There are four scenarios based on the type of literal address string and the value of the af argument.
     The two simple cases are when name is a dotted-decimal IPv4 address and af equals AF_INET, or when name
     is an IPv6 hex address and af equals AF_INET6.  The members of the returned hostent structure are:
     h_name points to a copy of the name argument, h_aliases is a NULL pointer, h_addrtype is a copy of the
     af argument, h_length is either 4 (for AF_INET) or 16 (for AF_INET6), h_addr_list[0] is a pointer to
     the 4-byte or 16-byte binary address, and h_addr_list[1] is a NULL pointer.

     When name is a dotted-decimal IPv4 address and af equals AF_INET6, and AI_V4MAPPED is specified, an
     IPv4-mapped IPv6 address is returned: h_name points to an IPv6 hex address containing the IPv4-mapped
     IPv6 address, h_aliases is a NULL pointer, h_addrtype is AF_INET6, h_length is 16, h_addr_list[0] is a
     pointer to the 16-byte binary address, and h_addr_list[1] is a NULL pointer.

     It is an error when name is an IPv6 hex address and af equals AF_INET.  The function's return value is
     a NULL pointer and the value pointed to by error_num equals HOST_NOT_FOUND.

     getipnodebyaddr() takes almost the same argument as gethostbyaddr(3), but adds a pointer to return an
     error number.  Additionally it takes care of IPv4-mapped IPv6 addresses, and IPv4-compatible IPv6
     addresses.

     getipnodebyname() and getipnodebyaddr() dynamically allocate the structure to be returned to the
     caller.  freehostent() reclaims memory region allocated and returned by getipnodebyname() or
     getipnodebyaddr().

FILES
     /etc/hosts
     /etc/host.conf
     /etc/resolv.conf

DIAGNOSTICS
     getipnodebyname() and getipnodebyaddr() returns NULL on errors.  The integer values pointed to by
     error_num may then be checked to see whether this is a temporary failure or an invalid or unknown host.
     The meanings of each error code are described in gethostbyname(3).

SEE ALSO
     gethostbyaddr(3), gethostbyname(3), hosts(5), services(5), hostname(7), named(8)

     R. Gilligan, S. Thomson, J. Bound, and W. Stevens, Basic Socket Interface Extensions for IPv6, RFC2553,
     March 1999.

HISTORY
     The implementation first appeared in KAME advanced networking kit.

STANDARDS
     getipnodebyname() and getipnodebyaddr() are documented in ``Basic Socket Interface Extensions for
     IPv6'' (RFC2553).

BUGS
     getipnodebyname() and getipnodebyaddr() do not handle scoped IPv6 address properly.  If you use these
     functions, your program will not be able to handle scoped IPv6 addresses.  For IPv6 address manipula-tion, manipulation,
     tion, getaddrinfo(3) and getnameinfo(3) are recommended.

     The text was shamelessly copied from RFC2553.

BSD                              May 25, 1995                              BSD*/
     struct hostent * getipnodebyname(const char *name, int af, int flags, int *error_num);
    void     freehostent(struct hostent *ptr);
     struct hostent *
     getipnodebyaddr(const void *src, size_t len, int af, int *error_num);

/*GETADDRINFO(3)           BSD Library Functions Manual           GETADDRINFO(3)

NAME
     freeaddrinfo, getaddrinfo -- socket address structure to host and service name

SYNOPSIS
     #include <sys/socket.h>
     #include <netdb.h>

     void
     freeaddrinfo(struct addrinfo *ai);

     int
     getaddrinfo(const char *restrict nodename, const char *restrict servname,
         const struct addrinfo *restrict hints, struct addrinfo **restrict res);

DESCRIPTION
     The getaddrinfo() function is used to get a list of IP addresses and port numbers for host nodename and
     service servname.  It is a replacement for and provides more flexibility than the gethostbyname(3) and
     getservbyname(3) functions.

     The nodename and servname arguments are either pointers to NUL-terminated strings or the null pointer.
     An acceptable value for nodename is either a valid host name or a numeric host address string consist-ing consisting
     ing of a dotted decimal IPv4 address or an IPv6 address.  The servname is either a decimal port number
     or a service name listed in services(5).  At least one of nodename and servname must be non-null.

     hints is an optional pointer to a struct addrinfo, as defined by <netdb.h>:

     struct addrinfo {
             int ai_flags;           // input flags //
             int ai_family;          // protocol family for socket //
             int ai_socktype;        // socket type //
             int ai_protocol;        // protocol for socket //
             socklen_t ai_addrlen;   // length of socket-address //
             struct sockaddr *ai_addr; // socket-address for socket //
             char *ai_canonname;     // canonical name for service location //
             struct addrinfo *ai_next; // pointer to next in list //
     };

     This structure can be used to provide hints concerning the type of socket that the caller supports or
     wishes to use.  The caller can supply the following structure elements in hints:

     ai_family      The protocol family that should be used.  When ai_family is set to PF_UNSPEC, it means
                    the caller will accept any protocol family supported by the operating system.

     ai_socktype    Denotes the type of socket that is wanted: SOCK_STREAM, SOCK_DGRAM, or SOCK_RAW.  When
                    ai_socktype is zero the caller will accept any socket type.

     ai_protocol    Indicates which transport protocol is desired, IPPROTO_UDP or IPPROTO_TCP.  If
                    ai_protocol is zero the caller will accept any protocol.

     ai_flags       ai_flags is formed by OR'ing the following values:

                    AI_CANONNAME    If the AI_CANONNAME bit is set, a successful call to getaddrinfo() will
                                    return a NUL-terminated string containing the canonical name of the
                                    specified hostname in the ai_canonname element of the first addrinfo
                                    structure returned.

                    AI_NUMERICHOST  If the AI_NUMERICHOST bit is set, it indicates that nodename should be
                                    treated as a numeric string defining an IPv4 or IPv6 address and no name
                                    resolution should be attempted.

                    AI_PASSIVE      If the AI_PASSIVE bit is set it indicates that the returned socket
                                    address structure is intended for use in a call to bind(2).  In this
                                    case, if the nodename argument is the null pointer, then the IP address
                                    portion of the socket address structure will be set to INADDR_ANY for an
                                    IPv4 address or IN6ADDR_ANY_INIT for an IPv6 address.

                                    If the AI_PASSIVE bit is not set, the returned socket address structure
                                    will be ready for use in a call to connect(2) for a connection-oriented
                                    protocol or connect(2), sendto(2), or sendmsg(2) if a connectionless
                                    protocol was chosen.  The IP address portion of the socket address
                                    structure will be set to the loopback address if nodename is the null
                                    pointer and AI_PASSIVE is not set.

     All other elements of the addrinfo structure passed via hints must be zero or the null pointer.

     If hints is the null pointer, getaddrinfo() behaves as if the caller provided a struct addrinfo with
     ai_family set to PF_UNSPEC and all other elements set to zero or NULL.

     After a successful call to getaddrinfo(), *res is a pointer to a linked list of one or more addrinfo
     structures.  The list can be traversed by following the ai_next pointer in each addrinfo structure
     until a null pointer is encountered.  The three members ai_family, ai_socktype, and ai_protocol in each
     returned addrinfo structure are suitable for a call to socket(2).  For each addrinfo structure in the
     list, the ai_addr member points to a filled-in socket address structure of length ai_addrlen.

     This implementation of getaddrinfo() allows numeric IPv6 address notation with scope identifier, as
     documented in chapter 11 of draft-ietf-ipv6-scoping-arch-02.txt.  By appending the percent character
     and scope identifier to addresses, one can fill the sin6_scope_id field for addresses.  This would make
     management of scoped addresses easier and allows cut-and-paste input of scoped addresses.

     At this moment the code supports only link-local addresses with the format.  The scope identifier is
     hardcoded to the name of the hardware interface associated with the link (such as ne0).  An example is
     ``fe80::1%ne0'', which means ``fe80::1 on the link associated with the ne0 interface''.

     The current implementation assumes a one-to-one relationship between the interface and link, which is
     not necessarily true from the specification.

     All of the information returned by getaddrinfo() is dynamically allocated: the addrinfo structures
     themselves as well as the socket address structures and the canonical host name strings included in the
     addrinfo structures.

     Memory allocated for the dynamically allocated structures created by a successful call to getaddrinfo()
     is released by the freeaddrinfo() function.  The ai pointer should be a addrinfo structure created by a
     call to getaddrinfo().

RETURN VALUES
     getaddrinfo() returns zero on success or one of the error codes listed in gai_strerror(3) if an error
     occurs.

EXAMPLES
     The following code tries to connect to ``www.kame.net'' service ``http'' via a stream socket.  It loops
     through all the addresses available, regardless of address family.  If the destination resolves to an
     IPv4 address, it will use an AF_INET socket.  Similarly, if it resolves to IPv6, an AF_INET6 socket is
     used.  Observe that there is no hardcoded reference to a particular address family.  The code works
     even if getaddrinfo() returns addresses that are not IPv4/v6.

           struct addrinfo hints, *res, *res0;
           int error;
           int s;
           const char *cause = NULL;

           memset(&hints, 0, sizeof(hints));
           hints.ai_family = PF_UNSPEC;
           hints.ai_socktype = SOCK_STREAM;
           error = getaddrinfo("www.kame.net", "http", &hints, &res0);
           if (error) {
                   errx(1, "%s", gai_strerror(error));
                   //NOTREACHED//
           }
           s = -1;
           for (res = res0; res; res = res->ai_next) {
                   s = socket(res->ai_family, res->ai_socktype,
                       res->ai_protocol);
                   if (s < 0) {
                           cause = "socket";
                           continue;
                   }

                   if (connect(s, res->ai_addr, res->ai_addrlen) < 0) {
                           cause = "connect";
                           close(s);
                           s = -1;
                           continue;
                   }

                   break;  // okay we got one //
           }
           if (s < 0) {
                   err(1, "%s", cause);
                   //NOTREACHED//
           }
           freeaddrinfo(res0);

     The following example tries to open a wildcard listening socket onto service ``http'', for all the
     address families available.

           struct addrinfo hints, *res, *res0;
           int error;
           int s[MAXSOCK];
           int nsock;
           const char *cause = NULL;

           memset(&hints, 0, sizeof(hints));
           hints.ai_family = PF_UNSPEC;
           hints.ai_socktype = SOCK_STREAM;
           hints.ai_flags = AI_PASSIVE;
           error = getaddrinfo(NULL, "http", &hints, &res0);
           if (error) {
                   errx(1, "%s", gai_strerror(error));
                   //NOTREACHED//
           }
           nsock = 0;
           for (res = res0; res && nsock < MAXSOCK; res = res->ai_next) {
                   s[nsock] = socket(res->ai_family, res->ai_socktype,
                       res->ai_protocol);
                   if (s[nsock] < 0) {
                           cause = "socket";
                           continue;
                   }

                   if (bind(s[nsock], res->ai_addr, res->ai_addrlen) < 0) {
                           cause = "bind";
                           close(s[nsock]);
                           continue;
                   }
                   (void) listen(s[nsock], 5);

                   nsock++;
           }
           if (nsock == 0) {
                   err(1, "%s", cause);
                   //NOTREACHED//
           }
           freeaddrinfo(res0);

LEGACY SYNOPSIS
     #include <sys/types.h>
     #include <sys/socket.h>
     #include <netdb.h>

     The include file <sys/types.h> is necessary.

SEE ALSO
     bind(2), connect(2), send(2), socket(2), gai_strerror(3), gethostbyname(3), getnameinfo(3),
     getservbyname(3), resolver(3), hosts(5), resolv.conf(5), services(5), hostname(7), named(8)

     R. Gilligan, S. Thomson, J. Bound, J. McCann, and W. Stevens, Basic Socket Interface Extensions for
     IPv6, RFC 3493, February 2003.

     S. Deering, B. Haberman, T. Jinmei, E. Nordmark, and B. Zill, IPv6 Scoped Address Architecture,
     internet draft, draft-ietf-ipv6-scoping-arch-02.txt, work in progress material.

     Craig Metz, "Protocol Independence Using the Sockets API", Proceedings of the freenix track: 2000
     USENIX annual technical conference, June 2000.

STANDARDS
     The getaddrinfo() function is defined by the IEEE Std 1003.1g-2000 (``POSIX.1'') draft specification
     and documented in RFC 3493, ``Basic Socket Interface Extensions for IPv6''.

BSD                            December 20, 2004                           BSD
*/
    
#ifndef restrict
		#define restrict __restrict
#endif		
#ifdef __CYGWIN__

	 int
     getaddrinfo(const char *restrict nodename, const char *restrict servname,
         const struct addrinfo *restrict hints, struct addrinfo **restrict res);
	
     void
     freeaddrinfo(struct addrinfo *ai);
#endif	//__CYGWIN__

#endif//OC_NETDB_H

