#ifndef __NOTIFICATION_H__
#define __NOTIFICATION_H__

#include <sys/cdefs.h>
#include <stdint.h>
#include <mach/message.h>

/*NOTIFY_STATUS_OK

See Also:
Status Codes
#define NOTIFY_STATUS_OK 0 
Discussion 

Status codes returned by the API.*/
#define NOTIFY_STATUS_OK 0 

/*NOTIFY_REUSE

#define NOTIFY_REUSE 0x00000001 
Discussion 

Flag bits used for registration.*/
#define NOTIFY_REUSE 0x00000001 

__BEGIN_DECLS

/*notify_cancel

uint32_t notify_cancel(
    int token);  
Parameters
token
(input) notification token
Return Value

Returns status. 
Discussion 

Cancel notification and free resources associated with a notification token. Mach ports and file descriptor associated with a token are released (deallocated or closed) when all registration tokens associated with the port or file descriptor have been cancelled.*/
uint32_t notify_cancel(
    int token);  

/*notify_set_state


uint32_t notify_set_state(
    int token,
    uint64_t state64) ;  
Parameters
token
(input) notification token
state64
(input) 64-bit unsigned integer value
Return Value

Returns status. 
Discussion 

Set or get a state value associated with a notification token. Each key in the notification namespace has an associated integer value available for use by clients as for application-specific purposes. A common usage is to allow two processes or threads to synchronize their activities. For example, a server process may need send a notification when a resource becomes available. A client process can register for the notification, but when it starts up it will not know whether the resource is available. The server can set the state value, and the client can check the value at startup time to synchronize with the server.
Set the 64-bit integer state value.

Availability
Introduced in Mac OS X v10.5.*/
uint32_t notify_set_state(
    int token,
    uint64_t state64) ;  

/*notify_post

uint32_t notify_post(
    const char *name);  
Discussion 

Post a notification for a name. 

This is the only call that is required for a notification producer. Returns status.*/
uint32_t notify_post(
    const char *name);  

__END_DECLS

#endif //__NOTIFICATION_H__

