#ifndef OC_RPC_NETDB_H
#define OC_RPC_NETDB_H

#define getrpcbynumber orig_getrpcbynumber
#include "/usr/include/rpc/netdb.h"
#undef getrpcbynumber

/*GETRPCENT(3)             BSD Library Functions Manual             GETRPCENT(3)

NAME
     getrpcent, getrpcbyname, getrpcbynumber, endrpcent, setrpcent -- get RPC entry

SYNOPSIS
     #include <netdb.h>

     struct rpcent *
     getrpcent(void);

     struct rpcent *
     getrpcbyname(char *name);

     struct rpcent *
     getrpcbynumber(int number);

     void
     setrpcent(int stayopen);

     void
     endrpcent(void);

DESCRIPTION
     getrpcent(), getrpcbyname(), and getrpcbynumber(), each return a pointer to an object with the follow-ing following
     ing structure containing the broken-out fields of a line in the rpc program number data base, /etc/rpc:

           struct rpcent {
                   char    *r_name;        // name of server for this rpc program 
                   char    **r_aliases;    // alias list 
                   long    r_number;       // rpc program number 
           };

     The members of this structure are:

           r_name     The name of the server for this rpc program.

           r_aliases  A zero terminated list of alternate names for the rpc program.

           r_number   The rpc program number for this service.

     getrpcent() reads the next line of the file, opening the file if necessary.

     setrpcent() opens and rewinds the file.  If the stayopen flag is non-zero, the net data base will not
     be closed after each call to getrpcent() (either directly, or indirectly through one of the other
     ``getrpc'' calls).

     endrpcent() closes the file.

     getrpcbyname() and getrpcbynumber() sequentially search from the beginning of the file until a matching
     rpc program name or program number is found, or until end-of-file is encountered.

FILES
     /etc/rpc

SEE ALSO
     rpc(5), rpcinfo(8), ypserv(8)

DIAGNOSTICS
     A NULL pointer is returned on EOF or error.

BUGS
     All information is contained in a static area so it must be copied if it is to be saved.

BSD                            December 14, 1987                           BSD*/

#ifdef __LP64__
struct rpcent	*getrpcbynumber(int number);//linux
#else
struct rpcent	*getrpcbynumber(long number);
#endif


#endif//OC_RPC_NETDB_H
