#ifndef OC_SYS_FCNTL_H_
#define OC_SYS_FCNTL_H_

#include <sys/_types.h>
#include <sys/cdefs.h>

#include <HYS/sys/fcntl.h>

#ifdef __CYGWIN__

#ifdef FREAD
#undef FREAD
#endif

#ifdef FWRITE
#undef FWRITE
#endif

#ifdef O_NOFOLLOW
#undef O_NOFOLLOW
#endif

#endif//__CYGWIN__
///////////////////
#include "/usr/include/sys/fcntl.h"
////////////////////////
/*FCNTL(2)                    BSD System Calls Manual                   FCNTL(2)

NAME
     fcntl -- file control

SYNOPSIS
     #include <fcntl.h>

     int
     fcntl(int fildes, int cmd, ...);

DESCRIPTION
     Fcntl() provides for control over descriptors.  The argument fildes is a descriptor to be operated on
     by cmd as follows:

     F_DUPFD            Return a new descriptor as follows:

                            oo   Lowest numbered available descriptor greater than or equal to arg.
                            oo   Same object references as the original descriptor.
                            oo   New descriptor shares the same file offset if the object was a file.
                            oo   Same access mode (read, write or read/write).
                            oo   Same file status flags (i.e., both file descriptors share the same file sta-tus status
                                tus flags).
                            oo   The close-on-exec flag associated with the new file descriptor is set to
                                remain open across execv(2) system calls.

     F_GETFD            Get the close-on-exec flag associated with the file descriptor fildes.  If the low-order loworder
                        order bit of the returned value is 0, the file will remain open across exec(), oth-erwise otherwise
                        erwise the file will be closed upon execution of exec() (arg is ignored).

     F_SETFD            Set the close-on-exec flag associated with fildes to the low order bit of arg (0 or
                        1 as above).

     F_GETFL            Get descriptor status flags, as described below (arg is ignored).

     F_SETFL            Set descriptor status flags to arg.

     F_GETOWN           Get the process ID or process group currently receiving SIGIO and SIGURG signals;
                        process groups are returned as negative values (arg is ignored).

     F_SETOWN           Set the process or process group to receive SIGIO and SIGURG signals; process groups
                        are specified by supplying arg as negative, otherwise arg is interpreted as a
                        process ID.

     F_GETPATH          Get the path of the file descriptor Fildes.  The argument must be a buffer of size
                        MAXPATHLEN or greater.

     F_PREALLOCATE      Preallocate file storage space.

     F_SETSIZE          Truncate a file without zeroing space.  The calling process must have root privi-leges. privileges.
                        leges.

     F_RDADVISE         Issue an advisory read async with no copy to user.

     F_RDAHEAD          Turn read ahead off/on.  A zero value in arg disables read ahead.  A non-zero value
                        in arg turns read ahead on.

     F_READBOOTSTRAP    Read bootstrap from disk.

     F_WRITEBOOTSTRAP   Write bootstrap on disk.  The calling process must have root privileges.

     F_NOCACHE          Turns data caching off/on. A non-zero value in arg turns data caching off.  A value
                        of zero in arg turns data caching on.

     F_LOG2PHYS         Get disk device information.  Currently this only includes the disk device address
                        that corresponds to the current file offset.

     F_FULLFSYNC        Does the same thing as fsync(2) then asks the drive to flush all buffered data to
                        the permanent storage device (arg is ignored).  This is currently implemented on
                        HFS, MS-DOS (FAT), and Universal Disk Format (UDF) file systems.  The operation may
                        take quite a while to complete.  Certain FireWire drives have also been known to
                        ignore the request to flush their buffered data.

     The flags for the F_GETFL and F_SETFL commands are as follows:

           O_NONBLOCK   Non-blocking I/O; if no data is available to a read call, or if a write operation
                        would block, the read or write call returns -1 with the error EAGAIN.

           O_APPEND     Force each write to append at the end of file; corresponds to the O_APPEND flag of
                        open(2).

           O_ASYNC      Enable the SIGIO signal to be sent to the process group when I/O is possible, e.g.,
                        upon availability of data to be read.

     Several commands are available for doing advisory file locking; they all operate on the following
     structure:

             struct flock {
                 off_t       l_start;    // starting offset //
                 off_t       l_len;      // len = 0 means until end of file //
                 pid_t       l_pid;      // lock owner //
                 short       l_type;     // lock type: read/write, etc. //
                 short       l_whence;   // type of l_start //
             };

     The commands available for advisory record locking are as follows:

     F_GETLK    Get the first lock that blocks the lock description pointed to by the third argument, arg,
                taken as a pointer to a struct flock (see above).  The information retrieved overwrites the
                information passed to fcntl in the flock structure.  If no lock is found that would prevent
                this lock from being created, the structure is left unchanged by this function call except
                for the lock type which is set to F_UNLCK.

     F_SETLK    Set or clear a file segment lock according to the lock description pointed to by the third
                argument, arg, taken as a pointer to a struct flock (see above).  F_SETLK is used to estab-lish establish
                lish shared (or read) locks (F_RDLCK) or exclusive (or write) locks, (F_WRLCK), as well as
                remove either type of lock (F_UNLCK).  If a shared or exclusive lock cannot be set, fcntl
                returns immediately with EACCES.

     F_SETLKW   This command is the same as F_SETLK except that if a shared or exclusive lock is blocked by
                other locks, the process waits until the request can be satisfied.  If a signal that is to
                be caught is received while fcntl is waiting for a region, the fcntl will be interrupted if
                the signal handler has not specified the SA_RESTART (see sigaction(2)).

     When a shared lock has been set on a segment of a file, other processes can set shared locks on that
     segment or a portion of it.  A shared lock prevents any other process from setting an exclusive lock on
     any portion of the protected area.  A request for a shared lock fails if the file descriptor was not
     opened with read access.

     An exclusive lock prevents any other process from setting a shared lock or an exclusive lock on any
     portion of the protected area.  A request for an exclusive lock fails if the file was not opened with
     write access.

     The value of l_whence is SEEK_SET, SEEK_CUR, or SEEK_END to indicate that the relative offset, l_start
     bytes, will be measured from the start of the file, current position, or end of the file, respectively.
     The value of l_len is the number of consecutive bytes to be locked.  If l_len is negative, the result
     is undefined.  The l_pid field is only used with F_GETLK to return the process ID of the process hold-ing holding
     ing a blocking lock.  After a successful F_GETLK request, the value of l_whence is SEEK_SET.

     Locks may start and extend beyond the current end of a file, but may not start or extend before the
     beginning of the file.  A lock is set to extend to the largest possible value of the file offset for
     that file if l_len is set to zero. If l_whence and l_start point to the beginning of the file, and
     l_len is zero, the entire file is locked.  If an application wishes only to do entire file locking, the
     flock(2) system call is much more efficient.

     There is at most one type of lock set for each byte in the file.  Before a successful return from an
     F_SETLK or an F_SETLKW request when the calling process has previously existing locks on bytes in the
     region specified by the request, the previous lock type for each byte in the specified region is
     replaced by the new lock type.  As specified above under the descriptions of shared locks and exclusive
     locks, an F_SETLK or an F_SETLKW request fails or blocks respectively when another process has existing
     locks on bytes in the specified region and the type of any of those locks conflicts with the type spec-ified specified
     ified in the request.

     This interface follows the completely stupid semantics of System V and IEEE Std 1003.1-1988
     (``POSIX.1'') that require that all locks associated with a file for a given process are removed when
     any file descriptor for that file is closed by that process.  This semantic means that applications
     must be aware of any files that a subroutine library may access.  For example if an application for
     updating the password file locks the password file database while making the update, and then calls
     getpwname(3) to retrieve a record, the lock will be lost because getpwname(3) opens, reads, and closes
     the password database.  The database close will release all locks that the process has associated with
     the database, even if the library routine never requested a lock on the database.  Another minor seman-tic semantic
     tic problem with this interface is that locks are not inherited by a child process created using the
     fork(2) function.  The flock(2) interface has much more rational last close semantics and allows locks
     to be inherited by child processes.  Flock(2) is recommended for applications that want to ensure the
     integrity of their locks when using library routines or wish to pass locks to their children.  Note
     that flock(2) and fcntl(2) locks may be safely used concurrently.

     All locks associated with a file for a given process are removed when the process terminates.

     A potential for deadlock occurs if a process controlling a locked region is put to sleep by attempting
     to lock the locked region of another process.  This implementation detects that sleeping until a locked
     region is unlocked would cause a deadlock and fails with an EDEADLK error.

     The F_PREALLOCATE command operates on the following structure:

             typedef struct fstore {
                 u_int32_t fst_flags;      // IN: flags word //
                 int       fst_posmode;    // IN: indicates offset field //
                 off_t     fst_offset;     // IN: start of the region //
                 off_t     fst_length;     // IN: size of the region //
                 off_t     fst_bytesalloc; // OUT: number of bytes allocated //
             } fstore_t;

     The flags (fst_flags) for the F_PREALLOCATE command are as follows:

           F_ALLOCATECONTIG   Allocate contiguous space.

           F_ALLOCATEALL      Allocate all requested space or no space at all.

     The position modes (fst_posmode) for the F_PREALLOCATE command indicate how to use the offset field.
     The modes are as follows:

           F_PEOFPOSMODE   Allocate from the physical end of file.

           F_VOLPOSMODE    Allocate from the volume offset.

     The F_RDADVISE command operates on the following structure which holds information passed from the user
     to the system:

             struct radvisory {
                off_t   ra_offset;  // offset into the file //
                int     ra_count;   // size of the read     //
             };





     The F_READBOOTSTRAP and F_WRITEBOOTSTRAP commands operate on the following structure.

             typedef struct fbootstraptransfer {
                 off_t fbt_offset;       // IN: offset to start read/write //
                 size_t fbt_length;      // IN: number of bytes to transfer //
                 void *fbt_buffer;       // IN: buffer to be read/written //
             } fbootstraptransfer_t;

     The F_LOG2PHYS command operates on the following structure.

             struct log2phys {
                 u_int32_t   l2p_flags;              // unused so far //
                 off_t       l2p_contigbytes;        // unused so far //
                 off_t       l2p_devoffset;      // bytes into device //
             };

RETURN VALUES
     Upon successful completion, the value returned depends on cmd as follows:

           F_DUPFD    A new file descriptor.

           F_GETFD    Value of flag (only the low-order bit is defined).

           F_GETFL    Value of flags.

           F_GETOWN   Value of file descriptor owner.

           other      Value other than -1.

     Otherwise, a value of -1 is returned and errno is set to indicate the error.

ERRORS
     The fcntl() system call will fail if:

     [EACCES]           The argument cmd is F_SETLK, the type of lock (l_type) is a shared lock (F_RDLCK) or
                        exclusive lock (F_WRLCK), and the segment of a file to be locked is already exclu-sive-locked exclusive-locked
                        sive-locked by another process; or the type is an exclusive lock and some portion of
                        the segment of a file to be locked is already shared-locked or exclusive-locked by
                        another process.

                        The argument cmd is either F_SETSIZE or F_WRITEBOOTSTRAP and the calling process
                        does not have root privileges.

     [EBADF]            Fildes is not a valid open file descriptor.

                        The argument cmd is F_SETLK or F_SETLKW, the type of lock (l_type) is a shared lock
                        (F_RDLCK), and fildes is not a valid file descriptor open for reading.

                        The argument cmd is F_SETLK or F_SETLKW, the type of lock (l_type) is an exclusive
                        lock (F_WRLCK), and fildes is not a valid file descriptor open for writing.

                        The argument cmd is F_PREALLOCATE and the calling process does not have file write
                        permission.

                        The argument cmd is F_LOG2PHYS and fildes is not a valid file descriptor open for
                        reading.

     [EDEADLK]          The argument cmd is F_SETLKW, and a deadlock condition was detected.

     [EINTR]            The argument cmd is F_SETLKW, and the function was interrupted by a signal.

     [EINVAL]           Cmd is F_DUPFD and arg is negative or greater than the maximum allowable number (see
                        getdtablesize(2)).

                        The argument cmd is F_GETLK, F_SETLK, or F_SETLKW and the data to which arg points
                        is not valid, or fildes refers to a file that does not support locking.

                        The argument cmd is F_PREALLOCATE and the fst_posmode is not a valid mode, or when
                        F_PEOFPOSMODE is set and fst_offset is a non-zero value, or when F_VOLPOSMODE is set
                        and fst_offset is a negative or zero value.

                        The argument cmd is either F_READBOOTSTRAP or F_WRITEBOOTSTRAP and the operation was
                        attempted on a non-HFS disk type.

     [EMFILE]           Cmd is F_DUPFD and the maximum allowed number of file descriptors are currently
                        open.

     [EMFILE]           The argument cmd is F_DUPED and the maximum number of file descriptors permitted for
                        the process are already in use, or no file descriptors greater than or equal to arg
                        are available.

     [ENOLCK]           The argument cmd is F_SETLK or F_SETLKW, and satisfying the lock or unlock request
                        would result in the number of locked regions in the system exceeding a system-imposed systemimposed
                        imposed limit.

     [EOVERFLOW]        A return value would overflow its representation.  For example, cmd is F_GETLK,
                        F_SETLK, or F_SETLKW and the smallest (or, if l_len is non-zero, the largest) offset
                        of a byte in the requested segment will not fit in an object of type off_t.

     [ESRCH]            Cmd is F_SETOWN and the process ID given as argument is not in use.

SEE ALSO
     close(2), execve(2), flock(2), getdtablesize(2), open(2), sigaction(3)

HISTORY
     The fcntl() function call appeared in 4.2BSD.

4.2 Berkeley Distribution      January 12, 1994      4.2 Berkeley Distribution*/

             struct log2phys {
                 u_int32_t   l2p_flags;              /* unused so far */
                 off_t       l2p_contigbytes;        /* unused so far */
                 off_t       l2p_devoffset;      /* bytes into device */
             };

             typedef struct fstore {
                 u_int32_t fst_flags;      // IN: flags word //
                 int       fst_posmode;    // IN: indicates offset field //
                 off_t     fst_offset;     // IN: start of the region //
                 off_t     fst_length;     // IN: size of the region //
                 off_t     fst_bytesalloc; // OUT: number of bytes allocated //
             } fstore_t;

/*OPEN(2)                     BSD System Calls Manual                    OPEN(2)

NAME
     open -- open or create a file for reading or writing

SYNOPSIS
     #include <fcntl.h>

     int
     open(const char *path, int oflag, ...);

DESCRIPTION
     The file name specified by path is opened for reading and/or writing, as specified by the argument
     oflag; the file descriptor is returned to the calling process.

     The oflag argument may indicate that the file is to be created if it does not exist (by specifying the
     O_CREAT flag).  In this case, open requires a third argument mode_t mode; the file is created with mode
     mode as described in chmod(2) and modified by the process' umask value (see umask(2)).

     The flags specified are formed by or'ing the following values:

           O_RDONLY        open for reading only
           O_WRONLY        open for writing only
           O_RDWR          open for reading and writing
           O_NONBLOCK      do not block on open or for data to become available
           O_APPEND        append on each write
           O_CREAT         create file if it does not exist
           O_TRUNC         truncate size to 0
           O_EXCL          error if O_CREAT and the file exists
           O_SHLOCK        atomically obtain a shared lock
           O_EXLOCK        atomically obtain an exclusive lock
           O_NOFOLLOW      do not follow symlinks
           O_SYMLINK       allow open of symlinks

     Opening a file with O_APPEND set causes each write on the file to be appended to the end.  If O_TRUNC
     is specified and the file exists, the file is truncated to zero length.  If O_EXCL is set with O_CREAT
     and the file already exists, open() returns an error.  This may be used to implement a simple exclu-sive-access exclusive-access
     sive-access locking mechanism.  If O_EXCL is set and the last component of the pathname is a symbolic
     link, open() will fail even if the symbolic link points to a non-existent name.

     If the O_NONBLOCK flag is specified, do not wait for the device or file to be ready or available.  If
     the open() call would result in the process being blocked for some reason (e.g., waiting for carrier on
     a dialup line), open() returns immediately.  This flag also has the effect of making all subsequent I/O
     on the open file non-blocking.

     When opening a file, a lock with flock(2) semantics can be obtained by setting O_SHLOCK for a shared
     lock, or O_EXLOCK for an exclusive lock.  If creating a file with O_CREAT, the request for the lock
     will never fail (provided that the underlying filesystem supports locking).

     If O_NOFOLLOW is used in the mask and the target file passed to open() is a symbolic link then the
     open() will fail.

     If O_SYMLINK is used in the mask and the target file passed to open() is a symbolic link then the
     open() will be for the symbolic link itself, not what it links to.

     If successful, open() returns a non-negative integer, termed a file descriptor.  It returns -1 on fail-ure. failure.
     ure.  The file pointer (used to mark the current position within the file) is set to the beginning of
     the file.

     When a new file is created, it is given the group of the directory which contains it.

     The new descriptor is set to remain open across execve system calls; see close(2) and fcntl(2).

     The system imposes a limit on the number of file descriptors that can be held open simultaneously by
     one process.  Getdtablesize(2) returns the current system limit.

RETURN VALUES
     If successful, open() returns a non-negative integer, termed a file descriptor.  It returns -1 on fail-ure, failure,
     ure, and sets errno to indicate the error.

ERRORS
     The named file is opened unless:

     [EACCES]           Search permission is denied for a component of the path prefix.

     [EACCES]           The required permissions (for reading and/or writing) are denied for the given
                        flags.

     [EACCES]           O_CREAT is specified, the file does not exist, and the directory in which it is to
                        be created does not permit writing.

     [EACCES]           O_TRUNC is specified and write permission is denied.

     [EAGAIN]           path specifies the slave side of a locked pseudo-terminal device.

     [EDQUOT]           O_CREAT is specified, the file does not exist, and the directory in which the entry
                        for the new file is being placed cannot be extended because the user's quota of disk
                        blocks on the file system containing the directory has been exhausted.

     [EDQUOT]           O_CREAT is specified, the file does not exist, and the user's quota of inodes on the
                        file system on which the file is being created has been exhausted.

     [EEXIST]           O_CREAT and O_EXCL are specified and the file exists.

     [EFAULT]           Path points outside the process's allocated address space.

     [EINTR]            The open() operation is interrupted by a signal.

     [EINVAL]           The value of oflag is not valid.

     [EIO]              An I/O error occurs while making the directory entry or allocating the inode for
                        O_CREAT.

     [EISDIR]           The named file is a directory, and the arguments specify that it is to be opened for
                        writing.

     [ELOOP]            Too many symbolic links are encountered in translating the pathname.  This is taken
                        to be indicative of a looping symbolic link.

     [EMFILE]           The process has already reached its limit for open file descriptors.

     [ENAMETOOLONG]     A component of a pathname exceeds {NAME_MAX} characters, or an entire path name
                        exceeded {PATH_MAX} characters.

     [ENFILE]           The system file table is full.

     [ELOOP]            O_NOFOLLOW was specified and the target is a symbolic link.

     [ENOENT]           O_CREAT is not set and the named file does not exist.

     [ENOENT]           A component of the path name that must exist does not exist.

     [ENOSPC]           O_CREAT is specified, the file does not exist, and the directory in which the entry
                        for the new file is being placed cannot be extended because there is no space left
                        on the file system containing the directory.

     [ENOSPC]           O_CREAT is specified, the file does not exist, and there are no free inodes on the
                        file system on which the file is being created.

     [ENOTDIR]          A component of the path prefix is not a directory.

     [ENXIO]            The named file is a character-special or block-special file and the device associ-ated associated
                        ated with this special file does not exist.

     [ENXIO]            O_NONBLOCK and O_WRONLY are set, the file is a FIFO, and no process has it open for
                        reading.

     [EOPNOTSUPP]       O_SHLOCK or O_EXLOCK is specified, but the underlying filesystem does not support
                        locking.

     [EOPNOTSUPP]       An attempt is made to open a socket (not currently implemented).

     [EOVERFLOW]        The named file is a regular file and its size does not fit in an object of type
                        off_t.

     [EROFS]            The named file resides on a read-only file system, and the file is to be modified.

     [ETXTBSY]          The file is a pure procedure (shared text) file that is being executed and the
                        open() call requests write access.

COMPATIBILITY
     open() on a terminal device (i.e., /dev/console) will now make that device a controlling terminal for
     the process.  Use the O_NOCTTY flag to open a terminal device without changing your controlling termi-nal. terminal.
     nal.

SEE ALSO
     chmod(2), close(2), dup(2), getdtablesize(2), lseek(2), read(2), umask(2), write(2)

HISTORY
     An open() function call appeared in Version 6 AT&T UNIX.

4th Berkeley Distribution      November 16, 1993     4th Berkeley Distribution*/
   int      open(const char *path, int oflag, ...);

#endif //OC_SYS_FCNTL_H_

