#ifndef SYS_KERN_EVENT_H
#define SYS_KERN_EVENT_H

#include <sys/appleapiopts.h>
#include <sys/ioccom.h>
#include <sys/sys_domain.h>

/*SIOCSKEVFILT

#define SIOCSKEVFILT _IOW('e', 2, struct kev_request) 
Discussion 

Set the kernel event filter for this socket. Kernel events not matching this filter will not be received on this socket*/
#define SIOCSKEVFILT _IOW('e', 2, struct kev_request) 

/*KEV_IOKIT_CLASS

#define KEV_IOKIT_CLASS 2 
Discussion 

IOKit kernel event class.*/
#define KEV_IOKIT_CLASS 2 

/*KEV_MSG_HEADER_SIZE

#define KEV_MSG_HEADER_SIZE  
Discussion 

Size of the header portion of the kern_event_msg structure. This accounts for everything right up to event_data. The size of the data can be found by subtracting KEV_MSG_HEADER_SIZE from the total size from the kern_event_msg.*/
#define KEV_MSG_HEADER_SIZE (offsetof(struct kern_event_msg, event_data[0]))

/*KEV_NETWORK_CLASS

#define KEV_NETWORK_CLASS 1 
Discussion 

Network kernel event class.*/
#define KEV_NETWORK_CLASS 1 

/*KEV_VENDOR_APPLE

#define KEV_VENDOR_APPLE 1 
Discussion 

Apple generated kernel events use the hard coded vendor code value of 1. Third party kernel events use a dynamically allocated vendor code. The vendor code can be found using the SIOCGKEVVENDOR ioctl.*/
#define KEV_VENDOR_APPLE 1 

/*kev_d_vectors

struct kev_d_vectors { 
    u_int32_t data_length; //
 Length of the event data *
    void *data_ptr; // Pointer to event data *
};  
Fields
data_length
The length of data.
data_ptr
A pointer to data.
Discussion 

This structure is used to append some data to a kernel event.*/

struct kev_d_vectors { 
    u_int32_t data_length; /* Length of the event data */
    void *data_ptr; /* Pointer to event data */
};  

/*kev_msg

struct kev_msg { 
    u_int32_t vendor_code; // For non-Apple extensibility /
    u_int32_t kev_class; // Layer of event source //
    u_int32_t kev_subclass; //Component within layer *
    u_int32_t event_code; // The event code *
    struct kev_d_vectors dv[5  ]; // Up to n data vectors *
};  
Fields
vendor_code
The vendor code assigned by kev_vendor_code_find.
kev_class
The event's class.
kev_class
The event's subclass.
kev_class
The event's code.
dv
An array of vectors describing additional data to be appended to the kernel event.
Discussion 

This structure is used when posting a kernel event.*/

struct kev_msg { 
    u_int32_t vendor_code; /* For non-Apple extensibility */
    u_int32_t kev_class; /* Layer of event source */
    u_int32_t kev_subclass; /* Component within layer */
    u_int32_t event_code; /* The event code */
    struct kev_d_vectors dv[5  ]; /* Up to n data vectors */
};

/*kern_event_msg

struct kern_event_msg { 
    u_int32_t total_size; // Size of entire event msg 
    u_int32_t vendor_code; // For non-Apple extensibility 
    u_int32_t kev_class; // Layer of event source 
    u_int32_t kev_subclass; // Component within layer 
    u_int32_t id; // Monotonically increasing value 
    u_int32_t event_code; //unique code 
    u_int32_t event_data[1]; // One or more data words 
};  
Fields
total_size
Total size of the kernel event message including the header.
vendor_code
The vendor code indicates which vendor generated the kernel event. This gives every vendor a unique set of classes and subclasses to use. Use the SIOCGKEVVENDOR ioctl to look up vendor codes for vendors other than Apple. Apple uses KEV_VENDOR_APPLE.
kev_class
The class of the kernel event.
kev_subclass
The subclass of the kernel event.
id
Monotonically increasing value.
event_code
The event code.
event_data
Any additional data about this event. Format will depend on the vendor_code, kev_class, kev_subclass, and event_code. The length of the event_data can be determined using total_size - KEV_MSG_HEADER_SIZE.
Discussion 

This structure is prepended to all kernel events. This structure is used to determine the format of the remainder of the kernel event. This structure will appear on all messages received on a kernel event socket. To post a kernel event, a slightly different structure is used.*/
struct kern_event_msg { 
    u_int32_t total_size; /* Size of entire event msg */
    u_int32_t vendor_code; /* For non-Apple extensibility */
    u_int32_t kev_class; /* Layer of event source */
    u_int32_t kev_subclass; /* Component within layer */
    u_int32_t id; /* Monotonically increasing value */
    u_int32_t event_code; /* unique code */
    u_int32_t event_data[1]; /* One or more data words */
};  

/*kev_request

struct kev_request { 
    u_int32_t vendor_code; 
    u_int32_t kev_class; 
    u_int32_t kev_subclass; 
};  
Fields
total_size
Total size of the kernel event message including the header.
vendor_code
All kernel events that don't match this vendor code will be ignored. KEV_ANY_VENDOR can be used to receive kernel events with any vendor code.
kev_class
All kernel events that don't match this class will be ignored. KEV_ANY_CLASS can be used to receive kernel events with any class.
kev_subclass
All kernel events that don't match this subclass will be ignored. KEV_ANY_SUBCLASS can be used to receive kernel events with any subclass.
Discussion 

This structure is used with the SIOCSKEVFILT and SIOCGKEVFILT to set and get the control filter setting for a kernel control socket.*/
struct kev_request { 
    u_int32_t vendor_code; 
    u_int32_t kev_class; 
    u_int32_t kev_subclass; 
};  

#endif //SYS_KERN_EVENT_H
