#ifndef KPI_MBUF_H
#define KPI_MBUF_H

//#ifndef   SYS_KERNELTYPES_H
#include <sys/kernel_types.h>
//#endif

#include <mach/vm_types.h>
//#include <sys/errno.h>//hys

#include <HYS/sys/kpi_mbuf.h>

/*mbuf_csum_performed_flags_t


Checksum performed/requested flags. 
enum { 
    MBUF_CSUM_DID_IP = 0x0100, 
    MBUF_CSUM_IP_GOOD = 0x0200, 
    MBUF_CSUM_DID_DATA = 0x0400, 
    MBUF_CSUM_PSEUDO_HDR = 0x0800 
};  
Constants
MBUF_CSUM_DID_IP
Indicates that the driver/hardware verified the IP checksum in hardware.
MBUF_CSUM_IP_GOOD
Indicates whether or not the IP checksum was good or bad. Only valid when MBUF_CSUM_DID_IP is set.
MBUF_CSUM_DID_DATA
Indicates that the TCP or UDP checksum was calculated. The value for the checksum calculated in hardware should be passed as the second parameter of mbuf_set_csum_performed. The hardware calculated checksum value can be retrieved using the second parameter passed to mbuf_get_csum_performed.
MBUF_CSUM_PSEUDO_HDR
If set, this indicates that the checksum value for MBUF_CSUM_DID_DATA includes the pseudo header value. If this is not set, the stack will calculate the pseudo header value and add that to the checksum. The value of this bit is only valid when MBUF_CSUM_DID_DATA is set.
Discussion 

Mbufs often contain packets. Some hardware supports performing checksums in hardware. The driver uses these flags to communicate to the stack the checksums that were calculated in hardware.*/
enum { 
    MBUF_CSUM_DID_IP = 0x0100, 
    MBUF_CSUM_IP_GOOD = 0x0200, 
    MBUF_CSUM_DID_DATA = 0x0400, 
    MBUF_CSUM_PSEUDO_HDR = 0x0800 
};  

/*mbuf_csum_request_flags_t


Checksum performed/requested flags. 
enum { 
    MBUF_CSUM_REQ_IP = 0x0001, 
    MBUF_CSUM_REQ_TCP = 0x0002, 
    MBUF_CSUM_REQ_UDP = 0x0004 
};  
Constants
MBUF_CSUM_REQ_IP
Indicates the IP checksum has not been calculated yet.
MBUF_CSUM_REQ_TCP
Indicates the TCP checksum has not been calculated yet.
MBUF_CSUM_REQ_UDP
Indicates the UDP checksum has not been calculated yet.
Discussion 

Mbufs often contain packets. Some hardware supports performing checksums in hardware. The stack uses these flags to indicate to the driver what sort of checksumming should be handled in by the driver/hardware. These flags will only be set if the driver indicates that it supports the corresponding checksums using ifnet_set_offload.*/
enum { 
    MBUF_CSUM_REQ_IP = 0x0001, 
    MBUF_CSUM_REQ_TCP = 0x0002, 
    MBUF_CSUM_REQ_UDP = 0x0004 
};  

/*mbuf_type_t


Types of mbufs. 
enum { 
    MBUF_TYPE_FREE = 0, // should be on free list //
    MBUF_TYPE_DATA = 1, // dynamic (data) allocation //
    MBUF_TYPE_HEADER = 2, // packet header //
    MBUF_TYPE_SOCKET = 3, // socket structure //
    MBUF_TYPE_PCB = 4, // protocol control block //
    MBUF_TYPE_RTABLE = 5, // routing tables //
    MBUF_TYPE_HTABLE = 6, // IMP host tables //
    MBUF_TYPE_ATABLE = 7, // address resolution tables //
    MBUF_TYPE_SONAME = 8, // socket name //
    MBUF_TYPE_SOOPTS = 10, // socket options //
    MBUF_TYPE_FTABLE = 11, // fragment reassembly header //
    MBUF_TYPE_RIGHTS = 12, // access rights //
    MBUF_TYPE_IFADDR = 13, // interface address //
    MBUF_TYPE_CONTROL = 14, // extra-data protocol message //
    MBUF_TYPE_OOBDATA = 15 // expedited data //
};  
Constants
MBUF_MT_FREE
Indicates the mbuf is free and is sitting on the queue of free mbufs. If you find that an mbuf you have a reference to has this type, something has gone terribly wrong.
MBUF_MT_DATA
Indicates this mbuf is being used to store data.
MBUF_MT_HEADER
Indicates this mbuf has a packet header, this is probably a packet.
MBUF_MT_SOCKET
Socket structure.
MBUF_MT_PCB
Protocol control block.
MBUF_MT_RTABLE
Routing table entry.
MBUF_MT_HTABLE
IMP host tables???.
MBUF_MT_ATABLE
Address resolution table data.
MBUF_MT_SONAME
Socket name, usually a sockaddr of some sort.
MBUF_MT_FTABLE
Fragment reassembly header.
MBUF_MT_RIGHTS
Access rights.
MBUF_MT_IFADDR
Interface address.
MBUF_MT_CONTROL
Extra-data protocol message (control message).
MBUF_MT_OOBDATA
Out of band data.
Discussion 

Some mbufs represent packets, some represnt data waiting on sockets. Other mbufs store control data or other various structures. The mbuf type is used to store what sort of data the mbuf contains.*/
enum { 
    MBUF_TYPE_FREE = 0, /* should be on free list */
    MBUF_TYPE_DATA = 1, /* dynamic (data) allocation */
    MBUF_TYPE_HEADER = 2, /* packet header */
    MBUF_TYPE_SOCKET = 3, /* socket structure */
    MBUF_TYPE_PCB = 4, /* protocol control block */
    MBUF_TYPE_RTABLE = 5, /* routing tables */
    MBUF_TYPE_HTABLE = 6, /* IMP host tables */
    MBUF_TYPE_ATABLE = 7, /* address resolution tables */
    MBUF_TYPE_SONAME = 8, /* socket name */
    MBUF_TYPE_SOOPTS = 10, /* socket options */
    MBUF_TYPE_FTABLE = 11, /* fragment reassembly header */
    MBUF_TYPE_RIGHTS = 12, /* access rights */
    MBUF_TYPE_IFADDR = 13, /* interface address */
    MBUF_TYPE_CONTROL = 14, /* extra-data protocol message */
    MBUF_TYPE_OOBDATA = 15 /* expedited data */
};  

//func

/*mbuf_flags

mbuf_flags_t mbuf_flags(
    const mbuf_t mbuf);  
Parameters
mbuf
The mbuf.
Return Value

The flags. 
Discussion 

Returns the set flags.*/
mbuf_flags_t mbuf_flags(
    const mbuf_t mbuf);  

/*mbuf_pkthdr_setlen

void mbuf_pkthdr_setlen(
    mbuf_t mbuf,
    size_t len);  
Parameters
mbuf
The mbuf containing the packet header.
len
The new length of the packet.
Discussion 

Sets the length of the packet in the packet header.*/

void mbuf_pkthdr_setlen(
    mbuf_t mbuf,
    size_t len);  

/*mbuf_setlen

void mbuf_setlen(
    mbuf_t mbuf,
    size_t len);  
Parameters
mbuf
The mbuf.
len
The new length.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Sets the length of data in this packet. Be careful to not set the length over the space available in the mbuf.*/

void mbuf_setlen(
    mbuf_t mbuf,
    size_t len);  

/*mbuf_data_to_physical

addr64_t mbuf_data_to_physical(
    void*ptr);  
Parameters
ptr
A pointer to data stored in an mbuf.
Return Value

The 64 bit physical address of the mbuf data or NULL if ptr does not point to data stored in an mbuf. 
Discussion 

mbuf_data_to_physical is a replacement for mcl_to_paddr. Given a pointer returned from mbuf_data of mbuf_datastart, mbuf_data_to_physical will return the phyical address for that block of data.*/
addr64_t mbuf_data_to_physical(
    void*ptr);  

/*mbuf_len

size_t mbuf_len(
    const mbuf_t mbuf);  
Parameters
mbuf
The mbuf.
Return Value

The length. 
Discussion 

Gets the length of data in this mbuf.*/
size_t mbuf_len(
    const mbuf_t mbuf);  

/*mbuf_next

mbuf_t mbuf_next(
    const mbuf_t mbuf);  
Parameters
mbuf
The mbuf.
Return Value

The next mbuf in the chain. 
Discussion 

Returns the next mbuf in the chain.*/
mbuf_t mbuf_next(
    const mbuf_t mbuf);  

/*mbuf_data

void* mbuf_data(
    mbuf_t mbuf);  
Parameters
mbuf
The mbuf.
Return Value

A pointer to the data in the mbuf. 
Discussion 

Returns a pointer to the start of data in this mbuf. There may be additional data on chained mbufs. The data you're looking for may not be contiguous if it spans more than one mbuf. Use mbuf_len to determine the lenght of data available in this mbuf. If a data structure you want to access stradles two mbufs in a chain, either use mbuf_pullup to get the data contiguous in one mbuf or copy the pieces of data from each mbuf in to a contiguous buffer. Using mbuf_pullup has the advantage of not having to copy the data. On the other hand, if you don't make sure there is space in the mbuf, mbuf_pullup may fail and free the mbuf.*/
void* mbuf_data(
    mbuf_t mbuf);  

/*mbuf_pkthdr_len

size_t mbuf_pkthdr_len(
    const mbuf_t mbuf);  
Parameters
mbuf
The mbuf containing the packet header with the length to be changed.
Return Value

The length, in bytes, of the packet. 
Discussion 

Returns the length as reported by the packet header.*/
size_t mbuf_pkthdr_len(
    const mbuf_t mbuf);  

/*mbuf_gethdr

errno_t mbuf_gethdr(
    mbuf_how_t how,
    mbuf_type_t type,
    mbuf_t*mbuf);  
Parameters
how
Blocking or non-blocking.
type
The type of the mbuf.
mbuf
The mbuf.
Return Value

0 on success, errno error on failure. 
Discussion 

Allocates an mbuf without a cluster for external data. Sets a flag to indicate there is a packet header and initializes the packet header.*/
errno_t mbuf_gethdr(
    mbuf_how_t how,
    mbuf_type_t type,
    mbuf_t*mbuf);  

/*mbuf_datastart

void* mbuf_datastart(
    mbuf_t mbuf);  
Parameters
mbuf
The mbuf.
Return Value

A pointer to smallest possible value for data. 
Discussion 

Returns the start of the space set aside for storing data in an mbuf. An mbuf's data may come from a cluster or be embedded in the mbuf structure itself. The data pointer retrieved by mbuf_data may not be at the start of the data (mbuf_leadingspace will be non-zero). This function will return to you a pointer that matches mbuf_data() - mbuf_leadingspace().*/
void* mbuf_datastart(
    mbuf_t mbuf);  

/*mbuf_trailingspace

size_t mbuf_trailingspace(
    const mbuf_t mbuf);  
Parameters
mbuf
The mbuf.
Return Value

The number of unused bytes following the current data. 
Discussion 

Determines the space available in the mbuf following the current data.*/
size_t mbuf_trailingspace(
    const mbuf_t mbuf);  

/*mbuf_setdata

errno_t mbuf_setdata(
    mbuf_t mbuf,
    void *data,
    size_t len);  
Parameters
mbuf
The mbuf.
data
The new pointer value for data.
len
The new length of data in the mbuf.
Return Value

0 on success, errno error on failure. 
Discussion 

Sets the data and length values for an mbuf. The data value must be in a valid range. In the case of an mbuf with a cluster, the data value must point to a location in the cluster and the data value plus the length, must be less than the end of the cluster. For data embedded directly in an mbuf (no cluster), the data value must fall somewhere between the start and end of the data area in the mbuf and the data + length must also be in the same range.*/
errno_t mbuf_setdata(
    mbuf_t mbuf,
    void *data,
    size_t len);  

/*mbuf_prepend

errno_t mbuf_prepend(
    mbuf_t*mbuf,
    size_t len,
    mbuf_how_t how);  
Parameters
mbuf
The mbuf to prepend data to. This may change if a new mbuf must be allocated or may be NULL if the operation fails.
len
The length, in bytes, to be prepended to the mbuf.
how
Blocking or non-blocking.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Prepend len bytes to an mbuf. If there is space (mbuf_leadingspace >= len), the mbuf's data ptr is changed and the same mbuf is returned. If there is no space, a new mbuf may be allocated and prepended to the mbuf chain. If the operation fails, the mbuf may be freed (*mbuf will be NULL).*/
errno_t mbuf_prepend(
    mbuf_t*mbuf,
    size_t len,
    mbuf_how_t how);  

/*mbuf_free

mbuf_t mbuf_free(
    mbuf_t mbuf);  
Parameters
mbuf
The mbuf to free.
Return Value

The next mbuf in the chain. 
Discussion 

Frees a single mbuf. Not commonly used because it doesn't touch the rest of the mbufs on the chain.*/
mbuf_t mbuf_free(
    mbuf_t mbuf); 

/*mbuf_pkthdr_rcvif

ifnet_t mbuf_pkthdr_rcvif(
    const mbuf_t mbuf);  
Parameters
mbuf
The mbuf containing the packet header.
Return Value

A reference to the interface. 
Discussion 

Returns the interface the packet was received on. This funciton does not modify the reference count of the interface. The interface is only valid for as long as the mbuf is not freed and the rcvif for the mbuf is not changed. Take a reference on the interface that you will release later before doing any of the following: free the mbuf, change the rcvif, pass the mbuf to any function that may free the mbuf or change the rcvif.*/
ifnet_t mbuf_pkthdr_rcvif(
    const mbuf_t mbuf);  

/*mbuf_pullup

errno_t mbuf_pullup(
    mbuf_t*mbuf,
    size_t len);  
Parameters
mbuf
The mbuf in the chain the data should be contiguous in.
len
The number of bytes to pull from the next mbuf(s).
Return Value

0 upon success otherwise the errno error. In the case of an error, the mbuf chain has been freed. 
Discussion 

Move the next len bytes in to mbuf from other mbufs in the chain. This is commonly used to get the IP and TCP or UDP header contiguous in the first mbuf. If mbuf_pullup fails, the entire mbuf chain will be freed.*/
errno_t mbuf_pullup(
    mbuf_t*mbuf,
    size_t len); 

/*mbuf_allocpacket

errno_t mbuf_allocpacket(
    mbuf_how_t how,
    size_t packetlen,
    unsigned int *maxchunks,
    mbuf_t *mbuf);  
Parameters
how
Blocking or non-blocking
packetlen
The total length of the packet mbuf to be allocated. The length must be greater than zero.
maxchunks
An input/output pointer to the maximum number of mbufs segments making up the chain. On input if maxchunks is zero, or the value pointed to by maxchunks is zero, the packet will be made of as many buffer segments as necessary to fit the length. The allocation will fail with ENOBUFS if the number of segments requested is too small and the sum of the maximum size of each individual segment is less than the packet length. On output, if the allocation succeed and maxchunks is non zero, it will point to the actual number of segments allocated.
Upon
success, *mbuf will be a reference to the new mbuf.
Return Value

Returns 0 upon success or the following error code: EINVAL - Invalid parameter ENOMEM - Not enough memory available ENOBUFS - Buffers not big enough for the maximum number of chunks requested 
Discussion 

Allocate an mbuf chain to store a single packet of the requested length. According to the requested length, a chain of mbufs will be created. The mbuf type will be set to MBUF_TYPE_DATA. The caller may specify the maximum number of buffer*/
errno_t mbuf_allocpacket(
    mbuf_how_t how,
    size_t packetlen,
    unsigned int *maxchunks,
    mbuf_t *mbuf); 

/*mbuf_maxlen

size_t mbuf_maxlen(
    const mbuf_t mbuf);  
Parameters
mbuf
The mbuf.
Return Value

The maximum lenght of data for this mbuf. 
Discussion 

Retrieves the maximum length of data that may be stored in this mbuf. This value assumes that the data pointer was set to the start of the possible range for that pointer (mbuf_data_start).*/
size_t mbuf_maxlen(
    const mbuf_t mbuf);  

/*mbuf_copym

errno_t mbuf_copym(
    const mbuf_t src,
    size_t offset,
    size_t len, 
    mbuf_how_t how,
    mbuf_t*new_mbuf);  
Parameters
src
The source mbuf.
offset
The offset in the mbuf to start copying from.
len
The the number of bytes to copy.
how
To block or not to block, that is a question.
new_mbuf
Upon success, the newly allocated mbuf.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Copies len bytes from offset from src to a new mbuf.*/
errno_t mbuf_copym(
    const mbuf_t src,
    size_t offset,
    size_t len, 
    mbuf_how_t how,
    mbuf_t*new_mbuf);  

/*mbuf_freem

void mbuf_freem(
    mbuf_t mbuf);  
Parameters
mbuf
The first mbuf in the chain to free.
Discussion 

Frees a chain of mbufs link through mnext.*/
void mbuf_freem(
    mbuf_t mbuf);  

/*mbuf_setflags

errno_t mbuf_setflags(
    mbuf_t mbuf,
    mbuf_flags_t flags);  
Parameters
mbuf
The mbuf.
flags
The flags that should be set, all other flags will be cleared.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Sets the set of set flags.*/
errno_t mbuf_setflags(
    mbuf_t mbuf,
    mbuf_flags_t flags);  

/*mbuf_get_vlan_tag

errno_t mbuf_get_vlan_tag(
    mbuf_t mbuf,
    u_int16_t *vlan);  
Parameters
mbuf
The mbuf containing the packet.
vlan
The protocol family of the aux data to add.
Return Value

0 upon success otherwise the errno error. ENXIO indicates that the vlan tag is not set. 
Discussion 

This function is used by drivers that support hardware vlan tagging to determine which vlan this packet belongs to. To differentiate between the case where the vlan tag is zero and the case where there is no vlan tag, this function will return ENXIO when there is no vlan.*/
errno_t mbuf_get_vlan_tag(
    mbuf_t mbuf,
    u_int16_t *vlan);  

/*mbuf_set_vlan_tag

errno_t mbuf_set_vlan_tag(
    mbuf_t mbuf,
    u_int16_t vlan);  
Parameters
mbuf
The mbuf containing the packet.
vlan
The protocol family of the aux data to add.
Return Value

0 upon success otherwise the errno error. 
Discussion 

This function is used by interfaces that support vlan tagging in hardware. This function will set properties in the mbuf to indicate which vlan the packet was received for.*/
errno_t mbuf_set_vlan_tag(
    mbuf_t mbuf,
    u_int16_t vlan);  

/*mbuf_setnext

errno_t mbuf_setnext(
    mbuf_t mbuf,
    mbuf_t next);  
Parameters
mbuf
The mbuf.
next
The new next mbuf.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Sets the next mbuf in the chain.*/

errno_t mbuf_setnext(
    mbuf_t mbuf,
    mbuf_t next);  

/*mbuf_get

errno_t mbuf_get(
    mbuf_how_t how,
    mbuf_type_t type,
    mbuf_t*mbuf);  
Parameters
how
Blocking or non-blocking.
type
The type of the mbuf.
mbuf
The mbuf.
Return Value

0 on success, errno error on failure. 
Discussion 

Allocates an mbuf without a cluster for external data.*/
errno_t mbuf_get(
    mbuf_how_t how,
    mbuf_type_t type,
    mbuf_t*mbuf);  

/*mbuf_mclget

errno_t mbuf_mclget(
    mbuf_how_t how,
    mbuf_type_t type,
    mbuf_t*mbuf);  
Parameters
how
Blocking or non-blocking.
type
The type of the mbuf.
mbuf
The mbuf the cluster will be attached to.
Return Value

0 on success, errno error on failure. If you specified NULL for the mbuf, any intermediate mbuf that may have been allocated will be freed. If you specify an mbuf value in *mbuf, mbuf_mclget will not free it. 
Discussion 

Allocate a cluster and attach it to an mbuf for use as external data. If mbuf points to a NULL mbuf_t, an mbuf will be allocated for you. If mbuf points to a non-NULL mbuf_t, mbuf_mclget may return a different mbuf_t than the one you passed in.*/
errno_t mbuf_mclget(
    mbuf_how_t how,
    mbuf_type_t type,
    mbuf_t*mbuf);  

/*mbuf_getpacket

errno_t mbuf_getpacket(
    mbuf_how_t how,
    mbuf_t*mbuf);  
Parameters
how
Blocking or non-blocking.
mbuf
Upon success, *mbuf will be a reference to the new mbuf.
Return Value

0 on success, errno error on failure. 
Discussion 

Allocate an mbuf, allocate and attach a cluster, and set the packet header flag.*/
errno_t mbuf_getpacket(
    mbuf_how_t how,
    mbuf_t*mbuf);  

/*mbuf_freem_list

int mbuf_freem_list(
    mbuf_t mbuf);  
Parameters
mbuf
The first mbuf in the linked list to free.
Return Value

The number of mbufs freed. 
Discussion 

Frees linked list of mbuf chains. Walks through mnextpackt and does the equivalent of mbuf_mfreem to each.*/
int mbuf_freem_list(
    mbuf_t mbuf);  

/*mbuf_pkthdr_setrcvif

errno_t mbuf_pkthdr_setrcvif(
    mbuf_t mbuf,
    ifnet_t ifnet);  
Parameters
mbuf
The mbuf containing the packet header.
ifnet
A reference to an interface.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Sets the interface the packet was received on.*/
errno_t mbuf_pkthdr_setrcvif(
    mbuf_t mbuf,
    ifnet_t ifnet);  

/*mbuf_pkthdr_setheader

void mbuf_pkthdr_setheader(
    mbuf_t mbuf,
    void*header);  
Parameters
mbuf
The mbuf containing the packet header.
ifnet
A pointer to the header.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Sets the pointer to the packet header.*/

void mbuf_pkthdr_setheader(
    mbuf_t mbuf,
    void*header);  

/*mbuf_setnextpkt

void mbuf_setnextpkt(
    mbuf_t mbuf,
    mbuf_t nextpkt);  
Parameters
mbuf
The mbuf.
nextpkt
The new next packet.
Discussion 

Sets the next packet attached to this mbuf.*/
void mbuf_setnextpkt(
    mbuf_t mbuf,
    mbuf_t nextpkt);  

/*mbuf_copy_pkthdr

errno_t mbuf_copy_pkthdr(
    mbuf_t dest,
    const mbuf_t src);  
Parameters
src
The mbuf from which the packet header will be copied.
mbuf
The mbuf to which the packet header will be copied.
Return Value

0 upon success otherwise the errno error. 
Discussion 

Copies the packet header from src to dest.*/

errno_t mbuf_copy_pkthdr(
    mbuf_t dest,
    const mbuf_t src);  

/*mbuf_get_csum_requested

errno_t mbuf_get_csum_requested(
    mbuf_t mbuf, 
    mbuf_csum_request_flags_t *request,
    u_int32_t *value);  
Parameters
mbuf
The mbuf containing the packet.
request
Flags indicating which checksums are being requested for this packet.
value
This parameter is currently unsupported.
Return Value

0 upon success otherwise the errno error. 
Discussion 

This function is used by the driver to determine which checksum operations should be performed in hardware.*/
errno_t mbuf_get_csum_requested(
    mbuf_t mbuf, 
    mbuf_csum_request_flags_t *request,
    u_int32_t *value);  

/*mbuf_set_csum_performed

errno_t mbuf_set_csum_performed(
    mbuf_t mbuf, 
    mbuf_csum_performed_flags_t flags,
    u_int32_t value);  
Parameters
mbuf
The mbuf containing the packet.
flags
Flags indicating which hardware checksum operations were performed.
value
If the MBUF_CSUM_DID_DATA flag is set, value should be set to the value of the TCP or UDP header as calculated by the hardware.
Return Value

0 upon success otherwise the errno error. 
Discussion 

This is used by the driver to indicate to the stack which checksum operations were performed in hardware.*/
errno_t mbuf_set_csum_performed(
    mbuf_t mbuf, 
    mbuf_csum_performed_flags_t flags,
    u_int32_t value);  

#endif //KPI_MBUF_H

