#include <CoreFoundation/CoreFoundation.h>

/*CFBagGetCountOfValue

Returns the number of times a value occurs in a bag.

CFIndex CFBagGetCountOfValue (
   CFBagRef theBag,
   const void *value
);
Parameters
theBag

The bag to examine. 
value

The value for which to find matches in theBag. The equal callback provided when theBag was created is used to compare. If the equal callback was NULL, pointer equality (in C, ==) is used. If value, or any other value in theBag, is not understood by the equal callback, the behavior is undefined.
Return Value

The number of times value occurs in theBag. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFIndex CFBagGetCountOfValue (
   CFBagRef theBag,
   const void *value
){};
#endif

/*CFBagRemoveValue

Removes a value from a mutable bag.

void CFBagRemoveValue (
   CFMutableBagRef theBag,
   const void *value
);

Parameters
theBag

The bag from which value is to be removed. 
value

The value to be removed from the collection. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
void CFBagRemoveValue (
   CFMutableBagRef theBag,
   const void *value
){};
#endif

/*CFBagAddValue

Adds a value to a mutable bag.

void CFBagAddValue (
   CFMutableBagRef theBag,
   const void *value
);

Parameters
theBag

The bag to which value is added.
value

A CFType object or a pointer value to add to theBag (or the value itself, if it fits into the size of a pointer). 
Discussion

The value parameter is retained by theBag using the retain callback provided when theBag was created. If value is not of the type expected by the retain callback, the behavior is undefined. If value already exists in the collection, it is simply retained again—no memory is allocated for the added value. Use a CFSet object if you don’t want duplicate values in your collection. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
void CFBagAddValue (
   CFMutableBagRef theBag,
   const void *value
){};
#endif

/*CFBagCreateMutable

Creates a new empty mutable bag.

CFMutableBagRef CFBagCreateMutable (
   CFAllocatorRef allocator,
   CFIndex capacity,
   const CFBagCallBacks *callBacks
);
Parameters
allocator

The allocator object to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator.
capacity

The maximum number of values that can be contained by the new bag. The bag starts empty and can grow to this number of values (and it can have less). If this parameter is 0, the bag’s maximum capacity is not limited. This value must not be negative. 
callBacks

A pointer to a CFBagCallBacks structure initialized with the callbacks to use to retain, release, describe, and compare values in the bag. A copy of the contents of the callbacks structure is made, so that a pointer to a structure on the stack can be passed in or can be reused for multiple collection creations. This parameter may be NULL, which is treated as if a valid structure of version 0 with all fields NULL had been passed in.

If any of the fields are not valid pointers to functions of the correct type, or this parameter is not a valid pointer to a CFBagCallBacks structure, the behavior is undefined. If any value put into the collection is not one understood by one of the callback functions, the behavior when that callback function is used is undefined.

If the collection contains only CFType objects, then pass kCFTypeBagCallBacks as this parameter to use the default callback functions. 
Return Value

A new mutable bag, or NULL if there was a problem creating the object. Ownership follows the Create Rule.
Discussion

This function creates an new empty mutable bag to which you can add values using the CFBagAddValue function. The capacity parameter specifies the maximum number of values that the CFBag object can contain. If it is 0, then there is no limit to the number of values that can be added (aside from constraints such as available memory). 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFMutableBagRef CFBagCreateMutable (
   CFAllocatorRef allocator,
   CFIndex capacity,
   const CFBagCallBacks *callBacks
){};
#endif

/*CFBagCreateMutableCopy

Creates a new mutable bag with the values from another bag.

CFMutableBagRef CFBagCreateMutableCopy (
   CFAllocatorRef allocator,
   CFIndex capacity,
   CFBagRef theBag
);

Parameters
allocator

The allocator to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
capacity

The maximum number of values that can be contained by the new bag. The bag starts with the same count as theBag, and can grow to this number of values (and it can have less). If this value is 0, the bag’s maximum capacity is not limited. This value must be greater than or equal to the count of theBag, and must not be negative. 
theBag

The bag to copy. The pointer values from theBag are copied into the new bag. However, the values are also retained by the new bag. The count of the new bag is the same as the count of theBag. The new bag uses the same callbacks as theBag. 
Return Value

A new mutable bag that contains the same values as theBag. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFMutableBagRef CFBagCreateMutableCopy (
   CFAllocatorRef allocator,
   CFIndex capacity,
   CFBagRef theBag
){};
#endif

/*CFBagGetCount

Returns the number of values currently in a bag.

CFIndex CFBagGetCount (
   CFBagRef theBag
);
Parameters
theBag

The bag to examine. 
Return Value

The number of values in theBag. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
CFIndex CFBagGetCount (
   CFBagRef theBag
){};
#endif

/*CFBagGetValues

Fills a buffer with values from a bag.

void CFBagGetValues (
   CFBagRef theBag,
   const void **values
);

Parameters
theBag

The bag to examine. 
values

A C array of pointer-sized values to be filled with values from theBag. The value must be a valid C array of the appropriate type and size (that is, a size equal to the count of theBag). 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
#ifdef OC_CF
void CFBagGetValues (
   CFBagRef theBag,
   const void **values
){};
#endif


/*CFBagCreateCopy

Creates an immutable bag with the values of another bag.

CFBagRef CFBagCreateCopy (
   CFAllocatorRef allocator,
   CFBagRef theBag
);
Parameters
allocator

The allocator to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
theBag

The bag to copy. The pointer values from theBag are copied into the new bag. However, the values are also retained by the new bag. The count of the new bag is the same as the count of theBag. The new bag uses the same callbacks as theBag. 
Return Value

A new bag that contains the same values as theBag, or NULL if there was a problem creating the object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
CFBagRef CFBagCreateCopy (
   CFAllocatorRef allocator,
   CFBagRef theBag
){};

/*CFBagApplyFunction

Calls a function once for each value in a bag.

void CFBagApplyFunction (
   CFBagRef theBag,
   CFBagApplierFunction applier,
   void *context
);

Parameters
theBag

The bag to operate upon. 
applier

The callback function to call once for each value in the theBag. If this parameter is not a pointer to a function of the correct prototype, the behavior is undefined. If there are values in the range that the applier function does not expect or cannot properly apply to, the behavior is undefined.
context

A pointer-sized program-defined value, which is passed as the second parameter to the applier function, but is otherwise unused by this function. If the context is not what is expected by the applier function, the behavior is undefined.
Discussion

While this function iterates over a mutable collection, it is unsafe for the applier function to change the contents of the collection. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBag.h*/
void CFBagApplyFunction (
   CFBagRef theBag,
   CFBagApplierFunction applier,
   void *context
){};


