#include <CoreFoundation/CoreFoundation.h>

/*Predefined Allocators

CFAllocator provides the following predefined allocators. In general, you should use kCFAllocatorDefault unless one of the special circumstances exist below.

const CFAllocatorRef kCFAllocatorDefault;
const CFAllocatorRef kCFAllocatorSystemDefault;
const CFAllocatorRef kCFAllocatorMalloc;
const CFAllocatorRef kCFAllocatorMallocZone;
const CFAllocatorRef kCFAllocatorNull;
const CFAllocatorRef kCFAllocatorUseContext;
Constants
kCFAllocatorDefault

This is a synonym for NULL. 

Available in Mac OS X v10.0 and later.
extern  const CFAllocatorRef kCFAllocatorDefault;extern  const CFAllocatorRef kCFAllocatorDefault;kCFAllocatorSystemDefault

Default system allocator.

You rarely need to use this.

Available in Mac OS X v10.0 and later.
kCFAllocatorMalloc

This allocator uses malloc(), realloc(), and free(). 

Typically you should not use this allocator, use kCFAllocatorDefault instead. This allocator is useful as the bytesDeallocator in CFData or contentsDeallocator in CFString where the memory was obtained as a result of malloc type functions.

Available in Mac OS X v10.0 and later.
kCFAllocatorMallocZone

This allocator explicitly uses the default malloc zone, returned by malloc_default_zone().

You should only use this when an object is safe to be allocated in non-scanned memory.

Available in Mac OS X v10.4 and later.
kCFAllocatorNull

This allocator does nothing—it allocates no memory. 

This allocator is useful as the bytesDeallocator in CFData or contentsDeallocator in CFString where the memory should not be freed.

Available in Mac OS X v10.0 and later.
kCFAllocatorUseContext

Special allocator argument to CFAllocatorCreate—it uses the functions given in the context to allocate the allocator.

Available in Mac OS X v10.0 and later.
Declared In
CFBase.h*/

#ifdef OC_CF
 const CFAllocatorRef kCFAllocatorDefault;
const CFAllocatorRef kCFAllocatorSystemDefault;
const CFAllocatorRef kCFAllocatorMalloc;
const CFAllocatorRef kCFAllocatorMallocZone;
 const CFAllocatorRef kCFAllocatorNull;
 const CFAllocatorRef kCFAllocatorUseContext;
#endif

//work

/*CFGetTypeID

Returns the unique identifier of an opaque type to which a Core Foundation object belongs.

CFTypeID CFGetTypeID (
   CFTypeRef cf
);
Parameters
cf

The CFType object to examine. 
Return Value

A value of type CFTypeID that identifies the opaque type of cf. 
Discussion

This function returns a value that uniquely identifies the opaque type of any Core Foundation object. You can compare this value with the known CFTypeID identifier obtained with a “GetTypeID” function specific to a type, for example CFDateGetTypeID. These values might change from release to release or platform to platform.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/

#ifdef OC_CF
CFTypeID CFGetTypeID (
   CFTypeRef cf
){};
#endif

/*CFRelease

Releases a Core Foundation object.

void CFRelease (
   CFTypeRef cf
);
Parameters
cf

A CFType object to release. This value must not be NULL. 
Discussion

If the retain count of cf becomes zero the memory allocated to the object is deallocated and the object is destroyed. If you create, copy, or explicitly retain (see the CFRetain function) a Core Foundation object, you are responsible for releasing it when you no longer need it (see Memory Management Programming Guide for Core Foundation).
Special Considerations

If cf is NULL, this will cause a runtime error and your application will crash. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFRelease (
   CFTypeRef cf
){};
#endif
/*CFRetain

Retains a Core Foundation object.

CFTypeRef CFRetain (
   CFTypeRef cf
);
Parameters
cf

The CFType object to retain. This value must not be NULL
Return Value

The input value, cf. 
Discussion

You should retain a Core Foundation object when you receive it from elsewhere (that is, you did not create or copy it) and you want it to persist. If you retain a Core Foundation object you are responsible for releasing it (see Memory Management Programming Guide for Core Foundation). 
Special Considerations

If cf is NULL, this will cause a runtime error and your application will crash. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTypeRef CFRetain (
   CFTypeRef cf
){};
#endif

/*CFCopyDescription

Returns a textual description of a Core Foundation object.

CFStringRef CFCopyDescription (
   CFTypeRef cf
);
Parameters
cf

The CFType object (a generic reference of type CFTypeRef) from which to derive a description.
Return Value

A string that contains a description of cf. Ownership follows the Create Rule.
Discussion

The nature of the description differs by object. For example, a description of a CFArray object would include descriptions of each of the elements in the collection.

You can use this function for debugging Core Foundation objects in your code. Note, however, that the description for a given object may be different in different releases of the operating system. Do not create dependencies in your code on the content or format of the information returned by this function. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFStringRef CFCopyDescription (
   CFTypeRef cf
){};
#endif

/*CFRangeMake

Declares and initializes a CFRange structure.

CFRange CFRangeMake (
   CFIndex loc,
   CFIndex len
);
Parameters
loc

The starting location of the range. 
len

The length of the range.
Return Value

An initialized structure of type CFRange. 
Discussion

This is an in-line convenience function for creating initialized CFRange structures. 
Availability
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFRange CFRangeMake (
   CFIndex loc,
   CFIndex len
){};
#endif

/*CFEqual

Determines whether two Core Foundation objects are considered equal.

Boolean CFEqual (
   CFTypeRef cf1,
   CFTypeRef cf2
);
Parameters
cf1

A CFType object to compare to cf2.
cf2

A CFType object to compare to cf1.
Return Value

true if cf1 and cf2 are of the same type and considered equal, otherwise false. 
Discussion

Equality is something specific to each Core Foundation opaque type. For example, two CFNumber objects are equal if the numeric values they represent are equal. Two CFString objects are equal if they represent identical sequences of characters, regardless of encoding. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
Boolean CFEqual (
   CFTypeRef cf1,
   CFTypeRef cf2
){};
#endif

/*CFGetRetainCount

Returns the reference count of a Core Foundation object.

CFIndex CFGetRetainCount (
   CFTypeRef cf
);
Parameters
cf

The CFType object to examine. 
Return Value

A number representing the reference count of cf. 
Discussion

You increment the reference count using the CFRetain function, and decrement the reference count using the CFRelease function.

This function may useful for debugging memory leaks. You normally do not use this function, otherwise.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFIndex CFGetRetainCount (
   CFTypeRef cf
){};
#endif

/*CFAllocatorAllocate

Allocates memory using the specified allocator.

void *CFAllocatorAllocate (
   CFAllocatorRef allocator,
   CFIndex size,
   CFOptionFlags hint
);
Parameters
allocator

The allocator to use to allocate the memory. Pass NULL or kCFAllocatorDefault to use the current default allocator.
size

The size of the memory to allocate. 
hint

A bitfield containing flags that suggest how memory is to be allocated. 0 indicates no hints. No hints are currently defined, so only 0 should be passed for this value.
Return Value

A pointer to the newly allocated memory. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void *CFAllocatorAllocate (
   CFAllocatorRef allocator,
   CFIndex size,
   CFOptionFlags hint
){};
#endif

/*CFAllocatorDeallocate

Deallocates a block of memory with a given allocator.

void CFAllocatorDeallocate (
   CFAllocatorRef allocator,
   void *ptr
);
Parameters
allocator

The allocator that was used to allocate the block of memory pointed to by ptr. 
ptr

An untyped pointer to a block of memory to deallocate using allocator.
Discussion

If the allocator does not specify a deallocate callback function, the memory is not deallocated. 
Special Considerations

You must use the same allocator to deallocate memory as was used to allocate it.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
void CFAllocatorDeallocate (
   CFAllocatorRef allocator,
   void *ptr
){};
#endif

/*CFAllocatorGetDefault

Gets the default allocator object for the current thread.

CFAllocatorRef CFAllocatorGetDefault ();

Return Value

A reference to the default allocator for the current thread. If none has been explicitly set, returns the generic system allocator, kCFAllocatorSystemDefault. Ownership follows the Get Rule.
Discussion

See the discussion for CFAllocatorSetDefault for more detail on the default allocator and for advice on how and when to set a custom allocator as the default. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFAllocatorRef CFAllocatorGetDefault (){};
#endif


/*CFCopyTypeIDDescription

Returns a textual description of a Core Foundation type, as identified by its type ID, which can be used when debugging.

CFStringRef CFCopyTypeIDDescription (
   CFTypeID theType
);
Parameters
theType

An integer of type CFTypeID that uniquely identifies a Core Foundation opaque type. 
Return Value

A string containing a type description. Ownership follows the Create Rule.
Discussion

You can use this function for debugging Core Foundation objects in your code. Note, however, that the description for a given object may be different in different releases of the operating system. Do not create dependencies in your code on the content or format of the information returned by this function.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFStringRef CFCopyTypeIDDescription (
   CFTypeID theType
){};
#endif


/*CFGetAllocator

Returns the allocator used to allocate a Core Foundation object.

CFAllocatorRef CFGetAllocator (
   CFTypeRef cf
);
Parameters
cf

The CFType object to examine. 
Return Value

The allocator used to allocate memory for cf. 
Discussion

When you are creating a Core Foundation object sometimes you want to ensure that the block of memory allocated for the object is from the same allocator used for another object. One way to do this is to reuse the allocator assigned to an existing Core Foundation object when you call a “creation” function. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFAllocatorRef CFGetAllocator (
   CFTypeRef cf
){};
#endif

/*CFHash

Returns a code that can be used to identify an object in a hashing structure.

CFHashCode CFHash (
   CFTypeRef cf
);

Parameters
cf

A CFType object to examine. 
Return Value

An integer of type CFHashCode that represents a hashing value for cf. 
Discussion

Two objects that are equal (as determined by the CFEqual function) have the same hashing value. However, the converse is not true: two objects with the same hashing value might not be equal. That is, hashing values are not necessarily unique.

The hashing value for an object might change from release to release or from platform to platform.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFBase.h*/
#ifdef OC_CF
CFHashCode CFHash (
   CFTypeRef cf
){};
#endif

/*CFMakeCollectable

Makes a newly-allocated Core Foundation object eligible for garbage collection.

CFTypeRef CFMakeCollectable (
   CFTypeRef cf
);
Parameters
cf

A CFType object to make collectable. This value must not be NULL. 
Return Value

cf.
Discussion

For more details, see Garbage Collection Programming Guide.
Special Considerations

If cf is NULL, this will cause a runtime error and your application will crash. 
Availability
Available in Mac OS X v10.4 and later.
Declared In
CFBase.h*/
#ifdef OC_CF
CFTypeRef CFMakeCollectable (
   CFTypeRef cf
){};
#endif

/*CFAllocatorReallocate

Reallocates memory using the specified allocator.

void * CFAllocatorReallocate (
   CFAllocatorRef allocator,
   void *ptr,
   CFIndex newsize,
   CFOptionFlags hint
);
Parameters
allocator

The allocator to use for reallocating memory. Pass NULL to request the default allocator. 
ptr

An untyped pointer to a block of memory to reallocate to a new size. If ptr is NULL and newsize is greater than 0, memory is allocated (using the allocate function callback of the allocator's context). If ptr is NULL and newsize is 0, the result is NULL.
newsize

The number of bytes to allocate. If you pass 0 and the ptr parameter is non-NULL, the block of memory that ptr points to is typically deallocated. If you pass 0 for this parameter and the ptr parameter is NULL, nothing happens and the result returned is NULL. 
hint

A bitfield of type CFOptionsFlags. Pass flags to the allocator that suggest how memory is to be allocated. Zero indicates no hints. No hints are currently defined, only 0 should be passed for this argument.
Discussion

The CFAllocatorReallocate function's primary purpose is to reallocate a block of memory to a new (and usually larger) size. However, based on the values passed in certain of the parameters, this function can also allocate memory afresh or deallocate a given block of memory. The following summarizes the semantic combinations:
If the ptr parameter is non- NULL and the newsize parameter is greater than 0, the behavior is to reallocate.
If the ptr parameter is NULL and the newsize parameter is greater than 0, the behavior is to allocate.
If the ptr parameter is non- NULL and the newsize parameter is 0, the behavior is to deallocate.

The result of the CFAllocatorReallocate function is either an untyped pointer to a block of memory or NULL. A NULL result indicates either a failure to allocate memory or some other outcome, the precise interpretation of which is determined by the values of certain parameters and the presence or absence of callbacks in the allocator context. To summarize, a NULL result can mean one of the following:
An error occurred in the attempt to allocate memory, such as insufficient free space.
No allocate, reallocate, or deallocate function callback (depending on parameters) was defined in the allocator context.
The semantic operation is "deallocate" (that is, there is no need to return anything). 
The ptr parameter is NULL and the requested size is 0. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBase.h*/
#ifdef OC_CF
void * CFAllocatorReallocate (
   CFAllocatorRef allocator,
   void *ptr,
   CFIndex newsize,
   CFOptionFlags hint
){};
#endif

/*CFNullGetTypeID

Returns the type identifier for the CFNull opaque type.

CFTypeID CFNullGetTypeID (
   void
);

Return Value

The type identifier for the CFNull opaque type.
Availability
Available in Mac OS X v10.2 and later. 
Declared In
CFBase.h*/
#ifdef OC_CF
CFTypeID CFNullGetTypeID (
   void
){};
#endif

/*CFAllocatorGetPreferredSizeForSize

Obtains the number of bytes likely to be allocated upon a specific request.

CFIndex CFAllocatorGetPreferredSizeForSize (
   CFAllocatorRef allocator,
   CFIndex size,
   CFOptionFlags hint
);
Parameters
allocator

The allocator to use, or NULL for the default allocator. 
size

The number of bytes to allocate. If the value is 0 or less, the result is the same value.
hint

A bitfield of type CFOptionsFlags. Pass flags to the allocator that suggest how memory is to be allocated. 0 indicates no hints. No hints are currently defined, only 0 should be passed for this argument.
Return Value

The number of bytes likely to be allocated upon a specific request. 
Discussion

The return value depends on the allocator's internal allocation strategy, and will be equal to or larger than size. Calling this function may help you better match your memory allocation or reallocation strategy to that of the allocator. 

Note that the return value depends on the internal implementation of the allocator and the results may change from release to release or from platform to platform.

If no function callback is assigned to the preferredSize field of the allocator's context (see the CFAllocatorContext structure), then the value of size is returned. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFBase.h*/
#ifdef OC_CF
CFIndex CFAllocatorGetPreferredSizeForSize (
   CFAllocatorRef allocator,
   CFIndex size,
   CFOptionFlags hint
){};
#endif

/*Predefined Value

Predefined CFNull object.

const CFNullRef kCFNull;

Constants
kCFNull

The singleton CFNull object.

Available in Mac OS X v10.2 and later.

Declared in CFBase.h*/
#ifdef OC_CF
const CFNullRef kCFNull;
#endif
