#include <CoreFoundation/CoreFoundation.h>

/*CFCharacterSetGetPredefined

Returns a predefined character set.

CFCharacterSetRef CFCharacterSetGetPredefined (
   CFCharacterSetPredefinedSet theSetIdentifier
);

Parameters
theSetIdentifier

A predefined character set. See “Predefined CFCharacterSet Selector Values” for the list of available character sets.
Return Value

A predefined character set. This instance is owned by Core Foundation.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFCharacterSetRef CFCharacterSetGetPredefined (
   CFCharacterSetPredefinedSet theSetIdentifier
){};
#endif

/*CFCharacterSetIsCharacterMember

Reports whether or not a given Unicode character is in a character set.

Boolean CFCharacterSetIsCharacterMember (
   CFCharacterSetRef theSet,
   UniChar theChar
);
Parameters
theSet

The character set to examine. 
theChar

The Unicode character for which to test against the character set. Note that this function takes 16-bit Unicode character value; hence, it does not support access to the non-BMP planes.
Return Value

true if theSet contains theChar, otherwise false.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
Boolean CFCharacterSetIsCharacterMember (
   CFCharacterSetRef theSet,
   UniChar theChar
){};
#endif

/*CFCharacterSetIsLongCharacterMember

Reports whether or not a given UTF-32 character is in a character set.

Boolean CFCharacterSetIsLongCharacterMember (
   CFCharacterSetRef theSet,
   UTF32Char theChar
);

Parameters
theSet

The character set to examine. 
theChar

The UTF-32 character for which to test against the character set.
Return Value

true if theSet contains theChar, otherwise false.
Availability
Available in Mac OS X v10.2 and later. 
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
Boolean CFCharacterSetIsLongCharacterMember (
   CFCharacterSetRef theSet,
   UTF32Char theChar
){};
#endif

/*CFCharacterSetCreateMutable

Creates a new empty mutable character set.

CFMutableCharacterSetRef CFCharacterSetCreateMutable (
   CFAllocatorRef alloc
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator.
Return Value

A new empty mutable character set. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFMutableCharacterSetRef CFCharacterSetCreateMutable (
   CFAllocatorRef alloc
){};
#endif

/*CFCharacterSetAddCharactersInRange

Adds a given range to a character set.

void CFCharacterSetAddCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
);

Parameters
theSet

The character set to modify.
theRange

The range to add to the character set. The range is specified in 32-bits in UTF-32 format, and must lie within the valid Unicode character range (from 0x00000 to 0x10FFFF).
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetAddCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
){};
#endif

/*CFCharacterSetAddCharactersInString

Adds the characters in a given string to a character set.

void CFCharacterSetAddCharactersInString (
   CFMutableCharacterSetRef theSet,
   CFStringRef theString
);

Parameters
theSet

The character set to modify.
theString

A string containing the characters to add to theSet.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetAddCharactersInString (
   CFMutableCharacterSetRef theSet,
   CFStringRef theString
){};
#endif

/*CFCharacterSetCreateCopy

Creates a new character set with the values from a given character set.

CFCharacterSetRef CFCharacterSetCreateCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
theSet

The character set to copy.
Return Value

A new character set that is a copy of theSet. Ownership follows the Create Rule.
Discussion

This function tries to compact the backing store where applicable.
Availability
Available in Mac OS X v10.3 and later. 
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFCharacterSetRef CFCharacterSetCreateCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
){};
#endif

/*CFCharacterSetRemoveCharactersInRange

Removes a given range of Unicode characters from a character set.

void CFCharacterSetRemoveCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
);
Parameters
theSet

The character set to modify.
theRange

The range to remove from the character set. The range is specified in 32-bits in UTF-32 format, and must lie within the valid Unicode character range (from 0x00000 to 0x10FFFF).
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetRemoveCharactersInRange (
   CFMutableCharacterSetRef theSet,
   CFRange theRange
){};
#endif

/*CFCharacterSetGetTypeID

Returns the type identifier of the CFCharacterSet opaque type.

CFTypeID CFCharacterSetGetTypeID (
   void
);

Return Value

The type identifier of the CFCharacterSet opaque type.
Discussion

CFMutableCharacterSet objects have the same type identifier as CFCharacterSet objects.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFTypeID CFCharacterSetGetTypeID (
   void
){};
#endif

/*CFCharacterSetCreateMutableCopy

Creates a new mutable character set with the values from another character set.

CFMutableCharacterSetRef CFCharacterSetCreateMutableCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator.
theSet

The character set to copy.
Return Value

A new mutable character set containing the same characters as theSet. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
CFMutableCharacterSetRef CFCharacterSetCreateMutableCopy (
   CFAllocatorRef alloc,
   CFCharacterSetRef theSet
){};
#endif

/*CFCharacterSetInvert

Inverts the content of a given character set.

void CFCharacterSetInvert (
   CFMutableCharacterSetRef theSet
);

Parameters
theSet

The character set to invert.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetInvert (
   CFMutableCharacterSetRef theSet
){};
#endif

/*CFCharacterSetIntersect

Forms an intersection of two character sets.

void CFCharacterSetIntersect (
   CFMutableCharacterSetRef theSet,
   CFCharacterSetRef theOtherSet
);

Parameters
theSet

The source character set, modified by intersection with theOtherSet.
theOtherSet

The character set with which the intersection is formed.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFCharacterSet.h*/
#ifdef OC_CF
void CFCharacterSetIntersect (
   CFMutableCharacterSetRef theSet,
   CFCharacterSetRef theOtherSet
){};
#endif



