#include <CoreFoundation/CoreFoundation.h>

//work


/*CFDateGetTypeID

Returns the type identifier for the CFDate opaque type.

CFTypeID CFDateGetTypeID ();
Return Value

The type identifier for the CFDate opaque type. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTypeID CFDateGetTypeID (){};
#endif

/*CFAbsoluteTimeGetCurrent

Returns the current system absolute time.

CFAbsoluteTime CFAbsoluteTimeGetCurrent ();
Return Value

The current absolute time. 
Discussion

Absolute time is measured in seconds relative to the absolute reference date of Jan 1 2001 00:00:00 GMT. A positive value represents a date after the reference date, a negative value represents a date before it. For example, the absolute time -32940326 is equivalent to December 16th, 1999 at 17:54:34. Repeated calls to this function do not guarantee monotonically increasing results. The system time may decrease due to synchronization with external time references or due to an explicit user change of the clock.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFDate.h*/
#ifdef OC_CF
CFAbsoluteTime CFAbsoluteTimeGetCurrent (){};
#endif

/*CFDateCreate

Creates a CFDate object given an absolute time.

CFDateRef CFDateCreate (
   CFAllocatorRef allocator,
   CFAbsoluteTime at
);
Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
at

The absolute time to converted to a CFDate object. 
Return Value

A date object that represents the absolute time at. Ownership follows the Create Rule.
Discussion

CFDate objects must always be created using absolute time. Time intervals are not supported. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFDateRef CFDateCreate (
   CFAllocatorRef allocator,
   CFAbsoluteTime at
){};
#endif

/*(CFGregorianDateGetAbsoluteTime

Converts a Gregorian date value into an absolute time value.

CFAbsoluteTime CFGregorianDateGetAbsoluteTime (
   CFGregorianDate gdate,
   CFTimeZoneRef tz
);
Parameters
gdate

The Gregorian date to convert. 
tz

The time zone to use for time correction. Pass NULL for GMT. 
Return Value

The absolute time equivalent of gdate. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFDate.h*/
#ifdef OC_CF
CFAbsoluteTime CFGregorianDateGetAbsoluteTime (
   CFGregorianDate gdate,
   CFTimeZoneRef tz
){};
#endif

/*CFAbsoluteTimeGetDayOfWeek

Returns an integer representing the day of the week indicated by the specified absolute time.

SInt32 CFAbsoluteTimeGetDayOfWeek (
   CFAbsoluteTime at,
   CFTimeZoneRef tz
);
Parameters
at

The absolute time to convert. 
tz

The time zone to use for time correction. Pass NULL for GMT. 
Return Value

An integer (1-7) representing the day of the week specified by at. Per ISO-8601, Monday is represented by 1, Tuesday by 2, and so on.
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFDate.h*/
#ifdef OC_CF
SInt32 CFAbsoluteTimeGetDayOfWeek (
   CFAbsoluteTime at,
   CFTimeZoneRef tz
){};
#endif

/*CFAbsoluteTimeAddGregorianUnits

Adds a time interval, expressed as Gregorian units, to a given absolute time.

CFAbsoluteTime CFAbsoluteTimeAddGregorianUnits (
   CFAbsoluteTime at,
   CFTimeZoneRef tz,
   CFGregorianUnits units
);
Parameters
at

The absolute time to which the interval is added. 
tz

The time zone to use for time correction. Pass NULL for GMT. 
units

The time interval to add to at. 
Return Value

An absolute time value equal to the sum of at and units. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFDate.h*/
#ifdef OC_CF
CFAbsoluteTime CFAbsoluteTimeAddGregorianUnits (
   CFAbsoluteTime at,
   CFTimeZoneRef tz,
   CFGregorianUnits units
){};
#endif

/*CFAbsoluteTimeGetGregorianDate

Converts an absolute time value into a Gregorian date.

CFGregorianDate CFAbsoluteTimeGetGregorianDate (
   CFAbsoluteTime at,
   CFTimeZoneRef tz
);
Parameters
at

The absolute time value to convert. 
tz

The time zone to use for time correction. Pass NULL for GMT. 
Return Value

The Gregorian date equivalent for at. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
CFDate.h*/
#ifdef OC_CF
CFGregorianDate CFAbsoluteTimeGetGregorianDate (
   CFAbsoluteTime at,
   CFTimeZoneRef tz
){};
#endif

/*CFDateGetAbsoluteTime

Returns a CFDate object’s absolute time.

CFAbsoluteTime CFDateGetAbsoluteTime (
   CFDateRef theDate
);

Parameters
theDate

The date to examine. 
Return Value

The absolute time of theDate. 
Discussion

Absolute time is measured in seconds relative to the absolute reference date of Jan 1 2001 00:00:00 GMT. A positive value represents a date after the reference date, a negative value represents a date before it. For example, the absolute time -32940326 is equivalent to December 16th, 1999 at 17:54:34. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFDate.h*/
#ifdef OC_CF
CFAbsoluteTime CFDateGetAbsoluteTime (
   CFDateRef theDate
){};
#endif


/*Predefined Time Interval Values

Time intervals between the absolute reference date and certain other dates. 

const CFTimeInterval kCFAbsoluteTimeIntervalSince1970;
const CFTimeInterval kCFAbsoluteTimeIntervalSince1904;

Constants
kCFAbsoluteTimeIntervalSince1970

The time interval between 1 January 1970 and the reference date 1 January 2001 00:00:00 GMT.

Available in Mac OS X v10.0 and later.

Declared in CFDate.h
kCFAbsoluteTimeIntervalSince1904

The time interval between 1 January 1904 and the reference date 1 January 2001 00:00:00 GMT.

Available in Mac OS X v10.0 and later.

Declared in CFDate.h*/
#ifdef OC_CF
 const CFTimeInterval kCFAbsoluteTimeIntervalSince1970;
 const CFTimeInterval kCFAbsoluteTimeIntervalSince1904;
#endif

/*CFDateCompare

Compares two CFDate objects and returns a comparison result.

CFComparisonResult CFDateCompare (
   CFDateRef theDate,
   CFDateRef otherDate,
   void *context
);

Parameters
theDate

The date to compare to otherDate. 
otherDate

The date to compare to theDate.
context

Unused. Pass NULL.
Return Value

A CFComparisonResult value that indicates whether theDate is equal to, less than, or greater than otherDate.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFDate.h*/
#ifdef OC_CF
CFComparisonResult CFDateCompare (
   CFDateRef theDate,
   CFDateRef otherDate,
   void *context
){};
#endif

