#include <CoreFoundation/CoreFoundation.h>

//work


/*CFDateFormatterCreate

Creates a new CFDateFormatter object, localized to the given locale, which will format dates to the given date and time styles.

CFDateFormatterRef CFDateFormatterCreate(
   CFAllocatorRef alloc,
   CFLocaleRef locale,
   CFDateFormatterStyle dateStyle,
   CFDateFormatterStyle timeStyle
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
locale

The locale to use for localization. If NULL uses the default system local. Use CFLocaleCopyCurrent to specify the locale of the current user.
dateStyle

The date style to use when formatting dates. See Date Formatter Styles for possible values.
timeStyle

The time style to use when formatting times. See Date Formatter Styles for possible values.
Return Value

A new date formatter, localized to the given locale, which will format dates to the given date and time styles. Returns NULL if there was a problem creating the object. Ownership follows the Create Rule.
Discussion

You can use kCFDateFormatterNoStyle to suppress output for the date or time. The following code fragment illustrates the creation and use of a date formatter that only outputs the date information (memory management is omitted for clarity).CFLocaleRef locale = CFLocaleCreate(kCFAllocatorDefault, CFSTR("en_GB"));
 
CFDateFormatterRef formatter = CFDateFormatterCreate(
        kCFAllocatorDefault, locale, kCFDateFormatterMediumStyle, kCFDateFormatterNoStyle);
 
CFDateRef date = CFDateCreate(kCFAllocatorDefault, 123456);
CFStringRef dateAsString = CFDateFormatterCreateStringWithDate (
        kCFAllocatorDefault, formatter, date);
 
CFShow(dateAsString);
// outputs "2 Jan 2001"

Availability
Available in Mac OS X v10.3 and later.*/
#ifdef OC_CF
CFDateFormatterRef CFDateFormatterCreate(
   CFAllocatorRef alloc,
   CFLocaleRef locale,
   CFDateFormatterStyle dateStyle,
   CFDateFormatterStyle timeStyle
){};
#endif

/*CFDateFormatterCreateStringWithDate

Returns a string representation of the given date using the specified date formatter.

CFStringRef CFDateFormatterCreateStringWithDate(
   CFAllocatorRef alloc,
   CFDateFormatterRef formatter,
   CFDateRef date
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
formatter

The date formatter object that specifies the format of the returned string. 
date

The date object for which to create a string representation. 
Return Value

A new string that represents date in the specified format. Returns NULL if there was a problem creating the object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.3 and later.*/
#ifdef OC_CF
CFStringRef CFDateFormatterCreateStringWithDate(
   CFAllocatorRef alloc,
   CFDateFormatterRef formatter,
   CFDateRef date
){};
#endif

/*CFDateFormatterCreateStringWithAbsoluteTime

Returns a string representation of the given absolute time using the specified date formatter.

CFStringRef CFDateFormatterCreateStringWithAbsoluteTime(
   CFAllocatorRef alloc,
   CFDateFormatterRef formatter,
   CFAbsoluteTime at
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
formatter

The date formatter object that specifies the format of the returned string. 
at

The absolute time for which to generate a string representation.
Return Value

A new string that represents at in the specified format. Returns NULL if there was a problem creating the object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.3 and later.*/

#ifdef OC_CF
CFStringRef CFDateFormatterCreateStringWithAbsoluteTime(
   CFAllocatorRef alloc,
   CFDateFormatterRef formatter,
   CFAbsoluteTime at
){};
#endif

/*CFDateFormatterGetAbsoluteTimeFromString

Returns an absolute time object representing a given string.

Boolean CFDateFormatterGetAbsoluteTimeFromString (
   CFDateFormatterRef formatter,
   CFStringRef string,
   CFRange *rangep,
   CFAbsoluteTime *atp
);
Parameters
formatter

The date formatter object to use to parse string. 
string

The string that contains the time to be parsed.
rangep

Reference to the range within the string specifying the substring to be parsed. If NULL, the whole string is parsed. On return, the range that defines the extent of the parse (may be less than the given range).
atp

An absolute time value, returned by reference, that represents string. Ownership follows the Get Rule.
Return Value

true if the string was parsed successfully, otherwise false.
Availability
Available in Mac OS X v10.3 and later.
Declared In
CFDateFormatter.h*/
#ifdef OC_CF
Boolean CFDateFormatterGetAbsoluteTimeFromString (
   CFDateFormatterRef formatter,
   CFStringRef string,
   CFRange *rangep,
   CFAbsoluteTime *atp
){};
#endif

/*Date Formatter Property Keys

Keys used in key-value pairs to discover and specify the value of date formatter properties—used in conjunction with CFDateFormatterCopyProperty and CFDateFormatterSetProperty.

const CFStringRef kCFDateFormatterIsLenient;
const CFStringRef kCFDateFormatterTimeZone;
const CFStringRef kCFDateFormatterCalendarName;
const CFStringRef kCFDateFormatterDefaultFormat;
   
const CFStringRef kCFDateFormatterTwoDigitStartDate;
const CFStringRef kCFDateFormatterDefaultDate;
const CFStringRef kCFDateFormatterCalendar;
const CFStringRef kCFDateFormatterEraSymbols;
const CFStringRef kCFDateFormatterMonthSymbols;
const CFStringRef kCFDateFormatterShortMonthSymbols;
const CFStringRef kCFDateFormatterWeekdaySymbols;
const CFStringRef kCFDateFormatterShortWeekdaySymbols;
const CFStringRef kCFDateFormatterAMSymbol;
const CFStringRef kCFDateFormatterPMSymbol;
   
const CFStringRef kCFDateFormatterLongEraSymbols;
const CFStringRef kCFDateFormatterVeryShortMonthSymbols;
const CFStringRef kCFDateFormatterStandaloneMonthSymbols;
const CFStringRef kCFDateFormatterShortStandaloneMonthSymbols;
const CFStringRef kCFDateFormatterVeryShortStandaloneMonthSymbols;
const CFStringRef kCFDateFormatterVeryShortWeekdaySymbols;
const CFStringRef kCFDateFormatterStandaloneWeekdaySymbols;
const CFStringRef kCFDateFormatterShortStandaloneWeekdaySymbols;
const CFStringRef kCFDateFormatterVeryShortStandaloneWeekdaySymbols;
const CFStringRef kCFDateFormatterQuarterSymbols;
const CFStringRef kCFDateFormatterShortQuarterSymbols;
const CFStringRef kCFDateFormatterStandaloneQuarterSymbols;
const CFStringRef kCFDateFormatterShortStandaloneQuarterSymbols;
const CFStringRef kCFDateFormatterGregorianStartDate;

Constants
kCFDateFormatterIsLenient

Specifies the lenient property, a CFBoolean object where a true value indicates that the parsing of strings into date or absolute time values will be fuzzy.

The formatter will use heuristics to guess at the date which is intended by the string. As with any guessing, it may get the result date wrong (that is, a date other than that which was intended).

Available in Mac OS X v10.3 and later.

Declared in CFDateFormatter.h
kCFDateFormatterTimeZone

Specifies the time zone property, a CFTimeZone object.

Available in Mac OS X v10.3 and later.

Declared in CFDateFormatter.h
kCFDateFormatterCalendarName

Specifies the calendar name, a CFString object. 

With Mac OS X version 10.3, kCFGregorianCalendar is the only possible value. With Mac OS X version 10.4, kCFGregorianCalendar and other calendar names are specified by CFLocale.

Available in Mac OS X v10.3 and later.

Declared in CFDateFormatter.h
kCFDateFormatterDefaultFormat

The original format string for the formatter (given the date & time style and locale specified at creation).

Available in Mac OS X v10.3 and later.

Declared in CFDateFormatter.h
kCFDateFormatterTwoDigitStartDate

Specifies the property representing the date from which two-digit years start, a CFDate object.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterDefaultDate

Specifies the default date property, a CFDate object.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterCalendar

Specifies the calendar property, a CFCalendar object.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterEraSymbols

Specifies the era symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterMonthSymbols

Specifies the month symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterShortMonthSymbols

Specifies the short month symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterWeekdaySymbols

Specifies the weekday symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterShortWeekdaySymbols

Specifies the short weekday symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterAMSymbol

Specifies the AM symbol property, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterPMSymbol

Specifies the PM symbol property, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFDateFormatter.h
kCFDateFormatterLongEraSymbols

Specifies the long era symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterVeryShortMonthSymbols

Specifies the very short month symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterStandaloneMonthSymbols

Specifies the standalone month symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterShortStandaloneMonthSymbols

Specifies the short standalone month symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterVeryShortStandaloneMonthSymbols

Specifies the very short standalone month symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterVeryShortWeekdaySymbols

Specifies the very short weekday symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterStandaloneWeekdaySymbols

Specifies the standalone weekday symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterShortStandaloneWeekdaySymbols

Specifies the short standalone weekday symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterVeryShortStandaloneWeekdaySymbols

Specifies the very short standalone weekday symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterQuarterSymbols

Specifies the quarter symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterShortQuarterSymbols

Specifies the short quarter symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterStandaloneQuarterSymbols

Specifies the standalone quarter symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterShortStandaloneQuarterSymbols

Specifies the short standalone quarter symbols property, a CFArray of CFString objects.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
kCFDateFormatterGregorianStartDate

Specifies the Gregorian start date property, a CFDate object.

This is used to specify the start date for the Gregorian calendar switch from the Julian calendar. Different locales switched at different times. Normally you should just accept the locale's default date for the switch.

Available in Mac OS X v10.5 and later.

Declared in CFDateFormatter.h
Discussion

The values for these keys are all CFType objects. The specific types for each key are specified above.
Declared In
CFDateFormatter.h*/
#ifdef OC_CF
 const CFStringRef kCFDateFormatterIsLenient;
 const CFStringRef kCFDateFormatterTimeZone;
 const CFStringRef kCFDateFormatterCalendarName;
 const CFStringRef kCFDateFormatterDefaultFormat;
 const CFStringRef kCFDateFormatterTwoDigitStartDate;
 const CFStringRef kCFDateFormatterDefaultDate;
 const CFStringRef kCFDateFormatterCalendar;
 const CFStringRef kCFDateFormatterEraSymbols;
 const CFStringRef kCFDateFormatterMonthSymbols;
 const CFStringRef kCFDateFormatterShortMonthSymbols;
 const CFStringRef kCFDateFormatterWeekdaySymbols;
 const CFStringRef kCFDateFormatterShortWeekdaySymbols;
 const CFStringRef kCFDateFormatterAMSymbol;
 const CFStringRef kCFDateFormatterPMSymbol;
 const CFStringRef kCFDateFormatterLongEraSymbols;
 const CFStringRef kCFDateFormatterVeryShortMonthSymbols;
 const CFStringRef kCFDateFormatterStandaloneMonthSymbols;
 const CFStringRef kCFDateFormatterShortStandaloneMonthSymbols;
 const CFStringRef kCFDateFormatterVeryShortStandaloneMonthSymbols;
 const CFStringRef kCFDateFormatterVeryShortWeekdaySymbols;
 const CFStringRef kCFDateFormatterStandaloneWeekdaySymbols;
 const CFStringRef kCFDateFormatterShortStandaloneWeekdaySymbols;
 const CFStringRef kCFDateFormatterVeryShortStandaloneWeekdaySymbols;
 const CFStringRef kCFDateFormatterQuarterSymbols;
 const CFStringRef kCFDateFormatterShortQuarterSymbols;
 const CFStringRef kCFDateFormatterStandaloneQuarterSymbols;
 const CFStringRef kCFDateFormatterShortStandaloneQuarterSymbols;
 const CFStringRef kCFDateFormatterGregorianStartDate;
 #endif
