#include <CoreFoundation/CFFileDescriptor.h>

/*CFFileDescriptorCreate

Creates a new CFFileDescriptor.

CFFileDescriptorRef CFFileDescriptorCreate (
   CFAllocatorRef allocator,
   CFFileDescriptorNativeDescriptor fd,
   Boolean closeOnInvalidate,
   CFFileDescriptorCallBack callout,
   const CFFileDescriptorContext *context
);

Parameters
allocator

The allocator to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
fd

The file descriptor for the new CFFileDescriptor.
closeOnInvalidate

true if the new CFFileDescriptor should close fd when it is invalidated, otherwise false.
callout

The CFFileDescriptorCallBack for the new CFFileDescriptor.
context

Contextual information for the new CFFileDescriptor.
Return Value

A new CFFileDescriptor or NULL if there was a problem creating the object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.5 and later.
See Also
CFFileDescriptorGetContext
CFFileDescriptorInvalidate
Declared In
CFFileDescriptor.h*/
CFFileDescriptorRef CFFileDescriptorCreate (
   CFAllocatorRef allocator,
   CFFileDescriptorNativeDescriptor fd,
   Boolean closeOnInvalidate,
   CFFileDescriptorCallBack callout,
   const CFFileDescriptorContext *context
){};

/*CFFileDescriptorCreateRunLoopSource

Creates a new runloop source for a given CFFileDescriptor.

CFRunLoopSourceRef CFFileDescriptorCreateRunLoopSource (
   CFAllocatorRef allocator,
   CFFileDescriptorRef f,
   CFIndex order
);
Parameters
allocator

The allocator to use to allocate memory for the new bag and its storage for values. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
f

A CFFileDescriptor.
order

The order for the new run loop (see CFRunLoopSourceCreate).
Return Value

A new runloop source for f, or NULL if there was a problem creating the object. Ownership follows the Create Rule.
Discussion

The context for the new runloop (see CFRunLoopSourceCreate) is the same as the context passed in when the CFFileDescriptor was created (see CFFileDescriptorCreate). 
Availability
Available in Mac OS X v10.5 and later.
Declared In
CFFileDescriptor.h*/
CFRunLoopSourceRef CFFileDescriptorCreateRunLoopSource (
   CFAllocatorRef allocator,
   CFFileDescriptorRef f,
   CFIndex order
){};

/*CFFileDescriptorEnableCallBacks

Enables callbacks for a given CFFileDescriptor.

void CFFileDescriptorEnableCallBacks (
   CFFileDescriptorRef f,
   CFOptionFlags callBackTypes
);
Parameters
f

A CFFileDescriptor.
callBackTypes

A bitmask that specifies which callbacks to enable (see “Callback Identifiers” for possible components). 
Availability
Available in Mac OS X v10.5 and later.
See Also
CFFileDescriptorDisableCallBacks
Declared In
CFFileDescriptor.h*/
void CFFileDescriptorEnableCallBacks (
   CFFileDescriptorRef f,
   CFOptionFlags callBackTypes
){};



/*CFFileDescriptorGetNativeDescriptor

Returns the native file descriptor for a given CFFileDescriptor.

CFFileDescriptorNativeDescriptor CFFileDescriptorGetNativeDescriptor (
   CFFileDescriptorRef f
);
Parameters
f

A CFFileDescriptor.
Return Value

The native file descriptor for f.
Availability
Available in Mac OS X v10.5 and later.
See Also
CFFileDescriptorInvalidate
Declared In
CFFileDescriptor.h*/
CFFileDescriptorNativeDescriptor CFFileDescriptorGetNativeDescriptor (
   CFFileDescriptorRef f
){};

