#include <CoreFoundation/CoreFoundation.h>

/*Boolean Values

CFBoolean evaluates to either true or false values where kCFBooleanTrue is the true, and kCFBooleanFalse is the false value. 

const CFBooleanRef kCFBooleanTrue;
const CFBooleanRef kCFBooleanFalse;
Constants
kCFBooleanTrue

Boolean true value.

Available in Mac OS X v10.0 and later.
kCFBooleanFalse

Boolean false value.

Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
const CFBooleanRef kCFBooleanTrue;
 const CFBooleanRef kCFBooleanFalse;
#endif


//work


/*CFBooleanGetValue

Returns the value of a CFBoolean object as a standard C type Boolean.

Boolean CFBooleanGetValue (
   CFBooleanRef boolean
);
Parameters
boolean

The boolean to examine. 
Return Value

The value of boolean. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
Boolean CFBooleanGetValue (
   CFBooleanRef boolean
){};
#endif

/*CFNumberCreate

Creates a CFNumber object using a specified value.

CFNumberRef CFNumberCreate (
   CFAllocatorRef allocator,
   CFNumberType theType,
   const void *valuePtr
);
Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the default allocator.
theType

A constant that specifies the data type of the value to convert. See Number Types for a list of possible values. 
valuePtr

A pointer to the value for the returned number object.
Return Value

A new number with the value specified by valuePtr. Ownership follows the Create Rule.
Discussion

The theType parameter is not necessarily preserved when creating a new CFNumber object. The CFNumber object will be created using whatever internal storage type the creation function deems appropriate. Use the function CFNumberGetType to find out what type the CFNumber object used to store your value. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFNumberRef CFNumberCreate (
   CFAllocatorRef allocator,
   CFNumberType theType,
   const void *valuePtr
){};
#endif

/*CFBooleanGetTypeID

Returns the Core Foundation type identifier for the CFBoolean opaque type.

CFTypeID CFBooleanGetTypeID ();
Return Value

The Core Foundation type identifier for CFBoolean opaque type. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTypeID CFBooleanGetTypeID (){};
#endif

/*CFNumberGetValue

Obtains the value of a CFNumber object cast to a specified type.

Boolean CFNumberGetValue (
   CFNumberRef number,
   CFNumberType theType,
   void *valuePtr
);
Parameters
number

The CFNumber object to examine. 
theType

A constant that specifies the data type to return. See Number Types for a list of possible values. 
valuePtr

On return, contains the value of number.
Return Value

true if the operation was successful, otherwise false. 
Discussion

If the argument type differs from the return type, and the conversion is lossy or the return value is out of range, then this function passes back an approximate value in valuePtr and returns false. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
Boolean CFNumberGetValue (
   CFNumberRef number,
   CFNumberType theType,
   void *valuePtr
){};
#endif

/*CFNumberGetTypeID

Returns the type identifier for the CFNumber opaque type.

CFTypeID CFNumberGetTypeID ();
Return Value

The type identifier for the CFNumber opaque type.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTypeID CFNumberGetTypeID (void){};
#endif

/*CFNumberIsFloatType

Determines whether a CFNumber object contains a value stored as one of the defined floating point types.

Boolean CFNumberIsFloatType (
   CFNumberRef number
);
Parameters
number

The CFNumber object to examine. 
Return Value

true if number's value is one of the defined floating point types, otherwise false. The valid floating point types are listed in Number Types. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFNumber.h*/
#ifdef OC_CF
Boolean CFNumberIsFloatType (
   CFNumberRef number
){};
#endif

/*CFNumberGetByteSize

Returns the number of bytes used by a CFNumber object to store its value.

CFIndex CFNumberGetByteSize (
   CFNumberRef number
);
Parameters
number

The CFNumber object to examine. 
Return Value

The size in bytes of the value contained in number. 
Discussion

Because a CFNumber object might store a value using a type different from that of the original value with which it was created, this function may return a size different from the size of the original value's type. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFNumber.h*/
#ifdef OC_CF
CFIndex CFNumberGetByteSize (
   CFNumberRef number
){};
#endif

/*CFNumberCompare

Compares two CFNumber objects and returns a comparison result.

CFComparisonResult CFNumberCompare (
   CFNumberRef number,
   CFNumberRef otherNumber,
   void *context
);

Parameters
number

The first CFNumber object to compare.
otherNumber

The second CFNumber object to compare.
context

Pass NULL.
Return Value

A CFComparisonResult constant that indicates whether number is equal to, less than, or greater than otherNumber.
Discussion

When comparing two CFNumber objects using this function, one or both objects can represent a special-case number such as signed 0, signed infinity, or NaN.

The following rules apply:
Negative 0 compares less than positive 0. 
Positive infinity compares greater than everything except itself, to which it compares equal. 
Negative infinity compares less than everything except itself, to which it compares equal. 
If both numbers are NaN, then they compare equal. 
If only one of the numbers is NaN, then the NaN compares greater than the other number if it is negative, and smaller than the other number if it is positive. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFNumber.h*/
#ifdef OC_CF
CFComparisonResult CFNumberCompare (
   CFNumberRef number,
   CFNumberRef otherNumber,
   void *context
){};
#endif

/*CFNumberGetType

Returns the type used by a CFNumber object to store its value.

CFNumberType CFNumberGetType (
   CFNumberRef number
);
Parameters
number

The CFNumber object to examine. 
Return Value

A constant that indicates the data type of the value contained in number. See Number Types for a list of possible values. 
Discussion

The type specified in the call to CFNumberCreate is not necessarily preserved when a new CFNumber object is created—it uses whatever internal storage type the creation function deems appropriate. 
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFNumber.h*/
#ifdef OC_CF
CFNumberType CFNumberGetType (
   CFNumberRef number
){};
#endif

/*Predefined Values

CFNumber provides some predefined number values. 

const CFNumberRef kCFNumberNaN;
const CFNumberRef kCFNumberNegativeInfinity;
const CFNumberRef kCFNumberPositiveInfinity;

Constants
kCFNumberNaN

“Not a Number.” This value is often the result of an invalid operation, such as the square-root of a negative number.

Available in Mac OS X v10.0 and later.

Declared in CFNumber.h
kCFNumberNegativeInfinity

Designates a negative infinity value.

Available in Mac OS X v10.0 and later.

Declared in CFNumber.h
kCFNumberPositiveInfinity

Designates a positive infinity value.

Available in Mac OS X v10.0 and later.

Declared in CFNumber.h*/
#ifdef OC_CF
 const CFNumberRef kCFNumberNaN;
 const CFNumberRef kCFNumberNegativeInfinity;
 const CFNumberRef kCFNumberPositiveInfinity;
#endif
