#include <CoreFoundation/CoreFoundation.h>
#include <CoreFoundation/CFNumberFormatter.h>

/*CFNumberFormatterCopyProperty

Returns a copy of a number formatter’s value for a given key. 

CFTypeRef CFNumberFormatterCopyProperty (
   CFNumberFormatterRef formatter,
   CFStringRef key
);

Parameters
formatter

The number formatter to examine.
key

A property key. See “Number Formatter Property Keys” for valid values.
Return Value

A CFType object that is a copy of the property value for key. Returns NULL if there is no value specified for key. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.3 and later. 
Declared In
CFNumberFormatter.h*/
#ifdef OC_CF
CFTypeRef CFNumberFormatterCopyProperty (
   CFNumberFormatterRef formatter,
   CFStringRef key)
{};
#endif

/*CFNumberFormatterCreateStringWithValue

Returns a string representation of the given number or value using the specified number formatter.

CFStringRef CFNumberFormatterCreateStringWithValue (
   CFAllocatorRef allocator,
   CFNumberFormatterRef formatter,
   CFNumberType numberType,
   const void *valuePtr
);

Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
formatter

The number formatter to use. 
numberType

The type of value that valuePtr references. Valid values are listed in CFNumberType.
valuePtr

A pointer to the value to be converted.
Return Value

A new string that represents the given number or value formatted by formatter. Returns NULL if there was a problem creating the object. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.3 and later. 
Declared In
CFNumberFormatter.h*/
#ifdef OC_CF
CFStringRef CFNumberFormatterCreateStringWithValue (
   CFAllocatorRef allocator,
   CFNumberFormatterRef formatter,
   CFNumberType numberType,
   const void *valuePtr
){};
#endif

/*CFNumberFormatterGetValueFromString

Returns a number or value representing a given string.

Boolean CFNumberFormatterGetValueFromString (
   CFNumberFormatterRef formatter,
   CFStringRef string,
   CFRange *rangep,
   CFNumberType numberType,
   void *valuePtr
);

Parameters
formatter

The number formatter to use. 
string

The string to parse.
rangep

A reference to a range that specifies the substring of string to be parsed. If NULL, the whole string is parsed. Upon return, contains the range of the actual extent of the parse (may be less than the given range).
numberType

The type of value that valuePtr references. Valid values are listed in CFNumberType. 
valuePtr

Upon return, contains a number or value representing the string in the specified format. You are responsible for releasing this value.
Return Value

true if the string was parsed successfully, otherwise false.
Availability
Available in Mac OS X v10.3 and later. 
Declared In
CFNumberFormatter.h*/

#ifdef OC_CF
Boolean CFNumberFormatterGetValueFromString (
   CFNumberFormatterRef formatter,
   CFStringRef string,
   CFRange *rangep,
   CFNumberType numberType,
   void *valuePtr
){};
#endif

/*Number Formatter Property Keys

The keys used in key-value pairs to specify the value of number formatter properties. 

const CFStringRef kCFNumberFormatterCurrencyCode;
const CFStringRef kCFNumberFormatterDecimalSeparator;
const CFStringRef kCFNumberFormatterCurrencyDecimalSeparator;
const CFStringRef kCFNumberFormatterAlwaysShowDecimalSeparator;
const CFStringRef kCFNumberFormatterGroupingSeparator;
const CFStringRef kCFNumberFormatterUseGroupingSeparator;
const CFStringRef kCFNumberFormatterPercentSymbol;
const CFStringRef kCFNumberFormatterZeroSymbol;
const CFStringRef kCFNumberFormatterNaNSymbol;
const CFStringRef kCFNumberFormatterInfinitySymbol;
const CFStringRef kCFNumberFormatterMinusSign;
const CFStringRef kCFNumberFormatterPlusSign;
const CFStringRef kCFNumberFormatterCurrencySymbol;
const CFStringRef kCFNumberFormatterExponentSymbol;
const CFStringRef kCFNumberFormatterMinIntegerDigits;
const CFStringRef kCFNumberFormatterMaxIntegerDigits;
const CFStringRef kCFNumberFormatterMinFractionDigits;
const CFStringRef kCFNumberFormatterMaxFractionDigits;
const CFStringRef kCFNumberFormatterGroupingSize;
const CFStringRef kCFNumberFormatterSecondaryGroupingSize;
const CFStringRef kCFNumberFormatterRoundingMode;
const CFStringRef kCFNumberFormatterRoundingIncrement;
const CFStringRef kCFNumberFormatterFormatWidth;
const CFStringRef kCFNumberFormatterPaddingPosition;
const CFStringRef kCFNumberFormatterPaddingCharacter;
const CFStringRef kCFNumberFormatterDefaultFormat;
const CFStringRef kCFNumberFormatterMultiplier;
const CFStringRef kCFNumberFormatterPositivePrefix;
const CFStringRef kCFNumberFormatterPositiveSuffix;
const CFStringRef kCFNumberFormatterNegativePrefix;
const CFStringRef kCFNumberFormatterNegativeSuffix;
const CFStringRef kCFNumberFormatterPerMillSymbol;
const CFStringRef kCFNumberFormatterInternationalCurrencySymbol;
const CFStringRef kCFNumberFormatterCurrencyGroupingSeparator;
const CFStringRef kCFNumberFormatterIsLenient;
const CFStringRef kCFNumberFormatterUseSignificantDigits;
const CFStringRef kCFNumberFormatterMinSignificantDigits;
const CFStringRef kCFNumberFormatterMaxSignificantDigits;

Constants
kCFNumberFormatterCurrencyCode

Specifies the currency code, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterDecimalSeparator

Specifies the decimal separator, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterCurrencyDecimalSeparator

Specifies the currency decimal separator, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterAlwaysShowDecimalSeparator

Specifies if the result of converting a value to a string should always contain the decimal separator, even if the number is an integer.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterGroupingSeparator

Specifies the grouping separator, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterUseGroupingSeparator

Specifies if the grouping separator should be used, a CFBoolean object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPercentSymbol

Specifies the string that is used to represent the percent symbol, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterZeroSymbol

Specifies the string that is used to represent zero, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterNaNSymbol

Specifies the string that is used to represent NaN (“not a number”) when values are converted to strings, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterInfinitySymbol

Specifies the string that is used to represent the symbol for infinity, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinusSign

Specifies the symbol for the minus sign, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPlusSign

Specifies the symbol for the plus sign, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterCurrencySymbol

Specifies the symbol for the currency, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterExponentSymbol

Specifies the exponent symbol (“E” or “e”) in the scientific notation of numbers (for example, as in 1.0e+56), a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinIntegerDigits

Specifies the minimum number of integer digits before a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMaxIntegerDigits

Specifies the maximum number of integer digits before a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinFractionDigits

Specifies the minimum number of digits after a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMaxFractionDigits

Specifies the maximum number of digits after a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterGroupingSize

Specifies how often the “thousands” or grouping separator appears, as in “10,000,000”, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterSecondaryGroupingSize

Specifies how often the secondary grouping separator appears, a CFNumber object. See Unicode Technical Standard #35 for more information.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterRoundingMode

Specifies how the last digit is rounded, as when 3.1415926535... is rounded to three decimal places, as in 3.142, a CFNumber object. See “Rounding Modes” for possible values.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterRoundingIncrement

Specifies a positive rounding increment, or 0.0 to disable rounding, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterFormatWidth

Specifies the width of a formatted number within a string that is either left justified or right justified based on the value of kCFNumberFormatterPaddingPosition, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPaddingPosition

Specifies the position of a formatted number within a string, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPaddingCharacter

Specifies the padding character to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterDefaultFormat

The original format string for the formatter (given the date and time style and locale specified at creation), a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMultiplier

Specifies the multiplier to use when placing a formatted number within a string, a CFNumber object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPositivePrefix

Specifies the plus sign prefix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPositiveSuffix

Specifies the plus sign suffix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterNegativePrefix

Specifies the minus sign prefix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterNegativeSuffix

Specifies the minus sign suffix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPerMillSymbol

Specifies the per mill (1/1000) symbol to use when placing a formatted number within a string, a CFString object.
Number Formatter Property Keys

The keys used in key-value pairs to specify the value of number formatter properties. 

const CFStringRef kCFNumberFormatterCurrencyCode;
const CFStringRef kCFNumberFormatterDecimalSeparator;
const CFStringRef kCFNumberFormatterCurrencyDecimalSeparator;
const CFStringRef kCFNumberFormatterAlwaysShowDecimalSeparator;
const CFStringRef kCFNumberFormatterGroupingSeparator;
const CFStringRef kCFNumberFormatterUseGroupingSeparator;
const CFStringRef kCFNumberFormatterPercentSymbol;
const CFStringRef kCFNumberFormatterZeroSymbol;
const CFStringRef kCFNumberFormatterNaNSymbol;
const CFStringRef kCFNumberFormatterInfinitySymbol;
const CFStringRef kCFNumberFormatterMinusSign;
const CFStringRef kCFNumberFormatterPlusSign;
const CFStringRef kCFNumberFormatterCurrencySymbol;
const CFStringRef kCFNumberFormatterExponentSymbol;
const CFStringRef kCFNumberFormatterMinIntegerDigits;
const CFStringRef kCFNumberFormatterMaxIntegerDigits;
const CFStringRef kCFNumberFormatterMinFractionDigits;
const CFStringRef kCFNumberFormatterMaxFractionDigits;
const CFStringRef kCFNumberFormatterGroupingSize;
const CFStringRef kCFNumberFormatterSecondaryGroupingSize;
const CFStringRef kCFNumberFormatterRoundingMode;
const CFStringRef kCFNumberFormatterRoundingIncrement;
const CFStringRef kCFNumberFormatterFormatWidth;
const CFStringRef kCFNumberFormatterPaddingPosition;
const CFStringRef kCFNumberFormatterPaddingCharacter;
const CFStringRef kCFNumberFormatterDefaultFormat;
const CFStringRef kCFNumberFormatterMultiplier;
const CFStringRef kCFNumberFormatterPositivePrefix;
const CFStringRef kCFNumberFormatterPositiveSuffix;
const CFStringRef kCFNumberFormatterNegativePrefix;
const CFStringRef kCFNumberFormatterNegativeSuffix;
const CFStringRef kCFNumberFormatterPerMillSymbol;
const CFStringRef kCFNumberFormatterInternationalCurrencySymbol;
const CFStringRef kCFNumberFormatterCurrencyGroupingSeparator;
const CFStringRef kCFNumberFormatterIsLenient;
const CFStringRef kCFNumberFormatterUseSignificantDigits;
const CFStringRef kCFNumberFormatterMinSignificantDigits;
const CFStringRef kCFNumberFormatterMaxSignificantDigits;

Constants
kCFNumberFormatterCurrencyCode

Specifies the currency code, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterDecimalSeparator

Specifies the decimal separator, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterCurrencyDecimalSeparator

Specifies the currency decimal separator, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterAlwaysShowDecimalSeparator

Specifies if the result of converting a value to a string should always contain the decimal separator, even if the number is an integer.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterGroupingSeparator

Specifies the grouping separator, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterUseGroupingSeparator

Specifies if the grouping separator should be used, a CFBoolean object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPercentSymbol

Specifies the string that is used to represent the percent symbol, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterZeroSymbol

Specifies the string that is used to represent zero, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterNaNSymbol

Specifies the string that is used to represent NaN (“not a number”) when values are converted to strings, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterInfinitySymbol

Specifies the string that is used to represent the symbol for infinity, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinusSign

Specifies the symbol for the minus sign, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPlusSign

Specifies the symbol for the plus sign, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterCurrencySymbol

Specifies the symbol for the currency, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterExponentSymbol

Specifies the exponent symbol (“E” or “e”) in the scientific notation of numbers (for example, as in 1.0e+56), a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinIntegerDigits

Specifies the minimum number of integer digits before a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMaxIntegerDigits

Specifies the maximum number of integer digits before a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinFractionDigits

Specifies the minimum number of digits after a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMaxFractionDigits

Specifies the maximum number of digits after a decimal point, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterGroupingSize

Specifies how often the “thousands” or grouping separator appears, as in “10,000,000”, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterSecondaryGroupingSize

Specifies how often the secondary grouping separator appears, a CFNumber object. See Unicode Technical Standard #35 for more information.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterRoundingMode

Specifies how the last digit is rounded, as when 3.1415926535... is rounded to three decimal places, as in 3.142, a CFNumber object. See “Rounding Modes” for possible values.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterRoundingIncrement

Specifies a positive rounding increment, or 0.0 to disable rounding, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterFormatWidth

Specifies the width of a formatted number within a string that is either left justified or right justified based on the value of kCFNumberFormatterPaddingPosition, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPaddingPosition

Specifies the position of a formatted number within a string, a CFNumber object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPaddingCharacter

Specifies the padding character to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterDefaultFormat

The original format string for the formatter (given the date and time style and locale specified at creation), a CFString object.

Available in Mac OS X v10.3 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMultiplier

Specifies the multiplier to use when placing a formatted number within a string, a CFNumber object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPositivePrefix

Specifies the plus sign prefix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPositiveSuffix

Specifies the plus sign suffix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterNegativePrefix

Specifies the minus sign prefix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterNegativeSuffix

Specifies the minus sign suffix symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterPerMillSymbol

Specifies the per mill (1/1000) symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterInternationalCurrencySymbol

Specifies the international currency symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterCurrencyGroupingSeparator

Specifies the grouping symbol to use when placing a currency value within a string, a CFString object. 

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterIsLenient

Specifies whether the formatter is lenient, aCFBoolean object. 

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterUseSignificantDigits

Specifies the whether the formatter uses significant digits, a CFBoolean object.

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinSignificantDigits

Specifies the minimum number of significant digits to use, aCFNumber object.

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMaxSignificantDigits

Specifies the maximum number of significant digits to use, aCFNumber object.

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
Discussion

The values for these keys are all CFType objects. The specific types for each key are specified above.
Declared In
CFNumberFormatter.h
Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterInternationalCurrencySymbol

Specifies the international currency symbol to use when placing a formatted number within a string, a CFString object.

Available in Mac OS X v10.4 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterCurrencyGroupingSeparator

Specifies the grouping symbol to use when placing a currency value within a string, a CFString object. 

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterIsLenient

Specifies whether the formatter is lenient, aCFBoolean object. 

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterUseSignificantDigits

Specifies the whether the formatter uses significant digits, a CFBoolean object.

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMinSignificantDigits

Specifies the minimum number of significant digits to use, aCFNumber object.

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
kCFNumberFormatterMaxSignificantDigits

Specifies the maximum number of significant digits to use, aCFNumber object.

Available in Mac OS X v10.5 and later.

Declared in CFNumberFormatter.h
Discussion

The values for these keys are all CFType objects. The specific types for each key are specified above.
Declared In
CFNumberFormatter.h*/
#ifdef OC_CF
 const CFStringRef kCFNumberFormatterCurrencyCode;
 const CFStringRef kCFNumberFormatterDecimalSeparator;
 const CFStringRef kCFNumberFormatterCurrencyDecimalSeparator;
 const CFStringRef kCFNumberFormatterAlwaysShowDecimalSeparator;
 const CFStringRef kCFNumberFormatterGroupingSeparator;
 const CFStringRef kCFNumberFormatterUseGroupingSeparator;
 const CFStringRef kCFNumberFormatterPercentSymbol;
 const CFStringRef kCFNumberFormatterZeroSymbol;
 const CFStringRef kCFNumberFormatterNaNSymbol;
 const CFStringRef kCFNumberFormatterInfinitySymbol;
 const CFStringRef kCFNumberFormatterMinusSign;
 const CFStringRef kCFNumberFormatterPlusSign;
 const CFStringRef kCFNumberFormatterCurrencySymbol;
 const CFStringRef kCFNumberFormatterExponentSymbol;
 const CFStringRef kCFNumberFormatterMinIntegerDigits;
 const CFStringRef kCFNumberFormatterMaxIntegerDigits;
 const CFStringRef kCFNumberFormatterMinFractionDigits;
 const CFStringRef kCFNumberFormatterMaxFractionDigits;
 const CFStringRef kCFNumberFormatterGroupingSize;
 const CFStringRef kCFNumberFormatterSecondaryGroupingSize;
 const CFStringRef kCFNumberFormatterRoundingMode;
 const CFStringRef kCFNumberFormatterRoundingIncrement;
 const CFStringRef kCFNumberFormatterFormatWidth;
 const CFStringRef kCFNumberFormatterPaddingPosition;
 const CFStringRef kCFNumberFormatterPaddingCharacter;
 const CFStringRef kCFNumberFormatterDefaultFormat;
 const CFStringRef kCFNumberFormatterMultiplier;
 const CFStringRef kCFNumberFormatterPositivePrefix;
 const CFStringRef kCFNumberFormatterPositiveSuffix;
 const CFStringRef kCFNumberFormatterNegativePrefix;
 const CFStringRef kCFNumberFormatterNegativeSuffix;
 const CFStringRef kCFNumberFormatterPerMillSymbol;
 const CFStringRef kCFNumberFormatterInternationalCurrencySymbol;
 const CFStringRef kCFNumberFormatterCurrencyGroupingSeparator;
 const CFStringRef kCFNumberFormatterIsLenient;
 const CFStringRef kCFNumberFormatterUseSignificantDigits;
 const CFStringRef kCFNumberFormatterMinSignificantDigits;
 const CFStringRef kCFNumberFormatterMaxSignificantDigits;
#endif//OC_CF

/*CFNumberFormatterCreate

Creates a new CFNumberFormatter object, localized to the given locale, which will format numbers to the given style.

CFNumberFormatterRef CFNumberFormatterCreate (
   CFAllocatorRef allocator,
   CFLocaleRef locale,
   CFNumberFormatterStyle style
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
locale

A locale to use for localization. If NULL, the function uses the default system locale. Use CFLocaleCopyCurrent to specify the locale of the current user.
style

A number style. See “Number Formatter Styles” for possible values.
Return Value

A new number formatter, localized to the given locale, which will format numbers using the given style. Returns NULL if there was a problem creating the formatter. Ownership follows the Create Rule.
Availability
Available in Mac OS X v10.3 and later. 
Declared In
CFNumberFormatter.h*/

CFNumberFormatterRef CFNumberFormatterCreate (
   CFAllocatorRef allocator,
   CFLocaleRef locale,
   CFNumberFormatterStyle style
){};
