#include <CoreFoundation/CoreFoundation.h>

//work


/*CFPropertyListCreateFromXMLData

Creates a property list using the specified XML or binary property list data.

CFPropertyListRef CFPropertyListCreateFromXMLData (
   CFAllocatorRef allocator,
   CFDataRef data,
   CFOptionFlags mutabilityOption,
   CFStringRef *errorString
);
Parameters
allocator

The allocator to use to allocate memory for the new property list. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
data

The raw bytes to convert into a property list. The bytes may be the content of an XML file or of a binary property list (see Property List Formats).
mutabilityOption

A constant that specifies the degree of mutability for the returned property list. See Property List Mutability Options for descriptions of possible values. 
errorString

On return, NULL if the conversion is successful, otherwise a string that describes the nature of the error. Error messages are not localized, but may be in the future, so they are not currently suitable for comparison.

Pass NULL if you do not wish to receive an error string. Ownership follows the Create Rule.
Return Value

A new property list if the conversion is successful, otherwise NULL. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFPropertyListRef CFPropertyListCreateFromXMLData (
   CFAllocatorRef allocator,
   CFDataRef data,
   CFOptionFlags mutabilityOption,
   CFStringRef *errorString
){};
#endif

/*CFPropertyListCreateXMLData

Creates an XML representation of the specified property list.

CFDataRef CFPropertyListCreateXMLData (
   CFAllocatorRef allocator,
   CFPropertyListRef propertyList
);
Parameters
allocator

The allocator to use to allocate memory for the new data object. Pass NULL or kCFAllocatorDefault to use the current default allocator.
propertyList

The property list to convert. This may be any of the standard property list objects, for example a CFArray or a CFDictionary object. 
Return Value

A CFData object containing the XML data. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.0 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFDataRef CFPropertyListCreateXMLData (
   CFAllocatorRef allocator,
   CFPropertyListRef propertyList
){};
#endif

/*CFPropertyListCreateDeepCopy

Recursively creates a copy of a given property list.

CFPropertyListRef CFPropertyListCreateDeepCopy (
   CFAllocatorRef allocator,
   CFPropertyListRef propertyList,
   CFOptionFlags mutabilityOption
);

Parameters
allocator

The allocator to use to allocate memory for the new property list. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
propertyList

The property list to copy. This may be any of the standard property list objects, for example a CFArray or a CFDictionary object. 
mutabilityOption

A constant that specifies the degree of mutability of the returned property list. See Property List Mutability Options for descriptions of possible values. 
Return Value

A new property list that is a copy of propertyList. Ownership follows the Create Rule.
Discussion

Recursively creates a copy of the given property list so nested arrays and dictionaries are copied as well as the top-most container.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFPropertyListRef CFPropertyListCreateDeepCopy (
   CFAllocatorRef allocator,
   CFPropertyListRef propertyList,
   CFOptionFlags mutabilityOption
){};
#endif

/*CFPropertyListCreateFromStream

Creates a property list using data from a stream.

CFPropertyListRef CFPropertyListCreateFromStream(
   CFAllocatorRef allocator,
   CFReadStreamRef stream,
   CFIndex streamLength,
   CFOptionFlags mutabilityOption,
   CFPropertyListFormat *format,
   CFStringRef *errorString
);

Parameters
allocator

The allocator to use to allocate memory for the new property list. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
stream

The stream whose data contains the content. The stream must be opened and configured—this function simply reads bytes from the stream. The stream may contain any supported property list type (see Property List Formats).
streamLength

The number of bytes to read. If 0, this function will read to the end of the stream. 
mutabilityOption

A constant that specifies the degree of mutability for the returned property list. See Property List Mutability Options for descriptions of possible values.
format

A constant that specifies the format of the property list. See Property List Formats for possible values.
errorString

On return, NULL if the conversion is successful, otherwise a string that describes the nature of the error. Error messages are not localized, but may be in the future, so they are not suitable for comparison.

Pass NULL if you do not wish to receive an error string. Ownership follows the Create Rule.
Return Value

A new property list initialized with the data contained in stream. Ownership follows the Create Rule.
Discussion

This function simply reads bytes from stream starting at the current location to the end, which is expected to be the end of the property list, or up to the number of bytes specified by streamLength if it is not 0. 
Availability
Available in Mac OS X v10.2 and later.*/
#ifdef OC_CF
CFPropertyListRef CFPropertyListCreateFromStream(
   CFAllocatorRef allocator,
   CFReadStreamRef stream,
   CFIndex streamLength,
   CFOptionFlags mutabilityOption,
   CFPropertyListFormat *format,
   CFStringRef *errorString
){};
#endif

/*CFPropertyListWriteToStream

Writes the bytes of a property list serialization out to a stream.

CFIndex CFPropertyListWriteToStream (
   CFPropertyListRef propertyList,
   CFWriteStreamRef stream,
   CFPropertyListFormat format,
   CFStringRef *errorString
);

Parameters
propertyList

The property list to write out. 
stream

The stream to write to. The stream must be opened and configured—this function simply writes bytes to the stream. 
format

A constant that specifies the format used to write propertyList. See Property List Formats for possible values. 
errorString

On return, NULL if the conversion is successful, otherwise a string that describes the nature of the errors. Error messages are not localized, but may be in the future, so they are not currently suitable for comparison.

Pass NULL if you do not wish to receive an error string. Ownership follows the Create Rule.
Return Value

The number of bytes written, or 0 if an error occurred. If 0 is returned, errorString will contain an error message. 
Discussion

This function leaves the stream open after reading the content. When reading a property list, this function expects the reading stream to end wherever the writing ended, so that the end of the property list data can be identified.
Availability
Available in Mac OS X v10.2 and later.*/
#ifdef OC_CF
CFIndex CFPropertyListWriteToStream (
   CFPropertyListRef propertyList,
   CFWriteStreamRef stream,
   CFPropertyListFormat format,
   CFStringRef *errorString
){};
#endif
