#include <CoreFoundation/CFTree.h>

/*CFTreeGetChildCount

Returns the number of children in a tree.

CFIndex CFTreeGetChildCount (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The number of children in tree.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFIndex CFTreeGetChildCount (
   CFTreeRef tree
){};
#endif

/*CFTreeGetChildAtIndex

Returns the child of a tree at the specified index.

CFTreeRef CFTreeGetChildAtIndex (
   CFTreeRef tree,
   CFIndex idx
);
Parameters
tree

The tree to examine.
idx

The index of the child obtain. The value must be less than the number of children in tree.
Return Value

The child tree at idx. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFTreeRef CFTreeGetChildAtIndex (
   CFTreeRef tree,
   CFIndex idx
){};
#endif

/*CFTreeAppendChild

Adds a new child to a tree as the last in its list of children.

void CFTreeAppendChild (
   CFTreeRef tree,
   CFTreeRef newChild
);

Parameters
tree

The tree to which to add newChild.
newChild

The child tree to add to tree. If this parameter is a tree which is already a child of any other tree, the behavior is undefined.
Discussion

When a child tree is added to another tree, the child tree is retained by its new parent.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeAppendChild (
   CFTreeRef tree,
   CFTreeRef newChild
){};
#endif

/*CFTreeGetParent

Returns the parent of a given tree.

CFTreeRef CFTreeGetParent (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The parent of tree. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeGetParent (
   CFTreeRef tree
){};
#endif

/*CFTreeCreate

Creates a new CFTree object.

CFTreeRef CFTreeCreate (
   CFAllocatorRef allocator,
   const CFTreeContext *context
);

Parameters
allocator

The allocator to use to allocate memory for the new tree. Pass NULL or kCFAllocatorDefault to use the current default allocator.
context

The CFTreeContext structure to be copied and used as the context of the new tree. The information pointer will be retained by the tree if a retain function is provided. If this value is not a valid C pointer to a CFTreeContext structure-sized block of storage, the result is undefined. If the version number of the storage is not a valid CFTreeContext version number, the result is undefined.
Return Value

A new CFTree object. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeCreate (
   CFAllocatorRef allocator,
   const CFTreeContext *context
){};
#endif

/*CFTreeGetContext

Returns the context of the specified tree.

void CFTreeGetContext (
   CFTreeRef tree,
   CFTreeContext *context
);
Parameters
tree

The tree to examine.
context

The CFTreeContext structure to be filled in with the context of the specified tree. This value must be a valid C pointer to a CFTreeContext structure-sized block of storage. If the version number of the storage is not a valid CFTreeContext structure version number, the result is undefined.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeGetContext (
   CFTreeRef tree,
   CFTreeContext *context
){};
#endif

/*CFTreeGetFirstChild

Returns the first child of a tree.

CFTreeRef CFTreeGetFirstChild (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The first child of tree. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeGetFirstChild (
   CFTreeRef tree
){};
#endif

/*CFTreeGetNextSibling

Returns the next sibling, adjacent to a given tree, in the parent's children list.

CFTreeRef CFTreeGetNextSibling (
   CFTreeRef tree
);

Parameters
tree

The tree to examine.
Return Value

The next sibling, adjacent to tree. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
CFTreeRef CFTreeGetNextSibling (
   CFTreeRef tree
){};
#endif

/*CFTreeRemoveAllChildren

Removes all the children of a tree.

void CFTreeRemoveAllChildren (
   CFTreeRef tree
);
Parameters
tree

The tree to modify.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeRemoveAllChildren (
   CFTreeRef tree
){};
#endif

/*CFTreeSetContext

Replaces the context of a tree by releasing the old information pointer and retaining the new one.

void CFTreeSetContext (
   CFTreeRef tree,
   const CFTreeContext *context
);

Parameters
tree

The tree to modify.
context

The CFTreeContext structure to be copied and used as the context of the new tree. The information pointer will be retained by the tree if a retain function is provided. If this value is not a valid C pointer to a CFTreeContext structure-sized block of storage, the result is undefined. If the version number of the storage is not a valid CFTreeContext version number, the result is undefined.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFTree.h*/
#ifdef OC_CF
void CFTreeSetContext (
   CFTreeRef tree,
   const CFTreeContext *context
){};
#endif


