#include <CoreFoundation/CFXMLNode.h>

/*CFXMLNodeGetTypeCode

Returns the XML structure type code for a CFXMLNode object.

CFXMLNodeTypeCode CFXMLNodeGetTypeCode (
   CFXMLNodeRef node
);

Parameters
node

The CFXMLNode object to examine. 
Return Value

The type code for node. 
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFXMLNodeTypeCode CFXMLNodeGetTypeCode (
   CFXMLNodeRef node
){};
#endif

/*CFXMLNodeGetInfoPtr

Returns the additional information pointer of a CFXMLNode object.

const void *CFXMLNodeGetInfoPtr (
   CFXMLNodeRef node
);

Parameters
node

The CFXMLNode object to examine. 
Return Value

A pointer to a structure containing additional information. The CFXMLNode version together with the node’s type determines the expected structure. See Node Type Code for information about the possible structures returned. If the returned value is a Core Foundation object, ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
const void *CFXMLNodeGetInfoPtr (
   CFXMLNodeRef node
){};
#endif

/*CFXMLNodeGetString

Returns the data string from a CFXMLNode.

CFStringRef CFXMLNodeGetString (
   CFXMLNodeRef node
);
Parameters
node

The CFXMLNode object to examine. 
Return Value

The data string from node. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.*/
#ifdef OC_CF
CFStringRef CFXMLNodeGetString (
   CFXMLNodeRef node
){};
#endif

/*CFXMLTreeGetNode

Returns the node of a CFXMLTree object.

CFXMLNodeRef CFXMLTreeGetNode (
   CFXMLTreeRef xmlTree
);
Parameters
xmlTree

The CFXMLTree object whose node you wish to obtain. 
Return Value

The node of xmlTree. Ownership follows the Get Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFXMLNode.h*/
#ifdef OC_CF
CFXMLNodeRef CFXMLTreeGetNode (
   CFXMLTreeRef xmlTree
){};
#endif

/*CFXMLNodeCreate

Creates a new CFXMLNode.

CFXMLNodeRef CFXMLNodeCreate (
   CFAllocatorRef alloc,
   CFXMLNodeTypeCode xmlType,
   CFStringRef dataString,
   const void *additionalInfoPtr,
   CFIndex version
);

Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
xmlType

Type identifier code for the XML structure you want this node to describe. 
dataString

The XML data. 
additionalInfoPtr

A pointer to a structure containing additional information about the XML data.
version

The version number of the CFXMLNode object you want to create. Pass one of the pre-defined constants, typically kCFXMLNodeCurrentVersion. 
Return Value

A new CFXMLNode object. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFXMLNode.h*/
#ifdef OC_CF
CFXMLNodeRef CFXMLNodeCreate (
   CFAllocatorRef alloc,
   CFXMLNodeTypeCode xmlType,
   CFStringRef dataString,
   const void *additionalInfoPtr,
   CFIndex version
){};
#endif

/*CFXMLNodeGetTypeID

Returns the type identifier code for the CFXMLNode opaque type.

CFTypeID CFXMLNodeGetTypeID (
   void
);
Return Value

The type identifier for the CFXMLNode opaque type. 
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFXMLNode.h*/
#ifdef OC_CF
CFTypeID CFXMLNodeGetTypeID (void){
};
#endif

/*CFXMLNodeCreateCopy

Creates a copy of a CFXMLNode object.

CFXMLNodeRef CFXMLNodeCreateCopy (
   CFAllocatorRef alloc,
   CFXMLNodeRef origNode
);
Parameters
alloc

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
origNode

The node to copy. Do not pass NULL. 
Return Value

A new CFXMLNode object. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFXMLNode.h*/
#ifdef OC_CF
CFXMLNodeRef CFXMLNodeCreateCopy (
   CFAllocatorRef alloc,
   CFXMLNodeRef origNode
){};
#endif

/*CFXMLTreeCreateWithNode

Creates a childless, parentless CFXMLTree object node for a CFXMLNode object.

CFXMLTreeRef CFXMLTreeCreateWithNode (
   CFAllocatorRef allocator,
   CFXMLNodeRef node
);

Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
node

The CFXMLNode object to use when creating the new CFXMLTree object.
Return Value

A CFXMLTree object. Ownership follows the Create Rule.
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFXMLNode.h*/
#ifdef OC_CF
CFXMLTreeRef CFXMLTreeCreateWithNode (
   CFAllocatorRef allocator,
   CFXMLNodeRef node
){};
#endif

