#include <CoreFoundation/CFXMLParser.h>



/*CFXMLTreeCreateFromData

Parses the given XML data and returns the resulting CFXMLTree object.

CFXMLTreeRef CFXMLTreeCreateFromData (
   CFAllocatorRef allocator,
   CFDataRef xmlData,
   CFURLRef dataSource,
   CFOptionFlags parseOptions,
   CFIndex versionOfNodes
);

Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
xmlData

The XML data you wish to parse. 
dataSource

The URL from which the XML data was obtained. The URL is used to resolve any relative references found in xmlData. Pass NULL if a valid URL is unavailable. 
parseOptions

Flags which control how the XML data will be parsed. See “Parsing Options” for the list of available options.
versionOfNodes

Determines which version of CFXMLNode objects are produced by the parser. 
Return Value

A new CFXMLTree object containing the data from the specified XML document. Ownership follows the Create Rule.
Discussion

This function represents the high-level interface to the XML parser. This single function creates a parser for the specified XML data using the specified options. The parser creates and returns a CFXMLTree object that you can examine and modify with the CFTree functions or obtain the node using the CFXMLTreeGetNode function and examine its attributes using CFXMLNode functions. 
Availability
Available in CarbonLib v1.1 and later.
Available in Mac OS X v10.0 and later.
Declared In
CFXMLParser.h*/
CFXMLTreeRef CFXMLTreeCreateFromData (
   CFAllocatorRef allocator,
   CFDataRef xmlData,
   CFURLRef dataSource,
   CFOptionFlags parseOptions,
   CFIndex versionOfNodes
){};


/*CFXMLTreeCreateFromDataWithError

Parses the given XML data and returns the resulting CFXMLTree object and any error information. 

CFXMLTreeRef CFXMLTreeCreateFromDataWithError (
   CFAllocatorRef allocator,
   CFDataRef xmlData,
   CFURLRef dataSource,
   CFOptionFlags parseOptions,
   CFIndex versionOfNodes
   CFDictionaryRef *errorDict
);
Parameters
allocator

The allocator to use to allocate memory for the new object. Pass NULL or kCFAllocatorDefault to use the current default allocator. 
xmlData

The XML data you wish to parse. 
dataSource

The URL from which the XML data was obtained. The URL is used to resolve any relative references found in xmlData. Pass NULL if a valid URL is unavailable. 
parseOptions

Flags which control how the XML data will be parsed. See “Parsing Options” for the list of available options.
versionOfNodes

Determines which version of CFXMLNode objects are produced by the parser. 
errorDict

Upon return, if an error occurs contains a CFDictionary object that describes the error. If no errors occur, this parameter is not changed. Pass NULL if you don’t want error information. See “Error Dictionary Keys” for a description of the key-value pairs in this dictionary. Ownership follows the Create Rule.
Return Value

A new CFXMLTree object containing the data from the specified XML document. Ownership follows the Create Rule.
Discussion

Use this function instead of CFXMLTreeCreateFromData if you need access to XML parsing errors.
Availability
Available in Mac OS X v10.3 and later.
Declared In
CFXMLParser.h*/
#ifdef OC_CF
CFXMLTreeRef CFXMLTreeCreateFromDataWithError (
   CFAllocatorRef allocator,
   CFDataRef xmlData,
   CFURLRef dataSource,
   CFOptionFlags parseOptions,
   CFIndex versionOfNodes,
   CFDictionaryRef *errorDict
){};
#endif
