 #include <IOKit/IOCommandGate.h>


/*runAction 


Single thread a call to an action with the target work-loop. 

public

virtual IOReturn runAction(
    Action action, 
    void *arg0 = 0,
    void *arg1 = 0, 
    void *arg2 = 0,
    void *arg3 = 0); 
Parameters
action 
Pointer to function to be executed in work-loop context.
arg0 
Parameter for action parameter, defaults to 0.
arg1 
Parameter for action parameter, defaults to 0.
arg2 
Parameter for action parameter, defaults to 0.
arg3 
Parameter for action parameter, defaults to 0.
Return Value

kIOReturnSuccess if successful. kIOReturnBadArgument if action is not defined, kIOReturnNotPermitted if this event source is currently disabled. 
Discussion 

Client function that causes the given action to be called in a single threaded manner. Beware the work-loop's gate is recursive and command gates can cause direct or indirect re-entrancy. When the executing on a client's thread runAction will sleep until the work-loop's gate opens for execution of client actions, the action is single threaded against all other work-loop event sources.*/
 IOReturn IOCommandGate ::  runAction(
    Action action, 
    void *arg0  ,
    void *arg1 , 
    void *arg2 ,
    void *arg3 ){}; 


/*commandSleep


Put a thread that is currently holding the command gate to sleep. 

public

virtual IOReturn commandSleep(
    void *event, 
    UInt32 interruptible = THREAD_ABORTSAFE); 
Parameters
event
Pointer to an address.
interruptible
THREAD_UNINT, THREAD_INTERRUPTIBLE or THREAD_ABORTSAFE, defaults to THREAD_ABORTSAFE.
Return Value

THREAD_AWAKENED - normal wakeup, THREAD_TIMED_OUT - timeout expired, THREAD_INTERRUPTED - interrupted by clear_wait, THREAD_RESTART - restart operation entirely, kIOReturnNotPermitted if the calling thread does not hold the command gate. 
Discussion 

Put a thread to sleep waiting for an event but release the gate first. If the event occurs then the commandGate is closed before the returns.*/
 IOReturn  IOCommandGate::commandSleep(
    void *event, 
    UInt32 interruptible ){};
 
/*commandWakeup


Wakeup one or more threads that are asleep on an event. 

public

virtual void commandWakeup(
    void *event,
    bool oneThread = false); 
Parameters
event
Pointer to an address.
onlyOneThread
true to only wake up at most one thread, false otherwise.*/
 void  IOCommandGate::commandWakeup(
    void *event,
    bool oneThread ){};


/*commandGate


Factory method to create and initialise an IOCommandGate, See $link init. 

public

static IOCommandGate *commandGate(
    OSObject *owner,
    Action action = 0); 
Return Value

Returns a pointer to the new command gate if sucessful, 0 otherwise.*/
 IOCommandGate * IOCommandGate::commandGate(
    OSObject *owner,
    Action action ){};
 /*enable


Enable command gate, this will unblock any blocked Commands and Actions. 

public

virtual void enable(); 
Discussion 

Enable the command gate. The attemptAction/attemptCommand calls will now be enabled and can succeeed. Stalled runCommand/runAction calls will be woken up.*/
void IOCommandGate:: enable(){};
 

/*runCommand


Single thread a command with the target work-loop. 

public

virtual IOReturn runCommand(
    void *arg0 = 0,
    void *arg1 = 0, 
    void *arg2 = 0,
    void *arg3 = 0); 
Parameters
arg0
Parameter for action of command gate, defaults to 0.
arg1
Parameter for action of command gate, defaults to 0.
arg2
Parameter for action of command gate, defaults to 0.
arg3
Parameter for action of command gate, defaults to 0.
Return Value

kIOReturnSuccess if successful. kIOReturnNotPermitted if this event source is currently disabled, kIOReturnNoResources if no action available. 
Discussion 

Client function that causes the current action to be called in a single threaded manner. Beware the work-loop's gate is recursive and command gates can cause direct or indirect re-entrancy. When the executing on a client's thread runCommand will sleep until the work-loop's gate opens for execution of client actions, the action is single threaded against all other work-loop event sources.*/
 IOReturn IOCommandGate::runCommand(
    void *arg0 ,
    void *arg1 , 
    void *arg2 ,
    void *arg3 ){};

/*attemptAction


Single thread a call to an action with the target work-loop. 

public

virtual IOReturn attemptAction(
    Action action, 
    void *arg0 = 0,
    void *arg1 = 0, 
    void *arg2 = 0,
    void *arg3 = 0); 
Parameters
action
Pointer to function to be executed in work-loop context.
arg0
Parameter for action parameter, defaults to 0.
arg1
Parameter for action parameter, defaults to 0.
arg2
Parameter for action parameter, defaults to 0.
arg3
Parameter for action parameter, defaults to 0.
Return Value

kIOReturnSuccess if successful. kIOReturnBadArgument if action is not defined, kIOReturnNotPermitted if this event source is currently disabled, kIOReturnCannotLock if lock attempt fails. 

Discussion 

Client function that causes the given action to be called in a single threaded manner. Beware the work-loop's gate is recursive and command gates can cause direct or indirect re-entrancy. When the executing on a client's thread attemptCommand will fail if the work-loop's gate is open.*/
 IOReturn IOCommandGate::attemptAction(
    Action action,
    void *arg0 ,
    void *arg1 ,
    void *arg2 ,
    void *arg3 ){};

