#include <IOKit/IOInterruptEventSource.h>


/*interruptEventSource


Factory function for IOInterruptEventSources creation and initialization. 

public

static IOInterruptEventSource * interruptEventSource(
    OSObject *owner, 
    Action action, 
    IOService *provider = 0, 
    int intIndex = 0); 
Parameters
owner
Owning client of the new event source.
action
C function to call when something happens.
provider
IOService that represents the interrupt source. Defaults to 0. When no provider is defined the event source assumes that the client will in some manner call the interruptOccurred method explicitly. This will start the ball rolling for safe delivery of asynchronous events into the driver.
intIndex
The index of the interrupt within the provider's interrupt sources. Defaults to 0, i.e. the first interrupt in the provider.
Return Value

Returns a new interrupt event source if successfully created and initialized, 0 otherwise.*/

 IOInterruptEventSource *  IOInterruptEventSource::interruptEventSource(
    OSObject *owner, 
    Action action, 
    IOService *provider , 
    int intIndex ){}; 

/*enable


Enables event source. 

public

virtual void enable(); 
Discussion 

A subclass implementation is expected to respect the enabled state when checkForWork is called. Calling this function will cause the work loop to be signalled so that a checkForWork is performed.*/
 void IOInterruptEventSource:: enable(){};
 

/*disable


Disables event source. 

public

virtual void disable(); 
Discussion 

A subclass implementation is expected to respect the enabled state when checkForWork is called.*/
void IOInterruptEventSource:: disable(){};

 /*getIntIndex


Get'ter for intIndex interrupt index variable. 

public

virtual int getIntIndex() const; 
Return Value

Returns the value of intIndex.*/

 int IOInterruptEventSource:: getIntIndex() const{};

/*interruptOccurred


Functions that get called by the interrupt controller (see IOService::registerInterrupt). 

public

virtual void interruptOccurred(
    void *,
    IOService *nub,
    int ind); 
Parameters
nub
Where the interrupt originated from.
ind
This interrupt's index within 'nub'.*/
 void IOInterruptEventSource::interruptOccurred(
    void *,
    IOService *nub,
    int ind){}; 
