#include <stdio.h>
#include <IOKit/IOLib.h>


const char *IOFindNameForValue(int value, 
	const IONamedValue *namedValueArray){};//c

void IOGetTime( mach_timespec_t * clock_time){};//c
struct OSDictionary * IOOFPathMatching( const char * path, char * buf, int maxLen ){};//c
void IOPanic(const char *reason){};//c

#ifdef KERNEL
#define KERNEL_IOBSDNameMatching IOBSDNameMatching
#endif
struct OSDictionary *KERNEL_IOBSDNameMatching( const char * name ){};//c

//////////////////////////
/*Debugger


Enter the kernel debugger. 
void Debugger(
    const char *reason);  
Parameters
reason
A C-string to describe why the debugger is being entered.
Discussion 

This function freezes the kernel and enters the builtin debugger. It may not be possible to exit the debugger without a second machine.*/
#ifndef MACTYPES_DEBUGGER
#define IOKIT_DEBUGGER
void Debugger(
    const char *reason){
printf ("Debugger",*reason);
};  
#endif


/*IOLog


Log a message to console in text mode, and /var/log/system.log. 
void IOLog(
    const char *format,
    ...) __attribute__(
    (
        format(
            printf,
            1,
            2)));  
Parameters
format
A printf() style format string (see printf() documentation).
other
arguments described by the format string.
Discussion 

This function allows a driver to log diagnostic information to the screen during verbose boots, and to a log file found at /var/log/system.log. IOLog should not be called from interrupt context.*/
void IOLog(const char *format, ...){
printf ("IOLog",*format);
};


/*IOSleep 


Sleep the calling thread for a number of milliseconds. 

void IOSleep(
    unsigned milliseconds);  
Parameters
milliseconds 
The integer number of milliseconds to wait.
Discussion 

This function blocks the calling thread for at least the number of specified milliseconds, giving time to other processes.*/

void IOSleep(unsigned milliseconds){}; 


/*IODelay


Spin delay for a number of microseconds. 

void IODelay(
    unsigned microseconds);  
Parameters
microseconds
The integer number of microseconds to spin wait.
Discussion 

This function spins to delay for at least the number of specified microseconds. Since the CPU is busy spinning no time is made available to other processes; this method of delay should be used only for short periods. Also, the AbsoluteTime based APIs of kern/clock.h provide finer grained and lower cost delays.*/

void IODelay(
    unsigned microseconds){};

/*kprintf

Print text to the console.    void kprintf(const char *format, ... );


Identical to printf in user space. It is not safe to call kprintf from within an interrupt context. This should generally not be an issue, as you should avoid calling NKE functions from within an I/O Kit driver’s filter routine as a matter of course, but it is worth noting.*/
void kprintf(const char *format, ... ){};


/*IOMalloc


Allocates general purpose, wired memory in the kernel map. 

void * IOMalloc(
    vm_size_t size);  
Parameters
size
Size of the memory requested.
Return Value

Pointer to the allocated memory, or zero on failure. 
Discussion 

This is a general purpose utility to allocate memory in the kernel. There are no alignment guarantees given on the returned memory, and alignment may vary depending on the kernel configuration. This function may block and so should not be called from interrupt level or while a simple lock is held.*/
void * IOMalloc(
    vm_size_t size){};

/*IOFree


Frees memory allocated with IOMalloc. 

void IOFree(
    void *address,
    vm_size_t size);  
Parameters
address
Pointer to the allocated memory.
size
Size of the memory allocated.
Discussion 

This function frees memory allocated with IOMalloc, it may block and so should not be called from interrupt level or while a simple lock is held.*/

void IOFree(
    void *address,
    vm_size_t size){};

/*IOMallocContiguous


Allocates wired memory in the kernel map, with an alignment restriction and physically contiguous. 

void * IOMallocContiguous(
    vm_size_t size,
    vm_size_t alignment, 
    IOPhysicalAddress *physicalAddress);  
Parameters
size
Size of the memory requested.
alignment
Byte count of the alignment for the memory. For example, pass 256 to get memory allocated at an address with bits 0-7 zero.
physicalAddress
IOMallocContiguous returns the physical address of the allocated memory here, if physicalAddress is a non-zero pointer.
Return Value

Virtual address of the allocated memory, or zero on failure. 
Discussion 

This is a utility to allocate memory in the kernel, with an alignment restriction which is specified as a byte count, and will allocate only physically contiguous memory. The request may fail if memory is fragmented, and may cause large amounts of paging activity. This function may block and so should not be called from interrupt level or while a simple lock is held.*/

void * IOMallocContiguous(
    vm_size_t size,
    vm_size_t alignment, 
    IOPhysicalAddress *physicalAddress){};


/*IOFreeContiguous


Frees memory allocated with IOMallocContiguous. 

void IOFreeContiguous(
    void *address,
    vm_size_t size);  
Parameters
address
Virtual address of the allocated memory.
size
Size of the memory allocated.
Discussion 

This function frees memory allocated with IOMallocContiguous, it may block and so should not be called from interrupt level or while a simple lock is held.*/
void IOFreeContiguous(
    void *address,
    vm_size_t size){};


/*IOCreateThread


Create a kernel thread. 

IOThread IOCreateThread(
    IOThreadFunc function,
    void *argument);  
Parameters
function
A C-function pointer where the thread will begin execution.
argument
Caller specified data to be passed to the new thread.
Return Value

An IOThread identifier for the new thread, equivalent to an osfmk thread_t. 
Discussion 

This function creates a kernel thread, and passes the caller supplied argument to the new thread. Warning: the value returned by this function is not 100% reliable. There is a race condition where it is possible that the new thread has already terminated before this call returns. Under that circumstance the IOThread returned will be invalid. In general there is little that can be done with this value except compare it against 0. The thread itself can call IOThreadSelf() 100% reliably and that is the prefered mechanism to manipulate the IOThreads state.*/
IOThread IOCreateThread(
    IOThreadFunc function,
    void *argument){};

/*IOExitThread


Terminate exceution of current thread. 

void IOExitThread(
    void) __dead2;  
Discussion 

This function destroys the currently running thread, and does not return.*/
void IOExitThread(
    void){};  


/*IOMallocAligned


Allocates wired memory in the kernel map, with an alignment restriction. 

void * IOMallocAligned(
    vm_size_t size,
    vm_offset_t alignment);  
Parameters
size
Size of the memory requested.
alignment
Byte count of the alignment for the memory. For example, pass 256 to get memory allocated at an address with bit 0-7 zero.
Return Value

Pointer to the allocated memory, or zero on failure. 
Discussion 

This is a utility to allocate memory in the kernel, with an alignment restriction which is specified as a byte count. This function may block and so should not be called from interrupt level or while a simple lock is held.*/
void * IOMallocAligned(
    vm_size_t size,
    vm_offset_t alignment){};  

/*IOFreeAligned


Frees memory allocated with IOMallocAligned. 

void IOFreeAligned(
    void *address,
    vm_size_t size);  
Parameters
address
Pointer to the allocated memory.
size
Size of the memory allocated.
Discussion 

This function frees memory allocated with IOMallocAligned, it may block and so should not be called from interrupt level or while a simple lock is held.*/
void IOFreeAligned(
    void *address,
    vm_size_t size){}; 


/*IOFreePageable


Frees memory allocated with IOMallocPageable. 

void IOFreePageable(
    void *address,
    vm_size_t size);  
Parameters
address
Virtual address of the allocated memory.
size
Size of the memory allocated.
Discussion 

This function frees memory allocated with IOMallocPageable, it may block and so should not be called from interrupt level or while a simple lock is held.*/
void IOFreePageable(
    void *address,
    vm_size_t size){};  

/*IOMallocPageable


Allocates pageable memory in the kernel map. 

void * IOMallocPageable(
    vm_size_t size,
    vm_size_t alignment);  
Parameters
size
Size of the memory requested.
alignment
Byte count of the alignment for the memory. For example, pass 256 to get memory allocated at an address with bits 0-7 zero.
Return Value

Pointer to the allocated memory, or zero on failure. 
Discussion 

This is a utility to allocate pageable memory in the kernel. This function may block and so should not be called from interrupt level or while a simple lock is held.*/
void * IOMallocPageable(
    vm_size_t size,
    vm_size_t alignment){};  

/*IOMappedWrite32


Write four bytes to the desired "Physical" IOSpace address. 

void IOMappedWrite32(
    IOPhysicalAddress address,
    UInt32 value);  
Parameters
address
The desired address, as returned by IOMemoryDescriptor::getPhysicalSegment.
value
Data to be writen to the desired location
Discussion 

Write four bytes to the desired "Physical" IOSpace address. This function allows the developer to write to an address returned from any memory descriptor's getPhysicalSegment routine.*/
void IOMappedWrite32(
    IOPhysicalAddress address,
    UInt32 value){}; 

/*IOMappedRead32


Read four bytes from the desired "Physical" IOSpace address. 

UInt32 IOMappedRead32(
    IOPhysicalAddress address);  
Parameters
address
The desired address, as returned by IOMemoryDescriptor::getPhysicalSegment.
Return Value

Data contained at that location 
Discussion 

Read four bytes from the desired "Physical" IOSpace address. This function allows the developer to read an address returned from any memory descriptor's getPhysicalSegment routine. It can then be used by segmenting a physical page slightly to tag the physical page with its kernel space virtual address.*/
UInt32 IOMappedRead32(
    IOPhysicalAddress address){};  
