#include <IOKit/IOLocks.h>

int IOLockInitWithState(IOLock* a,int b){};//?
int IOTakeLock(IOLock * a){};//?
int IOUnlock(IOLock* a){};//?

/*IOSimpleLockAlloc


Allocates and initializes a spin lock. 

IOSimpleLock * IOSimpleLockAlloc(
    void );  
Return Value

Pointer to the allocated lock, or zero on failure. 
Discussion 

Allocates an initializes a spin lock in general purpose memory, and initializes it. Spin locks provide non-blocking mutual exclusion for synchronization between thread context and interrupt context, or for multiprocessor synchronization, and are supplied by libkern/locks.h. This function may block and so should not be called from interrupt level or while a spin lock is held.*/
IOSimpleLock * IOSimpleLockAlloc(
    void ){};
 

/*IOSimpleLockInit


Initializes a spin lock. 

void IOSimpleLockInit(
    IOSimpleLock *lock );  
Parameters
lock
Pointer to the lock.
Discussion 

Initializes an embedded spin lock, to the unlocked state.*/
void IOSimpleLockInit(
    IOSimpleLock *lock ){};


/*IOSimpleLockLock


Locks a spin lock. 

void IOSimpleLockLock(
    IOSimpleLock *lock );  
Parameters
lock
Pointer to the lock.
Discussion 

Locks the spin lock. If the lock is held, spin waiting for its unlock. Spin locks disable preemption, cannot be held across any blocking operation, and should be held for very short periods. When used to synchronize between interrupt context and thread context they should be locked with interrupts disabled --- IOSimpleLockLockDisableInterrupt will do both. Locking the lock recursively from one thread will result in deadlock.*/
void IOSimpleLockLock(
    IOSimpleLock *lock ){};


/*IOSimpleLockUnlock


Unlocks a spin lock. 

void IOSimpleLockUnlock(
    IOSimpleLock *lock );  
Parameters
lock
Pointer to the lock.
Discussion 

Unlocks the lock, and restores preemption. Results are undefined if the caller has not locked the lock.*/
void IOSimpleLockUnlock(
    IOSimpleLock *lock ){};


/*IOSimpleLockFree


Frees a spin lock. 

void IOSimpleLockFree(
    IOSimpleLock *lock );  
Parameters
lock
Pointer to the lock.
Discussion 

Frees a lock allocated with IOSimpleLockAlloc.*/
void IOSimpleLockFree(
    IOSimpleLock *lock ){};


/*IOLockFree


Frees a mutex. 

void IOLockFree(
    IOLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Discussion 

Frees a lock allocated with IOLockAlloc. Any blocked waiters will not be awakened.*/

void IOLockFree(
    IOLock *lock){};


/*IOLockAlloc


Allocates and initializes a mutex. 

IOLock * IOLockAlloc(
    void );  
Return Value

Pointer to the allocated lock, or zero on failure. 
Discussion 

Allocates a mutex in general purpose memory, and initilizes it. Mutexes are general purpose blocking mutual exclusion locks, supplied by libkern/locks.h. This function may block and so should not be called from interrupt level or while a spin lock is held.*/
IOLock * IOLockAlloc(
    void ){};


/*IOLockLock


Locks a mutex. 

void IOLockLock(
    IOLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Discussion 

Locks the mutex. If the lock is held by any thread, block waiting for its unlock. This function may block and so should not be called from interrupt level or while a spin lock is held. Locking the mutex recursively from one thread will result in deadlock.*/

void IOLockLock(
    IOLock *lock){};

/*IOLockUnlock


Unlocks a mutex. 

void IOLockUnlock(
    IOLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Discussion 

Unlocks the mutex and wakes any blocked waiters. Results are undefined if the caller has not locked the mutex. This function may block and so should not be called from interrupt level or while a spin lock is held.*/

void IOLockUnlock(
    IOLock *lock){};  

/*IOSimpleLockLockDisableInterrupt


Locks a spin lock, disabling interrupts. 

static __inline__ IOInterruptState IOSimpleLockLockDisableInterrupt(
    IOSimpleLock *lock ) 
Parameters
lock
Pointer to the lock.
Return Value

True if interrupts are enabled, false if interrupts are disabled. 
Discussion 

Locks the spin lock, disabling interrupts. If the lock is held, spin waiting for its unlock. Simple locks disable preemption, cannot be held across any blocking operation, and should be held for very short periods. When used to synchronize between interrupt context and thread context they should be locked with interrupts disabled --- IOSimpleLockLockDisableInterrupt does both. Locking the lock recursively from one thread will result in deadlock.*/
 IOInterruptState IOSimpleLockLockDisableInterrupt(
    IOSimpleLock *lock ){};


/*IOSimpleLockUnlockEnableInterrupt


Unlocks a spin lock and restores interrupt state. 

static __inline__ void IOSimpleLockUnlockEnableInterrupt(
    IOSimpleLock *lock, 
    IOInterruptState state ) 
Parameters
lock
Pointer to the lock.
state
The interrupt state returned by IOSimpleLockLockDisableInterrupt.
Discussion 

Unlocks the lock, and restores preemption and interrupts to the state they were in when the lock was taken. Results are undefined if the caller has not locked the lock.*/
 void IOSimpleLockUnlockEnableInterrupt(
    IOSimpleLock *lock, 
    IOInterruptState state ) {};


/*IORecursiveLockAlloc


Allocates and initializes an recursive lock. 

IORecursiveLock * IORecursiveLockAlloc(
    void );  
Return Value

Pointer to the allocated lock, or zero on failure. 
Discussion 

Allocates a recursive lock in general purpose memory, and initializes it. Recursive locks function identically to mutexes but allow one thread to lock more than once, with balanced unlocks.*/

IORecursiveLock * IORecursiveLockAlloc(
    void ){};


/*IORecursiveLockHaveLock


Checks if a recursive lock is held by the calling thread. 

boolean_t IORecursiveLockHaveLock(
    const IORecursiveLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Return Value

True if the calling thread holds the lock, otherwise false. 
Discussion 

If the lock is held by the calling thread returns true, otherwise the lock is unlocked or held by another thread and false is returned.*/

boolean_t IORecursiveLockHaveLock(
    const IORecursiveLock *lock){};

/*IORecursiveLockLock


Locks a recursive lock. 

void IORecursiveLockLock(
    IORecursiveLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Discussion 

If the lock is held by another thread, block waiting for its unlock. This function may block and so should not be called from interrupt level or while a spin lock is held. The lock may be taken recursively by the same thread, with a balanced number of calls to IORecursiveLockUnlock.*/
void IORecursiveLockLock(
    IORecursiveLock *lock){};


/*IORecursiveLockUnlock


Unlocks a recursive lock. 

void IORecursiveLockUnlock(
    IORecursiveLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Discussion 

Undoes one call to IORecursiveLockLock; if the lock is now unlocked wake any blocked waiters. Results are undefined if the caller does not balance calls to IORecursiveLockLock with IORecursiveLockUnlock. This function may block and so should not be called from interrupt level or while a spin lock is held.*/

void IORecursiveLockUnlock(
    IORecursiveLock *lock){};

/*IORecursiveLockFree


Frees a recursive lock. 

void IORecursiveLockFree(
    IORecursiveLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Discussion 

Frees a lock allocated with IORecursiveLockAlloc. Any blocked waiters will not be awakened.*/
void IORecursiveLockFree(
    IORecursiveLock *lock){};

/*IOLockSleep


Sleeps with mutex unlocked and relocks on wakeup. 

int IOLockSleep(
    IOLock *lock,
    void *event,
    UInt32 interType);  
Parameters
lock
Pointer to the locked lock.
event
The event to sleep on.
interType
How the sleep can be interrupted. Possible values are: 
THREAD_UNINT Not interruptible
THREAD_INTERRUPTIBLE Interruptible, but not guaranteed to be restartable
THREAD_ABORTSAFE Safely abortable
Return Value

The wait-result value indicating how the thread was awakened. Possible values are: 
THREAD_WAITING Thread is waiting
THREAD_AWAKENED Normal wakeup
THREAD_TIMED_OUT Timeout has expired
THREAD_INTERRUPTED Thread has been interrupted or aborted
THREAD_RESTART Restart operation entirely

Discussion 

Prepare to sleep, unlocks the mutex, and re-acquires it on wakeup. Results are undefined if the caller has not locked the mutex. This function may block and so should not be called from interrupt level or while a spin lock is held.*/
int IOLockSleep(
    IOLock *lock,
    void *event,
    UInt32 interType){};  


/*IOLockWakeup


Wakes up the thread holding the specified lock. 

void IOLockWakeup(
    IOLock *lock,
    void *event,
    bool oneThread);  
Parameters
lock
Pointer to the locked lock.
event
The event being waited on.
oneThread
A Boolean value indicating whether only one thread should be awakened (true) or all (false).
Discussion 

Wakes up the thread holding the specified lock and waiting on the specified event.*/
void IOLockWakeup(
    IOLock *lock,
    void *event,
    bool oneThread){};

/*IOLockTryLock


Attempts to lock a mutex. 

boolean_t IOLockTryLock(
    IOLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Return Value

True if the mutex was unlocked and is now locked by the caller, otherwise false. 
Discussion 

Locks the mutex if it is currently unlocked and returns true. If the lock is held by any thread, this function returns false.*/
boolean_t IOLockTryLock(
    IOLock *lock){};
  

/*IORecursiveLockSleep


Sleeps with the recursive lock unlocked and relocks on wakeup. 

extern int IORecursiveLockSleep(
    IORecursiveLock *lock, 
    void *event,
    UInt32 interType);  
Parameters
lock
Pointer to the allocated lock.
event
The event to sleep on.
interType
How the sleep can be interrupted. Possible values are: 
THREAD_UNINT Not interruptible
THREAD_INTERRUPTIBLE Interruptible, but not guaranteed to be restartable
THREAD_ABORTSAFE Safely abortable
Return Value

The wait-result value indicating how the thread was awakened. Possible values are: 
THREAD_WAITING Thread is waiting
THREAD_AWAKENED Normal wakeup
THREAD_TIMED_OUT Timeout has expired
THREAD_INTERRUPTED Thread has been interrupted or aborted
THREAD_RESTART Restart operation entirely

Discussion 

Prepare to sleep, unlocks the lock, and re-establishes it on wakeup. Results are undefined if the caller has not locked the lock. This function may block and so should not be called from interrupt level or while a spin lock is held.*/
int IORecursiveLockSleep(
    IORecursiveLock *lock, 
    void *event,
    UInt32 interType){};  


/*IORecursiveLockWakeup


Wakes up the thread holding the specified recursive lock. 

extern void IORecursiveLockWakeup(
    IORecursiveLock *lock, 
    void *event,
    bool oneThread);  
Parameters
lock
Pointer to the allocated lock.
event
The event being waited on.
oneThread
A Boolean value indicating whether only one thread should be awakened (true) or all (false).
Discussion 

Wakes up the thread holding the specified recursive lock and waiting on the specified event.*/
void IORecursiveLockWakeup(
    IORecursiveLock *lock, 
    void *event,
    bool oneThread){};  

/*IORWLockAlloc


Allocates and initializes a read/write lock. 

IORWLock * IORWLockAlloc(
    void );  
Return Value

Pointer to the allocated lock, or zero on failure. 
Discussion 

Allocates and initializes a read/write lock in general purpose memory, and initilizes it. Read/write locks provide for multiple readers, one exclusive writer, and are supplied by libkern/locks.h. This function may block and so should not be called from interrupt level or while a spin lock is held.*/
IORWLock * IORWLockAlloc(
    void ){};

/*IORWLockFree


Frees a read/write lock. 

void IORWLockFree(
    IORWLock *lock);  
Parameters
lock
Pointer to the allocated lock.
Discussion 

Frees a lock allocated with IORWLockAlloc. Any blocked waiters will not be awakened.*/
void IORWLockFree(
    IORWLock *lock){};  


/*IOSimpleLockTryLock


Attempts to lock a spin lock. 

boolean_t IOSimpleLockTryLock(
    IOSimpleLock *lock );  
Parameters
lock
Pointer to the lock.
Return Value

True if the lock was unlocked and is now locked by the caller, otherwise false. 
Discussion 

Locks the spin lock if it is currently unlocked, and returns true. If the lock is held, this function returns false. Successful calls to IOSimpleLockTryLock should be balanced with calls to IOSimpleLockUnlock.*/
boolean_t IOSimpleLockTryLock(
    IOSimpleLock *lock ){};  
