#include <IOKit/IORangeAllocator.h>

/*allocateRange


Allocates from the free list, at a set offset. 

public

virtual bool allocateRange(
    IORangeScalar start, 
    IORangeScalar size ); 
Parameters
start
The beginning of the range requested.
size
The size of the range requested.
Return Value

Returns true if the allocation was successful, else false. 
Discussion 

This method allocates a range from the free list, given a set offset passed in*/
 bool IORangeAllocator::allocateRange(
    IORangeScalar start, 
    IORangeScalar size ){};


/*withRange


Standard factory method for IORangeAllocator. 

public

static IORangeAllocator * withRange(
    IORangeScalar endOfRange, 
    IORangeScalar defaultAlignment = 0,
    UInt32 capacity = 0, 
    IOOptionBits options = 0 ); 
Parameters
endOfRange
If the free list is to contain an initial fragment, set endOfRange to the last offset in the range, ie. size - 1, to create a free fragment for the range zero to endOfRange inclusive. If zero is passed the free list will be initialized empty, and can be populated with calls to the deallocate method.
defaultAlignment
If this parameter is non-zero it specifies a required alignment for all allocations, for example pass 256 to align allocations on 256 byte boundaries. Zero or one specify unaligned allocations.
capacity
Sets the initial size of the free list in number of non-contiguous fragments. This value is also used for the capacityIncrement.
options
Pass kLocking if the instance can be used by multiple threads.
Return Value

Returns the new IORangeAllocator instance, to be released by the caller, or zero on failure. 
Discussion 

This method allocates and initializes an IORangeAllocator and optionally sets the free list to contain one fragment, from zero to an endOfRange parameter. The capacity in terms of free fragments and locking options are set for the instance.*/

IORangeAllocator * IORangeAllocator:: withRange(
    IORangeScalar endOfRange, 
    IORangeScalar defaultAlignment ,
    UInt32 capacity , 
    IOOptionBits options  ){}; 

/*deallocate


Deallocates a range to the free list. 

public

virtual void deallocate(
    IORangeScalar start, 
    IORangeScalar size ); 
Parameters
start
The beginning of the range requested.
size
Returns the size of the range requested.
Discussion 

This method deallocates a range to the free list, given a the start offset and length passed in.*/
 void IORangeAllocator::deallocate(
    IORangeScalar start, 
    IORangeScalar size ){}; 

/*allocate


Allocates from the free list, at any offset. 

public

virtual bool allocate(
    IORangeScalar size, 
    IORangeScalar *result, 
    IORangeScalar alignment = 0 ); 
Parameters
size
The size of the range requested.
result
The beginning of the range allocated is returned here on success.
alignment
If zero is passed, default to the allocators alignment, otherwise pass an alignment required for the allocation, for example 4096 to page align.
Return Value

Returns true if the allocation was successful, else false. 
Discussion 

This method allocates a range from the free list. The alignment will default to the alignment set when the allocator was created or may be set here.*/
 bool IORangeAllocator:: allocate(
    IORangeScalar size, 
    IORangeScalar *result, 
    IORangeScalar alignment  ){}; 

/*getFreeCount


Totals the sizes of the free fragments. 

public

virtual IORangeScalar getFreeCount(
    void ); 
Return Value

Returns the total of the free fragments sizes. 
Discussion 

This method returns the total of the sizes of the fragments on the free list.*/
 IORangeScalar IORangeAllocator::getFreeCount(
    void ){}; 
