#include <IOKit/hidsystem/IOHIDDescriptorParser.h>


/*HIDOpenReportDescriptor


The HIDOpenReportDescriptor function allocates the memory the parser needs to handle the given report descriptor, and then parses the report descriptor. 

extern OSStatus HIDOpenReportDescriptor (
    void *hidReportDescriptor, 
    ByteCount descriptorLength, 
    HIDPreparsedDataRef *preparsedDataRef, 
    UInt32 flags);  
Parameters
hidReportDescriptor
Contains a pointer to the actual HID report descriptor from the USB device's firmware
descriptorLength
The length of the HID report descriptor
preparsedDataRef
Preparsed data reference to be used for subsequent function calls
flags
Flags for this runction are kHIDFlag_StrictErrorChecking = 0x00000001
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success. 
Discussion 

When the parsed information is no longer needed, clients should call the HIDCloseReportDescriptor function.*/
OSStatus HIDOpenReportDescriptor (
    void *hidReportDescriptor, 
    ByteCount descriptorLength, 
    HIDPreparsedDataRef *preparsedDataRef, 
    UInt32 flags){};  

/*HIDCloseReportDescriptor


Disposes of the memory the parser allocated for the HIDOpenReportDescriptor function. 

extern OSStatus HIDCloseReportDescriptor (
    HIDPreparsedDataRef preparsedDataRef);  
Parameters
hidReportDescriptor
Contains a pointer to the actual HID report descriptor from the USB device's firmware
preparsedDataRef
Preparsed data reference for the report that is returned by the HIDOpenReportDescriptor function. After making a call to the HIDCloseReportDescriptor function, the preparsedDataRef is invalid and should not be used.
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success.*/
 OSStatus HIDCloseReportDescriptor (
    HIDPreparsedDataRef preparsedDataRef){}; 


/*HIDGetCapabilities


Returns the capabilities of a HID device based on the given preparsed data. 

extern OSStatus HIDGetCapabilities (
    HIDPreparsedDataRef preparsedDataRef, 
    HIDCapabilitiesPtr capabilities);  
Parameters
preparsedDataRef
Preparsed data reference for the report that is retuned by the HIDOpenReportDescriptor function
capabilities
Points to a caller allocated buffer, that upon return contains the parsed capability information for this HID device.
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success.*/
OSStatus HIDGetCapabilities (
    HIDPreparsedDataRef preparsedDataRef, 
    HIDCapabilitiesPtr capabilities){};  



/*HIDGetButtonCapabilities


Returns the button capabilities structures for a HID device based on the given preparsed data. 

extern OSStatus HIDGetButtonCapabilities (
    HIDReportType reportType, 
    HIDButtonCapabilitiesPtr buttonCaps, 
    UInt32 *buttonCapsSize, 
    HIDPreparsedDataRef preparsedDataRef);  
Parameters
reportType
Specifies the type of report for which to retrieve the scaled value. This parameter must be one of the following: kHIDInputReport, kHIDOutputReport, or kHIDFeatureReport
buttonCaps
Points to a caller-allocated buffer that will contain, on return, an array of HIDButtonCapabilities structures. The structures contain information for all buttons that meet the search criteria
buttonCapsSize
Contains the size of the buttonCaps array passed in to the function and is set to the number of elements actually placed in the array after the call completes.
preparsedDataRef
Preparsed data reference for the report that is retuned by the HIDOpenReportDescriptor function
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success.*/
 OSStatus HIDGetButtonCapabilities (
    HIDReportType reportType, 
    HIDButtonCapabilitiesPtr buttonCaps, 
    UInt32 *buttonCapsSize, 
    HIDPreparsedDataRef preparsedDataRef){};  



/*HIDGetValueCapabilities


The HIDGetValueCapabilities function retrieves the capabilities for all values for a specified top level collection. 

extern OSStatus HIDGetValueCapabilities (
    HIDReportType reportType, 
    HIDValueCapabilitiesPtr valueCaps, 
    UInt32 *valueCapsSize, 
    HIDPreparsedDataRef preparsedDataRef);  
Parameters
reportType
Specifies the type of report for which to retrieve the value capabilities. This parameter must be one of the following: kHIDInputReport, kHIDOutputReport, or kHIDFeatureReport.
valueCaps
On return, points to a caller-allocated buffer that contains an array of HIDValueCapabilities structures containing information for all values in the top level collection.
valueCapsSize
On input, specifies the size in array elements of the buffer provided in the valueCaps parameter. On output, this parameter is set to the actual number of elements that were returned in the buffer provided in the valueCaps parameter, if the function completed without error. The correct length necessary to retrieve the value capabilities can be found in the capability data returned for the device by the HIDGetCapabilities function.
preparsedDataRef
Preparsed data reference for the report that is retuned by the HIDOpenReportDescriptor function
Return Value

OSStatus Returns an error code if an error was encountered or noErr on success. 
Discussion 

The HIDGetValueCapabilities function retrieves the capability data for all values in a top level collection without regard for the usage, usage page or collection of the value. To retrieve value capabilities for a specific usage, usage page or collection, use the HIDGetSpecificValueCapabilities function.*/
 OSStatus HIDGetValueCapabilities (
    HIDReportType reportType, 
    HIDValueCapabilitiesPtr valueCaps, 
    UInt32 *valueCapsSize, 
    HIDPreparsedDataRef preparsedDataRef){};  
