#include <libkern/OSTypes.h>
#include <IOKit/IOReturn.h>
#include <IOKit/network/IONetworkData.h>

/*getBuffer


Gets a pointer to the data buffer. 

public

virtual const void * getBuffer() const; 
Return Value

Returns a pointer to the data buffer. Returns 0 if the buffer type is kIONetworkDataBufferTypeNone.*/
 const void * IONetworkData:: getBuffer() const{}; 

/*withInternalBuffer


Factory method that constructs and initializes an IONetworkData object with an internal data buffer. 

public

static IONetworkData * withInternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferSize
The number of bytes to allocate for the internal data buffer.
accessTypes
The initial supported access types.
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns an IONetworkData object on success, or 0 otherwise.*/
IONetworkData * IONetworkData::withInternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes,
    void *target , 
    Action action , 
    void *param ){}; 

/*withExternalBuffer


Factory method that constructs and initializes an IONetworkData object with an external data buffer. 

public

static IONetworkData * withExternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    void *externalBuffer, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferSize
The size of the external data buffer.
externalBuffer
Pointer to the external data buffer.
accessTypes
The initial supported access types.
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns an IONetworkData object on success, or 0 otherwise.*/
IONetworkData * IONetworkData::withExternalBuffer(
    const char *name, 
    UInt32 bufferSize, 
    void *externalBuffer, 
    UInt32 accessTypes   , 
    void *target , 
    Action action, 
    void *param ){}; 

/*getKey


Gets a unique OSSymbol key associated with this object. 

public

virtual const OSSymbol * getKey() const; 
Return Value

Returns an OSSymbol key that was generated from the name assigned to this object. 
Discussion 

During initialization, IONetworkData will create an OSSymbol key based on its assigned name.*/
 const OSSymbol * IONetworkData::getKey() const{}; 

/*reset


An access method that resets the data buffer. 

public

virtual IOReturn reset(); 
Return Value

Returns kIOReturnSuccess on success, kIOReturnNotWritable if reset access is not permitted, or an error from the notification handler. 
Discussion 

This method handles an external request to reset the data buffer. If notification is enabled, then the notification handler is called after the data buffer has been cleared.*/
IOReturn IONetworkData::reset(){}; 

/*write


An access method that writes to the data buffer. 

public

virtual IOReturn write(
    void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset = 0); 
Parameters
srcBuffer
Pointer to the source buffer.
srcBufferSize
The number of bytes to write to the data buffer.
writeOffset
An offset from the start of the destination data buffer to begin writing.
Return Value

Returns kIOReturnSuccess on success, kIOReturnBadArgument if any of the arguments provided is invalid, kIOReturnNotWritable if write access is not permitted, or an error from the notification handler. 
Discussion 

This method handles an external request to write to the data buffer from a source buffer provided by the accessor. After checking that the data object supports write accesses, the data buffer is updated if it exists. Then the registered notification handler is called.*/
 IOReturn IONetworkData:: write(
    void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset ){}; 

/*read


An access method that reads from the data buffer. 

public

virtual IOReturn read(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset = 0); 
Parameters
dstBuffer
Pointer to the destination buffer.
dstBufferSize
Pointer to an integer containing the size of the destination buffer. And is overwritten by this method to the actual number of bytes copied to the destination buffer.
readOffset
An offset from the start of the source data buffer to begin reading.
Return Value

Returns kIOReturnSuccess on success, kIOReturnBadArgument if any of the arguments provided is invalid, kIOReturnNotReadable if read access is not permitted, or an error from the notification handler. 
Discussion 

This method handles an external request to read from the data buffer and copy it to the destination buffer provided by the accessor. If notification is enabled, then the notification handler is called before the data buffer is copied to the destination buffer. The notification handler may use this opportunity to intervene and to update the contents of the data buffer.*/
IOReturn IONetworkData::read(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset ){}; 

/*getSize


Gets the size of the data buffer. 

public

virtual UInt32 getSize() const; 
Return Value

Returns the size of the data buffer managed by this object in bytes.*/
 UInt32 IONetworkData::getSize() const{}; 

/*init


Initializes an IONetworkData object. 

public

virtual bool init(
    const char *name, 
    UInt32 bufferType, 
    UInt32 bufferSize, 
    void *externalBuffer = 0, 
    UInt32 accessTypes =  (
        kIONetworkDataAccessTypeRead | kIONetworkDataAccessTypeSerialize), 
    void *target = 0, 
    Action action = 0, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferType
The type of buffer associated with this object.
bufferSize
The size of the data buffer.
externalBuffer
Pointer to an external data buffer.
accessTypes
The initial supported access types. Can be later modified by calling setAccessTypes().
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns true if initialized successfully, false otherwise.*/
 bool IONetworkData::init(
    const char *name, 
    UInt32 bufferType, 
    UInt32 bufferSize, 
    void *externalBuffer , 
    UInt32 accessTypes, 
    void *target , 
    Action action , 
    void *param ){};

/*withNoBuffer


Factory method that constructs and initializes an IONetworkData object without a data buffer. 

public

static IONetworkData * withNoBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes, 
    void *target, 
    Action action, 
    void *param = 0); 
Parameters
name
A name to assign to this object.
bufferSize
The size of the phantom data buffer.
accessTypes
The initial supported access types.
target
The notification target.
action
The notification action.
param
A parameter to pass to the notification action.
Return Value

Returns an IONetworkData object on success, or 0 otherwise. 
Discussion 

The notification handler must intervene when the IONetworkData is accessed.*/
 IONetworkData * IONetworkData::withNoBuffer(
    const char *name, 
    UInt32 bufferSize, 
    UInt32 accessTypes, 
    void *target, 
    Action action, 
    void *param ){}; 

/*free


Frees the IONetworkData object. 

protected

virtual void free(); */

 void IONetworkData::free(){}; 


/*getBufferType


Gets the type of data buffer managed by this object. 

public

virtual UInt32 getBufferType() const; 
Return Value

Returns a constant that describes the type of the data buffer.*/

UInt32 IONetworkData::getBufferType() const{}; 


/*setAccessTypes


Sets the types of access that are permitted on the data buffer. 

public

virtual void setAccessTypes(
    UInt32 types); 
Parameters
types
A mask of access types indicating the supported access types.*/
 void IONetworkData::setAccessTypes(
    UInt32 types){}; 


/*setNotificationTarget


Registers a C function to handle access notifications sent from this object. 

public

virtual void setNotificationTarget(
    void *target, 
    Action action, 
    void *param = 0); 
Parameters
target
The first parameter passed to the notification handler.
action
A pointer to a C function that will handle the notification. If 0, then notification is disabled.
param
An optional parameter passed to the notification handler.
Discussion 

A notification is sent by an IONetworkData object to the registered notification handler, when an access method is called to modify the contents of the data buffer.*/
 void IONetworkData::setNotificationTarget(
    void *target, 
    Action action, 
    void *param ){}; 

/*getAccessTypes


Gets the types of data access supported by this object. 

public

virtual UInt32 getAccessTypes() const; 
Return Value

Returns a mask of supported access types.*/
UInt32 IONetworkData::getAccessTypes() const{};

/*getNotificationTarget


Gets the first parameter that will be passed to the access notification handler. 

public

virtual void * getNotificationTarget() const; 
Return Value

Returns the first parameter that will be passed to the access notification handler.*/
 void *IONetworkData:: getNotificationTarget() const{}; 

/*getNotificationAction


Gets the C function that was registered to handle access notifications sent from this object. 

public

virtual Action getNotificationAction() const; 
Return Value

Returns a pointer to a C function, or 0 if notification is disabled.*/
 IONetworkData::Action IONetworkData::getNotificationAction() const{}; 


/*getNotificationParameter


Gets the parameter that will be passed to the access notification handler. 

public

virtual void * getNotificationParameter() const; 
Return Value

Returns the parameter that will be passed to the access notification handler.*/
 void * IONetworkData::getNotificationParameter() const{}; 

/*writeBytes


Writes to the data buffer with data from a source buffer provided by the caller. 

protected

virtual bool writeBytes(
    const void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset = 0); 
Parameters
srcBuffer
Pointer to a source buffer provided by the caller.
srcBufferSize
The size of the source buffer.
writeOffset
A byte offset from the start of the data buffer to begin writting.
Return Value

Returns true if the operation was successful, false otherwise.*/
 bool IONetworkData::writeBytes(
    const void *srcBuffer, 
    UInt32 srcBufferSize, 
    UInt32 writeOffset ){}; 



/*readBytes


Reads from the data buffer and copies the data to a destination buffer provided by the caller. 

protected

virtual bool readBytes(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset = 0) const; 
Parameters
dstBuffer
Pointer to the destination buffer.
dstBufferSize
Pointer to an integer containing the size of the destination buffer. And is overwritten by this method with the actual number of bytes copied to the destination buffer.
readOffset
A byte offset from the start of the data buffer to begin reading.
Return Value

Returns true if the operation was successful, false otherwise.*/
 bool IONetworkData::readBytes(
    void *dstBuffer, 
    UInt32 *dstBufferSize, 
    UInt32 readOffset ) const{}; 

/*clearBuffer


Clears the data buffer by filling it with zeroes. 

protected

virtual bool clearBuffer(); 
Return Value

Returns true if the operation was successful, false otherwise.*/
 bool IONetworkData::clearBuffer(){}; 

/*serialize


Serializes the IONetworkData object. 

public

virtual bool serialize(
    OSSerialize *s) const; 
Parameters
s
An OSSerialize object.
Return Value

Returns true on success, false otherwise. 
Discussion 

If notification is enabled, then the notification handler is called just before the data buffer is serialized.*/
 bool IONetworkData::serialize(
    OSSerialize *s) const{}; 

