#include <libkern/OSTypes.h>
#include <IOKit/network/IONetworkMedium.h>


/*getIndex


public

virtual UInt32 getIndex() const; 
Return Value

Returns the assigned medium index.*/
 UInt32 IONetworkMedium::getIndex() const{};
 
/*getType


public

virtual IOMediumType getType() const; 
Return Value

Returns the medium type assigned to this medium object.*/
 IOMediumType IONetworkMedium::getType() const{};


/*getMediumWithType


Finds a medium object from a dictionary with a given type. 

public

static IONetworkMedium * getMediumWithType(
    const OSDictionary *dict, 
    IOMediumType type, 
    IOMediumType mask = 0); 
Parameters
dict
The dictionary to look for a matching entry.
type
Search for an entry with this type.
mask
The don't care bits in IOMediumType. Defaults to 0, which implies that a perfect match is desired.
Return Value

Returns the first matching IONetworkMedium entry found, or 0 if no match was found. 
Discussion 

This method iterates through a dictionary and returns an IONetworkMedium entry with the given type. An optional mask supplies the don't care bits.*/
 IONetworkMedium * IONetworkMedium:: getMediumWithType(
    const OSDictionary *dict, 
    IOMediumType type, 
    IOMediumType mask){};


/*medium


Factory method that allocates and initializes an IONetworkMedium object. 

public

static IONetworkMedium * medium(
    IOMediumType type, 
    UInt64 speed, 
    UInt32 flags = 0, 
    UInt32 index = 0, 
    const char *name = 0); 
Parameters
type
The medium type, this value is encoded with bits defined in IONetworkMedium.h.
speed
The maximum (or the only) link speed supported over this medium in units of bits per second.
flags
An optional flag for the medium object. See IONetworkMedium.h for defined flags.
index
An optional index number assigned by the owner. Drivers can use this to store an index to a media table in the driver, or it may map to a driver-defined media type.
name
An optional name assigned to this medium object. If 0, then a name will be created based on the medium type by calling IONetworkMedium::nameForType(). Since the name of the medium is used as a key when inserted into a dictionary, the name chosen must be unique within the scope of the owner.
Return Value

Returns an IONetworkMedium instance on success, or 0 otherwise.*/

 IONetworkMedium * IONetworkMedium:: medium(
    IOMediumType type, 
    UInt64 speed, 
    UInt32 flags , 
    UInt32 index , 
    const char *name ){}; 


/*addMedium


Adds an IONetworkMedium object to a dictionary. 

public

static bool addMedium(
    OSDictionary *dict, 
    const IONetworkMedium *medium); 
Parameters
dict
An OSDictionary object where the medium object should be added as a new entry.
medium
The IONetworkMedium object to add to the dictionary.
Return Value

Returns true on success, false otherwise. 
Discussion 

A helper function to add an IONetworkMedium object to a given dictionary. The name of the medium is used as the key for the new dictionary entry.*/
bool IONetworkMedium:: addMedium(
    OSDictionary *dict, 
    const IONetworkMedium *medium){};
 
/*getSpeed


public

virtual UInt64 getSpeed() const; 
Return Value

Returns the maximum link speed supported by this medium.*/
 UInt64 IONetworkMedium::getSpeed() const{}; 

/*getKey


public

virtual const OSSymbol * getKey() const; 
Return Value

Returns the key to use for this medium object. This key should be used when this object is added to a dictionary. Same as getName().*/
const OSSymbol *  IONetworkMedium::getKey() const{}; 

/*getName


public

virtual const OSSymbol * getName() const; 
Return Value

Returns the name assigned to this medium object.*/
 const OSSymbol * IONetworkMedium::getName() const{}; 

/*init


Initializes an IONetworkMedium object. 

public

virtual bool init(
    IOMediumType type, 
    UInt64 speed, 
    UInt32 flags = 0, 
    UInt32 index = 0, 
    const char *name = 0); 
Parameters
type
The medium type, this value is encoded with bits defined in IONetworkMedium.h.
speed
The maximum (or the only) link speed supported over this medium in units of bits per second.
flags
An optional flag for the medium object. See IONetworkMedium.h for defined flags.
index
An optional index number assigned by the owner. Drivers can use this to store an index to a media table in the driver, or it may map to a driver-defined media type.
name
An optional name assigned to this medium object. If 0, then a name will be created based on the medium type by calling IONetworkMedium::nameForType(). Since the name of the medium is used as a key when inserted into a dictionary, the name chosen must be unique within the scope of the owner.
Return Value

Returns true on success, false otherwise.*/
 bool IONetworkMedium::init(
    IOMediumType type, 
    UInt64 speed, 
    UInt32 flags , 
    UInt32 index , 
    const char *name ){}; 

/*nameForType


Creates a name that describes a medium type. 

public

static const OSSymbol * nameForType(
    IOMediumType type); 
Parameters
type
A medium type. See IONetworkMedium.h for type encoding.
Return Value

Returns an OSSymbol object is created based on the type provided. 
Discussion 

Given a medium type, creates an OSymbol object that describes the medium type. There is a 1-to-1 mapping between the medium type, and the medium name created by this method. The caller is responsible for releasing the OSSymbol object returned.*/

const OSSymbol * IONetworkMedium:: nameForType(
    IOMediumType type){}; 


/*free


Frees the IONetworkMedium object. 

protected

virtual void free(); */
 void IONetworkMedium::free(){};


/*getFlags


public

virtual UInt32 getFlags() const; 
Return Value

Returns the medium flags.*/

UInt32 IONetworkMedium::getFlags() const{}; 

/*isEqualTo(const OSMetaClassBase *)


Tests for equality between a IONetworkMedium object and an OSObject. 

public

virtual bool isEqualTo(
    const OSMetaClassBase *obj) const; 
Parameters
obj
An OSObject to test against an IONetworkMedium object.
Return Value

Returns true if equal, false otherwise. 
Discussion 

The OSObject is considered equal to the IONetworkMedium object if the OSObject is an IONetworkMedium, and they have similar properties assigned to them during initialization.*/
bool IONetworkMedium::isEqualTo(
    const OSMetaClassBase *obj) const{}; 

/*isEqualTo(const IONetworkMedium *)


Tests for equality between two IONetworkMedium objects. 

public

virtual bool isEqualTo(
    const IONetworkMedium *medium) const; 
Parameters
medium
An IONetworkMedium to test against the IONetworkMedium object being called.
Return Value

Returns true if equal, false otherwise. 
Discussion 

Two IONetworkMedium objects are considered equal if they have similar properties assigned to them during initialization. */
 bool IONetworkMedium::isEqualTo(
    const IONetworkMedium *medium) const{}; 

/*serialize


Serializes the IONetworkMedium object. 

public

virtual bool serialize(
    OSSerialize *s) const; 
Parameters
s
An OSSerialize object.
Return Value

Returns true on success, false otherwise. 
Discussion 

A dictionary is created containing the properties assigned to this medium object, and this dictionary is then serialized using the OSSerialize object provided.*/
 bool IONetworkMedium::serialize(
    OSSerialize *s) const{}; 

/*removeMedium


Removes an IONetworkMedium object from a dictionary. 

public

static void removeMedium(
    OSDictionary *dict, 
    const IONetworkMedium *medium); 
Parameters
dict
The OSDictionary object where the medium object should be removed from.
medium
The name of this medium object is used as the key.
Discussion 

A helper function to remove an entry in a dictionary.*/
void IONetworkMedium::removeMedium(
    OSDictionary *dict, 
    const IONetworkMedium *medium){}; 

/*getMediumWithIndex


Finds a medium object from a dictionary with a given index. 

public

static IONetworkMedium * getMediumWithIndex(
    const OSDictionary *dict, 
    UInt32 index, 
    UInt32 mask = 0); 
Parameters
dict
The dictionary to look for a matching entry.
index
Search for an entry with the given index.
mask
The don't care bits in index. Defaults to 0, which implies that a perfect match is desired.
Return Value

Returns the first matching IONetworkMedium entry found, or 0 if no match was found. 
Discussion 

This method iterates through a dictionary and returns an IONetworkMedium entry with the given index. An optional mask supplies the don't care bits.*/
IONetworkMedium * IONetworkMedium::getMediumWithIndex(
    const OSDictionary *dict, 
    UInt32 index, 
    UInt32 mask ){}; 
