#include <IOKit/network/IOPacketQueue.h>


/*withCapacity


Factory method that constructs and initializes an IOPacketQueue object. 

public

static IOPacketQueue * withCapacity(
    UInt32 capacity = IOPacketQueueDefaultCapacity); 
Parameters
capacity
The initial capacity of the queue object. Can be later changed by calling the setCapacity() method.
Return Value

Returns an IOPacketQueue instance on success, or 0 otherwise.*/
 IOPacketQueue * IOPacketQueue::withCapacity(
    UInt32 capacity){};

/*getSize


Gets the size of the queue. 

public

virtual UInt32 getSize() const; 
Return Value

Returns the number of packets currently held by the queue.*/
 UInt32  IOPacketQueue:: getSize() const{};


/*flush


Frees all packets currently held in the queue and releases them back to the free mbuf pool. 

public

virtual UInt32 flush(); 
Return Value

Returns the number of packets freed. 
Discussion 

The size of the queue is cleared to zero.*/
 UInt32 IOPacketQueue:: flush(){};

/*enqueue(IOPacketQueue *)


Removes all packets from the specified queue, and adds them to the tail of this queue. 

public

virtual bool enqueue(
    IOPacketQueue *queue); 
Parameters
queue
The source IOPacketQueue object containing the packets to be transferred.
Return Value

Always returns true.*/
 bool IOPacketQueue::enqueue(
    IOPacketQueue *queue){}; 

/*enqueue(mbuf_t)


Adds a chain of packets to the tail of the queue. 

public

virtual bool enqueue(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns true on success, or false to indicate over-capacity and refusal to accept the packet chain provided. 
Discussion 

Packets are not added if the size of the queue has reached its capacity.*/
 bool IOPacketQueue:: enqueue(
    mbuf_t m){};

/*initWithCapacity


Initializes an IOPacketQueue object. 

public

virtual bool initWithCapacity(
    UInt32 capacity = IOPacketQueueDefaultCapacity); 
Parameters
capacity
The initial capacity of the queue. Can be later changed by calling the setCapacity() method.
Return Value

Returns true if initialized successfully, false otherwise. 
Discussion 

This method initializes an IOPacketQueue object with the given capacity.*/
 bool IOPacketQueue:: initWithCapacity(
    UInt32 capacity){}; 

/*free


Frees the IOPacketQueue object. 

protected

virtual void free(); 
Discussion 

All packets held by the queue are released back to the free pool, resource are deallocated, then super::free() is called.*/
 void IOPacketQueue:: free(){};

/*prepend(mbuf_t)


Adds a chain of packets to the head of the queue. 

public

virtual void prepend(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the head of the queue.*/
 void IOPacketQueue::prepend(
    mbuf_t m){}; 

/*prepend(IOPacketQueue *)


Removes all packets from the specified queue, and adds them to the head of this queue. 

public

virtual void prepend(
    IOPacketQueue *queue); 
Parameters
queue
The source IOPacketQueue object containing the packets to be transferred.*/
void IOPacketQueue:: prepend(
    IOPacketQueue *queue){}; 

/*dequeue


Removes a single packet from the head of the queue. 

public

virtual mbuf_t dequeue(); 
Return Value

Returns a packet removed from the head of the queue, or NULL if the queue was empty.*/
 mbuf_t IOPacketQueue::dequeue(){}; 


/*dequeueAll


Removes all packets from the queue and returns the head of the packet chain. 

public

virtual mbuf_t dequeueAll(); 
Return Value

Returns the head of a packet chain linking all packets that were held in the queue, or NULL if the queue was empty. 
Discussion 

The size of the queue is cleared to zero.*/
mbuf_t IOPacketQueue::dequeueAll(){}; 

/*getCapacity


Gets the current capacity of the queue. 

public

virtual UInt32 getCapacity() const; 
Return Value

Returns the current queue capacity.*/
UInt32 IOPacketQueue::getCapacity() const{}; 


/*peek


Examines the packet at the head of the queue without removing it from the queue. 

public

virtual const mbuf_t peek() const; 
Return Value

Returns the packet at the head of the queue. 
Discussion 

A following call to peek() or dequeue() will return the same packet. The caller must never modify the mbuf packet returned*/
 const mbuf_t IOPacketQueue::peek() const{}; 

/*setCapacity


Changes the capacity of the queue. 

public

virtual bool setCapacity(
    UInt32 capacity); 
Parameters
capacity
The new capacity.
Return Value

Returns true if the new capacity was accepted, false otherwise.*/
 bool IOPacketQueue::setCapacity(
    UInt32 capacity){}; 

/*enqueueWithDrop


Adds a chain of packets to the tail of the queue. 

public

virtual UInt32 enqueueWithDrop(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns the number of packets dropped and freed by the queue. 
Discussion 

Packets are dropped if the size of the queue has reached its capacity.*/
UInt32 IOPacketQueue::enqueueWithDrop(
    mbuf_t m){}; 

/*lockPrepend


Adds a chain of packets to the head of a synchronized queue. 

public

virtual void lockPrepend(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the head of the queue.
Return Value

Always returns true. 
Discussion 

A spinlock is used to synchronize access to the queue.*/
void IOPacketQueue:: lockPrepend(
    mbuf_t m){}; 

/*lockEnqueue


Adds a chain of packets to the tail of a synchronized queue. 

public

virtual bool lockEnqueue(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns true on success, or false to indicate over-capacity and refusal to accept the packet chain provided. 
Discussion 

Packets are not added if the size of the queue has reached its capacity. A spinlock is used to synchronize access to the queue.*/
 bool IOPacketQueue:: lockEnqueue(
    mbuf_t m){}; 

/*lockEnqueueWithDrop


Adds a chain of packets to the tail of a synchronized queue. 

public

virtual UInt32 lockEnqueueWithDrop(
    mbuf_t m); 
Parameters
m
A chain of packets to add to the tail of the queue.
Return Value

Returns the number of packets dropped and freed by the queue. 
Discussion 

Packets are dropped if the size of the queue has reached its capacity. A spinlock is used to synchronize access to the queue.*/
 UInt32 IOPacketQueue::lockEnqueueWithDrop(
    mbuf_t m){}; 

/*lockDequeue


Removes a single packet from the head of a synchronized queue. 

public

virtual mbuf_t lockDequeue(); 
Return Value

Returns a packet removed from the head of the queue, or NULL if the queue was empty. 
Discussion 

A spinlock is used to synchronize access to the queue.*/

 mbuf_t IOPacketQueue::lockDequeue(){}; 

/*lockDequeueAll


Removes all packets from a synchronized queue and returns the head of the packet chain. 

public

virtual mbuf_t lockDequeueAll(); 
Return Value

Returns the head of a packet chain linking all packets that were held in the queue, or NULL if the queue was empty. 
Discussion 

The size of the queue is cleared to zero. A spinlock is used to synchronize access to the queue.*/
 mbuf_t IOPacketQueue::lockDequeueAll(){}; 

/*lockFlush


Frees all packets currently held in a synchronized queue and releases them back to the free mbuf pool. 

public

virtual UInt32 lockFlush(); 
Return Value

Returns the number of packets freed. 
Discussion 

The size of the queue is cleared to zero. A spinlock is used to synchronize access to the queue.*/
 UInt32 IOPacketQueue::lockFlush(){};

