#include <ImageCapture/ImageCapture.h>


/*ICAObjectSendMessage

Use this API to send a message to a device object.

extern ICAError ICAObjectSendMessage( 
    ICAObjectSendMessagePB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAObjectSendMessagePB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAObjectSendMessage function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to send a message to a device object. All devices do not respond to all the messages defined above.

Availability
    Introduced in Mac OS X v10.0. */
 ICAError ICAObjectSendMessage( 
    ICAObjectSendMessagePB *pb, 
    ICACompletion completion ){};  
	
/*ICAGetDeviceList
7
Fetches the object at the top of the object heirarchy.

extern ICAError ICAGetDeviceList( 
    ICAGetDeviceListPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetDeviceListPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetDeviceList function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Image Capture framework presents cameras and scanners, their contents and their capabilities as a heirarchy of objects and their properties. The device list object is at the top of the heirarchy of objects. The ICAGetDeviceList function fetches this object in the object field of parameter pb. Children of the device list object can be accessed by passing the device list object to functions ICAGetChildCount() and ICAGetNthChild().



        Example:
        
        ICAObject GetDeviceList()
        {
            ICAGetDeviceListPB getDeviceListPB  = {};
            ICAObject          deviceList       = 0;
            OSErr              err;
            
            err = ICAGetDeviceList( &getDeviceListPB, nil );
            
            if ( noErr == err )
            {
                deviceList = getDeviceListPB.object;
            }
            
            return deviceList;
        }



Availability
    Introduced in Mac OS X v10.0. */
ICAError ICAGetDeviceList( 
    ICAGetDeviceListPB *pb, 
    ICACompletion completion ){}; 
	
	/*ICAGetChildCount

Fetches the number of children of an object. This API is deprecated in 10.5.

extern ICAError ICAGetChildCount( 
    ICAGetChildCountPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetChildCountPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetChildCount function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Image Capture framework presents cameras and scanners, their contents and their capabilities as a heirarchy of objects and their properties. The ICAGetChildCount function fetches the number of children of the object specified in the object field of paramter pb.



        Example:
        
        UInt32 GetNumberOfDevices ()
        {
            ICAGetChildCountPB getChildCountPB;
            OSErr              err;
            
            memset(&getChildCountPB, 0, sizeof(ICAGetChildCountPB));
            getChildCountPB.object = GetDeviceList();
            err = ICAGetChildCount(&getChildCountPB, nil);
            
            return getChildCountPB.count;
        }



Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
ICAError ICAGetChildCount( 
    ICAGetChildCountPB *pb, 
    ICACompletion completion ){};  
	
	/*ICAGetNthChild

Fetches the child of a given object at a given index. This API is deprecated in 10.5.

extern ICAError ICAGetNthChild( 
    ICAGetNthChildPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetNthChildPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetNthChild function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Image Capture framework presents cameras and scanners, their contents and their capabilities as a heirarchy of objects and their properties. The ICAGetNthChild function fetches the child object of an object specifed in the parentObject field of the parameter pb at the index specified in the index field of the parameter pb. The index is zero-based. The function also returns the ICAObjectInfo for the child object in the childInfo field of the parameter pb.



        Example:
        
        ICAObject GetFirstDevice () {
            ICAGetNthChildPB getNthChildPB;
            ICAObject        firstDevice = NULL;
            OSErr            err;
            UInt32           count;
            
            count = GetNumberOfDevices();
            if (count > 0)
            {
                memset(&getNthChildPB, 0, sizeof(ICAGetNthChildPB));
                getNthChildPB.parentObject = Get_Device_List();
                getNthChildPB.index = 0;
                err = ICAGetNthChild (&getNthChildPB, nil);
                if (noErr == err)
                {
                    firstDevice = getNthChildPB.childObject;
                }
            }
            return firstDevice;
        }



Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
 ICAError ICAGetNthChild( 
    ICAGetNthChildPB *pb, 
    ICACompletion completion ){};  
	
		
/*ICACopyObjectPropertyDictionary

Use this API to get a CFDictionaryRef containing all the properties for an object specified in the object field of the ICACopyObjectPropertyDictionaryPB struct.

extern ICAError ICACopyObjectPropertyDictionary( 
    ICACopyObjectPropertyDictionaryPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICACopyObjectPropertyDictionaryPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICACopyObjectPropertyDictionary function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

This API is the preferred way to get to any ICAObject related property data.



        Example:
        
        void  CopyObjectPropertyDictionary()
        {
            OSErr                             err;
            ICACopyObjectPropertyDictionaryPB pb = {};

            pb.object = <#ICAObject object#>;
            err = ICACopyObjectPropertyDictionary( &pb, NULL );

            if ( noErr != err)
            {
                // handle error
            }
            else
            {
                // Make sure to release the returned dictionary
                // pb.theDict   // CFDictionaryRef *
            }
        }
        



Availability
    Introduced in Mac OS X v10.1. */
	 ICAError ICACopyObjectPropertyDictionary( 
    ICACopyObjectPropertyDictionaryPB *pb, 
    ICACompletion completion ){};  


/*ICAGetObjectInfo

Use this API to get information about an object. This API is deprecated in 10.5.

extern ICAError ICAGetObjectInfo( 
    ICAGetObjectInfoPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetObjectInfoPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetObjectInfo function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get information about an object. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
 ICAError ICAGetObjectInfo( 
    ICAGetObjectInfoPB *pb, 
    ICACompletion completion ){};


/*ICAGetPropertyData

Use this API to get data associated with a property. This API is deprecated in 10.5. Use one of the ICACopy* APIs instead.

extern ICAError ICAGetPropertyData( 
    ICAGetPropertyDataPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetPropertyDataPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetPropertyData function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get data associated with a property. This API is deprecated in 10.5. Use one of the ICACopy* APIs instead.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
 ICAError ICAGetPropertyData( 
    ICAGetPropertyDataPB *pb, 
    ICACompletion completion ){};  
	
/*ICAGetPropertyByType

Use this API to get an object's property by type and its information. This API is deprecated in 10.5.

extern ICAError ICAGetPropertyByType( 
    ICAGetPropertyByTypePB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetPropertyByTypePB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetPropertyByType function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get an object's property by type and its information. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
	ICAError ICAGetPropertyByType( 
    ICAGetPropertyByTypePB *pb, 
    ICACompletion completion ){}; 

		
/*ICADownloadFile

Use this API to download a file to disk.

extern ICAError ICADownloadFile( 
    ICADownloadFilePB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICADownloadFilePB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICADownloadFile function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

This API is a convenient way to download a file to disk. To receive the image data in memory use ICACopyObjectData. Using ICAGetPropertyData is not recommend for this purpose since ICAGetPropertyData is Deprecated in 10.5.



        Example:
        
        void DownloadFile()
        {
            OSErr             err;
            ICADownloadFilePB pb = {};

            pb.flags         = <#UInt32 flags#>;
            pb.rotationAngle = <#Fixed rotationAngle#>;
            pb.object        = <#ICAObject object#>;
            pb.fileCreator   = <#OSType fileCreator#>;
            pb.dirFSRef      = <#FSRef * dirFSRef#>;
            pb.fileType      = <#OSType fileType#>;
            
            err = ICADownloadFile( &pb, NULL );

            if ( noErr != err )
            {
                // handle error
            }
            else
            {
                // pb.fileFSRef   // FSRef *
            }
        }



Availability
    Introduced in Mac OS X v10.1. */
ICAError ICADownloadFile( 
    ICADownloadFilePB *pb, 
    ICACompletion completion ){};

	/*ICAGetPropertyCount

Use this API to get the number of properties an object has. This API is deprecated in 10.5.

extern ICAError ICAGetPropertyCount( 
    ICAGetPropertyCountPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetPropertyCountPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetPropertyCount function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get the number of properties an object has. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
ICAError ICAGetPropertyCount( 
    ICAGetPropertyCountPB *pb, 
    ICACompletion completion ){};


/*ICAGetNthProperty

Use this API to get an object's specific property and its information. This API is deprecated in 10.5.

extern ICAError ICAGetNthProperty( 
    ICAGetNthPropertyPB *pb, 
    ICACompletion completion );  

Parameters

pb
    A pointer to an ICAGetNthPropertyPB parameter block.
completion
    A pointer to a completion routine that will be invoked at the completion of ICAGetNthProperty function. Set this parameter to NULL to invoke this API synchronously.

Return Value

Returns an error code defined in ICAApplication.h
Discussion

Use this API to get an object's specific property and its information. This API is deprecated in 10.5.

Availability
    Introduced in Mac OS X v10.0, but later deprecated in Mac OS X v10.5. */
 ICAError ICAGetNthProperty( 
    ICAGetNthPropertyPB *pb, 
    ICACompletion completion ){};


