#include <stdio.h>
#include <Security/SecKeychain.h>

//work


/*SecKeychainFindInternetPassword

Finds the first Internet password based on the attributes passed.

OSStatus SecKeychainFindInternetPassword (
   CFTypeRef keychainOrArray,
   UInt32 serverNameLength,
   const char *serverName,
   UInt32 securityDomainLength,
   const char *securityDomain,
   UInt32 accountNameLength,
   const char *accountName,
   UInt32 pathLength,
   const char *path,
   UInt16 port,
   SecProtocolType protocol,
   SecAuthenticationType authenticationType,
   UInt32 *passwordLength,
   void **passwordData,
   SecKeychainItemRef *itemRef
);
Parameters
keychainOrArray

A reference to an array of keychains to search, a single keychain or NULL to search the user’s default keychain search list.
serverNameLength

The length of the serverName character string.
serverName

A UTF-8 encoded character string representing the server name.
securityDomainLength

The length of the securityDomain character string.
securityDomain

A UTF-8 encoded character string representing the security domain. This parameter is optional, as not all protocols require it. Pass NULL if it is not required.
accountNameLength

The length of the accountName character string.
accountName

A UTF-8 encoded character string representing the account name.
pathLength

The length of the path character string.
path

A UTF-8 encoded character string representing the path.
port

The TCP/IP port number. Pass 0 to ignore the port number.
protocol

The protocol associated with this password. See “Keychain Protocol Type Constants” for a description of possible values.
authenticationType

The authentication scheme used. See “Keychain Authentication Type Constants” for a description of possible values. Pass the constant kSecAuthenticationTypeDefault, to specify the default authentication scheme.
passwordLength

On return, the length of the buffer pointed to by passwordData.
passwordData

On return, a pointer to a buffer containing the password data. Pass NULL if you want to obtain the item object but not the password data. In this case, you must also pass NULL in the passwordLength parameter. You should use the SecKeychainItemFreeContent function to free the memory pointed to by this parameter.
itemRef

On return, a pointer to the item object of the Internet password. Pass NULL if you don’t want to obtain this object.
Return Value

A result code. See “Keychain Services Result Codes”.
Discussion

This function finds the first Internet password item that matches the attributes you provide. This function optionally returns a reference to the found item.

This function decrypts the password before returning it to you. If the calling application is not in the list of trusted applications, the user is prompted before access is allowed. If the access controls for this item do not allow decryption, the function returns the errSecAuthFailed result code.

This function automatically calls the function SecKeychainUnlock to display the Unlock Keychain dialog box if the keychain is currently locked.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecKeychain.h*/

OSStatus SecKeychainFindInternetPassword (
   CFTypeRef keychainOrArray,
   UInt32 serverNameLength,
   const char *serverName,
   UInt32 securityDomainLength,
   const char *securityDomain,
   UInt32 accountNameLength,
   const char *accountName,
   UInt32 pathLength,
   const char *path,
   UInt16 port,
   SecProtocolType protocol,
   SecAuthenticationType authenticationType,
   UInt32 *passwordLength,
   void **passwordData,
   SecKeychainItemRef *itemRef
){};

/*SecKeychainAddInternetPassword

Adds a new Internet password to a keychain.

OSStatus SecKeychainAddInternetPassword (
   SecKeychainRef keychain,
   UInt32 serverNameLength,
   const char *serverName,
   UInt32 securityDomainLength,
   const char *securityDomain,
   UInt32 accountNameLength,
   const char *accountName,
   UInt32 pathLength,
   const char *path,
   UInt16 port,
   SecProtocolType protocol,
   SecAuthenticationType authenticationType,
   UInt32 passwordLength,
   const void *passwordData,
   SecKeychainItemRef *itemRef
);
Parameters
keychain

A reference to the keychain in which to store an Internet password. Pass NULL to specify the user’s default keychain.
serverNameLength

The length of the serverName character string.
serverName

A UTF-8 encoded character string representing the server name.
securityDomainLength

The length of the securityDomain character string.
securityDomain

A UTF-8 encoded character string representing the security domain. This parameter is optional. Pass NULL if the protocol does not require it.
accountNameLength

The length of the accountName character string.
accountName

A UTF-8 encoded character string representing the account name.
pathLength

The length of the path character string.
path

A UTF-8 encoded character string representing the path.
port

The TCP/IP port number. If no specific port number is associated with this password, pass 0.
protocol

The protocol associated with this password. See “Keychain Protocol Type Constants” for a description of possible values.
authenticationType

The authentication scheme used. See “Keychain Authentication Type Constants” for a description of possible values. Pass the constant kSecAuthenticationTypeDefault, to specify the default authentication scheme.
passwordLength

The length of the passwordData buffer.
passwordData

A pointer to a buffer containing the password data to be stored in the keychain.
itemRef

On return, a pointer to a reference to the new keychain item. Pass NULL if you don’t want to obtain this object. You must allocate the memory for this pointer. The memory that this pointer occupies must be released by calling the CFRelease function when finished with it.
Return Value

A result code. See “Keychain Services Result Codes”. The result code errSecNoDefaultKeychain indicates that no default keychain could be found. The result code errSecDuplicateItem indicates that you tried to add a password that already exists in the keychain. The result code errSecDataTooLarge indicates that you tried to add more data than is allowed for a structure of this type.
Discussion

This function adds a new Internet server password to the specified keychain. Required parameters to identify the password are serverName and accountName (you cannot pass NULL for both parameters). In addition, some protocols may require an optional securityDomain when authentication is requested. This function optionally returns a reference to the newly added item.

This function sets the initial access rights for the new keychain item so that the application creating the item is given trusted access. 

This function automatically calls the function SecKeychainUnlock to display the Unlock Keychain dialog box if the keychain is currently locked.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecKeychain.h*/
OSStatus SecKeychainAddInternetPassword (
   SecKeychainRef keychain,
   UInt32 serverNameLength,
   const char *serverName,
   UInt32 securityDomainLength,
   const char *securityDomain,
   UInt32 accountNameLength,
   const char *accountName,
   UInt32 pathLength,
   const char *path,
   UInt16 port,
   SecProtocolType protocol,
   SecAuthenticationType authenticationType,
   UInt32 passwordLength,
   const void *passwordData,
   SecKeychainItemRef *itemRef
){};

/*SecKeychainCopyDefault

Retrieves a pointer to the default keychain.

OSStatus SecKeychainCopyDefault (
   SecKeychainRef *keychain
);
Parameters
keychain

On return, a pointer to the default keychain object. The memory that this pointer occupies must be released by calling the CFRelease function when finished with it.
Return Value

A result code. See “Keychain Services Result Codes”. The result code errSecNoDefaultKeychain indicates that there is no default keychain.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecKeychain.h*/
OSStatus SecKeychainCopyDefault (
   SecKeychainRef *keychain
){
printf ("SecKeychainCopyDefault",*keychain);
};



/*SecKeychainGetPath

Determines the path of a keychain.

OSStatus SecKeychainGetPath (
   SecKeychainRef keychain,
   UInt32 *ioPathLength,
   char *pathName
);
Parameters
keychain

A reference to a keychain whose path you wish to obtain.
ioPathLength

On input, a pointer to the size of the character string pathName. On return, the size of pathName without the zero termination.
pathName

On input, a pointer to a buffer that you have allocated. On output, the buffer contains the POSIX path of the keychain as a UTF-8 encoded string. The function returns errSecBufferTooSmall if the provided buffer is too small.
Return Value

A result code. See “Keychain Services Result Codes”.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecKeychain.h*/

OSStatus SecKeychainGetPath (
   SecKeychainRef keychain,
   UInt32 *ioPathLength,
   char *pathName
){
printf ("SecKeychainGetPath",keychain,*ioPathLength,*pathName);
};

/*SecKeychainOpen

Opens a keychain.

OSStatus SecKeychainOpen (
   const char *pathName,
   SecKeychainRef *keychain
);
Parameters
pathName

A constant character string representing the POSIX path to the keychain to open.
keychain

On return, a pointer to the keychain object. The memory that this pointer occupies must be released by calling the CFRelease function when finished with it.
Return Value

A result code. See “Keychain Services Result Codes”.
Discussion

You may use this function to retrieve a pointer to a keychain object given the path of the keychain. You do not need to close the keychain, but you should release the memory that the pointer occupies when you are finished with it.
Availability
Available in Mac OS X v10.2 and later.
Declared In
SecKeychain.h*/
OSStatus SecKeychainOpen (
   const char *pathName,
   SecKeychainRef *keychain
){
printf ("SecKeychainOpen",*pathName,*keychain);
};

/*SecKeychainCopyDomainDefault

Retrieves the default keychain from a specified preference domain.

OSStatus SecKeychainCopyDomainDefault (
   SecPreferencesDomain domain,
   SecKeychainRef *keychain
);
Parameters
domain

The preference domain from which you wish to retrieve the default keychain. See “Keychain Preference Domain Constants” for possible domain values.
keychain

On return, a pointer to the keychain object of the default keychain in the specified preference domain.
Return Value

A result code. See “Keychain Services Result Codes.”
Discussion

A preference domain is a set of security-related preferences, such as the default keychain and the current keychain search list. Use this function if you want to retrieve the default keychain for a specific preference domain. Use the SecKeychainCopyDefault function if you want the default keychain for the current preference domain. See the SecKeychainSetPreferenceDomain function for a discussion of current and default preference domains.
Availability
Available in Mac OS X v10.3 and later.
Declared In
SecKeychain.h*/
OSStatus SecKeychainCopyDomainDefault (
   SecPreferencesDomain domain,
   SecKeychainRef *keychain
){};

/*SecKeychainGetPreferenceDomain

Gets the current keychain preference domain.

OSStatus SecKeychainGetPreferenceDomain (
   SecPreferencesDomain *domain
);
Parameters
domain

On return, a pointer to the keychain preference domain. See “Keychain Preference Domain Constants” for possible domain values.
Return Value

A result code. See “Keychain Services Result Codes.”
Discussion

A preference domain is a set of security-related preferences, such as the default keychain and the current keychain search list. The default preference domain for system daemons (that is, for daemons running in the root session) is the system domain. The default preference domain for all other programs is the user domain. Use the SecKeychainSetPreferenceDomain function to change the preference domain.
Availability
Available in Mac OS X v10.3 and later.
Declared In
SecKeychain.h*/
OSStatus SecKeychainGetPreferenceDomain (
   SecPreferencesDomain *domain
){};

/*SecKeychainSetDomainDefault

Sets the default keychain for a specified preference domain.

OSStatus SecKeychainSetDomainDefault (
   SecPreferencesDomain domain,
   SecKeychainRef keychain
);

Parameters
domain

The preference domain for which you wish to set the default keychain. See “Keychain Preference Domain Constants” for possible domain values.
keychain

A reference to the keychain you wish to set as default in the specified preference domain.
Return Value

A result code. See “Keychain Services Result Codes.”
Discussion

A preference domain is a set of security-related preferences, such as the default keychain and the current keychain search list. Use this function if you want to set the default keychain for a specific preference domain. Use the SecKeychainSetDefault function if you want to set the default keychain for the current preference domain. See the SecKeychainSetPreferenceDomain function for a discussion of current and default preference domains.
Availability
Available in Mac OS X v10.3 and later.
Declared In
SecKeychain.h*/
OSStatus SecKeychainSetDomainDefault (
   SecPreferencesDomain domain,
   SecKeychainRef keychain
){};

/*SecKeychainSetPreferenceDomain

Sets the keychain preference domain.

OSStatus SecKeychainSetPreferenceDomain (
   SecPreferencesDomain domain
);

Parameters
domain

The keychain preference domain to set. See “Keychain Preference Domain Constants” for possible domain values.
Return Value

A result code. See “Keychain Services Result Codes.”
Discussion

A preference domain is a set of security-related preferences, such as the default keychain and the current keychain search list. The default preference domain for system daemons (that is, for daemons running in the root session) is the system domain. The default preference domain for all other programs is the user domain.

This function changes the preference domain for all subsequent function calls; for example, if you change from the system domain to the user domain and then call SecKeychainLock specifying NULL for the keychain, the function locks the default system keychain rather than the default user keychain. You might want to use this function, for example, when launching a system daemon from a user session so that the daemon uses system preferences rather than user preferences.
Availability
Available in Mac OS X v10.3 and later.
Declared In
SecKeychain.h*/
OSStatus SecKeychainSetPreferenceDomain (
   SecPreferencesDomain domain
){};
