#include <mach/thread_act.h>
#include <stdio.h>

/*thread_get_state

Function - Return the execution state for a thread. 
SYNOPSIS
kern_return_t   thread_get_state
                (thread_act_t                     target_thread,
                 thread_state_flavor_t                   flavor,
                 thread_state_t                       old_state,
                 mach_msg_type_number_t         old_state_count);
PARAMETERS

target_thread 
[in thread send right] The thread for which the execution state is to be returned. The calling thread cannot specify itself. 

flavor 
[in scalar] The type of execution state to be returned. Valid values correspond to supported machined architectures. 

old_state 
[out structure] State information for the specified thread. 

old_state_count 
[in/out scalar] On input, the maximum size of the buffer; on output, the size returned (in natural-sized units). 
DESCRIPTION

The thread_get_state function returns the execution state (for example, the machine registers) for target_thread. flavor specifies the type of state information returned. 

The format of the data returned is machine specific; it is defined in \*L\*O. 
RETURN VALUES

Only generic errors apply. 
RELATED INFORMATION

Functions: task_info, thread_info, thread_set_state.*/
kern_return_t   thread_get_state
                (thread_act_t                     target_thread,
                 thread_state_flavor_t                   flavor,
                 thread_state_t                       old_state,
                 mach_msg_type_number_t         old_state_count){
printf ("thread_get_state",target_thread,flavor,old_state,old_state_count);
};


/*Thread Affinity API

An affinity set is a collection of threads which share memory resources and wish to share an L2 cache. Distinct affinity sets represent separate affinities—that is, threads belonging to a different set should use a separate L2 cache and hence be run on a different logical processors.

An affinity set is identified by a "tag". Threads are assigned to a particular affinity set by assigning it the tag identifying that set. A thread can belong to at most one affinity set; that is, it has one affinity tag. The default, null, tag represents no affinity.

Each task has a distinct universe of affinity sets and thus a private namespace of tags; a tag value in one task does not identify the same affinity set in another task.

The Mach thread policy calls are defined in header /usr/include/mach/thread_policy.h and in /System/Library/Frameworks/System.framework/PrivateHeaders/mach/thread_policy.h as follows:kern_return_t  thread_policy_set(
                        thread_t                thread,
                        thread_policy_flavor_t  flavor,
                        thread_policy_t         policy_info,
                        mach_msg_type_number_t  count);
kern_return_t  thread_policy_get(
                        thread_t                thread,
                        thread_policy_flavor_t  flavor,
                        thread_policy_t         policy_info,
                        mach_msg_type_number_t  *count);
                        boolean_t               *get_default);


These calls have been extended by adding a new flavor of thread policy:#define THREAD_AFFINITY_POLICY         4

struct thread_affinity_policy {
        integer_t       affinity_tag;
};
typedef struct thread_affinity_policy   thread_affinity_policy_data_t;
typedef struct thread_affinity_policy   *thread_affinity_policy_t;

#define THREAD_AFFINITY_POLICY_COUNT    ((mach_msg_type_number_t) \
                (sizeof (thread_affinity_policy_data_t) / sizeof (integer_t)))

#define THREAD_AFFINITY_TAG_NULL        0


By setting a (non-null) affinity tag for a thread, the thread is placed into the affinity set identified by the "tag". By default, all threads have the THREAD_AFFINITY_NULL affinity. A non-null tag is arbitrary and can convey application-specific information.

The thread_policy_set(THREAD_AFFINITY_POLICY) call can be made after creating a thread but before starting it running in order to influence its initial placement.

For example, an application wanting to run 2 threads on separate L2 caches would set the threads with different affinity tags. On a dual core machine, this affinity will effectively be ignored. However, on a 4-core MacPro, the scheduler will try to run threads on separate packages. Similarly, on an 8-core MacPro, the scheduler will try to run these threads on separate dies (which may or may not be in the same physical CPU package).

An application with a producer and a consumer thread that should share an L2 cache would perform the following steps:
Create both threads.
Set the same affinity tag for each thread.
Start both threads.

An application that wants to place a thread on every available processor would do the following:
Obtain the number of processors on the system using sysctl(3) (see below).
Create that number of threads.
Set each thread with a distinct affinity tag.
Start all threads.

Threads with default affinity policy will be scheduled more freely on any processor. These threads will be preferentially migrated to run on an idle processor. Threads with affinity tags will tend to remain in place.

Generally, the affinity tag namespace is private to one task (process). However, a child process forked after its parent has made a THREAD_AFFINITY_POLICY call will share the affinity namespace of the parent process. This enables a family of forked processes to share an affinity namespace despite comprising separate tasks. Moreover, the forked child inherits the affinity tag of its parent. Hence, a parent can seed a number of child processes within an arbitrary organization of shared affinity sets. Note: affinity namespace inheritance is destroyed by the exec(3) system call, however.

In addition, the header /usr/include/mach/task_info.h includes the following new information request:struct task_affinity_tag_info {         integer_t        count;
        integer_t        min;
        integer_t        max;
        integer_t        task_count;
};
typedef struct task_affinity_tag_info   task_affinity_tag_info_data_t;
typedef struct task_affinity_tag_info   *task_affinity_tag_info_t;
#define TASK_AFFINITY_TAG_INFO          16
#define TASK_AFFINITY_TAG_INFO_COUNT    \
                (sizeof(task_affinity_tag_info_data_t) / sizeof(natural_t))


This enables you to obtain the number (count) and range [min .. max] of the affinity tags currently defined for a task.*/
kern_return_t  thread_policy_set(
                        thread_t                thread,
                        thread_policy_flavor_t  flavor,
                        thread_policy_t         policy_info,
                        mach_msg_type_number_t  count){};
