#include <stdio.h>
#include <string.h>
#include <sys/types.h>

#ifndef native_bzero
void	 bzero(void *a, size_t b){};//c
#endif

////////////////////
/*FFS(3)                   BSD Library Functions Manual                   FFS(3)

NAME
     ffs, ffsl, fls, flsl -- find first or last bit set in a bit string

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <strings.h>

     int
     ffs(int i);

     int
     ffsl(long i);

     int
     fls(int i);

     int
     flsl(long i);

DESCRIPTION
     The ffs() and ffsl() functions find the first bit set in i and return the
     index of that bit.

     The fls() and flsl() functions find the last bit set in i and return the
     index of that bit.

     Bits are numbered starting from 1, starting at the right-most (least sig-nificant) significant)
     nificant) bit.  A return value of zero from any of these functions means
     that the argument was zero.

SEE ALSO
     bitstring(3)

HISTORY
     The ffs() function appeared in 4.3BSD.  Its prototype existed previously
     in <string.h> before it was moved to <strings.h> for IEEE Std 1003.1-2001
     (``POSIX.1'') compliance.

     The ffsl(), fls(), and flsl() functions appeared in FreeBSD 5.3.

BSD                            January 13, 2004                            BSD*/
     int   flsl(long i){};

/*STRLCPY(3)               BSD Library Functions Manual               STRLCPY(3)

NAME
     strlcpy, strlcat -- size-bounded string copying and concatenation

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <string.h>

     size_t
     strlcpy(char *dst, const char *src, size_t size);

     size_t
     strlcat(char *dst, const char *src, size_t size);

DESCRIPTION
     The strlcpy() and strlcat() functions copy and concatenate strings
     respectively.  They are designed to be safer, more consistent, and less
     error prone replacements for strncpy(3) and strncat(3).  Unlike those
     functions, strlcpy() and strlcat() take the full size of the buffer (not
     just the length) and guarantee to NUL-terminate the result (as long as
     size is larger than 0 or, in the case of strlcat(), as long as there is
     at least one byte free in dst).  Note that you should include a byte for
     the NUL in size.  Also note that strlcpy() and strlcat() only operate on
     true ``C'' strings.  This means that for strlcpy() src must be NUL-termi-nated NUL-terminated
     nated and for strlcat() both src and dst must be NUL-terminated.

     The strlcpy() function copies up to size - 1 characters from the NUL-ter-minated NUL-terminated
     minated string src to dst, NUL-terminating the result.

     The strlcat() function appends the NUL-terminated string src to the end
     of dst.  It will append at most size - strlen(dst) - 1 bytes, NUL-termi-nating NUL-terminating
     nating the result.

RETURN VALUES
     The strlcpy() and strlcat() functions return the total length of the
     string they tried to create.  For strlcpy() that means the length of src.
     For strlcat() that means the initial length of dst plus the length of
     src.  While this may seem somewhat confusing it was done to make trunca-tion truncation
     tion detection simple.

     Note however, that if strlcat() traverses size characters without finding
     a NUL, the length of the string is considered to be size and the destina-tion destination
     tion string will not be NUL-terminated (since there was no space for the
     NUL).  This keeps strlcat() from running off the end of a string.  In
     practice this should not happen (as it means that either size is incor-rect incorrect
     rect or that dst is not a proper ``C'' string).  The check exists to pre-vent prevent
     vent potential security problems in incorrect code.

EXAMPLES
     The following code fragment illustrates the simple case:

           char *s, *p, buf[BUFSIZ];

           ...

           (void)strlcpy(buf, s, sizeof(buf));
           (void)strlcat(buf, p, sizeof(buf));

     To detect truncation, perhaps while building a pathname, something like
     the following might be used:

           char *dir, *file, pname[MAXPATHLEN];

           ...

           if (strlcpy(pname, dir, sizeof(pname)) >= sizeof(pname))
                   goto toolong;
           if (strlcat(pname, file, sizeof(pname)) >= sizeof(pname))
                   goto toolong;

     Since we know how many characters we copied the first time, we can speed
     things up a bit by using a copy instead of an append:

           char *dir, *file, pname[MAXPATHLEN];
           size_t n;

           ...

           n = strlcpy(pname, dir, sizeof(pname));
           if (n >= sizeof(pname))
                   goto toolong;
           if (strlcpy(pname + n, file, sizeof(pname) - n) >= sizeof(pname) - n)
                   goto toolong;

     However, one may question the validity of such optimizations, as they
     defeat the whole purpose of strlcpy() and strlcat().  As a matter of
     fact, the first version of this manual page got it wrong.

SEE ALSO
     snprintf(3), strncat(3), strncpy(3)

HISTORY
     The strlcpy() and strlcat() functions first appeared in OpenBSD 2.4, and
     made their appearance in FreeBSD 3.3.

BSD                              June 22, 1998                             BSD*/

     size_t
     strlcpy(char *dst, const char *src, size_t size){};

     size_t
     strlcat(char *dst, const char *src, size_t size){};


/*STRMODE(3)               BSD Library Functions Manual               STRMODE(3)

NAME
     strmode -- convert inode status information into a symbolic string

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <string.h>

     void
     strmode(int mode, char *bp);

DESCRIPTION
     The strmode() function converts a file mode (the type and permission information associated with an
     inode, see stat(2)) into a symbolic string which is stored in the location referenced by bp.  This
     stored string is eleven characters in length plus a trailing NUL.

     The first character is the inode type, and will be one of the following:

           -     regular file
           b     block special
           c     character special
           d     directory
           l     symbolic link
           p     fifo
           s     socket
           w     whiteout
           ?     unknown inode type

     The next nine characters encode three sets of permissions, in three characters each.  The first three
     characters are the permissions for the owner of the file, the second three for the group the file
     belongs to, and the third for the ``other'', or default, set of users.

     Permission checking is done as specifically as possible.  If read permission is denied to the owner of
     a file in the first set of permissions, the owner of the file will not be able to read the file.  This
     is true even if the owner is in the file's group and the group permissions allow reading or the
     ``other'' permissions allow reading.

     If the first character of the three character set is an ``r'', the file is readable for that set of
     users; if a dash ``-'', it is not readable.

     If the second character of the three character set is a ``w'', the file is writable for that set of
     users; if a dash ``-'', it is not writable.

     The third character is the first of the following characters that apply:

     S     If the character is part of the owner permissions and the file is not executable or the directory
           is not searchable by the owner, and the set-user-id bit is set.

     S     If the character is part of the group permissions and the file is not executable or the directory
           is not searchable by the group, and the set-group-id bit is set.

     T     If the character is part of the other permissions and the file is not executable or the directory
           is not searchable by others, and the ``sticky'' (S_ISVTX) bit is set.

     s     If the character is part of the owner permissions and the file is executable or the directory
           searchable by the owner, and the set-user-id bit is set.

     s     If the character is part of the group permissions and the file is executable or the directory
           searchable by the group, and the set-group-id bit is set.

     t     If the character is part of the other permissions and the file is executable or the directory
           searchable by others, and the ``sticky'' (S_ISVTX) bit is set.

     x     The file is executable or the directory is searchable.

     -     None of the above apply.

     The last character is a plus sign ``+'' if any there are any alternate or additional access control
     methods associated with the inode, otherwise it will be a space.

SEE ALSO
     chmod(1), find(1), stat(2), getmode(3), setmode(3)

HISTORY
     The strmode() function first appeared in 4.4BSD.

BSD                              July 28, 1994                             BSD*/
     void strmode(int mode, char *bp){};


/*STRSTR(3)                BSD Library Functions Manual                STRSTR(3)

NAME
     strcasestr, strcasestr_l, strnstr, strstr -- locate a substring in a string

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <string.h>

     char *
     strcasestr(const char *s1, const char *s2);

     char *
     strnstr(const char *s1, const char *s2, size_t n);

     char *
     strstr(const char *s1, const char *s2);

     #include <string.h>
     #include <xlocale.h>

     char *
     strcasestr_l(const char *s1, const char *s2, locale_t loc);

DESCRIPTION
     The strstr() function locates the first occurrence of the null-terminated string s2 in the null-termi-nated null-terminated
     nated string s1.

     The strcasestr() function is similar to strstr(), but ignores the case of both strings.

     The strnstr() function locates the first occurrence of the null-terminated string s2 in the string s1,
     where not more than n characters are searched.  Characters that appear after a `\0' character are not
     searched.  Since the strnstr() function is a FreeBSD specific API, it should only be used when porta-bility portability
     bility is not a concern.

     While the strcasestr() function uses the current locale, the strcasestr_l() function may be passed a
     locale directly. See xlocale(3) for more information.

RETURN VALUES
     If s2 is an empty string, s1 is returned; if s2 occurs nowhere in s1, NULL is returned; otherwise a
     pointer to the first character of the first occurrence of s2 is returned.

EXAMPLES
     The following sets the pointer ptr to the "Bar Baz" portion of largestring:

           const char *largestring = "Foo Bar Baz";
           const char *smallstring = "Bar";
           char *ptr;

           ptr = strstr(largestring, smallstring);

     The following sets the pointer ptr to NULL, because only the first 4 characters of largestring are
     searched:

           const char *largestring = "Foo Bar Baz";
           const char *smallstring = "Bar";
           char *ptr;

           ptr = strnstr(largestring, smallstring, 4);

SEE ALSO
     memchr(3), strchr(3), strcspn(3), strpbrk(3), strrchr(3), strsep(3), strspn(3), strtok(3), xlocale(3)

STANDARDS
     The strstr() function conforms to ISO/IEC 9899:1990 (``ISO C90'').

BSD                            October 11, 2001                            BSD*/

     char *  strnstr(const char *s1, const char *s2, size_t n){};

/*STRDUP(3)                BSD Library Functions Manual                STRDUP(3)

NAME
     strdup -- save a copy of a string

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <string.h>

     char *
     strdup(const char *s1);

DESCRIPTION
     The strdup() function allocates sufficient memory for a copy of the string s1, does the copy, and
     returns a pointer to it.  The pointer may subsequently be used as an argument to the function free(3).

     If insufficient memory is available, NULL is returned and errno is set to ENOMEM.

SEE ALSO
     free(3), malloc(3)

HISTORY
     The strdup() function first appeared in 4.4BSD.

BSD                              June 9, 1993                              BSD*/
#ifndef native_strdup
     char * strdup(const char *s1){};
#endif

/*BCMP(3)                  BSD Library Functions Manual                  BCMP(3)

NAME
     bcmp -- compare byte string

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <strings.h>

     int
     bcmp(const void *s1, const void *s2, size_t n);

DESCRIPTION
     The bcmp() function compares byte string s1 against byte string s2, returning zero if they are identi-cal, identical,
     cal, non-zero otherwise.  Both strings are assumed to be n bytes long.  Zero-length strings are always
     identical.

     The strings may overlap.

SEE ALSO
     memcmp(3), strcasecmp(3), strcmp(3), strcoll(3), strxfrm(3)

HISTORY
     A bcmp() function first appeared in 4.2BSD.  Its prototype existed previously in <string.h> before it
     was moved to <strings.h> for IEEE Std 1003.1-2001 (``POSIX.1'') compliance.

BSD                              June 4, 1993                              BSD*/
#ifndef native_bcmp
     int bcmp(const void *s1, const void *s2, size_t n){};
#endif

/*BCOPY(3)                 BSD Library Functions Manual                 BCOPY(3)

NAME
     bcopy -- copy byte string

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <strings.h>

     void
     bcopy(const void *s1, void *s2, size_t n);

DESCRIPTION
     The bcopy() function copies n bytes from string s1 to string s2.  The two strings may overlap.  If n is
     zero, no bytes are copied.

SEE ALSO
     memccpy(3), memcpy(3), memmove(3), strcpy(3), strncpy(3)

HISTORY
     A bcopy() function appeared in 4.2BSD.  Its prototype existed previously in <string.h> before it was
     moved to <strings.h> for IEEE Std 1003.1-2001 (``POSIX.1'') compliance.

BSD                              June 4, 1993                              BSD*/

#ifndef native_bcopy
     void  bcopy(const void *s1, void *s2, size_t n){};
#endif
