#include <stdio.h>
#include <unistd.h>


/*ISSETUGID(2)                BSD System Calls Manual               ISSETUGID(2)

NAME
     issetugid -- is current process tainted by uid or gid changes

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <unistd.h>

     int
     issetugid(void);

DESCRIPTION
     The issetugid() system call returns 1 if the process environment or mem-ory memory
     ory address space is considered ``tainted'', and returns 0 otherwise.

     A process is tainted if it was created as a result of an execve(2) system
     call which had either of the setuid or setgid bits set (and extra privi-leges privileges
     leges were given as a result) or if it has changed any of its real,
     effective or saved user or group ID's since it began execution.

     This system call exists so that library routines (eg: libc, libtermcap)
     can reliably determine if it is safe to use information that was obtained
     from the user, in particular the results from getenv(3) should be viewed
     with suspicion if it is used to control operation.

     A ``tainted'' status is inherited by child processes as a result of the
     fork(2) system call (or other library code that calls fork, such as
     popen(3)).

     It is assumed that a program that clears all privileges as it prepares to
     execute another will also reset the environment, hence the ``tainted''
     status will not be passed on.  This is important for programs such as
     su(1) which begin setuid but need to be able to create an untainted
     process.

ERRORS
     The issetugid() system call is always successful, and no return value is
     reserved to indicate an error.

SEE ALSO
     execve(2), fork(2), setegid(2), seteuid(2), setgid(2), setregid(2),
     setreuid(2), setuid(2)

HISTORY
     The issetugid() system call first appeared in OpenBSD 2.0 and was also
     implemented in FreeBSD 3.0.

BSD                             August 25, 1996                            BSD(*/
     int  issetugid(void){};

/*GETOPT(3)                BSD Library Functions Manual                GETOPT(3)

NAME
     getopt -- get option character from command line argument list

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <unistd.h>

     extern char *optarg;
     extern int optind;
     extern int optopt;
     extern int opterr;
     extern int optreset;

     int
     getopt(int argc, char * const argv[], const char *optstring);

DESCRIPTION
     The getopt() function incrementally parses a command line argument list argv and returns the next known
     option character.  An option character is known if it has been specified in the string of accepted
     option characters, optstring.

     The option string optstring may contain the following elements: individual characters, and characters
     followed by a colon to indicate an option argument is to follow.  For example, an option string "x"
     recognizes an option ``-x'', and an option string "x:" recognizes an option and argument ``-x
     argument''.  It does not matter to getopt() if a following argument has leading white space.

     On return from getopt(), optarg points to an option argument, if it is anticipated, and the variable
     optind contains the index to the next argv argument for a subsequent call to getopt().  The variable
     optopt saves the last known option character returned by getopt().

     The variables opterr and optind are both initialized to 1.  The optind variable may be set to another
     value before a set of calls to getopt() in order to skip over more or less argv entries.

     In order to use getopt() to evaluate multiple sets of arguments, or to evaluate a single set of argu-ments arguments
     ments multiple times, the variable optreset must be set to 1 before the second and each additional set
     of calls to getopt(), and the variable optind must be reinitialized.

     The getopt() function returns -1 when the argument list is exhausted.  The interpretation of options in
     the argument list may be cancelled by the option `--' (double dash) which causes getopt() to signal the
     end of argument processing and return -1.  When all options have been processed (i.e., up to the first
     non-option argument), getopt() returns -1.

RETURN VALUES
     The getopt() function returns the next known option character in optstring.  If getopt() encounters a
     character not found in optstring or if it detects a missing option argument, it returns `?' (question
     mark).  If optstring has a leading `:' then a missing option argument causes `:' to be returned instead
     of `?'.  In either case, the variable optopt is set to the character that caused the error.  The
     getopt() function returns -1 when the argument list is exhausted.

EXAMPLES
     #include <unistd.h>
     int bflag, ch, fd;

     bflag = 0;
     while ((ch = getopt(argc, argv, "bf:")) != -1) {
             switch (ch) {
             case 'b':
                     bflag = 1;
                     break;
             case 'f':
                     if ((fd = open(optarg, O_RDONLY, 0)) < 0) {
                             (void)fprintf(stderr,
                                 "myname: %s: %s\n", optarg, strerror(errno));
                             exit(1);
                     }
                     break;
             case '?':
             default:
                     usage();
             }
     }
     argc -= optind;
     argv += optind;

DIAGNOSTICS
     If the getopt() function encounters a character not found in the string optstring or detects a missing
     option argument it writes an error message to the stderr and returns `?'.  Setting opterr to a zero
     will disable these error messages.  If optstring has a leading `:' then a missing option argument
     causes a `:' to be returned in addition to suppressing any error messages.

     Option arguments are allowed to begin with ``-''; this is reasonable but reduces the amount of error
     checking possible.

SEE ALSO
     getopt(1), getopt_long(3), getsubopt(3)

STANDARDS
     The optreset variable was added to make it possible to call the getopt() function multiple times.  This
     is an extension to the IEEE Std 1003.2 (``POSIX.2'') specification.

HISTORY
     The getopt() function appeared in 4.3BSD.

BUGS
     The getopt() function was once specified to return EOF instead of -1.  This was changed by IEEE Std
     1003.2-1992 (``POSIX.2'') to decouple getopt() from <stdio.h>.

     A single dash ``-'' may be specified as a character in optstring, however it should never have an argu-ment argument
     ment associated with it.  This allows getopt() to be used with programs that expect ``-'' as an option
     flag.  This practice is wrong, and should not be used in any current development.  It is provided for
     backward compatibility only.  Care should be taken not to use `-' as the first character in optstring
     to avoid a semantic conflict with GNU getopt(), which assigns different meaning to an optstring that
     begins with a `-'.  By default, a single dash causes getopt() to return -1.

     It is also possible to handle digits as option letters.  This allows getopt() to be used with programs
     that expect a number (``-3'') as an option.  This practice is wrong, and should not be used in any cur-rent current
     rent development.  It is provided for backward compatibility only.  The following code fragment works
     in most cases.

           int ch;
           long length;
           char *p, *ep;

           while ((ch = getopt(argc, argv, "0123456789")) != -1)
                   switch (ch) {
                   case '0': case '1': case '2': case '3': case '4':
                   case '5': case '6': case '7': case '8': case '9':
                           p = argv[optind - 1];
                           if (p[0] == '-' && p[1] == ch && !p[2]) {
                                   length = ch - '0';
                                   ep = "";
                           } else if (argv[optind] && argv[optind][1] == ch) {
                                   length = strtol((p = argv[optind] + 1),
                                       &ep, 10);
                                   optind++;
                                   optreset = 1;
                           } else
                                   usage();
                           if (*ep != '\0')
                                   errx(EX_USAGE, "illegal number -- %s", p);
                           break;
                   }

BSD                             April 27, 1995                             BSD*/
#ifndef native_optreset
 int optreset;
#endif

/*GETPID(2)                   BSD System Calls Manual                  GETPID(2)

NAME
     getpid, getppid -- get parent or calling process identification

SYNOPSIS
     #include <unistd.h>

     pid_t
     getpid(void);

     pid_t
     getppid(void);

DESCRIPTION
     Getpid() returns the process ID of the calling process.  The ID is guaranteed to be unique and is use-ful useful
     ful for constructing temporary file names.

     Getppid() returns the process ID of the parent of the calling process.

ERRORS
     The getpid() and getppid() functions are always successful, and no return value is reserved to indicate
     an error.

LEGACY SYNOPSIS
     #include <sys/types.h>
     #include <unistd.h>

     The include file <sys/types.h> is necessary.

SEE ALSO
     gethostid(2), compat(5)

STANDARDS
     Getpid() and getppid() conform to IEEE Std 1003.1-1988 (``POSIX.1'').

4th Berkeley Distribution        June 4, 1993        4th Berkeley Distribution*/
#ifndef native_getpid
     pid_t  getpid(void){};
#endif

/*GETHOSTNAME(3)           BSD Library Functions Manual           GETHOSTNAME(3)

NAME
     gethostname, sethostname -- get/set name of current host

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <unistd.h>

     int
     gethostname(char *name, size_t namelen);

     int
     sethostname(const char *name, int namelen);

DESCRIPTION
     The gethostname() function returns the standard host name for the current processor, as previously set
     by sethostname().  The namelen argument specifies the size of the name array.  The returned name is
     null-terminated, unless insufficient space is provided.

     The sethostname() function sets the name of the host machine to be name, which has length namelen.
     This call is restricted to the super-user and is normally used only when the system is bootstrapped.

     Host names are limited to {HOST_NAME_MAX} characters, not including the trailing null, currently 255.

RETURN VALUES
     Upon successful completion, the value 0 is returned; otherwise the value -1 is returned and the global
     variable errno is set to indicate the error.

ERRORS
     The following errors may be returned by these calls:

     [EFAULT]           The name or namelen argument gave an invalid address.

     [ENAMETOOLONG]     The current host name is longer than namelen.  (For gethostname() only.)

     [EPERM]            The caller tried to set the host name and was not the super-user.

SEE ALSO
     sysconf(3), sysctl(3)

STANDARDS
     The gethostname() function conforms to IEEE Std 1003.1-2001 (``POSIX.1'').  Callers should be aware
     that {HOST_NAME_MAX} may be variable or infinite, but is guaranteed to be no less than
     {_POSIX_HOST_NAME_MAX}.  On older systems, this limit was defined in the non-standard header
     <sys/param.h> as MAXHOSTNAMELEN, and counted the terminating null.  The sethostname() function and the
     error returns for gethostname() are not standardized.

HISTORY
     The gethostname() function appeared in 4.2BSD.  The namelen argument to gethostname() was changed to
     size_t in FreeBSD 5.2 for alignment with IEEE Std 1003.1-2001 (``POSIX.1'').

BSD                             August 18, 2003                            BSD*/
     int  gethostname(char *name, size_t namelen){};

/*READLINK(2)                 BSD System Calls Manual                READLINK(2)

NAME
     readlink -- read value of a symbolic link

SYNOPSIS
     #include <unistd.h>

     ssize_t
     readlink(const char *restrict path, char *restrict buf, size_t bufsize);

DESCRIPTION
     Readlink() places the contents of the symbolic link path in the buffer buf, which has size bufsize.
     Readlink does not append a NUL character to buf.

RETURN VALUES
     The call returns the count of characters placed in the buffer if it succeeds, or a -1 if an error
     occurs, placing the error code in the global variable errno.

ERRORS
     Readlink() will fail if:

     [EACCES]           Search permission is denied for a component of the path prefix.

     [EFAULT]           Buf extends outside the process's allocated address space.

     [EINVAL]           The named file is not a symbolic link.

     [EIO]              An I/O error occurred while reading from the file system.

     [ELOOP]            Too many symbolic links are encountered in translating the pathname.  This is taken
                        to be indicative of a looping symbolic link.

     [ENAMETOOLONG]     A component of a pathname exceeded {NAME_MAX} characters, or an entire path name
                        (possibly expanded by a symbolic link) exceeded {PATH_MAX} characters.

     [ENOENT]           The named file does not exist.

     [ENOTDIR]          A component of the path prefix is not a directory.

LEGACY SYNOPSIS
     #include <unistd.h>

     int
     readlink(const char *path, char *buf, int bufsize);

     The function type and the type of bufsize have changed.

SEE ALSO
     lstat(2), stat(2), symlink(2), compat(5), symlink(7)

HISTORY
     The readlink() function call appeared in 4.2BSD.

4.2 Berkeley Distribution        June 4, 1993        4.2 Berkeley Distribution*/
#ifndef native_readlink
     ssize_t readlink(const char * path, char * buf, size_t bufsize){};
#endif

/*FSYNC(2)                    BSD System Calls Manual                   FSYNC(2)

NAME
     fsync -- synchronize a file's in-core state with that on disk

SYNOPSIS
     #include <unistd.h>

     int
     fsync(int fildes);

DESCRIPTION
     Fsync() causes all modified data and attributes of fildes to be moved to a permanent storage device.
     This normally results in all in-core modified copies of buffers for the associated file to be written
     to a disk.

     Note that while fsync() will flush all data from the host to the drive (i.e. the "permanent storage
     device"), the drive itself may not physically write the data to the platters for quite some time and it
     may be written in an out-of-order sequence.

     Specifically, if the drive loses power or the OS crashes, the application may find that only some or
     none of their data was written.  The disk drive may also re-order the data so that later writes may be
     present, while earlier writes are not.

     This is not a theoretical edge case.  This scenario is easily reproduced with real world workloads and
     drive power failures.

     For applications that require tighter guarantees about the integrity of their data, Mac OS X provides
     the F_FULLFSYNC fcntl.  The F_FULLFSYNC fcntl asks the drive to flush all buffered data to permanent
     storage.  Applications, such as databases, that require a strict ordering of writes should use F_FULLF-SYNC F_FULLFSYNC
     SYNC to ensure that their data is written in the order they expect.  Please see fcntl(2) for more
     detail.

RETURN VALUES
     The fsync() function returns the value 0 if successful; otherwise the value -1 is returned and the
     global variable errno is set to indicate the error.

ERRORS
     The fsync() system call will fail if:

     [EBADF]            fildes is not a valid descriptor.

     [EINTR]            Its execution is interrupted by a signal.

     [EINVAL]           fildes refers to a file type (e.g., a socket) that does not support this operation.

     [EIO]              An I/O error occurred while reading from or writing to the file system.

     If a queued I/O operation fails, fsync() may fail with any of the errors defined for read(2) or
     write(2).

SEE ALSO
     fcntl(2), read(2), sync(2), write(2), sync(8), update(8)

HISTORY
     The fsync() function call appeared in 4.2BSD.

4.2 Berkeley Distribution        June 4, 1993        4.2 Berkeley Distribution*/
     int fsync(int fildes){};

/*MKTEMP(3)                BSD Library Functions Manual                MKTEMP(3)

NAME
     mkdtemp, mkstemp, mktemp, mktemps -- make temporary file name (unique)

LIBRARY
     Standard C Library (libc, -lc)

SYNOPSIS
     #include <unistd.h>

     char *
     mkdtemp(char *template);

     int
     mkstemps(char *template, int suffixlen);

     #include <stdlib.h>

     int
     mkstemp(char *template);

     char *
     mktemp(char *template);

DESCRIPTION
     The mktemp() function takes the given file name template and overwrites a portion of it to create a
     file name.  This file name is guaranteed not to exist at the time of function invocation and is suit-able suitable
     able for use by the application.  The template may be any file name with some number of `Xs' appended
     to it, for example /tmp/temp.XXXXXX.  The trailing `Xs' are replaced with a unique alphanumeric combi-nation. combination.
     nation.  The number of unique file names mktemp() can return depends on the number of `Xs' provided;
     six `Xs' will result in mktemp() selecting one of 56800235584 (62 ** 6) possible temporary file names.

     The mkstemp() function makes the same replacement to the template and creates the template file, mode
     0600, returning a file descriptor opened for reading and writing.  This avoids the race between testing
     for a file's existence and opening it for use.

     The mkstemps() function acts the same as mkstemp(), except it permits a suffix to exist in the tem-plate. template.
     plate.  The template should be of the form /tmp/tmpXXXXXXsuffix.  The mkstemps() function is told the
     length of the suffix string.

     The mkdtemp() function makes the same replacement to the template as in mktemp() and creates the tem-plate template
     plate directory, mode 0700.

RETURN VALUES
     The mktemp() and mkdtemp() functions return a pointer to the template on success and NULL on failure.
     The mkstemp() and mkstemps() functions return -1 if no suitable file could be created.  If either call
     fails an error code is placed in the global variable errno.

ERRORS
     The mkstemp(), mkstemps() and mkdtemp() functions may set errno to one of the following values:

     [ENOTDIR]          The pathname portion of the template is not an existing directory.

     The mkstemp(), mkstemps(), and mkdtemp() functions may also set errno to any value specified by the
     stat(2) function.

     The mkstemp() and mkstemps() functions may also set errno to any value specified by the open(2) func-tion. function.
     tion.

     The mkdtemp() function may also set errno to any value specified by the mkdir(2) function.

NOTES
     A common problem that results in a core dump is that the programmer passes in a read-only string to
     mktemp(), mkstemp(), mkstemps(), or mkdtemp().  This is common with programs that were developed before
     ISO/IEC 9899:1990 (``ISO C90'') compilers were common.  For example, calling mkstemp() with an argument
     of "/tmp/tempfile.XXXXXX" will result in a core dump due to mkstemp() attempting to modify the string
     constant that was given.  If the program in question makes heavy use of that type of function call, you
     do have the option of compiling the program so that it will store string constants in a writable seg-ment segment
     ment of memory.  See gcc(1) for more information.

BUGS
     This family of functions produces filenames which can be guessed, though the risk is minimized when
     large numbers of `Xs' are used to increase the number of possible temporary filenames.  This makes the
     race in mktemp(), between testing for a file's existence (in the mktemp() function call) and opening it
     for use (later in the user application) particularly dangerous from a security perspective.  Whenever
     it is possible, mkstemp() should be used instead, since it does not have the race condition.  If
     mkstemp() cannot be used, the filename created by mktemp() should be created using the O_EXCL flag to
     open(2) and the return status of the call should be tested for failure.  This will ensure that the pro-gram program
     gram does not continue blindly in the event that an attacker has already created the file with the
     intention of manipulating or reading its contents.

     The implementation of these functions calls arc4random(3), which is not reentrant.  You must provide
     your own locking around this and other consumers of the arc4random(3) API.

LEGACY SYNOPSIS
     #include <unistd.h>

     The include file <unistd.h> is necessary and sufficient for all functions.

SEE ALSO
     chmod(2), getpid(2), mkdir(2), open(2), stat(2), compat(5)

HISTORY
     A mktemp() function appeared in Version 7 AT&T UNIX.  The mkstemp() function appeared in 4.4BSD.  The
     mkdtemp() function first appeared in OpenBSD 2.2, and later in FreeBSD 3.2.  The mkstemps() function
     first appeared in OpenBSD 2.4, and later in FreeBSD 3.4.

BSD                            February 11, 1998                           BSD*/

#ifndef  native_mkstemp
     int   mkstemp(char *templatea){};
#endif